'use strict';

var types = require('@typescript-eslint/types');
var utils = require('@typescript-eslint/utils');
var tsPattern = require('ts-pattern');
var scopeManager = require('@typescript-eslint/scope-manager');
var ShortUniqueId = require('short-unique-id');
var valibot = require('valibot');

function _interopDefault (e) { return e && e.__esModule ? e : { default: e }; }

var ShortUniqueId__default = /*#__PURE__*/_interopDefault(ShortUniqueId);

var __defProp = Object.defineProperty;
var __export = (target, all9) => {
  for (var name in all9)
    __defProp(target, name, { get: all9[name], enumerable: true });
};

// ../../node_modules/.pnpm/eslint-visitor-keys@3.4.3/node_modules/eslint-visitor-keys/lib/visitor-keys.js
var KEYS = {
  ArrayExpression: [
    "elements"
  ],
  ArrayPattern: [
    "elements"
  ],
  ArrowFunctionExpression: [
    "params",
    "body"
  ],
  AssignmentExpression: [
    "left",
    "right"
  ],
  AssignmentPattern: [
    "left",
    "right"
  ],
  AwaitExpression: [
    "argument"
  ],
  BinaryExpression: [
    "left",
    "right"
  ],
  BlockStatement: [
    "body"
  ],
  BreakStatement: [
    "label"
  ],
  CallExpression: [
    "callee",
    "arguments"
  ],
  CatchClause: [
    "param",
    "body"
  ],
  ChainExpression: [
    "expression"
  ],
  ClassBody: [
    "body"
  ],
  ClassDeclaration: [
    "id",
    "superClass",
    "body"
  ],
  ClassExpression: [
    "id",
    "superClass",
    "body"
  ],
  ConditionalExpression: [
    "test",
    "consequent",
    "alternate"
  ],
  ContinueStatement: [
    "label"
  ],
  DebuggerStatement: [],
  DoWhileStatement: [
    "body",
    "test"
  ],
  EmptyStatement: [],
  ExperimentalRestProperty: [
    "argument"
  ],
  ExperimentalSpreadProperty: [
    "argument"
  ],
  ExportAllDeclaration: [
    "exported",
    "source"
  ],
  ExportDefaultDeclaration: [
    "declaration"
  ],
  ExportNamedDeclaration: [
    "declaration",
    "specifiers",
    "source"
  ],
  ExportSpecifier: [
    "exported",
    "local"
  ],
  ExpressionStatement: [
    "expression"
  ],
  ForInStatement: [
    "left",
    "right",
    "body"
  ],
  ForOfStatement: [
    "left",
    "right",
    "body"
  ],
  ForStatement: [
    "init",
    "test",
    "update",
    "body"
  ],
  FunctionDeclaration: [
    "id",
    "params",
    "body"
  ],
  FunctionExpression: [
    "id",
    "params",
    "body"
  ],
  Identifier: [],
  IfStatement: [
    "test",
    "consequent",
    "alternate"
  ],
  ImportDeclaration: [
    "specifiers",
    "source"
  ],
  ImportDefaultSpecifier: [
    "local"
  ],
  ImportExpression: [
    "source"
  ],
  ImportNamespaceSpecifier: [
    "local"
  ],
  ImportSpecifier: [
    "imported",
    "local"
  ],
  JSXAttribute: [
    "name",
    "value"
  ],
  JSXClosingElement: [
    "name"
  ],
  JSXClosingFragment: [],
  JSXElement: [
    "openingElement",
    "children",
    "closingElement"
  ],
  JSXEmptyExpression: [],
  JSXExpressionContainer: [
    "expression"
  ],
  JSXFragment: [
    "openingFragment",
    "children",
    "closingFragment"
  ],
  JSXIdentifier: [],
  JSXMemberExpression: [
    "object",
    "property"
  ],
  JSXNamespacedName: [
    "namespace",
    "name"
  ],
  JSXOpeningElement: [
    "name",
    "attributes"
  ],
  JSXOpeningFragment: [],
  JSXSpreadAttribute: [
    "argument"
  ],
  JSXSpreadChild: [
    "expression"
  ],
  JSXText: [],
  LabeledStatement: [
    "label",
    "body"
  ],
  Literal: [],
  LogicalExpression: [
    "left",
    "right"
  ],
  MemberExpression: [
    "object",
    "property"
  ],
  MetaProperty: [
    "meta",
    "property"
  ],
  MethodDefinition: [
    "key",
    "value"
  ],
  NewExpression: [
    "callee",
    "arguments"
  ],
  ObjectExpression: [
    "properties"
  ],
  ObjectPattern: [
    "properties"
  ],
  PrivateIdentifier: [],
  Program: [
    "body"
  ],
  Property: [
    "key",
    "value"
  ],
  PropertyDefinition: [
    "key",
    "value"
  ],
  RestElement: [
    "argument"
  ],
  ReturnStatement: [
    "argument"
  ],
  SequenceExpression: [
    "expressions"
  ],
  SpreadElement: [
    "argument"
  ],
  StaticBlock: [
    "body"
  ],
  Super: [],
  SwitchCase: [
    "test",
    "consequent"
  ],
  SwitchStatement: [
    "discriminant",
    "cases"
  ],
  TaggedTemplateExpression: [
    "tag",
    "quasi"
  ],
  TemplateElement: [],
  TemplateLiteral: [
    "quasis",
    "expressions"
  ],
  ThisExpression: [],
  ThrowStatement: [
    "argument"
  ],
  TryStatement: [
    "block",
    "handler",
    "finalizer"
  ],
  UnaryExpression: [
    "argument"
  ],
  UpdateExpression: [
    "argument"
  ],
  VariableDeclaration: [
    "declarations"
  ],
  VariableDeclarator: [
    "id",
    "init"
  ],
  WhileStatement: [
    "test",
    "body"
  ],
  WithStatement: [
    "object",
    "body"
  ],
  YieldExpression: [
    "argument"
  ]
};
var NODE_TYPES = Object.keys(KEYS);
for (const type of NODE_TYPES) {
  Object.freeze(KEYS[type]);
}
Object.freeze(KEYS);
var visitor_keys_default = KEYS;

// ../../node_modules/.pnpm/eslint-visitor-keys@3.4.3/node_modules/eslint-visitor-keys/lib/index.js
var KEY_BLACKLIST = /* @__PURE__ */ new Set([
  "parent",
  "leadingComments",
  "trailingComments"
]);
function filterKey(key) {
  return !KEY_BLACKLIST.has(key) && key[0] !== "_";
}
function getKeys(node) {
  return Object.keys(node).filter(filterKey);
}

// ../../node_modules/.pnpm/@eslint-community+eslint-utils@4.4.0_eslint@9.4.0/node_modules/@eslint-community/eslint-utils/index.mjs
function getInnermostScope(initialScope, node) {
  const location = node.range[0];
  let scope = initialScope;
  let found = false;
  do {
    found = false;
    for (const childScope of scope.childScopes) {
      const range2 = childScope.block.range;
      if (range2[0] <= location && location < range2[1]) {
        scope = childScope;
        found = true;
        break;
      }
    }
  } while (found);
  return scope;
}
function findVariable(initialScope, nameOrNode) {
  let name = "";
  let scope = initialScope;
  if (typeof nameOrNode === "string") {
    name = nameOrNode;
  } else {
    name = nameOrNode.name;
    scope = getInnermostScope(scope, nameOrNode);
  }
  while (scope != null) {
    const variable = scope.set.get(name);
    if (variable != null) {
      return variable;
    }
    scope = scope.upper;
  }
  return null;
}
function negate0(token) {
  return !this(token);
}
function negate(f3) {
  return negate0.bind(f3);
}
function isPunctuatorTokenWithValue(token, value) {
  return token.type === "Punctuator" && token.value === value;
}
function isArrowToken(token) {
  return isPunctuatorTokenWithValue(token, "=>");
}
function isCommaToken(token) {
  return isPunctuatorTokenWithValue(token, ",");
}
function isSemicolonToken(token) {
  return isPunctuatorTokenWithValue(token, ";");
}
function isColonToken(token) {
  return isPunctuatorTokenWithValue(token, ":");
}
function isOpeningParenToken(token) {
  return isPunctuatorTokenWithValue(token, "(");
}
function isClosingParenToken(token) {
  return isPunctuatorTokenWithValue(token, ")");
}
function isOpeningBracketToken(token) {
  return isPunctuatorTokenWithValue(token, "[");
}
function isClosingBracketToken(token) {
  return isPunctuatorTokenWithValue(token, "]");
}
function isOpeningBraceToken(token) {
  return isPunctuatorTokenWithValue(token, "{");
}
function isClosingBraceToken(token) {
  return isPunctuatorTokenWithValue(token, "}");
}
function isCommentToken(token) {
  return ["Block", "Line", "Shebang"].includes(token.type);
}
negate(isArrowToken);
negate(isCommaToken);
negate(isSemicolonToken);
negate(isColonToken);
negate(isOpeningParenToken);
negate(isClosingParenToken);
negate(isOpeningBracketToken);
negate(isClosingBracketToken);
negate(isOpeningBraceToken);
negate(isClosingBraceToken);
negate(isCommentToken);
function getOpeningParenOfParams(node, sourceCode) {
  return node.id ? sourceCode.getTokenAfter(node.id, isOpeningParenToken) : sourceCode.getFirstToken(node, isOpeningParenToken);
}
function getFunctionHeadLocation(node, sourceCode) {
  const parent = node.parent;
  let start = null;
  let end = null;
  if (node.type === "ArrowFunctionExpression") {
    const arrowToken = sourceCode.getTokenBefore(node.body, isArrowToken);
    start = arrowToken.loc.start;
    end = arrowToken.loc.end;
  } else if (parent.type === "Property" || parent.type === "MethodDefinition" || parent.type === "PropertyDefinition") {
    start = parent.loc.start;
    end = getOpeningParenOfParams(node, sourceCode).loc.start;
  } else {
    start = node.loc.start;
    end = getOpeningParenOfParams(node, sourceCode).loc.start;
  }
  return {
    start: { ...start },
    end: { ...end }
  };
}
var globalObject = typeof globalThis !== "undefined" ? globalThis : typeof self !== "undefined" ? self : typeof window !== "undefined" ? window : typeof global !== "undefined" ? global : {};
var builtinNames = Object.freeze(
  /* @__PURE__ */ new Set([
    "Array",
    "ArrayBuffer",
    "BigInt",
    "BigInt64Array",
    "BigUint64Array",
    "Boolean",
    "DataView",
    "Date",
    "decodeURI",
    "decodeURIComponent",
    "encodeURI",
    "encodeURIComponent",
    "escape",
    "Float32Array",
    "Float64Array",
    "Function",
    "Infinity",
    "Int16Array",
    "Int32Array",
    "Int8Array",
    "isFinite",
    "isNaN",
    "isPrototypeOf",
    "JSON",
    "Map",
    "Math",
    "NaN",
    "Number",
    "Object",
    "parseFloat",
    "parseInt",
    "Promise",
    "Proxy",
    "Reflect",
    "RegExp",
    "Set",
    "String",
    "Symbol",
    "Uint16Array",
    "Uint32Array",
    "Uint8Array",
    "Uint8ClampedArray",
    "undefined",
    "unescape",
    "WeakMap",
    "WeakSet"
  ])
);
var callAllowed = new Set(
  [
    Array.isArray,
    Array.of,
    Array.prototype.at,
    Array.prototype.concat,
    Array.prototype.entries,
    Array.prototype.every,
    Array.prototype.filter,
    Array.prototype.find,
    Array.prototype.findIndex,
    Array.prototype.flat,
    Array.prototype.includes,
    Array.prototype.indexOf,
    Array.prototype.join,
    Array.prototype.keys,
    Array.prototype.lastIndexOf,
    Array.prototype.slice,
    Array.prototype.some,
    Array.prototype.toString,
    Array.prototype.values,
    typeof BigInt === "function" ? BigInt : void 0,
    Boolean,
    Date,
    Date.parse,
    decodeURI,
    decodeURIComponent,
    encodeURI,
    encodeURIComponent,
    escape,
    isFinite,
    isNaN,
    isPrototypeOf,
    Map,
    Map.prototype.entries,
    Map.prototype.get,
    Map.prototype.has,
    Map.prototype.keys,
    Map.prototype.values,
    ...Object.getOwnPropertyNames(Math).filter((k3) => k3 !== "random").map((k3) => Math[k3]).filter((f3) => typeof f3 === "function"),
    Number,
    Number.isFinite,
    Number.isNaN,
    Number.parseFloat,
    Number.parseInt,
    Number.prototype.toExponential,
    Number.prototype.toFixed,
    Number.prototype.toPrecision,
    Number.prototype.toString,
    Object,
    Object.entries,
    Object.is,
    Object.isExtensible,
    Object.isFrozen,
    Object.isSealed,
    Object.keys,
    Object.values,
    parseFloat,
    parseInt,
    RegExp,
    Set,
    Set.prototype.entries,
    Set.prototype.has,
    Set.prototype.keys,
    Set.prototype.values,
    String,
    String.fromCharCode,
    String.fromCodePoint,
    String.raw,
    String.prototype.at,
    String.prototype.charAt,
    String.prototype.charCodeAt,
    String.prototype.codePointAt,
    String.prototype.concat,
    String.prototype.endsWith,
    String.prototype.includes,
    String.prototype.indexOf,
    String.prototype.lastIndexOf,
    String.prototype.normalize,
    String.prototype.padEnd,
    String.prototype.padStart,
    String.prototype.slice,
    String.prototype.startsWith,
    String.prototype.substr,
    String.prototype.substring,
    String.prototype.toLowerCase,
    String.prototype.toString,
    String.prototype.toUpperCase,
    String.prototype.trim,
    String.prototype.trimEnd,
    String.prototype.trimLeft,
    String.prototype.trimRight,
    String.prototype.trimStart,
    Symbol.for,
    Symbol.keyFor,
    unescape
  ].filter((f3) => typeof f3 === "function")
);
var callPassThrough = /* @__PURE__ */ new Set([
  Object.freeze,
  Object.preventExtensions,
  Object.seal
]);
var getterAllowed = [
  [Map, /* @__PURE__ */ new Set(["size"])],
  [
    RegExp,
    /* @__PURE__ */ new Set([
      "dotAll",
      "flags",
      "global",
      "hasIndices",
      "ignoreCase",
      "multiline",
      "source",
      "sticky",
      "unicode"
    ])
  ],
  [Set, /* @__PURE__ */ new Set(["size"])]
];
function getPropertyDescriptor(object2, name) {
  let x3 = object2;
  while ((typeof x3 === "object" || typeof x3 === "function") && x3 !== null) {
    const d3 = Object.getOwnPropertyDescriptor(x3, name);
    if (d3) {
      return d3;
    }
    x3 = Object.getPrototypeOf(x3);
  }
  return null;
}
function isGetter(object2, name) {
  const d3 = getPropertyDescriptor(object2, name);
  return d3 != null && d3.get != null;
}
function getElementValues(nodeList, initialScope) {
  const valueList = [];
  for (let i3 = 0; i3 < nodeList.length; ++i3) {
    const elementNode = nodeList[i3];
    if (elementNode == null) {
      valueList.length = i3 + 1;
    } else if (elementNode.type === "SpreadElement") {
      const argument = getStaticValueR(elementNode.argument, initialScope);
      if (argument == null) {
        return null;
      }
      valueList.push(...argument.value);
    } else {
      const element = getStaticValueR(elementNode, initialScope);
      if (element == null) {
        return null;
      }
      valueList.push(element.value);
    }
  }
  return valueList;
}
function isEffectivelyConst(variable) {
  const refs = variable.references;
  const inits = refs.filter((r3) => r3.init).length;
  const reads = refs.filter((r3) => r3.isReadOnly()).length;
  if (inits === 1 && reads + inits === refs.length) {
    return true;
  }
  return false;
}
var operations = Object.freeze({
  ArrayExpression(node, initialScope) {
    const elements = getElementValues(node.elements, initialScope);
    return elements != null ? { value: elements } : null;
  },
  AssignmentExpression(node, initialScope) {
    if (node.operator === "=") {
      return getStaticValueR(node.right, initialScope);
    }
    return null;
  },
  //eslint-disable-next-line complexity
  BinaryExpression(node, initialScope) {
    if (node.operator === "in" || node.operator === "instanceof") {
      return null;
    }
    const left7 = getStaticValueR(node.left, initialScope);
    const right7 = getStaticValueR(node.right, initialScope);
    if (left7 != null && right7 != null) {
      switch (node.operator) {
        case "==":
          return { value: left7.value == right7.value };
        case "!=":
          return { value: left7.value != right7.value };
        case "===":
          return { value: left7.value === right7.value };
        case "!==":
          return { value: left7.value !== right7.value };
        case "<":
          return { value: left7.value < right7.value };
        case "<=":
          return { value: left7.value <= right7.value };
        case ">":
          return { value: left7.value > right7.value };
        case ">=":
          return { value: left7.value >= right7.value };
        case "<<":
          return { value: left7.value << right7.value };
        case ">>":
          return { value: left7.value >> right7.value };
        case ">>>":
          return { value: left7.value >>> right7.value };
        case "+":
          return { value: left7.value + right7.value };
        case "-":
          return { value: left7.value - right7.value };
        case "*":
          return { value: left7.value * right7.value };
        case "/":
          return { value: left7.value / right7.value };
        case "%":
          return { value: left7.value % right7.value };
        case "**":
          return { value: left7.value ** right7.value };
        case "|":
          return { value: left7.value | right7.value };
        case "^":
          return { value: left7.value ^ right7.value };
        case "&":
          return { value: left7.value & right7.value };
      }
    }
    return null;
  },
  CallExpression(node, initialScope) {
    const calleeNode = node.callee;
    const args = getElementValues(node.arguments, initialScope);
    if (args != null) {
      if (calleeNode.type === "MemberExpression") {
        if (calleeNode.property.type === "PrivateIdentifier") {
          return null;
        }
        const object2 = getStaticValueR(calleeNode.object, initialScope);
        if (object2 != null) {
          if (object2.value == null && (object2.optional || node.optional)) {
            return { value: void 0, optional: true };
          }
          const property = getStaticPropertyNameValue(
            calleeNode,
            initialScope
          );
          if (property != null) {
            const receiver = object2.value;
            const methodName = property.value;
            if (callAllowed.has(receiver[methodName])) {
              return { value: receiver[methodName](...args) };
            }
            if (callPassThrough.has(receiver[methodName])) {
              return { value: args[0] };
            }
          }
        }
      } else {
        const callee = getStaticValueR(calleeNode, initialScope);
        if (callee != null) {
          if (callee.value == null && node.optional) {
            return { value: void 0, optional: true };
          }
          const func = callee.value;
          if (callAllowed.has(func)) {
            return { value: func(...args) };
          }
          if (callPassThrough.has(func)) {
            return { value: args[0] };
          }
        }
      }
    }
    return null;
  },
  ConditionalExpression(node, initialScope) {
    const test = getStaticValueR(node.test, initialScope);
    if (test != null) {
      return test.value ? getStaticValueR(node.consequent, initialScope) : getStaticValueR(node.alternate, initialScope);
    }
    return null;
  },
  ExpressionStatement(node, initialScope) {
    return getStaticValueR(node.expression, initialScope);
  },
  Identifier(node, initialScope) {
    if (initialScope != null) {
      const variable = findVariable(initialScope, node);
      if (variable != null && variable.defs.length === 0 && builtinNames.has(variable.name) && variable.name in globalObject) {
        return { value: globalObject[variable.name] };
      }
      if (variable != null && variable.defs.length === 1) {
        const def = variable.defs[0];
        if (def.parent && def.type === "Variable" && (def.parent.kind === "const" || isEffectivelyConst(variable)) && // TODO(mysticatea): don't support destructuring here.
        def.node.id.type === "Identifier") {
          return getStaticValueR(def.node.init, initialScope);
        }
      }
    }
    return null;
  },
  Literal(node) {
    if ((node.regex != null || node.bigint != null) && node.value == null) {
      return null;
    }
    return { value: node.value };
  },
  LogicalExpression(node, initialScope) {
    const left7 = getStaticValueR(node.left, initialScope);
    if (left7 != null) {
      if (node.operator === "||" && Boolean(left7.value) === true || node.operator === "&&" && Boolean(left7.value) === false || node.operator === "??" && left7.value != null) {
        return left7;
      }
      const right7 = getStaticValueR(node.right, initialScope);
      if (right7 != null) {
        return right7;
      }
    }
    return null;
  },
  MemberExpression(node, initialScope) {
    if (node.property.type === "PrivateIdentifier") {
      return null;
    }
    const object2 = getStaticValueR(node.object, initialScope);
    if (object2 != null) {
      if (object2.value == null && (object2.optional || node.optional)) {
        return { value: void 0, optional: true };
      }
      const property = getStaticPropertyNameValue(node, initialScope);
      if (property != null) {
        if (!isGetter(object2.value, property.value)) {
          return { value: object2.value[property.value] };
        }
        for (const [classFn, allowed] of getterAllowed) {
          if (object2.value instanceof classFn && allowed.has(property.value)) {
            return { value: object2.value[property.value] };
          }
        }
      }
    }
    return null;
  },
  ChainExpression(node, initialScope) {
    const expression = getStaticValueR(node.expression, initialScope);
    if (expression != null) {
      return { value: expression.value };
    }
    return null;
  },
  NewExpression(node, initialScope) {
    const callee = getStaticValueR(node.callee, initialScope);
    const args = getElementValues(node.arguments, initialScope);
    if (callee != null && args != null) {
      const Func = callee.value;
      if (callAllowed.has(Func)) {
        return { value: new Func(...args) };
      }
    }
    return null;
  },
  ObjectExpression(node, initialScope) {
    const object2 = {};
    for (const propertyNode of node.properties) {
      if (propertyNode.type === "Property") {
        if (propertyNode.kind !== "init") {
          return null;
        }
        const key = getStaticPropertyNameValue(
          propertyNode,
          initialScope
        );
        const value = getStaticValueR(propertyNode.value, initialScope);
        if (key == null || value == null) {
          return null;
        }
        object2[key.value] = value.value;
      } else if (propertyNode.type === "SpreadElement" || propertyNode.type === "ExperimentalSpreadProperty") {
        const argument = getStaticValueR(
          propertyNode.argument,
          initialScope
        );
        if (argument == null) {
          return null;
        }
        Object.assign(object2, argument.value);
      } else {
        return null;
      }
    }
    return { value: object2 };
  },
  SequenceExpression(node, initialScope) {
    const last2 = node.expressions[node.expressions.length - 1];
    return getStaticValueR(last2, initialScope);
  },
  TaggedTemplateExpression(node, initialScope) {
    const tag = getStaticValueR(node.tag, initialScope);
    const expressions = getElementValues(
      node.quasi.expressions,
      initialScope
    );
    if (tag != null && expressions != null) {
      const func = tag.value;
      const strings = node.quasi.quasis.map((q) => q.value.cooked);
      strings.raw = node.quasi.quasis.map((q) => q.value.raw);
      if (func === String.raw) {
        return { value: func(strings, ...expressions) };
      }
    }
    return null;
  },
  TemplateLiteral(node, initialScope) {
    const expressions = getElementValues(node.expressions, initialScope);
    if (expressions != null) {
      let value = node.quasis[0].value.cooked;
      for (let i3 = 0; i3 < expressions.length; ++i3) {
        value += expressions[i3];
        value += node.quasis[i3 + 1].value.cooked;
      }
      return { value };
    }
    return null;
  },
  UnaryExpression(node, initialScope) {
    if (node.operator === "delete") {
      return null;
    }
    if (node.operator === "void") {
      return { value: void 0 };
    }
    const arg = getStaticValueR(node.argument, initialScope);
    if (arg != null) {
      switch (node.operator) {
        case "-":
          return { value: -arg.value };
        case "+":
          return { value: +arg.value };
        case "!":
          return { value: !arg.value };
        case "~":
          return { value: ~arg.value };
        case "typeof":
          return { value: typeof arg.value };
      }
    }
    return null;
  }
});
function getStaticValueR(node, initialScope) {
  if (node != null && Object.hasOwnProperty.call(operations, node.type)) {
    return operations[node.type](node, initialScope);
  }
  return null;
}
function getStaticPropertyNameValue(node, initialScope) {
  const nameNode = node.type === "Property" ? node.key : node.property;
  if (node.computed) {
    return getStaticValueR(nameNode, initialScope);
  }
  if (nameNode.type === "Identifier") {
    return { value: nameNode.name };
  }
  if (nameNode.type === "Literal") {
    if (nameNode.bigint) {
      return { value: nameNode.bigint };
    }
    return { value: String(nameNode.value) };
  }
  return null;
}
function getStaticValue(node, initialScope = null) {
  try {
    return getStaticValueR(node, initialScope);
  } catch (_error) {
    return null;
  }
}
function getStringIfConstant(node, initialScope = null) {
  if (node && node.type === "Literal" && node.value === null) {
    if (node.regex) {
      return `/${node.regex.pattern}/${node.regex.flags}`;
    }
    if (node.bigint) {
      return node.bigint;
    }
  }
  const evaluated = getStaticValue(node, initialScope);
  return evaluated && String(evaluated.value);
}
function getPropertyName(node, initialScope) {
  switch (node.type) {
    case "MemberExpression":
      if (node.computed) {
        return getStringIfConstant(node.property, initialScope);
      }
      if (node.property.type === "PrivateIdentifier") {
        return null;
      }
      return node.property.name;
    case "Property":
    case "MethodDefinition":
    case "PropertyDefinition":
      if (node.computed) {
        return getStringIfConstant(node.key, initialScope);
      }
      if (node.key.type === "Literal") {
        return String(node.key.value);
      }
      if (node.key.type === "PrivateIdentifier") {
        return null;
      }
      return node.key.name;
  }
  return null;
}
function getFunctionNameWithKind(node, sourceCode) {
  const parent = node.parent;
  const tokens = [];
  const isObjectMethod = parent.type === "Property" && parent.value === node;
  const isClassMethod = parent.type === "MethodDefinition" && parent.value === node;
  const isClassFieldMethod = parent.type === "PropertyDefinition" && parent.value === node;
  if (isClassMethod || isClassFieldMethod) {
    if (parent.static) {
      tokens.push("static");
    }
    if (parent.key.type === "PrivateIdentifier") {
      tokens.push("private");
    }
  }
  if (node.async) {
    tokens.push("async");
  }
  if (node.generator) {
    tokens.push("generator");
  }
  if (isObjectMethod || isClassMethod) {
    if (parent.kind === "constructor") {
      return "constructor";
    }
    if (parent.kind === "get") {
      tokens.push("getter");
    } else if (parent.kind === "set") {
      tokens.push("setter");
    } else {
      tokens.push("method");
    }
  } else if (isClassFieldMethod) {
    tokens.push("method");
  } else {
    if (node.type === "ArrowFunctionExpression") {
      tokens.push("arrow");
    }
    tokens.push("function");
  }
  if (isObjectMethod || isClassMethod || isClassFieldMethod) {
    if (parent.key.type === "PrivateIdentifier") {
      tokens.push(`#${parent.key.name}`);
    } else {
      const name = getPropertyName(parent);
      if (name) {
        tokens.push(`'${name}'`);
      } else if (sourceCode) {
        const keyText = sourceCode.getText(parent.key);
        if (!keyText.includes("\n")) {
          tokens.push(`[${keyText}]`);
        }
      }
    }
  } else if (node.id) {
    tokens.push(`'${node.id.name}'`);
  } else if (parent.type === "VariableDeclarator" && parent.id && parent.id.type === "Identifier") {
    tokens.push(`'${parent.id.name}'`);
  } else if ((parent.type === "AssignmentExpression" || parent.type === "AssignmentPattern") && parent.left && parent.left.type === "Identifier") {
    tokens.push(`'${parent.left.name}'`);
  } else if (parent.type === "ExportDefaultDeclaration" && parent.declaration === node) {
    tokens.push("'default'");
  }
  return tokens.join(" ");
}
var typeConversionBinaryOps = Object.freeze(
  /* @__PURE__ */ new Set([
    "==",
    "!=",
    "<",
    "<=",
    ">",
    ">=",
    "<<",
    ">>",
    ">>>",
    "+",
    "-",
    "*",
    "/",
    "%",
    "|",
    "^",
    "&",
    "in"
  ])
);
var typeConversionUnaryOps = Object.freeze(/* @__PURE__ */ new Set(["-", "+", "!", "~"]));
function isNode(x3) {
  return x3 !== null && typeof x3 === "object" && typeof x3.type === "string";
}
var visitor = Object.freeze(
  Object.assign(/* @__PURE__ */ Object.create(null), {
    $visit(node, options, visitorKeys) {
      const { type } = node;
      if (typeof this[type] === "function") {
        return this[type](node, options, visitorKeys);
      }
      return this.$visitChildren(node, options, visitorKeys);
    },
    $visitChildren(node, options, visitorKeys) {
      const { type } = node;
      for (const key of visitorKeys[type] || getKeys(node)) {
        const value = node[key];
        if (Array.isArray(value)) {
          for (const element of value) {
            if (isNode(element) && this.$visit(element, options, visitorKeys)) {
              return true;
            }
          }
        } else if (isNode(value) && this.$visit(value, options, visitorKeys)) {
          return true;
        }
      }
      return false;
    },
    ArrowFunctionExpression() {
      return false;
    },
    AssignmentExpression() {
      return true;
    },
    AwaitExpression() {
      return true;
    },
    BinaryExpression(node, options, visitorKeys) {
      if (options.considerImplicitTypeConversion && typeConversionBinaryOps.has(node.operator) && (node.left.type !== "Literal" || node.right.type !== "Literal")) {
        return true;
      }
      return this.$visitChildren(node, options, visitorKeys);
    },
    CallExpression() {
      return true;
    },
    FunctionExpression() {
      return false;
    },
    ImportExpression() {
      return true;
    },
    MemberExpression(node, options, visitorKeys) {
      if (options.considerGetters) {
        return true;
      }
      if (options.considerImplicitTypeConversion && node.computed && node.property.type !== "Literal") {
        return true;
      }
      return this.$visitChildren(node, options, visitorKeys);
    },
    MethodDefinition(node, options, visitorKeys) {
      if (options.considerImplicitTypeConversion && node.computed && node.key.type !== "Literal") {
        return true;
      }
      return this.$visitChildren(node, options, visitorKeys);
    },
    NewExpression() {
      return true;
    },
    Property(node, options, visitorKeys) {
      if (options.considerImplicitTypeConversion && node.computed && node.key.type !== "Literal") {
        return true;
      }
      return this.$visitChildren(node, options, visitorKeys);
    },
    PropertyDefinition(node, options, visitorKeys) {
      if (options.considerImplicitTypeConversion && node.computed && node.key.type !== "Literal") {
        return true;
      }
      return this.$visitChildren(node, options, visitorKeys);
    },
    UnaryExpression(node, options, visitorKeys) {
      if (node.operator === "delete") {
        return true;
      }
      if (options.considerImplicitTypeConversion && typeConversionUnaryOps.has(node.operator) && node.argument.type !== "Literal") {
        return true;
      }
      return this.$visitChildren(node, options, visitorKeys);
    },
    UpdateExpression() {
      return true;
    },
    YieldExpression() {
      return true;
    }
  })
);
function hasSideEffect(node, sourceCode, { considerGetters = false, considerImplicitTypeConversion = false } = {}) {
  return visitor.$visit(
    node,
    { considerGetters, considerImplicitTypeConversion },
    sourceCode.visitorKeys || visitor_keys_default
  );
}
function getParentSyntaxParen(node, sourceCode) {
  const parent = node.parent;
  switch (parent.type) {
    case "CallExpression":
    case "NewExpression":
      if (parent.arguments.length === 1 && parent.arguments[0] === node) {
        return sourceCode.getTokenAfter(
          parent.callee,
          isOpeningParenToken
        );
      }
      return null;
    case "DoWhileStatement":
      if (parent.test === node) {
        return sourceCode.getTokenAfter(
          parent.body,
          isOpeningParenToken
        );
      }
      return null;
    case "IfStatement":
    case "WhileStatement":
      if (parent.test === node) {
        return sourceCode.getFirstToken(parent, 1);
      }
      return null;
    case "ImportExpression":
      if (parent.source === node) {
        return sourceCode.getFirstToken(parent, 1);
      }
      return null;
    case "SwitchStatement":
      if (parent.discriminant === node) {
        return sourceCode.getFirstToken(parent, 1);
      }
      return null;
    case "WithStatement":
      if (parent.object === node) {
        return sourceCode.getFirstToken(parent, 1);
      }
      return null;
    default:
      return null;
  }
}
function isParenthesized(timesOrNode, nodeOrSourceCode, optionalSourceCode) {
  let times, node, sourceCode, maybeLeftParen, maybeRightParen;
  if (typeof timesOrNode === "number") {
    times = timesOrNode | 0;
    node = nodeOrSourceCode;
    sourceCode = optionalSourceCode;
    if (!(times >= 1)) {
      throw new TypeError("'times' should be a positive integer.");
    }
  } else {
    times = 1;
    node = timesOrNode;
    sourceCode = nodeOrSourceCode;
  }
  if (node == null || // `Program` can't be parenthesized
  node.parent == null || // `CatchClause.param` can't be parenthesized, example `try {} catch (error) {}`
  node.parent.type === "CatchClause" && node.parent.param === node) {
    return false;
  }
  maybeLeftParen = maybeRightParen = node;
  do {
    maybeLeftParen = sourceCode.getTokenBefore(maybeLeftParen);
    maybeRightParen = sourceCode.getTokenAfter(maybeRightParen);
  } while (maybeLeftParen != null && maybeRightParen != null && isOpeningParenToken(maybeLeftParen) && isClosingParenToken(maybeRightParen) && // Avoid false positive such as `if (a) {}`
  maybeLeftParen !== getParentSyntaxParen(node, sourceCode) && --times > 0);
  return times === 0;
}
Function.call.bind(Object.hasOwnProperty);
var __defProp2 = Object.defineProperty;
var __export2 = (target, all33) => {
  for (var name in all33)
    __defProp2(target, name, { get: all33[name], enumerable: true });
};
var NodeType = types.AST_NODE_TYPES;
var is = utils.ASTUtils.isNodeOfType;
var isOneOf = utils.ASTUtils.isNodeOfTypes;
var isFunction = isOneOf([
  NodeType.ArrowFunctionExpression,
  NodeType.FunctionDeclaration,
  NodeType.FunctionExpression
]);
isOneOf([
  NodeType.ArrowFunctionExpression,
  NodeType.FunctionDeclaration,
  NodeType.FunctionExpression,
  NodeType.TSCallSignatureDeclaration,
  NodeType.TSConstructSignatureDeclaration,
  NodeType.TSDeclareFunction,
  NodeType.TSEmptyBodyFunctionExpression,
  NodeType.TSFunctionType,
  NodeType.TSMethodSignature
]);
var isClass = isOneOf([NodeType.ClassDeclaration, NodeType.ClassExpression]);
isOneOf([
  NodeType.DoWhileStatement,
  NodeType.ForInStatement,
  NodeType.ForOfStatement,
  NodeType.ForStatement,
  NodeType.WhileStatement
]);
isOneOf([NodeType.TSArrayType, NodeType.TSTupleType]);
isOneOf([
  NodeType.PropertyDefinition,
  NodeType.TSIndexSignature,
  NodeType.TSParameterProperty,
  NodeType.TSPropertySignature
]);
is(NodeType.JSXElement);
is(NodeType.JSXFragment);
isOneOf([
  NodeType.JSXAttribute,
  NodeType.JSXSpreadChild,
  NodeType.JSXClosingElement,
  NodeType.JSXClosingFragment,
  NodeType.JSXElement,
  NodeType.JSXEmptyExpression,
  NodeType.JSXExpressionContainer,
  NodeType.JSXFragment,
  NodeType.JSXIdentifier,
  NodeType.JSXMemberExpression,
  NodeType.JSXNamespacedName,
  NodeType.JSXOpeningElement,
  NodeType.JSXOpeningFragment,
  NodeType.JSXSpreadAttribute,
  NodeType.JSXSpreadChild,
  NodeType.JSXText
]);
isOneOf([
  NodeType.JSXIdentifier,
  NodeType.JSXMemberExpression,
  NodeType.JSXNamespacedName
]);
isOneOf([
  NodeType.ArrayPattern,
  NodeType.AssignmentPattern,
  NodeType.ObjectPattern,
  NodeType.RestElement
]);
isOneOf([
  NodeType.TSInterfaceDeclaration,
  NodeType.TSTypeAliasDeclaration
]);
isOneOf([
  NodeType.ArrayExpression,
  NodeType.ArrayPattern,
  NodeType.ArrowFunctionExpression,
  NodeType.CallExpression,
  NodeType.ClassExpression,
  NodeType.FunctionExpression,
  NodeType.Identifier,
  NodeType.JSXElement,
  NodeType.JSXFragment,
  NodeType.Literal,
  NodeType.TemplateLiteral,
  NodeType.MemberExpression,
  NodeType.MetaProperty,
  NodeType.ObjectExpression,
  NodeType.ObjectPattern,
  NodeType.SequenceExpression,
  NodeType.Super,
  NodeType.TaggedTemplateExpression,
  NodeType.ThisExpression
]);
isOneOf([
  NodeType.ArrayExpression,
  NodeType.ArrayPattern,
  NodeType.ArrowFunctionExpression,
  NodeType.CallExpression,
  NodeType.ClassExpression,
  NodeType.FunctionExpression,
  NodeType.Identifier,
  NodeType.JSXElement,
  NodeType.JSXFragment,
  NodeType.Literal,
  NodeType.TemplateLiteral,
  NodeType.MemberExpression,
  NodeType.MetaProperty,
  NodeType.ObjectExpression,
  NodeType.ObjectPattern,
  NodeType.SequenceExpression,
  NodeType.Super,
  NodeType.TaggedTemplateExpression,
  NodeType.ThisExpression,
  NodeType.TSAsExpression,
  NodeType.TSNonNullExpression,
  NodeType.TSTypeAssertion
]);
var Function_exports = {};
__export2(Function_exports, {
  SK: () => SK,
  absurd: () => absurd,
  apply: () => apply,
  compose: () => compose,
  constFalse: () => constFalse,
  constNull: () => constNull,
  constTrue: () => constTrue,
  constUndefined: () => constUndefined,
  constVoid: () => constVoid,
  constant: () => constant,
  dual: () => dual,
  flip: () => flip,
  flow: () => flow,
  hole: () => hole,
  identity: () => identity,
  isFunction: () => isFunction2,
  pipe: () => pipe,
  satisfies: () => satisfies,
  tupled: () => tupled,
  unsafeCoerce: () => unsafeCoerce,
  untupled: () => untupled
});
var isFunction2 = (input) => typeof input === "function";
var dual = function(arity, body) {
  if (typeof arity === "function") {
    return function() {
      if (arity(arguments)) {
        return body.apply(this, arguments);
      }
      return (self2) => body(self2, ...arguments);
    };
  }
  switch (arity) {
    case 0:
    case 1:
      throw new RangeError(`Invalid arity ${arity}`);
    case 2:
      return function(a3, b3) {
        if (arguments.length >= 2) {
          return body(a3, b3);
        }
        return function(self2) {
          return body(self2, a3);
        };
      };
    case 3:
      return function(a3, b3, c3) {
        if (arguments.length >= 3) {
          return body(a3, b3, c3);
        }
        return function(self2) {
          return body(self2, a3, b3);
        };
      };
    case 4:
      return function(a3, b3, c3, d3) {
        if (arguments.length >= 4) {
          return body(a3, b3, c3, d3);
        }
        return function(self2) {
          return body(self2, a3, b3, c3);
        };
      };
    case 5:
      return function(a3, b3, c3, d3, e3) {
        if (arguments.length >= 5) {
          return body(a3, b3, c3, d3, e3);
        }
        return function(self2) {
          return body(self2, a3, b3, c3, d3);
        };
      };
    default:
      return function() {
        if (arguments.length >= arity) {
          return body.apply(this, arguments);
        }
        const args = arguments;
        return function(self2) {
          return body(self2, ...args);
        };
      };
  }
};
var apply = (a3) => (self2) => self2(a3);
var identity = (a3) => a3;
var satisfies = () => (b3) => b3;
var unsafeCoerce = identity;
var constant = (value) => () => value;
var constTrue = /* @__PURE__ */ constant(true);
var constFalse = /* @__PURE__ */ constant(false);
var constNull = /* @__PURE__ */ constant(null);
var constUndefined = /* @__PURE__ */ constant(void 0);
var constVoid = constUndefined;
var flip = (f3) => (...b3) => (...a3) => f3(...a3)(...b3);
var compose = /* @__PURE__ */ dual(2, (ab, bc) => (a3) => bc(ab(a3)));
var absurd = (_3) => {
  throw new Error("Called `absurd` function which should be uncallable");
};
var tupled = (f3) => (a3) => f3(...a3);
var untupled = (f3) => (...a3) => f3(a3);
function pipe(a3, ab, bc, cd, de, ef, fg, gh, hi) {
  switch (arguments.length) {
    case 1:
      return a3;
    case 2:
      return ab(a3);
    case 3:
      return bc(ab(a3));
    case 4:
      return cd(bc(ab(a3)));
    case 5:
      return de(cd(bc(ab(a3))));
    case 6:
      return ef(de(cd(bc(ab(a3)))));
    case 7:
      return fg(ef(de(cd(bc(ab(a3))))));
    case 8:
      return gh(fg(ef(de(cd(bc(ab(a3)))))));
    case 9:
      return hi(gh(fg(ef(de(cd(bc(ab(a3))))))));
    default: {
      let ret = arguments[0];
      for (let i3 = 1; i3 < arguments.length; i3++) {
        ret = arguments[i3](ret);
      }
      return ret;
    }
  }
}
function flow(ab, bc, cd, de, ef, fg, gh, hi, ij) {
  switch (arguments.length) {
    case 1:
      return ab;
    case 2:
      return function() {
        return bc(ab.apply(this, arguments));
      };
    case 3:
      return function() {
        return cd(bc(ab.apply(this, arguments)));
      };
    case 4:
      return function() {
        return de(cd(bc(ab.apply(this, arguments))));
      };
    case 5:
      return function() {
        return ef(de(cd(bc(ab.apply(this, arguments)))));
      };
    case 6:
      return function() {
        return fg(ef(de(cd(bc(ab.apply(this, arguments))))));
      };
    case 7:
      return function() {
        return gh(fg(ef(de(cd(bc(ab.apply(this, arguments)))))));
      };
    case 8:
      return function() {
        return hi(gh(fg(ef(de(cd(bc(ab.apply(this, arguments))))))));
      };
    case 9:
      return function() {
        return ij(hi(gh(fg(ef(de(cd(bc(ab.apply(this, arguments)))))))));
      };
  }
  return;
}
var hole = /* @__PURE__ */ unsafeCoerce(absurd);
var SK = (_3, b3) => b3;
var make = (isEquivalent) => (self2, that) => self2 === that || isEquivalent(self2, that);
var let_ = (map62) => dual(3, (self2, name, f3) => map62(self2, (a3) => Object.assign({}, a3, {
  [name]: f3(a3)
})));
var bindTo = (map62) => dual(2, (self2, name) => map62(self2, (a3) => ({
  [name]: a3
})));
var bind = (map62, flatMap42) => dual(3, (self2, name, f3) => flatMap42(self2, (a3) => map62(f3(a3), (b3) => Object.assign({}, a3, {
  [name]: b3
}))));
var moduleVersion = "3.2.8";
var getCurrentVersion = () => moduleVersion;
var globalStoreId = /* @__PURE__ */ Symbol.for(`effect/GlobalValue/globalStoreId/${/* @__PURE__ */ getCurrentVersion()}`);
if (!(globalStoreId in globalThis)) {
  globalThis[globalStoreId] = /* @__PURE__ */ new Map();
}
var globalStore = globalThis[globalStoreId];
var globalValue = (id, compute) => {
  if (!globalStore.has(id)) {
    globalStore.set(id, compute());
  }
  return globalStore.get(id);
};
var Predicate_exports = {};
__export2(Predicate_exports, {
  all: () => all,
  and: () => and,
  compose: () => compose2,
  eqv: () => eqv,
  every: () => every,
  hasProperty: () => hasProperty,
  implies: () => implies,
  isBigInt: () => isBigInt,
  isBoolean: () => isBoolean,
  isDate: () => isDate,
  isError: () => isError,
  isFunction: () => isFunction3,
  isIterable: () => isIterable,
  isMap: () => isMap,
  isNever: () => isNever,
  isNotNull: () => isNotNull,
  isNotNullable: () => isNotNullable,
  isNotUndefined: () => isNotUndefined,
  isNull: () => isNull,
  isNullable: () => isNullable,
  isNumber: () => isNumber,
  isObject: () => isObject,
  isPromise: () => isPromise,
  isPromiseLike: () => isPromiseLike,
  isReadonlyRecord: () => isReadonlyRecord,
  isRecord: () => isRecord,
  isSet: () => isSet,
  isString: () => isString,
  isSymbol: () => isSymbol,
  isTagged: () => isTagged,
  isTruthy: () => isTruthy,
  isUint8Array: () => isUint8Array,
  isUndefined: () => isUndefined,
  isUnknown: () => isUnknown,
  mapInput: () => mapInput,
  nand: () => nand,
  nor: () => nor,
  not: () => not,
  or: () => or,
  product: () => product,
  productMany: () => productMany,
  some: () => some,
  struct: () => struct,
  tuple: () => tuple,
  xor: () => xor
});
var mapInput = /* @__PURE__ */ dual(2, (self2, f3) => (b3) => self2(f3(b3)));
var isTruthy = (input) => !!input;
var isSet = (input) => input instanceof Set;
var isMap = (input) => input instanceof Map;
var isString = (input) => typeof input === "string";
var isNumber = (input) => typeof input === "number";
var isBoolean = (input) => typeof input === "boolean";
var isBigInt = (input) => typeof input === "bigint";
var isSymbol = (input) => typeof input === "symbol";
var isFunction3 = isFunction2;
var isUndefined = (input) => input === void 0;
var isNotUndefined = (input) => input !== void 0;
var isNull = (input) => input === null;
var isNotNull = (input) => input !== null;
var isNever = (_3) => false;
var isUnknown = (_3) => true;
var isRecordOrArray = (input) => typeof input === "object" && input !== null;
var isObject = (input) => isRecordOrArray(input) || isFunction3(input);
var hasProperty = /* @__PURE__ */ dual(2, (self2, property) => isObject(self2) && property in self2);
var isTagged = /* @__PURE__ */ dual(2, (self2, tag) => hasProperty(self2, "_tag") && self2["_tag"] === tag);
var isNullable = (input) => input === null || input === void 0;
var isNotNullable = (input) => input !== null && input !== void 0;
var isError = (input) => input instanceof Error;
var isUint8Array = (input) => input instanceof Uint8Array;
var isDate = (input) => input instanceof Date;
var isIterable = (input) => hasProperty(input, Symbol.iterator);
var isRecord = (input) => isRecordOrArray(input) && !Array.isArray(input);
var isReadonlyRecord = isRecord;
var isPromise = (input) => hasProperty(input, "then") && "catch" in input && isFunction3(input.then) && isFunction3(input.catch);
var isPromiseLike = (input) => hasProperty(input, "then") && isFunction3(input.then);
var compose2 = /* @__PURE__ */ dual(2, (ab, bc) => (a3) => ab(a3) && bc(a3));
var product = (self2, that) => ([a3, b3]) => self2(a3) && that(b3);
var all = (collection) => {
  return (as24) => {
    let collectionIndex = 0;
    for (const p3 of collection) {
      if (collectionIndex >= as24.length) {
        break;
      }
      if (p3(as24[collectionIndex]) === false) {
        return false;
      }
      collectionIndex++;
    }
    return true;
  };
};
var productMany = (self2, collection) => {
  const rest = all(collection);
  return ([head22, ...tail3]) => self2(head22) === false ? false : rest(tail3);
};
var tuple = (...elements) => all(elements);
var struct = (fields) => {
  const keys23 = Object.keys(fields);
  return (a3) => {
    for (const key of keys23) {
      if (!fields[key](a3[key])) {
        return false;
      }
    }
    return true;
  };
};
var not = (self2) => (a3) => !self2(a3);
var or = /* @__PURE__ */ dual(2, (self2, that) => (a3) => self2(a3) || that(a3));
var and = /* @__PURE__ */ dual(2, (self2, that) => (a3) => self2(a3) && that(a3));
var xor = /* @__PURE__ */ dual(2, (self2, that) => (a3) => self2(a3) !== that(a3));
var eqv = /* @__PURE__ */ dual(2, (self2, that) => (a3) => self2(a3) === that(a3));
var implies = /* @__PURE__ */ dual(2, (self2, that) => (a3) => self2(a3) ? that(a3) : true);
var nor = /* @__PURE__ */ dual(2, (self2, that) => (a3) => !(self2(a3) || that(a3)));
var nand = /* @__PURE__ */ dual(2, (self2, that) => (a3) => !(self2(a3) && that(a3)));
var every = (collection) => (a3) => {
  for (const p3 of collection) {
    if (!p3(a3)) {
      return false;
    }
  }
  return true;
};
var some = (collection) => (a3) => {
  for (const p3 of collection) {
    if (p3(a3)) {
      return true;
    }
  }
  return false;
};
var getBugErrorMessage = (message) => `BUG: ${message} - please report an issue at https://github.com/Effect-TS/effect/issues`;
var GenKindTypeId = /* @__PURE__ */ Symbol.for("effect/Gen/GenKind");
var isGenKind = (u3) => isObject(u3) && GenKindTypeId in u3;
var GenKindImpl = class {
  value;
  constructor(value) {
    this.value = value;
  }
  /**
   * @since 2.0.0
   */
  get _F() {
    return identity;
  }
  /**
   * @since 2.0.0
   */
  get _R() {
    return (_3) => _3;
  }
  /**
   * @since 2.0.0
   */
  get _O() {
    return (_3) => _3;
  }
  /**
   * @since 2.0.0
   */
  get _E() {
    return (_3) => _3;
  }
  /**
   * @since 2.0.0
   */
  [GenKindTypeId] = GenKindTypeId;
  /**
   * @since 2.0.0
   */
  [Symbol.iterator]() {
    return new SingleShotGen(this);
  }
};
var SingleShotGen = class _SingleShotGen {
  self;
  called = false;
  constructor(self2) {
    this.self = self2;
  }
  /**
   * @since 2.0.0
   */
  next(a3) {
    return this.called ? {
      value: a3,
      done: true
    } : (this.called = true, {
      value: this.self,
      done: false
    });
  }
  /**
   * @since 2.0.0
   */
  return(a3) {
    return {
      value: a3,
      done: true
    };
  }
  /**
   * @since 2.0.0
   */
  throw(e3) {
    throw e3;
  }
  /**
   * @since 2.0.0
   */
  [Symbol.iterator]() {
    return new _SingleShotGen(this.self);
  }
};
var adapter = () => function() {
  let x3 = arguments[0];
  for (let i3 = 1; i3 < arguments.length; i3++) {
    x3 = arguments[i3](x3);
  }
  return new GenKindImpl(x3);
};
var defaultIncHi = 335903614;
var defaultIncLo = 4150755663;
var MUL_HI = 1481765933 >>> 0;
var MUL_LO = 1284865837 >>> 0;
var BIT_53 = 9007199254740992;
var BIT_27 = 134217728;
var PCGRandom = class {
  _state;
  constructor(seedHi, seedLo, incHi, incLo) {
    if (isNullable(seedLo) && isNullable(seedHi)) {
      seedLo = Math.random() * 4294967295 >>> 0;
      seedHi = 0;
    } else if (isNullable(seedLo)) {
      seedLo = seedHi;
      seedHi = 0;
    }
    if (isNullable(incLo) && isNullable(incHi)) {
      incLo = this._state ? this._state[3] : defaultIncLo;
      incHi = this._state ? this._state[2] : defaultIncHi;
    } else if (isNullable(incLo)) {
      incLo = incHi;
      incHi = 0;
    }
    this._state = new Int32Array([0, 0, incHi >>> 0, ((incLo || 0) | 1) >>> 0]);
    this._next();
    add64(this._state, this._state[0], this._state[1], seedHi >>> 0, seedLo >>> 0);
    this._next();
    return this;
  }
  /**
   * Returns a copy of the internal state of this random number generator as a
   * JavaScript Array.
   *
   * @category getters
   * @since 2.0.0
   */
  getState() {
    return [this._state[0], this._state[1], this._state[2], this._state[3]];
  }
  /**
   * Restore state previously retrieved using `getState()`.
   *
   * @since 2.0.0
   */
  setState(state) {
    this._state[0] = state[0];
    this._state[1] = state[1];
    this._state[2] = state[2];
    this._state[3] = state[3] | 1;
  }
  /**
   * Get a uniformly distributed 32 bit integer between [0, max).
   *
   * @category getter
   * @since 2.0.0
   */
  integer(max3) {
    if (!max3) {
      return this._next();
    }
    max3 = max3 >>> 0;
    if ((max3 & max3 - 1) === 0) {
      return this._next() & max3 - 1;
    }
    let num = 0;
    const skew = (-max3 >>> 0) % max3 >>> 0;
    for (num = this._next(); num < skew; num = this._next()) {
    }
    return num % max3;
  }
  /**
   * Get a uniformly distributed IEEE-754 double between 0.0 and 1.0, with
   * 53 bits of precision (every bit of the mantissa is randomized).
   *
   * @category getters
   * @since 2.0.0
   */
  number() {
    const hi = (this._next() & 67108863) * 1;
    const lo = (this._next() & 134217727) * 1;
    return (hi * BIT_27 + lo) / BIT_53;
  }
  /** @internal */
  _next() {
    const oldHi = this._state[0] >>> 0;
    const oldLo = this._state[1] >>> 0;
    mul64(this._state, oldHi, oldLo, MUL_HI, MUL_LO);
    add64(this._state, this._state[0], this._state[1], this._state[2], this._state[3]);
    let xsHi = oldHi >>> 18;
    let xsLo = (oldLo >>> 18 | oldHi << 14) >>> 0;
    xsHi = (xsHi ^ oldHi) >>> 0;
    xsLo = (xsLo ^ oldLo) >>> 0;
    const xorshifted = (xsLo >>> 27 | xsHi << 5) >>> 0;
    const rot = oldHi >>> 27;
    const rot2 = (-rot >>> 0 & 31) >>> 0;
    return (xorshifted >>> rot | xorshifted << rot2) >>> 0;
  }
};
function mul64(out, aHi, aLo, bHi, bLo) {
  let c1 = (aLo >>> 16) * (bLo & 65535) >>> 0;
  let c0 = (aLo & 65535) * (bLo >>> 16) >>> 0;
  let lo = (aLo & 65535) * (bLo & 65535) >>> 0;
  let hi = (aLo >>> 16) * (bLo >>> 16) + ((c0 >>> 16) + (c1 >>> 16)) >>> 0;
  c0 = c0 << 16 >>> 0;
  lo = lo + c0 >>> 0;
  if (lo >>> 0 < c0 >>> 0) {
    hi = hi + 1 >>> 0;
  }
  c1 = c1 << 16 >>> 0;
  lo = lo + c1 >>> 0;
  if (lo >>> 0 < c1 >>> 0) {
    hi = hi + 1 >>> 0;
  }
  hi = hi + Math.imul(aLo, bHi) >>> 0;
  hi = hi + Math.imul(aHi, bLo) >>> 0;
  out[0] = hi;
  out[1] = lo;
}
function add64(out, aHi, aLo, bHi, bLo) {
  let hi = aHi + bHi >>> 0;
  const lo = aLo + bLo >>> 0;
  if (lo >>> 0 < aLo >>> 0) {
    hi = hi + 1 | 0;
  }
  out[0] = hi;
  out[1] = lo;
}
var YieldWrapTypeId = /* @__PURE__ */ Symbol.for("effect/Utils/YieldWrap");
var YieldWrap = class {
  /**
   * @since 3.0.6
   */
  #value;
  constructor(value) {
    this.#value = value;
  }
  /**
   * @since 3.0.6
   */
  [YieldWrapTypeId]() {
    return this.#value;
  }
};
function yieldWrapGet(self2) {
  if (typeof self2 === "object" && self2 !== null && YieldWrapTypeId in self2) {
    return self2[YieldWrapTypeId]();
  }
  throw new Error(getBugErrorMessage("yieldWrapGet"));
}
var structuralRegionState = /* @__PURE__ */ globalValue("effect/Utils/isStructuralRegion", () => ({
  enabled: false,
  tester: void 0
}));
var randomHashCache = /* @__PURE__ */ globalValue(/* @__PURE__ */ Symbol.for("effect/Hash/randomHashCache"), () => /* @__PURE__ */ new WeakMap());
var pcgr = /* @__PURE__ */ globalValue(/* @__PURE__ */ Symbol.for("effect/Hash/pcgr"), () => new PCGRandom());
var symbol = /* @__PURE__ */ Symbol.for("effect/Hash");
var hash = (self2) => {
  if (structuralRegionState.enabled === true) {
    return 0;
  }
  switch (typeof self2) {
    case "number":
      return number(self2);
    case "bigint":
      return string(self2.toString(10));
    case "boolean":
      return string(String(self2));
    case "symbol":
      return string(String(self2));
    case "string":
      return string(self2);
    case "undefined":
      return string("undefined");
    case "function":
    case "object": {
      if (self2 === null) {
        return string("null");
      } else if (self2 instanceof Date) {
        return hash(self2.toISOString());
      } else if (isHash(self2)) {
        return self2[symbol]();
      } else {
        return random(self2);
      }
    }
    default:
      throw new Error(`BUG: unhandled typeof ${typeof self2} - please report an issue at https://github.com/Effect-TS/effect/issues`);
  }
};
var random = (self2) => {
  if (!randomHashCache.has(self2)) {
    randomHashCache.set(self2, number(pcgr.integer(Number.MAX_SAFE_INTEGER)));
  }
  return randomHashCache.get(self2);
};
var combine = (b3) => (self2) => self2 * 53 ^ b3;
var optimize = (n3) => n3 & 3221225471 | n3 >>> 1 & 1073741824;
var isHash = (u3) => hasProperty(u3, symbol);
var number = (n3) => {
  if (n3 !== n3 || n3 === Infinity) {
    return 0;
  }
  let h3 = n3 | 0;
  if (h3 !== n3) {
    h3 ^= n3 * 4294967295;
  }
  while (n3 > 4294967295) {
    h3 ^= n3 /= 4294967295;
  }
  return optimize(n3);
};
var string = (str) => {
  let h3 = 5381, i3 = str.length;
  while (i3) {
    h3 = h3 * 33 ^ str.charCodeAt(--i3);
  }
  return optimize(h3);
};
var structureKeys = (o3, keys23) => {
  let h3 = 12289;
  for (let i3 = 0; i3 < keys23.length; i3++) {
    h3 ^= pipe(string(keys23[i3]), combine(hash(o3[keys23[i3]])));
  }
  return optimize(h3);
};
var structure = (o3) => structureKeys(o3, Object.keys(o3));
var array = (arr) => {
  let h3 = 6151;
  for (let i3 = 0; i3 < arr.length; i3++) {
    h3 = pipe(h3, combine(hash(arr[i3])));
  }
  return optimize(h3);
};
var cached = function() {
  if (arguments.length === 1) {
    const self22 = arguments[0];
    return function(hash32) {
      Object.defineProperty(self22, symbol, {
        value() {
          return hash32;
        },
        enumerable: false
      });
      return hash32;
    };
  }
  const self2 = arguments[0];
  const hash24 = arguments[1];
  Object.defineProperty(self2, symbol, {
    value() {
      return hash24;
    },
    enumerable: false
  });
  return hash24;
};
var symbol2 = /* @__PURE__ */ Symbol.for("effect/Equal");
function equals() {
  if (arguments.length === 1) {
    return (self2) => compareBoth(self2, arguments[0]);
  }
  return compareBoth(arguments[0], arguments[1]);
}
function compareBoth(self2, that) {
  if (self2 === that) {
    return true;
  }
  const selfType = typeof self2;
  if (selfType !== typeof that) {
    return false;
  }
  if (selfType === "object" || selfType === "function") {
    if (self2 !== null && that !== null) {
      if (isEqual(self2) && isEqual(that)) {
        if (hash(self2) === hash(that) && self2[symbol2](that)) {
          return true;
        } else {
          return structuralRegionState.enabled && structuralRegionState.tester ? structuralRegionState.tester(self2, that) : false;
        }
      } else if (self2 instanceof Date && that instanceof Date) {
        return self2.toISOString() === that.toISOString();
      }
    }
    if (structuralRegionState.enabled) {
      if (Array.isArray(self2) && Array.isArray(that)) {
        return self2.length === that.length && self2.every((v3, i3) => compareBoth(v3, that[i3]));
      }
      if (Object.getPrototypeOf(self2) === Object.prototype && Object.getPrototypeOf(self2) === Object.prototype) {
        const keysSelf = Object.keys(self2);
        const keysThat = Object.keys(that);
        if (keysSelf.length === keysThat.length) {
          for (const key of keysSelf) {
            if (!(key in that && compareBoth(self2[key], that[key]))) {
              return structuralRegionState.tester ? structuralRegionState.tester(self2, that) : false;
            }
          }
          return true;
        }
      }
      return structuralRegionState.tester ? structuralRegionState.tester(self2, that) : false;
    }
  }
  return structuralRegionState.enabled && structuralRegionState.tester ? structuralRegionState.tester(self2, that) : false;
}
var isEqual = (u3) => hasProperty(u3, symbol2);
var equivalence = () => equals;
var NodeInspectSymbol = /* @__PURE__ */ Symbol.for("nodejs.util.inspect.custom");
var toJSON = (x3) => {
  if (hasProperty(x3, "toJSON") && isFunction3(x3["toJSON"]) && x3["toJSON"].length === 0) {
    return x3.toJSON();
  } else if (Array.isArray(x3)) {
    return x3.map(toJSON);
  }
  return x3;
};
var format = (x3) => JSON.stringify(x3, null, 2);
var pipeArguments = (self2, args) => {
  switch (args.length) {
    case 1:
      return args[0](self2);
    case 2:
      return args[1](args[0](self2));
    case 3:
      return args[2](args[1](args[0](self2)));
    case 4:
      return args[3](args[2](args[1](args[0](self2))));
    case 5:
      return args[4](args[3](args[2](args[1](args[0](self2)))));
    case 6:
      return args[5](args[4](args[3](args[2](args[1](args[0](self2))))));
    case 7:
      return args[6](args[5](args[4](args[3](args[2](args[1](args[0](self2)))))));
    case 8:
      return args[7](args[6](args[5](args[4](args[3](args[2](args[1](args[0](self2))))))));
    case 9:
      return args[8](args[7](args[6](args[5](args[4](args[3](args[2](args[1](args[0](self2)))))))));
    default: {
      let ret = self2;
      for (let i3 = 0, len = args.length; i3 < len; i3++) {
        ret = args[i3](ret);
      }
      return ret;
    }
  }
};
var OP_COMMIT = "Commit";
var OP_FAILURE = "Failure";
var OP_WITH_RUNTIME = "WithRuntime";
var EffectTypeId = /* @__PURE__ */ Symbol.for("effect/Effect");
var StreamTypeId = /* @__PURE__ */ Symbol.for("effect/Stream");
var SinkTypeId = /* @__PURE__ */ Symbol.for("effect/Sink");
var ChannelTypeId = /* @__PURE__ */ Symbol.for("effect/Channel");
var effectVariance = {
  /* c8 ignore next */
  _R: (_3) => _3,
  /* c8 ignore next */
  _E: (_3) => _3,
  /* c8 ignore next */
  _A: (_3) => _3,
  _V: /* @__PURE__ */ getCurrentVersion()
};
var sinkVariance = {
  /* c8 ignore next */
  _A: (_3) => _3,
  /* c8 ignore next */
  _In: (_3) => _3,
  /* c8 ignore next */
  _L: (_3) => _3,
  /* c8 ignore next */
  _E: (_3) => _3,
  /* c8 ignore next */
  _R: (_3) => _3
};
var channelVariance = {
  /* c8 ignore next */
  _Env: (_3) => _3,
  /* c8 ignore next */
  _InErr: (_3) => _3,
  /* c8 ignore next */
  _InElem: (_3) => _3,
  /* c8 ignore next */
  _InDone: (_3) => _3,
  /* c8 ignore next */
  _OutErr: (_3) => _3,
  /* c8 ignore next */
  _OutElem: (_3) => _3,
  /* c8 ignore next */
  _OutDone: (_3) => _3
};
var EffectPrototype = {
  [EffectTypeId]: effectVariance,
  [StreamTypeId]: effectVariance,
  [SinkTypeId]: sinkVariance,
  [ChannelTypeId]: channelVariance,
  [symbol2](that) {
    return this === that;
  },
  [symbol]() {
    return cached(this, random(this));
  },
  [Symbol.iterator]() {
    return new SingleShotGen(new YieldWrap(this));
  },
  pipe() {
    return pipeArguments(this, arguments);
  }
};
var StructuralPrototype = {
  [symbol]() {
    return cached(this, structure(this));
  },
  [symbol2](that) {
    const selfKeys = Object.keys(this);
    const thatKeys = Object.keys(that);
    if (selfKeys.length !== thatKeys.length) {
      return false;
    }
    for (const key of selfKeys) {
      if (!(key in that && equals(this[key], that[key]))) {
        return false;
      }
    }
    return true;
  }
};
var CommitPrototype = {
  ...EffectPrototype,
  _op: OP_COMMIT
};
var StructuralCommitPrototype = {
  ...CommitPrototype,
  ...StructuralPrototype
};
var TypeId = /* @__PURE__ */ Symbol.for("effect/Option");
var CommonProto = {
  ...EffectPrototype,
  [TypeId]: {
    _A: (_3) => _3
  },
  [NodeInspectSymbol]() {
    return this.toJSON();
  },
  toString() {
    return format(this.toJSON());
  }
};
var SomeProto = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(CommonProto), {
  _tag: "Some",
  _op: "Some",
  [symbol2](that) {
    return isOption(that) && isSome(that) && equals(this.value, that.value);
  },
  [symbol]() {
    return cached(this, combine(hash(this._tag))(hash(this.value)));
  },
  toJSON() {
    return {
      _id: "Option",
      _tag: this._tag,
      value: toJSON(this.value)
    };
  }
});
var NoneHash = /* @__PURE__ */ hash("None");
var NoneProto = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(CommonProto), {
  _tag: "None",
  _op: "None",
  [symbol2](that) {
    return isOption(that) && isNone(that);
  },
  [symbol]() {
    return NoneHash;
  },
  toJSON() {
    return {
      _id: "Option",
      _tag: this._tag
    };
  }
});
var isOption = (input) => hasProperty(input, TypeId);
var isNone = (fa) => fa._tag === "None";
var isSome = (fa) => fa._tag === "Some";
var none = /* @__PURE__ */ Object.create(NoneProto);
var some2 = (value) => {
  const a3 = Object.create(SomeProto);
  a3.value = value;
  return a3;
};
var TypeId2 = /* @__PURE__ */ Symbol.for("effect/Either");
var CommonProto2 = {
  ...EffectPrototype,
  [TypeId2]: {
    _R: (_3) => _3
  },
  [NodeInspectSymbol]() {
    return this.toJSON();
  },
  toString() {
    return format(this.toJSON());
  }
};
var RightProto = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(CommonProto2), {
  _tag: "Right",
  _op: "Right",
  [symbol2](that) {
    return isEither(that) && isRight(that) && equals(this.right, that.right);
  },
  [symbol]() {
    return combine(hash(this._tag))(hash(this.right));
  },
  toJSON() {
    return {
      _id: "Either",
      _tag: this._tag,
      right: toJSON(this.right)
    };
  }
});
var LeftProto = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(CommonProto2), {
  _tag: "Left",
  _op: "Left",
  [symbol2](that) {
    return isEither(that) && isLeft(that) && equals(this.left, that.left);
  },
  [symbol]() {
    return combine(hash(this._tag))(hash(this.left));
  },
  toJSON() {
    return {
      _id: "Either",
      _tag: this._tag,
      left: toJSON(this.left)
    };
  }
});
var isEither = (input) => hasProperty(input, TypeId2);
var isLeft = (ma) => ma._tag === "Left";
var isRight = (ma) => ma._tag === "Right";
var left = (left33) => {
  const a3 = Object.create(LeftProto);
  a3.left = left33;
  return a3;
};
var right = (right33) => {
  const a3 = Object.create(RightProto);
  a3.right = right33;
  return a3;
};
var getLeft = (self2) => isRight(self2) ? none : some2(self2.left);
var getRight = (self2) => isLeft(self2) ? none : some2(self2.right);
var right2 = right;
var left2 = left;
var Option_exports = {};
__export2(Option_exports, {
  Do: () => Do,
  TypeId: () => TypeId3,
  all: () => all2,
  andThen: () => andThen,
  ap: () => ap,
  as: () => as,
  asVoid: () => asVoid,
  bind: () => bind2,
  bindTo: () => bindTo2,
  composeK: () => composeK,
  contains: () => contains,
  containsWith: () => containsWith,
  exists: () => exists,
  filter: () => filter,
  filterMap: () => filterMap,
  firstSomeOf: () => firstSomeOf,
  flatMap: () => flatMap,
  flatMapNullable: () => flatMapNullable,
  flatten: () => flatten,
  fromIterable: () => fromIterable,
  fromNullable: () => fromNullable,
  gen: () => gen,
  getEquivalence: () => getEquivalence,
  getLeft: () => getLeft2,
  getOrElse: () => getOrElse,
  getOrNull: () => getOrNull,
  getOrThrow: () => getOrThrow,
  getOrThrowWith: () => getOrThrowWith,
  getOrUndefined: () => getOrUndefined,
  getOrder: () => getOrder,
  getRight: () => getRight2,
  isNone: () => isNone2,
  isOption: () => isOption2,
  isSome: () => isSome2,
  let: () => let_2,
  lift2: () => lift2,
  liftNullable: () => liftNullable,
  liftPredicate: () => liftPredicate,
  liftThrowable: () => liftThrowable,
  map: () => map,
  match: () => match2,
  none: () => none2,
  orElse: () => orElse,
  orElseEither: () => orElseEither,
  orElseSome: () => orElseSome,
  partitionMap: () => partitionMap,
  product: () => product2,
  productMany: () => productMany2,
  reduceCompact: () => reduceCompact,
  some: () => some3,
  tap: () => tap,
  toArray: () => toArray,
  toRefinement: () => toRefinement,
  void: () => void_,
  zipLeft: () => zipLeft,
  zipRight: () => zipRight,
  zipWith: () => zipWith
});
var make2 = (compare) => (self2, that) => self2 === that ? 0 : compare(self2, that);
var TypeId3 = /* @__PURE__ */ Symbol.for("effect/Option");
var none2 = () => none;
var some3 = some2;
var isOption2 = isOption;
var isNone2 = isNone;
var isSome2 = isSome;
var match2 = /* @__PURE__ */ dual(2, (self2, {
  onNone,
  onSome
}) => isNone2(self2) ? onNone() : onSome(self2.value));
var toRefinement = (f3) => (a3) => isSome2(f3(a3));
var fromIterable = (collection) => {
  for (const a3 of collection) {
    return some3(a3);
  }
  return none2();
};
var getRight2 = getRight;
var getLeft2 = getLeft;
var getOrElse = /* @__PURE__ */ dual(2, (self2, onNone) => isNone2(self2) ? onNone() : self2.value);
var orElse = /* @__PURE__ */ dual(2, (self2, that) => isNone2(self2) ? that() : self2);
var orElseSome = /* @__PURE__ */ dual(2, (self2, onNone) => isNone2(self2) ? some3(onNone()) : self2);
var orElseEither = /* @__PURE__ */ dual(2, (self2, that) => isNone2(self2) ? map(that(), right) : map(self2, left));
var firstSomeOf = (collection) => {
  let out = none2();
  for (out of collection) {
    if (isSome2(out)) {
      return out;
    }
  }
  return out;
};
var fromNullable = (nullableValue) => nullableValue == null ? none2() : some3(nullableValue);
var liftNullable = (f3) => (...a3) => fromNullable(f3(...a3));
var getOrNull = /* @__PURE__ */ getOrElse(constNull);
var getOrUndefined = /* @__PURE__ */ getOrElse(constUndefined);
var liftThrowable = (f3) => (...a3) => {
  try {
    return some3(f3(...a3));
  } catch (e3) {
    return none2();
  }
};
var getOrThrowWith = /* @__PURE__ */ dual(2, (self2, onNone) => {
  if (isSome2(self2)) {
    return self2.value;
  }
  throw onNone();
});
var getOrThrow = /* @__PURE__ */ getOrThrowWith(() => new Error("getOrThrow called on a None"));
var map = /* @__PURE__ */ dual(2, (self2, f3) => isNone2(self2) ? none2() : some3(f3(self2.value)));
var as = /* @__PURE__ */ dual(2, (self2, b3) => map(self2, () => b3));
var asVoid = /* @__PURE__ */ as(void 0);
var void_ = /* @__PURE__ */ some3(void 0);
var flatMap = /* @__PURE__ */ dual(2, (self2, f3) => isNone2(self2) ? none2() : f3(self2.value));
var andThen = /* @__PURE__ */ dual(2, (self2, f3) => flatMap(self2, (a3) => {
  const b3 = isFunction2(f3) ? f3(a3) : f3;
  return isOption2(b3) ? b3 : some3(b3);
}));
var flatMapNullable = /* @__PURE__ */ dual(2, (self2, f3) => isNone2(self2) ? none2() : fromNullable(f3(self2.value)));
var flatten = /* @__PURE__ */ flatMap(identity);
var zipRight = /* @__PURE__ */ dual(2, (self2, that) => flatMap(self2, () => that));
var composeK = /* @__PURE__ */ dual(2, (afb, bfc) => (a3) => flatMap(afb(a3), bfc));
var zipLeft = /* @__PURE__ */ dual(2, (self2, that) => tap(self2, () => that));
var tap = /* @__PURE__ */ dual(2, (self2, f3) => flatMap(self2, (a3) => map(f3(a3), () => a3)));
var product2 = (self2, that) => isSome2(self2) && isSome2(that) ? some3([self2.value, that.value]) : none2();
var productMany2 = (self2, collection) => {
  if (isNone2(self2)) {
    return none2();
  }
  const out = [self2.value];
  for (const o3 of collection) {
    if (isNone2(o3)) {
      return none2();
    }
    out.push(o3.value);
  }
  return some3(out);
};
var all2 = (input) => {
  if (Symbol.iterator in input) {
    const out2 = [];
    for (const o3 of input) {
      if (isNone2(o3)) {
        return none2();
      }
      out2.push(o3.value);
    }
    return some3(out2);
  }
  const out = {};
  for (const key of Object.keys(input)) {
    const o3 = input[key];
    if (isNone2(o3)) {
      return none2();
    }
    out[key] = o3.value;
  }
  return some3(out);
};
var zipWith = /* @__PURE__ */ dual(3, (self2, that, f3) => map(product2(self2, that), ([a3, b3]) => f3(a3, b3)));
var ap = /* @__PURE__ */ dual(2, (self2, that) => zipWith(self2, that, (f3, a3) => f3(a3)));
var reduceCompact = /* @__PURE__ */ dual(3, (self2, b3, f3) => {
  let out = b3;
  for (const oa of self2) {
    if (isSome2(oa)) {
      out = f3(out, oa.value);
    }
  }
  return out;
});
var toArray = (self2) => isNone2(self2) ? [] : [self2.value];
var partitionMap = /* @__PURE__ */ dual(2, (self2, f3) => {
  if (isNone2(self2)) {
    return [none2(), none2()];
  }
  const e3 = f3(self2.value);
  return isLeft(e3) ? [some3(e3.left), none2()] : [none2(), some3(e3.right)];
});
var filterMap = /* @__PURE__ */ dual(2, (self2, f3) => isNone2(self2) ? none2() : f3(self2.value));
var filter = /* @__PURE__ */ dual(2, (self2, predicate) => filterMap(self2, (b3) => predicate(b3) ? some2(b3) : none));
var getEquivalence = (isEquivalent) => make((x3, y3) => x3 === y3 || (isNone2(x3) ? isNone2(y3) : isNone2(y3) ? false : isEquivalent(x3.value, y3.value)));
var getOrder = (O3) => make2((self2, that) => isSome2(self2) ? isSome2(that) ? O3(self2.value, that.value) : 1 : -1);
var lift2 = (f3) => dual(2, (self2, that) => zipWith(self2, that, f3));
var liftPredicate = (predicate) => (b3) => predicate(b3) ? some3(b3) : none2();
var containsWith = (isEquivalent) => dual(2, (self2, a3) => isNone2(self2) ? false : isEquivalent(self2.value, a3));
var _equivalence = /* @__PURE__ */ equivalence();
var contains = /* @__PURE__ */ containsWith(_equivalence);
var exists = /* @__PURE__ */ dual(2, (self2, refinement) => isNone2(self2) ? false : refinement(self2.value));
var bindTo2 = /* @__PURE__ */ bindTo(map);
var let_2 = /* @__PURE__ */ let_(map);
var bind2 = /* @__PURE__ */ bind(map, flatMap);
var Do = /* @__PURE__ */ some3({});
var adapter2 = /* @__PURE__ */ adapter();
var gen = (f3) => {
  const iterator = f3(adapter2);
  let state = iterator.next();
  if (state.done) {
    return some3(state.value);
  } else {
    let current = state.value;
    if (isGenKind(current)) {
      current = current.value;
    } else {
      current = yieldWrapGet(current);
    }
    if (isNone2(current)) {
      return current;
    }
    while (!state.done) {
      state = iterator.next(current.value);
      if (!state.done) {
        current = state.value;
        if (isGenKind(current)) {
          current = current.value;
        } else {
          current = yieldWrapGet(current);
        }
        if (isNone2(current)) {
          return current;
        }
      }
    }
    return some3(state.value);
  }
};
var fromIterable2 = (collection) => Array.isArray(collection) ? collection : Array.from(collection);
var reverse = (self2) => Array.from(self2).reverse();
var reduce = /* @__PURE__ */ dual(3, (self2, b3, f3) => fromIterable2(self2).reduce((b22, a3, i3) => f3(b22, a3, i3), b3));
var TagTypeId = /* @__PURE__ */ Symbol.for("effect/Context/Tag");
var STMSymbolKey = "effect/STM";
var STMTypeId = /* @__PURE__ */ Symbol.for(STMSymbolKey);
var TagProto = {
  ...EffectPrototype,
  _tag: "Tag",
  _op: "Tag",
  [STMTypeId]: effectVariance,
  [TagTypeId]: {
    _Service: (_3) => _3,
    _Identifier: (_3) => _3
  },
  toString() {
    return format(this.toJSON());
  },
  toJSON() {
    return {
      _id: "Tag",
      key: this.key,
      stack: this.stack
    };
  },
  [NodeInspectSymbol]() {
    return this.toJSON();
  },
  of(self2) {
    return self2;
  },
  context(self2) {
    return make3(this, self2);
  }
};
var makeGenericTag = (key) => {
  const limit = Error.stackTraceLimit;
  Error.stackTraceLimit = 2;
  const creationError = new Error();
  Error.stackTraceLimit = limit;
  const tag = Object.create(TagProto);
  Object.defineProperty(tag, "stack", {
    get() {
      return creationError.stack;
    }
  });
  tag.key = key;
  return tag;
};
var TypeId4 = /* @__PURE__ */ Symbol.for("effect/Context");
var ContextProto = {
  [TypeId4]: {
    _Services: (_3) => _3
  },
  [symbol2](that) {
    if (isContext(that)) {
      if (this.unsafeMap.size === that.unsafeMap.size) {
        for (const k3 of this.unsafeMap.keys()) {
          if (!that.unsafeMap.has(k3) || !equals(this.unsafeMap.get(k3), that.unsafeMap.get(k3))) {
            return false;
          }
        }
        return true;
      }
    }
    return false;
  },
  [symbol]() {
    return cached(this, number(this.unsafeMap.size));
  },
  pipe() {
    return pipeArguments(this, arguments);
  },
  toString() {
    return format(this.toJSON());
  },
  toJSON() {
    return {
      _id: "Context",
      services: Array.from(this.unsafeMap).map(toJSON)
    };
  },
  [NodeInspectSymbol]() {
    return this.toJSON();
  }
};
var makeContext = (unsafeMap) => {
  const context = Object.create(ContextProto);
  context.unsafeMap = unsafeMap;
  return context;
};
var isContext = (u3) => hasProperty(u3, TypeId4);
var _empty = /* @__PURE__ */ makeContext(/* @__PURE__ */ new Map());
var empty = () => _empty;
var make3 = (tag, service) => makeContext(/* @__PURE__ */ new Map([[tag.key, service]]));
var GenericTag = makeGenericTag;
var empty2 = empty;
var TypeId5 = /* @__PURE__ */ Symbol.for("effect/Chunk");
function copy(src, srcPos, dest, destPos, len) {
  for (let i3 = srcPos; i3 < Math.min(src.length, srcPos + len); i3++) {
    dest[destPos + i3 - srcPos] = src[i3];
  }
  return dest;
}
var emptyArray = [];
var getEquivalence2 = (isEquivalent) => make((self2, that) => self2.length === that.length && toReadonlyArray(self2).every((value, i3) => isEquivalent(value, unsafeGet2(that, i3))));
var _equivalence2 = /* @__PURE__ */ getEquivalence2(equals);
var ChunkProto = {
  [TypeId5]: {
    _A: (_3) => _3
  },
  toString() {
    return format(this.toJSON());
  },
  toJSON() {
    return {
      _id: "Chunk",
      values: toReadonlyArray(this).map(toJSON)
    };
  },
  [NodeInspectSymbol]() {
    return this.toJSON();
  },
  [symbol2](that) {
    return isChunk(that) && _equivalence2(this, that);
  },
  [symbol]() {
    return cached(this, array(toReadonlyArray(this)));
  },
  [Symbol.iterator]() {
    switch (this.backing._tag) {
      case "IArray": {
        return this.backing.array[Symbol.iterator]();
      }
      case "IEmpty": {
        return emptyArray[Symbol.iterator]();
      }
      default: {
        return toReadonlyArray(this)[Symbol.iterator]();
      }
    }
  },
  pipe() {
    return pipeArguments(this, arguments);
  }
};
var makeChunk = (backing) => {
  const chunk = Object.create(ChunkProto);
  chunk.backing = backing;
  switch (backing._tag) {
    case "IEmpty": {
      chunk.length = 0;
      chunk.depth = 0;
      chunk.left = chunk;
      chunk.right = chunk;
      break;
    }
    case "IConcat": {
      chunk.length = backing.left.length + backing.right.length;
      chunk.depth = 1 + Math.max(backing.left.depth, backing.right.depth);
      chunk.left = backing.left;
      chunk.right = backing.right;
      break;
    }
    case "IArray": {
      chunk.length = backing.array.length;
      chunk.depth = 0;
      chunk.left = _empty2;
      chunk.right = _empty2;
      break;
    }
    case "ISingleton": {
      chunk.length = 1;
      chunk.depth = 0;
      chunk.left = _empty2;
      chunk.right = _empty2;
      break;
    }
    case "ISlice": {
      chunk.length = backing.length;
      chunk.depth = backing.chunk.depth + 1;
      chunk.left = _empty2;
      chunk.right = _empty2;
      break;
    }
  }
  return chunk;
};
var isChunk = (u3) => hasProperty(u3, TypeId5);
var _empty2 = /* @__PURE__ */ makeChunk({
  _tag: "IEmpty"
});
var empty3 = () => _empty2;
var make4 = (...as24) => as24.length === 1 ? of(as24[0]) : unsafeFromNonEmptyArray(as24);
var of = (a3) => makeChunk({
  _tag: "ISingleton",
  a: a3
});
var copyToArray = (self2, array33, initial) => {
  switch (self2.backing._tag) {
    case "IArray": {
      copy(self2.backing.array, 0, array33, initial, self2.length);
      break;
    }
    case "IConcat": {
      copyToArray(self2.left, array33, initial);
      copyToArray(self2.right, array33, initial + self2.left.length);
      break;
    }
    case "ISingleton": {
      array33[initial] = self2.backing.a;
      break;
    }
    case "ISlice": {
      let i3 = 0;
      let j3 = initial;
      while (i3 < self2.length) {
        array33[j3] = unsafeGet2(self2, i3);
        i3 += 1;
        j3 += 1;
      }
      break;
    }
  }
};
var toReadonlyArray = (self2) => {
  switch (self2.backing._tag) {
    case "IEmpty": {
      return emptyArray;
    }
    case "IArray": {
      return self2.backing.array;
    }
    default: {
      const arr = new Array(self2.length);
      copyToArray(self2, arr, 0);
      self2.backing = {
        _tag: "IArray",
        array: arr
      };
      self2.left = _empty2;
      self2.right = _empty2;
      self2.depth = 0;
      return arr;
    }
  }
};
var reverse2 = (self2) => {
  switch (self2.backing._tag) {
    case "IEmpty":
    case "ISingleton":
      return self2;
    case "IArray": {
      return makeChunk({
        _tag: "IArray",
        array: reverse(self2.backing.array)
      });
    }
    case "IConcat": {
      return makeChunk({
        _tag: "IConcat",
        left: reverse2(self2.backing.right),
        right: reverse2(self2.backing.left)
      });
    }
    case "ISlice":
      return unsafeFromArray(reverse(toReadonlyArray(self2)));
  }
};
var unsafeFromArray = (self2) => makeChunk({
  _tag: "IArray",
  array: self2
});
var unsafeFromNonEmptyArray = (self2) => unsafeFromArray(self2);
var unsafeGet2 = /* @__PURE__ */ dual(2, (self2, index) => {
  switch (self2.backing._tag) {
    case "IEmpty": {
      throw new Error(`Index out of bounds`);
    }
    case "ISingleton": {
      if (index !== 0) {
        throw new Error(`Index out of bounds`);
      }
      return self2.backing.a;
    }
    case "IArray": {
      if (index >= self2.length || index < 0) {
        throw new Error(`Index out of bounds`);
      }
      return self2.backing.array[index];
    }
    case "IConcat": {
      return index < self2.left.length ? unsafeGet2(self2.left, index) : unsafeGet2(self2.right, index - self2.left.length);
    }
    case "ISlice": {
      return unsafeGet2(self2.backing.chunk, index + self2.backing.offset);
    }
  }
});
var prepend = /* @__PURE__ */ dual(2, (self2, elem) => appendAll(of(elem), self2));
var drop = /* @__PURE__ */ dual(2, (self2, n3) => {
  if (n3 <= 0) {
    return self2;
  } else if (n3 >= self2.length) {
    return _empty2;
  } else {
    switch (self2.backing._tag) {
      case "ISlice": {
        return makeChunk({
          _tag: "ISlice",
          chunk: self2.backing.chunk,
          offset: self2.backing.offset + n3,
          length: self2.backing.length - n3
        });
      }
      case "IConcat": {
        if (n3 > self2.left.length) {
          return drop(self2.right, n3 - self2.left.length);
        }
        return makeChunk({
          _tag: "IConcat",
          left: drop(self2.left, n3),
          right: self2.right
        });
      }
      default: {
        return makeChunk({
          _tag: "ISlice",
          chunk: self2,
          offset: n3,
          length: self2.length - n3
        });
      }
    }
  }
});
var appendAll = /* @__PURE__ */ dual(2, (self2, that) => {
  if (self2.backing._tag === "IEmpty") {
    return that;
  }
  if (that.backing._tag === "IEmpty") {
    return self2;
  }
  const diff23 = that.depth - self2.depth;
  if (Math.abs(diff23) <= 1) {
    return makeChunk({
      _tag: "IConcat",
      left: self2,
      right: that
    });
  } else if (diff23 < -1) {
    if (self2.left.depth >= self2.right.depth) {
      const nr = appendAll(self2.right, that);
      return makeChunk({
        _tag: "IConcat",
        left: self2.left,
        right: nr
      });
    } else {
      const nrr = appendAll(self2.right.right, that);
      if (nrr.depth === self2.depth - 3) {
        const nr = makeChunk({
          _tag: "IConcat",
          left: self2.right.left,
          right: nrr
        });
        return makeChunk({
          _tag: "IConcat",
          left: self2.left,
          right: nr
        });
      } else {
        const nl = makeChunk({
          _tag: "IConcat",
          left: self2.left,
          right: self2.right.left
        });
        return makeChunk({
          _tag: "IConcat",
          left: nl,
          right: nrr
        });
      }
    }
  } else {
    if (that.right.depth >= that.left.depth) {
      const nl = appendAll(self2, that.left);
      return makeChunk({
        _tag: "IConcat",
        left: nl,
        right: that.right
      });
    } else {
      const nll = appendAll(self2, that.left.left);
      if (nll.depth === that.depth - 3) {
        const nl = makeChunk({
          _tag: "IConcat",
          left: nll,
          right: that.left.right
        });
        return makeChunk({
          _tag: "IConcat",
          left: nl,
          right: that.right
        });
      } else {
        const nr = makeChunk({
          _tag: "IConcat",
          left: that.left.right,
          right: that.right
        });
        return makeChunk({
          _tag: "IConcat",
          left: nll,
          right: nr
        });
      }
    }
  }
});
var isEmpty = (self2) => self2.length === 0;
var isNonEmpty = (self2) => self2.length > 0;
var unsafeHead = (self2) => unsafeGet2(self2, 0);
var headNonEmpty = unsafeHead;
var tailNonEmpty = (self2) => drop(self2, 1);
var SIZE = 5;
var BUCKET_SIZE = /* @__PURE__ */ Math.pow(2, SIZE);
var MASK = BUCKET_SIZE - 1;
var MAX_INDEX_NODE = BUCKET_SIZE / 2;
var MIN_ARRAY_NODE = BUCKET_SIZE / 4;
function popcount(x3) {
  x3 -= x3 >> 1 & 1431655765;
  x3 = (x3 & 858993459) + (x3 >> 2 & 858993459);
  x3 = x3 + (x3 >> 4) & 252645135;
  x3 += x3 >> 8;
  x3 += x3 >> 16;
  return x3 & 127;
}
function hashFragment(shift2, h3) {
  return h3 >>> shift2 & MASK;
}
function toBitmap(x3) {
  return 1 << x3;
}
function fromBitmap(bitmap, bit) {
  return popcount(bitmap & bit - 1);
}
var make5 = (value, previous) => ({
  value,
  previous
});
function arrayUpdate(mutate23, at, v3, arr) {
  let out = arr;
  if (!mutate23) {
    const len = arr.length;
    out = new Array(len);
    for (let i3 = 0; i3 < len; ++i3) out[i3] = arr[i3];
  }
  out[at] = v3;
  return out;
}
function arraySpliceOut(mutate23, at, arr) {
  const newLen = arr.length - 1;
  let i3 = 0;
  let g3 = 0;
  let out = arr;
  if (mutate23) {
    i3 = g3 = at;
  } else {
    out = new Array(newLen);
    while (i3 < at) out[g3++] = arr[i3++];
  }
  ++i3;
  while (i3 <= newLen) out[g3++] = arr[i3++];
  if (mutate23) {
    out.length = newLen;
  }
  return out;
}
function arraySpliceIn(mutate23, at, v3, arr) {
  const len = arr.length;
  if (mutate23) {
    let i22 = len;
    while (i22 >= at) arr[i22--] = arr[i22];
    arr[at] = v3;
    return arr;
  }
  let i3 = 0, g3 = 0;
  const out = new Array(len + 1);
  while (i3 < at) out[g3++] = arr[i3++];
  out[at] = v3;
  while (i3 < len) out[++g3] = arr[i3++];
  return out;
}
var EmptyNode = class _EmptyNode {
  _tag = "EmptyNode";
  modify(edit, _shift, f3, hash24, key, size43) {
    const v3 = f3(none2());
    if (isNone2(v3)) return new _EmptyNode();
    ++size43.value;
    return new LeafNode(edit, hash24, key, v3);
  }
};
function isEmptyNode(a3) {
  return isTagged(a3, "EmptyNode");
}
function isLeafNode(node) {
  return isEmptyNode(node) || node._tag === "LeafNode" || node._tag === "CollisionNode";
}
function canEditNode(node, edit) {
  return isEmptyNode(node) ? false : edit === node.edit;
}
var LeafNode = class _LeafNode {
  edit;
  hash;
  key;
  value;
  _tag = "LeafNode";
  constructor(edit, hash24, key, value) {
    this.edit = edit;
    this.hash = hash24;
    this.key = key;
    this.value = value;
  }
  modify(edit, shift2, f3, hash24, key, size43) {
    if (equals(key, this.key)) {
      const v22 = f3(this.value);
      if (v22 === this.value) return this;
      else if (isNone2(v22)) {
        --size43.value;
        return new EmptyNode();
      }
      if (canEditNode(this, edit)) {
        this.value = v22;
        return this;
      }
      return new _LeafNode(edit, hash24, key, v22);
    }
    const v3 = f3(none2());
    if (isNone2(v3)) return this;
    ++size43.value;
    return mergeLeaves(edit, shift2, this.hash, this, hash24, new _LeafNode(edit, hash24, key, v3));
  }
};
var CollisionNode = class _CollisionNode {
  edit;
  hash;
  children;
  _tag = "CollisionNode";
  constructor(edit, hash24, children) {
    this.edit = edit;
    this.hash = hash24;
    this.children = children;
  }
  modify(edit, shift2, f3, hash24, key, size43) {
    if (hash24 === this.hash) {
      const canEdit = canEditNode(this, edit);
      const list = this.updateCollisionList(canEdit, edit, this.hash, this.children, f3, key, size43);
      if (list === this.children) return this;
      return list.length > 1 ? new _CollisionNode(edit, this.hash, list) : list[0];
    }
    const v3 = f3(none2());
    if (isNone2(v3)) return this;
    ++size43.value;
    return mergeLeaves(edit, shift2, this.hash, this, hash24, new LeafNode(edit, hash24, key, v3));
  }
  updateCollisionList(mutate23, edit, hash24, list, f3, key, size43) {
    const len = list.length;
    for (let i3 = 0; i3 < len; ++i3) {
      const child = list[i3];
      if ("key" in child && equals(key, child.key)) {
        const value = child.value;
        const newValue2 = f3(value);
        if (newValue2 === value) return list;
        if (isNone2(newValue2)) {
          --size43.value;
          return arraySpliceOut(mutate23, i3, list);
        }
        return arrayUpdate(mutate23, i3, new LeafNode(edit, hash24, key, newValue2), list);
      }
    }
    const newValue = f3(none2());
    if (isNone2(newValue)) return list;
    ++size43.value;
    return arrayUpdate(mutate23, len, new LeafNode(edit, hash24, key, newValue), list);
  }
};
var IndexedNode = class _IndexedNode {
  edit;
  mask;
  children;
  _tag = "IndexedNode";
  constructor(edit, mask, children) {
    this.edit = edit;
    this.mask = mask;
    this.children = children;
  }
  modify(edit, shift2, f3, hash24, key, size43) {
    const mask = this.mask;
    const children = this.children;
    const frag = hashFragment(shift2, hash24);
    const bit = toBitmap(frag);
    const indx = fromBitmap(mask, bit);
    const exists24 = mask & bit;
    const canEdit = canEditNode(this, edit);
    if (!exists24) {
      const _newChild = new EmptyNode().modify(edit, shift2 + SIZE, f3, hash24, key, size43);
      if (!_newChild) return this;
      return children.length >= MAX_INDEX_NODE ? expand(edit, frag, _newChild, mask, children) : new _IndexedNode(edit, mask | bit, arraySpliceIn(canEdit, indx, _newChild, children));
    }
    const current = children[indx];
    const child = current.modify(edit, shift2 + SIZE, f3, hash24, key, size43);
    if (current === child) return this;
    let bitmap = mask;
    let newChildren;
    if (isEmptyNode(child)) {
      bitmap &= ~bit;
      if (!bitmap) return new EmptyNode();
      if (children.length <= 2 && isLeafNode(children[indx ^ 1])) {
        return children[indx ^ 1];
      }
      newChildren = arraySpliceOut(canEdit, indx, children);
    } else {
      newChildren = arrayUpdate(canEdit, indx, child, children);
    }
    if (canEdit) {
      this.mask = bitmap;
      this.children = newChildren;
      return this;
    }
    return new _IndexedNode(edit, bitmap, newChildren);
  }
};
var ArrayNode = class _ArrayNode {
  edit;
  size;
  children;
  _tag = "ArrayNode";
  constructor(edit, size43, children) {
    this.edit = edit;
    this.size = size43;
    this.children = children;
  }
  modify(edit, shift2, f3, hash24, key, size43) {
    let count = this.size;
    const children = this.children;
    const frag = hashFragment(shift2, hash24);
    const child = children[frag];
    const newChild = (child || new EmptyNode()).modify(edit, shift2 + SIZE, f3, hash24, key, size43);
    if (child === newChild) return this;
    const canEdit = canEditNode(this, edit);
    let newChildren;
    if (isEmptyNode(child) && !isEmptyNode(newChild)) {
      ++count;
      newChildren = arrayUpdate(canEdit, frag, newChild, children);
    } else if (!isEmptyNode(child) && isEmptyNode(newChild)) {
      --count;
      if (count <= MIN_ARRAY_NODE) {
        return pack(edit, count, frag, children);
      }
      newChildren = arrayUpdate(canEdit, frag, new EmptyNode(), children);
    } else {
      newChildren = arrayUpdate(canEdit, frag, newChild, children);
    }
    if (canEdit) {
      this.size = count;
      this.children = newChildren;
      return this;
    }
    return new _ArrayNode(edit, count, newChildren);
  }
};
function pack(edit, count, removed, elements) {
  const children = new Array(count - 1);
  let g3 = 0;
  let bitmap = 0;
  for (let i3 = 0, len = elements.length; i3 < len; ++i3) {
    if (i3 !== removed) {
      const elem = elements[i3];
      if (elem && !isEmptyNode(elem)) {
        children[g3++] = elem;
        bitmap |= 1 << i3;
      }
    }
  }
  return new IndexedNode(edit, bitmap, children);
}
function expand(edit, frag, child, bitmap, subNodes) {
  const arr = [];
  let bit = bitmap;
  let count = 0;
  for (let i3 = 0; bit; ++i3) {
    if (bit & 1) arr[i3] = subNodes[count++];
    bit >>>= 1;
  }
  arr[frag] = child;
  return new ArrayNode(edit, count + 1, arr);
}
function mergeLeavesInner(edit, shift2, h1, n1, h22, n22) {
  if (h1 === h22) return new CollisionNode(edit, h1, [n22, n1]);
  const subH1 = hashFragment(shift2, h1);
  const subH2 = hashFragment(shift2, h22);
  if (subH1 === subH2) {
    return (child) => new IndexedNode(edit, toBitmap(subH1) | toBitmap(subH2), [child]);
  } else {
    const children = subH1 < subH2 ? [n1, n22] : [n22, n1];
    return new IndexedNode(edit, toBitmap(subH1) | toBitmap(subH2), children);
  }
}
function mergeLeaves(edit, shift2, h1, n1, h22, n22) {
  let stack = void 0;
  let currentShift = shift2;
  while (true) {
    const res = mergeLeavesInner(edit, currentShift, h1, n1, h22, n22);
    if (typeof res === "function") {
      stack = make5(res, stack);
      currentShift = currentShift + SIZE;
    } else {
      let final = res;
      while (stack != null) {
        final = stack.value(final);
        stack = stack.previous;
      }
      return final;
    }
  }
}
var HashMapSymbolKey = "effect/HashMap";
var HashMapTypeId = /* @__PURE__ */ Symbol.for(HashMapSymbolKey);
var HashMapProto = {
  [HashMapTypeId]: HashMapTypeId,
  [Symbol.iterator]() {
    return new HashMapIterator(this, (k3, v3) => [k3, v3]);
  },
  [symbol]() {
    let hash24 = hash(HashMapSymbolKey);
    for (const item of this) {
      hash24 ^= pipe(hash(item[0]), combine(hash(item[1])));
    }
    return cached(this, hash24);
  },
  [symbol2](that) {
    if (isHashMap(that)) {
      if (that._size !== this._size) {
        return false;
      }
      for (const item of this) {
        const elem = pipe(that, getHash(item[0], hash(item[0])));
        if (isNone2(elem)) {
          return false;
        } else {
          if (!equals(item[1], elem.value)) {
            return false;
          }
        }
      }
      return true;
    }
    return false;
  },
  toString() {
    return format(this.toJSON());
  },
  toJSON() {
    return {
      _id: "HashMap",
      values: Array.from(this).map(toJSON)
    };
  },
  [NodeInspectSymbol]() {
    return this.toJSON();
  },
  pipe() {
    return pipeArguments(this, arguments);
  }
};
var makeImpl = (editable, edit, root, size43) => {
  const map62 = Object.create(HashMapProto);
  map62._editable = editable;
  map62._edit = edit;
  map62._root = root;
  map62._size = size43;
  return map62;
};
var HashMapIterator = class _HashMapIterator {
  map;
  f;
  v;
  constructor(map62, f3) {
    this.map = map62;
    this.f = f3;
    this.v = visitLazy(this.map._root, this.f, void 0);
  }
  next() {
    if (isNone2(this.v)) {
      return {
        done: true,
        value: void 0
      };
    }
    const v0 = this.v.value;
    this.v = applyCont(v0.cont);
    return {
      done: false,
      value: v0.value
    };
  }
  [Symbol.iterator]() {
    return new _HashMapIterator(this.map, this.f);
  }
};
var applyCont = (cont) => cont ? visitLazyChildren(cont[0], cont[1], cont[2], cont[3], cont[4]) : none2();
var visitLazy = (node, f3, cont = void 0) => {
  switch (node._tag) {
    case "LeafNode": {
      if (isSome2(node.value)) {
        return some3({
          value: f3(node.key, node.value.value),
          cont
        });
      }
      return applyCont(cont);
    }
    case "CollisionNode":
    case "ArrayNode":
    case "IndexedNode": {
      const children = node.children;
      return visitLazyChildren(children.length, children, 0, f3, cont);
    }
    default: {
      return applyCont(cont);
    }
  }
};
var visitLazyChildren = (len, children, i3, f3, cont) => {
  while (i3 < len) {
    const child = children[i3++];
    if (child && !isEmptyNode(child)) {
      return visitLazy(child, f3, [len, children, i3, f3, cont]);
    }
  }
  return applyCont(cont);
};
var _empty3 = /* @__PURE__ */ makeImpl(false, 0, /* @__PURE__ */ new EmptyNode(), 0);
var empty4 = () => _empty3;
var isHashMap = (u3) => hasProperty(u3, HashMapTypeId);
var getHash = /* @__PURE__ */ dual(3, (self2, key, hash24) => {
  let node = self2._root;
  let shift2 = 0;
  while (true) {
    switch (node._tag) {
      case "LeafNode": {
        return equals(key, node.key) ? node.value : none2();
      }
      case "CollisionNode": {
        if (hash24 === node.hash) {
          const children = node.children;
          for (let i3 = 0, len = children.length; i3 < len; ++i3) {
            const child = children[i3];
            if ("key" in child && equals(key, child.key)) {
              return child.value;
            }
          }
        }
        return none2();
      }
      case "IndexedNode": {
        const frag = hashFragment(shift2, hash24);
        const bit = toBitmap(frag);
        if (node.mask & bit) {
          node = node.children[fromBitmap(node.mask, bit)];
          shift2 += SIZE;
          break;
        }
        return none2();
      }
      case "ArrayNode": {
        node = node.children[hashFragment(shift2, hash24)];
        if (node) {
          shift2 += SIZE;
          break;
        }
        return none2();
      }
      default:
        return none2();
    }
  }
});
var set = /* @__PURE__ */ dual(3, (self2, key, value) => modifyAt(self2, key, () => some3(value)));
var setTree = /* @__PURE__ */ dual(3, (self2, newRoot, newSize) => {
  if (self2._editable) {
    self2._root = newRoot;
    self2._size = newSize;
    return self2;
  }
  return newRoot === self2._root ? self2 : makeImpl(self2._editable, self2._edit, newRoot, newSize);
});
var keys = (self2) => new HashMapIterator(self2, (key) => key);
var size = (self2) => self2._size;
var beginMutation = (self2) => makeImpl(true, self2._edit + 1, self2._root, self2._size);
var modifyAt = /* @__PURE__ */ dual(3, (self2, key, f3) => modifyHash(self2, key, hash(key), f3));
var modifyHash = /* @__PURE__ */ dual(4, (self2, key, hash24, f3) => {
  const size43 = {
    value: self2._size
  };
  const newRoot = self2._root.modify(self2._editable ? self2._edit : NaN, 0, f3, hash24, key, size43);
  return pipe(self2, setTree(newRoot, size43.value));
});
var forEach = /* @__PURE__ */ dual(2, (self2, f3) => reduce2(self2, void 0, (_3, value, key) => f3(value, key)));
var reduce2 = /* @__PURE__ */ dual(3, (self2, zero, f3) => {
  const root = self2._root;
  if (root._tag === "LeafNode") {
    return isSome2(root.value) ? f3(zero, root.value.value, root.key) : zero;
  }
  if (root._tag === "EmptyNode") {
    return zero;
  }
  const toVisit = [root.children];
  let children;
  while (children = toVisit.pop()) {
    for (let i3 = 0, len = children.length; i3 < len; ) {
      const child = children[i3++];
      if (child && !isEmptyNode(child)) {
        if (child._tag === "LeafNode") {
          if (isSome2(child.value)) {
            zero = f3(zero, child.value.value, child.key);
          }
        } else {
          toVisit.push(child.children);
        }
      }
    }
  }
  return zero;
});
var HashSetSymbolKey = "effect/HashSet";
var HashSetTypeId = /* @__PURE__ */ Symbol.for(HashSetSymbolKey);
var HashSetProto = {
  [HashSetTypeId]: HashSetTypeId,
  [Symbol.iterator]() {
    return keys(this._keyMap);
  },
  [symbol]() {
    return cached(this, combine(hash(this._keyMap))(hash(HashSetSymbolKey)));
  },
  [symbol2](that) {
    if (isHashSet(that)) {
      return size(this._keyMap) === size(that._keyMap) && equals(this._keyMap, that._keyMap);
    }
    return false;
  },
  toString() {
    return format(this.toJSON());
  },
  toJSON() {
    return {
      _id: "HashSet",
      values: Array.from(this).map(toJSON)
    };
  },
  [NodeInspectSymbol]() {
    return this.toJSON();
  },
  pipe() {
    return pipeArguments(this, arguments);
  }
};
var makeImpl2 = (keyMap) => {
  const set24 = Object.create(HashSetProto);
  set24._keyMap = keyMap;
  return set24;
};
var isHashSet = (u3) => hasProperty(u3, HashSetTypeId);
var _empty4 = /* @__PURE__ */ makeImpl2(/* @__PURE__ */ empty4());
var empty5 = () => _empty4;
var size2 = (self2) => size(self2._keyMap);
var beginMutation2 = (self2) => makeImpl2(beginMutation(self2._keyMap));
var endMutation = (self2) => {
  self2._keyMap._editable = false;
  return self2;
};
var mutate = /* @__PURE__ */ dual(2, (self2, f3) => {
  const transient = beginMutation2(self2);
  f3(transient);
  return endMutation(transient);
});
var add2 = /* @__PURE__ */ dual(2, (self2, value) => self2._keyMap._editable ? (set(value, true)(self2._keyMap), self2) : makeImpl2(set(value, true)(self2._keyMap)));
var union2 = /* @__PURE__ */ dual(2, (self2, that) => mutate(empty5(), (set24) => {
  forEach2(self2, (value) => add2(set24, value));
  for (const value of that) {
    add2(set24, value);
  }
}));
var forEach2 = /* @__PURE__ */ dual(2, (self2, f3) => forEach(self2._keyMap, (_3, k3) => f3(k3)));
var empty6 = empty5;
var size3 = size2;
var add3 = add2;
var union3 = union2;
var ArrayProto = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(Array.prototype), {
  [symbol]() {
    return cached(this, array(this));
  },
  [symbol2](that) {
    if (Array.isArray(that) && this.length === that.length) {
      return this.every((v3, i3) => equals(v3, that[i3]));
    } else {
      return false;
    }
  }
});
var Structural = /* @__PURE__ */ function() {
  function Structural33(args) {
    if (args) {
      Object.assign(this, args);
    }
  }
  Structural33.prototype = StructuralPrototype;
  return Structural33;
}();
var struct2 = (as24) => Object.assign(Object.create(StructuralPrototype), as24);
var ContextPatchTypeId = /* @__PURE__ */ Symbol.for("effect/DifferContextPatch");
function variance(a3) {
  return a3;
}
var PatchProto = {
  ...Structural.prototype,
  [ContextPatchTypeId]: {
    _Value: variance,
    _Patch: variance
  }
};
var EmptyProto = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(PatchProto), {
  _tag: "Empty"
});
var _empty5 = /* @__PURE__ */ Object.create(EmptyProto);
var empty7 = () => _empty5;
var AndThenProto = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(PatchProto), {
  _tag: "AndThen"
});
var makeAndThen = (first, second) => {
  const o3 = Object.create(AndThenProto);
  o3.first = first;
  o3.second = second;
  return o3;
};
var AddServiceProto = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(PatchProto), {
  _tag: "AddService"
});
var makeAddService = (key, service) => {
  const o3 = Object.create(AddServiceProto);
  o3.key = key;
  o3.service = service;
  return o3;
};
var RemoveServiceProto = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(PatchProto), {
  _tag: "RemoveService"
});
var makeRemoveService = (key) => {
  const o3 = Object.create(RemoveServiceProto);
  o3.key = key;
  return o3;
};
var UpdateServiceProto = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(PatchProto), {
  _tag: "UpdateService"
});
var makeUpdateService = (key, update22) => {
  const o3 = Object.create(UpdateServiceProto);
  o3.key = key;
  o3.update = update22;
  return o3;
};
var diff = (oldValue, newValue) => {
  const missingServices = new Map(oldValue.unsafeMap);
  let patch23 = empty7();
  for (const [tag, newService] of newValue.unsafeMap.entries()) {
    if (missingServices.has(tag)) {
      const old = missingServices.get(tag);
      missingServices.delete(tag);
      if (!equals(old, newService)) {
        patch23 = combine2(makeUpdateService(tag, () => newService))(patch23);
      }
    } else {
      missingServices.delete(tag);
      patch23 = combine2(makeAddService(tag, newService))(patch23);
    }
  }
  for (const [tag] of missingServices.entries()) {
    patch23 = combine2(makeRemoveService(tag))(patch23);
  }
  return patch23;
};
var combine2 = /* @__PURE__ */ dual(2, (self2, that) => makeAndThen(self2, that));
var patch = /* @__PURE__ */ dual(2, (self2, context) => {
  if (self2._tag === "Empty") {
    return context;
  }
  let wasServiceUpdated = false;
  let patches = of(self2);
  const updatedContext = new Map(context.unsafeMap);
  while (isNonEmpty(patches)) {
    const head22 = headNonEmpty(patches);
    const tail3 = tailNonEmpty(patches);
    switch (head22._tag) {
      case "Empty": {
        patches = tail3;
        break;
      }
      case "AddService": {
        updatedContext.set(head22.key, head22.service);
        patches = tail3;
        break;
      }
      case "AndThen": {
        patches = prepend(prepend(tail3, head22.second), head22.first);
        break;
      }
      case "RemoveService": {
        updatedContext.delete(head22.key);
        patches = tail3;
        break;
      }
      case "UpdateService": {
        updatedContext.set(head22.key, head22.update(updatedContext.get(head22.key)));
        wasServiceUpdated = true;
        patches = tail3;
        break;
      }
    }
  }
  if (!wasServiceUpdated) {
    return makeContext(updatedContext);
  }
  const map62 = /* @__PURE__ */ new Map();
  for (const [tag] of context.unsafeMap) {
    if (updatedContext.has(tag)) {
      map62.set(tag, updatedContext.get(tag));
      updatedContext.delete(tag);
    }
  }
  for (const [tag, s3] of updatedContext) {
    map62.set(tag, s3);
  }
  return makeContext(map62);
});
var DifferTypeId = /* @__PURE__ */ Symbol.for("effect/Differ");
var DifferProto = {
  [DifferTypeId]: {
    _P: identity,
    _V: identity
  }
};
var make7 = (params) => {
  const differ = Object.create(DifferProto);
  differ.empty = params.empty;
  differ.diff = params.diff;
  differ.combine = params.combine;
  differ.patch = params.patch;
  return differ;
};
var environment = () => make7({
  empty: empty7(),
  combine: (first, second) => combine2(second)(first),
  diff: (oldValue, newValue) => diff(oldValue, newValue),
  patch: (patch23, oldValue) => patch(oldValue)(patch23)
});
var OP_DIE = "Die";
var OP_EMPTY = "Empty";
var OP_FAIL = "Fail";
var OP_INTERRUPT = "Interrupt";
var OP_PARALLEL = "Parallel";
var OP_SEQUENTIAL = "Sequential";
var CauseSymbolKey = "effect/Cause";
var CauseTypeId = /* @__PURE__ */ Symbol.for(CauseSymbolKey);
var variance2 = {
  /* c8 ignore next */
  _E: (_3) => _3
};
var proto = {
  [CauseTypeId]: variance2,
  [symbol]() {
    return pipe(hash(CauseSymbolKey), combine(hash(flattenCause(this))), cached(this));
  },
  [symbol2](that) {
    return isCause(that) && causeEquals(this, that);
  },
  pipe() {
    return pipeArguments(this, arguments);
  },
  toJSON() {
    switch (this._tag) {
      case "Empty":
        return {
          _id: "Cause",
          _tag: this._tag
        };
      case "Die":
        return {
          _id: "Cause",
          _tag: this._tag,
          defect: toJSON(this.defect)
        };
      case "Interrupt":
        return {
          _id: "Cause",
          _tag: this._tag,
          fiberId: this.fiberId.toJSON()
        };
      case "Fail":
        return {
          _id: "Cause",
          _tag: this._tag,
          failure: toJSON(this.error)
        };
      case "Sequential":
      case "Parallel":
        return {
          _id: "Cause",
          _tag: this._tag,
          left: toJSON(this.left),
          right: toJSON(this.right)
        };
    }
  },
  toString() {
    return pretty(this);
  },
  [NodeInspectSymbol]() {
    return this.toJSON();
  }
};
var fail = (error) => {
  const o3 = Object.create(proto);
  o3._tag = OP_FAIL;
  o3.error = error;
  return o3;
};
var parallel = (left33, right33) => {
  const o3 = Object.create(proto);
  o3._tag = OP_PARALLEL;
  o3.left = left33;
  o3.right = right33;
  return o3;
};
var sequential = (left33, right33) => {
  const o3 = Object.create(proto);
  o3._tag = OP_SEQUENTIAL;
  o3.left = left33;
  o3.right = right33;
  return o3;
};
var isCause = (u3) => hasProperty(u3, CauseTypeId);
var isInterruptedOnly = (self2) => reduceWithContext(void 0, IsInterruptedOnlyCauseReducer)(self2);
var causeEquals = (left33, right33) => {
  let leftStack = of(left33);
  let rightStack = of(right33);
  while (isNonEmpty(leftStack) && isNonEmpty(rightStack)) {
    const [leftParallel, leftSequential] = pipe(headNonEmpty(leftStack), reduce4([empty6(), empty3()], ([parallel23, sequential23], cause) => {
      const [par, seq] = evaluateCause(cause);
      return some3([pipe(parallel23, union3(par)), pipe(sequential23, appendAll(seq))]);
    }));
    const [rightParallel, rightSequential] = pipe(headNonEmpty(rightStack), reduce4([empty6(), empty3()], ([parallel23, sequential23], cause) => {
      const [par, seq] = evaluateCause(cause);
      return some3([pipe(parallel23, union3(par)), pipe(sequential23, appendAll(seq))]);
    }));
    if (!equals(leftParallel, rightParallel)) {
      return false;
    }
    leftStack = leftSequential;
    rightStack = rightSequential;
  }
  return true;
};
var flattenCause = (cause) => {
  return flattenCauseLoop(of(cause), empty3());
};
var flattenCauseLoop = (causes, flattened) => {
  while (1) {
    const [parallel23, sequential23] = pipe(causes, reduce([empty6(), empty3()], ([parallel32, sequential32], cause) => {
      const [par, seq] = evaluateCause(cause);
      return [pipe(parallel32, union3(par)), pipe(sequential32, appendAll(seq))];
    }));
    const updated = size3(parallel23) > 0 ? pipe(flattened, prepend(parallel23)) : flattened;
    if (isEmpty(sequential23)) {
      return reverse2(updated);
    }
    causes = sequential23;
    flattened = updated;
  }
  throw new Error(getBugErrorMessage("Cause.flattenCauseLoop"));
};
var evaluateCause = (self2) => {
  let cause = self2;
  const stack = [];
  let _parallel = empty6();
  let _sequential = empty3();
  while (cause !== void 0) {
    switch (cause._tag) {
      case OP_EMPTY: {
        if (stack.length === 0) {
          return [_parallel, _sequential];
        }
        cause = stack.pop();
        break;
      }
      case OP_FAIL: {
        _parallel = add3(_parallel, make4(cause._tag, cause.error));
        if (stack.length === 0) {
          return [_parallel, _sequential];
        }
        cause = stack.pop();
        break;
      }
      case OP_DIE: {
        _parallel = add3(_parallel, make4(cause._tag, cause.defect));
        if (stack.length === 0) {
          return [_parallel, _sequential];
        }
        cause = stack.pop();
        break;
      }
      case OP_INTERRUPT: {
        _parallel = add3(_parallel, make4(cause._tag, cause.fiberId));
        if (stack.length === 0) {
          return [_parallel, _sequential];
        }
        cause = stack.pop();
        break;
      }
      case OP_SEQUENTIAL: {
        switch (cause.left._tag) {
          case OP_EMPTY: {
            cause = cause.right;
            break;
          }
          case OP_SEQUENTIAL: {
            cause = sequential(cause.left.left, sequential(cause.left.right, cause.right));
            break;
          }
          case OP_PARALLEL: {
            cause = parallel(sequential(cause.left.left, cause.right), sequential(cause.left.right, cause.right));
            break;
          }
          default: {
            _sequential = prepend(_sequential, cause.right);
            cause = cause.left;
            break;
          }
        }
        break;
      }
      case OP_PARALLEL: {
        stack.push(cause.right);
        cause = cause.left;
        break;
      }
    }
  }
  throw new Error(getBugErrorMessage("Cause.evaluateCauseLoop"));
};
var IsInterruptedOnlyCauseReducer = {
  emptyCase: constTrue,
  failCase: constFalse,
  dieCase: constFalse,
  interruptCase: constTrue,
  sequentialCase: (_3, left33, right33) => left33 && right33,
  parallelCase: (_3, left33, right33) => left33 && right33
};
var OP_SEQUENTIAL_CASE = "SequentialCase";
var OP_PARALLEL_CASE = "ParallelCase";
var reduce4 = /* @__PURE__ */ dual(3, (self2, zero, pf) => {
  let accumulator = zero;
  let cause = self2;
  const causes = [];
  while (cause !== void 0) {
    const option = pf(accumulator, cause);
    accumulator = isSome2(option) ? option.value : accumulator;
    switch (cause._tag) {
      case OP_SEQUENTIAL: {
        causes.push(cause.right);
        cause = cause.left;
        break;
      }
      case OP_PARALLEL: {
        causes.push(cause.right);
        cause = cause.left;
        break;
      }
      default: {
        cause = void 0;
        break;
      }
    }
    if (cause === void 0 && causes.length > 0) {
      cause = causes.pop();
    }
  }
  return accumulator;
});
var reduceWithContext = /* @__PURE__ */ dual(3, (self2, context, reducer) => {
  const input = [self2];
  const output = [];
  while (input.length > 0) {
    const cause = input.pop();
    switch (cause._tag) {
      case OP_EMPTY: {
        output.push(right2(reducer.emptyCase(context)));
        break;
      }
      case OP_FAIL: {
        output.push(right2(reducer.failCase(context, cause.error)));
        break;
      }
      case OP_DIE: {
        output.push(right2(reducer.dieCase(context, cause.defect)));
        break;
      }
      case OP_INTERRUPT: {
        output.push(right2(reducer.interruptCase(context, cause.fiberId)));
        break;
      }
      case OP_SEQUENTIAL: {
        input.push(cause.right);
        input.push(cause.left);
        output.push(left2({
          _tag: OP_SEQUENTIAL_CASE
        }));
        break;
      }
      case OP_PARALLEL: {
        input.push(cause.right);
        input.push(cause.left);
        output.push(left2({
          _tag: OP_PARALLEL_CASE
        }));
        break;
      }
    }
  }
  const accumulator = [];
  while (output.length > 0) {
    const either = output.pop();
    switch (either._tag) {
      case "Left": {
        switch (either.left._tag) {
          case OP_SEQUENTIAL_CASE: {
            const left33 = accumulator.pop();
            const right33 = accumulator.pop();
            const value = reducer.sequentialCase(context, left33, right33);
            accumulator.push(value);
            break;
          }
          case OP_PARALLEL_CASE: {
            const left33 = accumulator.pop();
            const right33 = accumulator.pop();
            const value = reducer.parallelCase(context, left33, right33);
            accumulator.push(value);
            break;
          }
        }
        break;
      }
      case "Right": {
        accumulator.push(either.right);
        break;
      }
    }
  }
  if (accumulator.length === 0) {
    throw new Error("BUG: Cause.reduceWithContext - please report an issue at https://github.com/Effect-TS/effect/issues");
  }
  return accumulator.pop();
});
var pretty = (cause) => {
  if (isInterruptedOnly(cause)) {
    return "All fibers interrupted without errors.";
  }
  return prettyErrors(cause).map((e3) => e3.stack).join("\n");
};
var PrettyError = class extends globalThis.Error {
  span = void 0;
  constructor(originalError) {
    const prevLimit = Error.stackTraceLimit;
    Error.stackTraceLimit = 0;
    super(prettyErrorMessage(originalError));
    Error.stackTraceLimit = prevLimit;
    this.name = originalError instanceof Error ? originalError.name : "Error";
    if (typeof originalError === "object" && originalError !== null) {
      if (spanSymbol in originalError) {
        this.span = originalError[spanSymbol];
      }
      Object.keys(originalError).forEach((key) => {
        if (!(key in this)) {
          this[key] = originalError[key];
        }
      });
    }
    this.stack = prettyErrorStack(this.message, originalError instanceof Error && originalError.stack ? originalError.stack : "", this.span);
  }
  toJSON() {
    const out = {
      message: this.message,
      stack: this.stack
    };
    if (this.span) {
      out.span = this.span;
    }
    return out;
  }
};
var prettyErrorMessage = (u3) => {
  if (typeof u3 === "string") {
    return `Error: ${u3}`;
  }
  try {
    if (hasProperty(u3, "toString") && isFunction3(u3["toString"]) && u3["toString"] !== Object.prototype.toString && u3["toString"] !== globalThis.Array.prototype.toString) {
      return u3["toString"]();
    }
  } catch {
  }
  return `Error: ${JSON.stringify(u3)}`;
};
var locationRegex = /\((.*)\)/;
var spanToTrace = /* @__PURE__ */ globalValue("effect/Tracer/spanToTrace", () => /* @__PURE__ */ new WeakMap());
var prettyErrorStack = (message, stack, span2) => {
  const out = [message];
  const lines = stack.split("\n");
  for (let i3 = 1; i3 < lines.length; i3++) {
    if (lines[i3].includes("Generator.next")) {
      break;
    }
    if (lines[i3].includes("effect_internal_function")) {
      out.pop();
      break;
    }
    out.push(lines[i3].replace(/at .*effect_instruction_i.*\((.*)\)/, "at $1").replace(/EffectPrimitive\.\w+/, "<anonymous>"));
  }
  if (span2) {
    let current = span2;
    let i3 = 0;
    while (current && current._tag === "Span" && i3 < 10) {
      const stackFn = spanToTrace.get(current);
      if (typeof stackFn === "function") {
        const stack2 = stackFn();
        const locationMatch = stack2.match(locationRegex);
        const location = locationMatch ? locationMatch[1] : stack2.replace(/^at /, "");
        out.push(`    at ${current.name} (${location})`);
      } else {
        out.push(`    at ${current.name}`);
      }
      current = getOrUndefined(current.parent);
      i3++;
    }
  }
  return out.join("\n");
};
var spanSymbol = /* @__PURE__ */ Symbol.for("effect/SpanAnnotation");
var prettyErrors = (cause) => reduceWithContext(cause, void 0, {
  emptyCase: () => [],
  dieCase: (_3, unknownError) => {
    return [new PrettyError(unknownError)];
  },
  failCase: (_3, error) => {
    return [new PrettyError(error)];
  },
  interruptCase: () => [],
  parallelCase: (_3, l3, r3) => [...l3, ...r3],
  sequentialCase: (_3, l3, r3) => [...l3, ...r3]
});
var SingleShotGen2 = class _SingleShotGen2 {
  self;
  called = false;
  constructor(self2) {
    this.self = self2;
  }
  next(a3) {
    return this.called ? {
      value: a3,
      done: true
    } : (this.called = true, {
      value: this.self,
      done: false
    });
  }
  return(a3) {
    return {
      value: a3,
      done: true
    };
  }
  throw(e3) {
    throw e3;
  }
  [Symbol.iterator]() {
    return new _SingleShotGen2(this.self);
  }
};
var spanTag = /* @__PURE__ */ GenericTag("effect/ParentSpan");
var EffectTypeId2 = /* @__PURE__ */ Symbol.for("effect/Effect");
var EffectPrimitive = class {
  _op;
  effect_instruction_i0 = void 0;
  effect_instruction_i1 = void 0;
  effect_instruction_i2 = void 0;
  trace = void 0;
  [EffectTypeId2] = effectVariance;
  constructor(_op) {
    this._op = _op;
  }
  [symbol2](that) {
    return this === that;
  }
  [symbol]() {
    return cached(this, random(this));
  }
  pipe() {
    return pipeArguments(this, arguments);
  }
  toJSON() {
    return {
      _id: "Effect",
      _op: this._op,
      effect_instruction_i0: toJSON(this.effect_instruction_i0),
      effect_instruction_i1: toJSON(this.effect_instruction_i1),
      effect_instruction_i2: toJSON(this.effect_instruction_i2)
    };
  }
  toString() {
    return format(this.toJSON());
  }
  [NodeInspectSymbol]() {
    return this.toJSON();
  }
  [Symbol.iterator]() {
    return new SingleShotGen2(new YieldWrap(this));
  }
};
var EffectPrimitiveFailure = class {
  _op;
  effect_instruction_i0 = void 0;
  effect_instruction_i1 = void 0;
  effect_instruction_i2 = void 0;
  trace = void 0;
  [EffectTypeId2] = effectVariance;
  constructor(_op) {
    this._op = _op;
    this._tag = _op;
  }
  [symbol2](that) {
    return exitIsExit(that) && that._op === "Failure" && // @ts-expect-error
    equals(this.effect_instruction_i0, that.effect_instruction_i0);
  }
  [symbol]() {
    return pipe(
      // @ts-expect-error
      string(this._tag),
      // @ts-expect-error
      combine(hash(this.effect_instruction_i0)),
      cached(this)
    );
  }
  get cause() {
    return this.effect_instruction_i0;
  }
  pipe() {
    return pipeArguments(this, arguments);
  }
  toJSON() {
    return {
      _id: "Exit",
      _tag: this._op,
      cause: this.cause.toJSON()
    };
  }
  toString() {
    return format(this.toJSON());
  }
  [NodeInspectSymbol]() {
    return this.toJSON();
  }
  [Symbol.iterator]() {
    return new SingleShotGen2(new YieldWrap(this));
  }
};
var isEffect = (u3) => hasProperty(u3, EffectTypeId2);
var withFiberRuntime = (withRuntime) => {
  const effect = new EffectPrimitive(OP_WITH_RUNTIME);
  effect.effect_instruction_i0 = withRuntime;
  return effect;
};
var spanSymbol2 = /* @__PURE__ */ Symbol.for("effect/SpanAnnotation");
var originalSymbol = /* @__PURE__ */ Symbol.for("effect/OriginalAnnotation");
var capture = (obj, span2) => {
  if (isSome2(span2)) {
    return new Proxy(obj, {
      has(target, p3) {
        return p3 === spanSymbol2 || p3 === originalSymbol || p3 in target;
      },
      get(target, p3) {
        if (p3 === spanSymbol2) {
          return span2.value;
        }
        if (p3 === originalSymbol) {
          return obj;
        }
        return target[p3];
      }
    });
  }
  return obj;
};
var fail2 = (error) => isObject(error) && !(spanSymbol2 in error) ? withFiberRuntime((fiber) => failCause(fail(capture(error, currentSpanFromFiber(fiber))))) : failCause(fail(error));
var failCause = (cause) => {
  const effect = new EffectPrimitiveFailure(OP_FAILURE);
  effect.effect_instruction_i0 = cause;
  return effect;
};
var FiberRefSymbolKey = "effect/FiberRef";
var FiberRefTypeId = /* @__PURE__ */ Symbol.for(FiberRefSymbolKey);
var fiberRefVariance = {
  /* c8 ignore next */
  _A: (_3) => _3
};
var fiberRefUnsafeMakeContext = (initial) => {
  const differ = environment();
  return fiberRefUnsafeMakePatch(initial, {
    differ,
    fork: differ.empty
  });
};
var fiberRefUnsafeMakePatch = (initial, options) => ({
  [FiberRefTypeId]: fiberRefVariance,
  initial,
  diff: (oldValue, newValue) => options.differ.diff(oldValue, newValue),
  combine: (first, second) => options.differ.combine(first, second),
  patch: (patch23) => (oldValue) => options.differ.patch(patch23, oldValue),
  fork: options.fork,
  join: options.join ?? ((_3, n3) => n3),
  pipe() {
    return pipeArguments(this, arguments);
  }
});
var currentContext = /* @__PURE__ */ globalValue(/* @__PURE__ */ Symbol.for("effect/FiberRef/currentContext"), () => fiberRefUnsafeMakeContext(empty2()));
var YieldableError = /* @__PURE__ */ function() {
  class YieldableError23 extends globalThis.Error {
    commit() {
      return fail2(this);
    }
    toString() {
      return this.message ? `${this.name}: ${this.message}` : this.name;
    }
    toJSON() {
      return {
        ...this
      };
    }
    [NodeInspectSymbol]() {
      const stack = this.stack;
      if (stack) {
        return `${this.toString()}
${stack.split("\n").slice(1).join("\n")}`;
      }
      return this.toString();
    }
  }
  Object.assign(YieldableError23.prototype, StructuralCommitPrototype);
  return YieldableError23;
}();
var exitIsExit = (u3) => isEffect(u3) && "_tag" in u3 && (u3._tag === "Success" || u3._tag === "Failure");
var currentSpanFromFiber = (fiber) => {
  const span2 = fiber.getFiberRef(currentContext).unsafeMap.get(spanTag.key);
  return span2 !== void 0 && span2._tag === "Span" ? some3(span2) : none2();
};
var Data_exports = {};
__export2(Data_exports, {
  Class: () => Class2,
  Error: () => Error2,
  Structural: () => Structural2,
  TaggedClass: () => TaggedClass,
  TaggedError: () => TaggedError,
  array: () => array2,
  case: () => _case,
  struct: () => struct3,
  tagged: () => tagged,
  taggedEnum: () => taggedEnum,
  tuple: () => tuple2,
  unsafeArray: () => unsafeArray,
  unsafeStruct: () => unsafeStruct
});
var struct3 = struct2;
var unsafeStruct = (as24) => Object.setPrototypeOf(as24, StructuralPrototype);
var tuple2 = (...as24) => unsafeArray(as24);
var array2 = (as24) => unsafeArray(as24.slice(0));
var unsafeArray = (as24) => Object.setPrototypeOf(as24, ArrayProto);
var _case = () => (args) => args === void 0 ? Object.create(StructuralPrototype) : struct3(args);
var tagged = (tag) => (args) => {
  const value = args === void 0 ? Object.create(StructuralPrototype) : struct3(args);
  value._tag = tag;
  return value;
};
var Class2 = Structural;
var TaggedClass = (tag) => {
  class Base extends Class2 {
    _tag = tag;
  }
  return Base;
};
var Structural2 = Structural;
var taggedEnum = () => new Proxy({}, {
  get(_target, tag, _receiver) {
    if (tag === "$is") {
      return isTagged;
    } else if (tag === "$match") {
      return taggedMatch;
    }
    return tagged(tag);
  }
});
function taggedMatch() {
  if (arguments.length === 1) {
    const cases2 = arguments[0];
    return function(value2) {
      return cases2[value2._tag](value2);
    };
  }
  const value = arguments[0];
  const cases = arguments[1];
  return cases[value._tag](value);
}
var Error2 = /* @__PURE__ */ function() {
  return class Base extends YieldableError {
    constructor(args) {
      super();
      if (args) {
        Object.assign(this, args);
      }
    }
  };
}();
var TaggedError = (tag) => {
  class Base extends Error2 {
    _tag = tag;
  }
  Base.prototype.name = tag;
  return Base;
};
var traverseUp = Function_exports.dual(2, (node, predicate) => {
  const { parent } = node;
  if (!parent || parent.type === NodeType.Program) return Option_exports.none();
  return predicate(parent) ? Option_exports.some(parent) : traverseUp(parent, predicate);
});
var traverseUpGuard = Function_exports.dual(2, (node, predicate) => {
  const { parent } = node;
  if (!parent || parent.type === NodeType.Program) return Option_exports.none();
  return predicate(parent) ? Option_exports.some(parent) : traverseUpGuard(parent, predicate);
});
var ESLintCommunityESLintUtils;
((ESLintCommunityESLintUtils23) => {
  ESLintCommunityESLintUtils23.getFunctionHeadLocation = getFunctionHeadLocation;
  ESLintCommunityESLintUtils23.getFunctionNameWithKind = getFunctionNameWithKind;
  ESLintCommunityESLintUtils23.getPropertyName = getPropertyName;
  ESLintCommunityESLintUtils23.getStaticValue = getStaticValue;
  ESLintCommunityESLintUtils23.getStringIfConstant = getStringIfConstant;
  ESLintCommunityESLintUtils23.hasSideEffect = hasSideEffect;
  ESLintCommunityESLintUtils23.isParenthesized = isParenthesized;
})(ESLintCommunityESLintUtils || (ESLintCommunityESLintUtils = {}));
var Construction = Data_exports.taggedEnum();
Construction.None();
function getClassIdentifier(node) {
  if (node.id) return Option_exports.fromNullable(node.id);
  if (node.parent.type === NodeType.VariableDeclarator && node.parent.id.type === NodeType.Identifier) {
    return Option_exports.fromNullable(node.parent.id);
  }
  return Option_exports.none();
}
function getFunctionIdentifier(node) {
  if (node.id) return Option_exports.some(node.id);
  if (node.parent.type === NodeType.VariableDeclarator && node.parent.init === node && node.parent.id.type === NodeType.Identifier) {
    return Option_exports.some(node.parent.id);
  }
  if (node.parent.type === NodeType.AssignmentExpression && node.parent.right === node && node.parent.operator === "=" && node.parent.left.type === NodeType.Identifier) {
    return Option_exports.some(node.parent.left);
  }
  if (node.parent.type === NodeType.Property && node.parent.value === node && !node.parent.computed && node.parent.key.type === NodeType.Identifier) {
    return Option_exports.some(node.parent.key);
  }
  if (isOneOf([NodeType.MethodDefinition, NodeType.PropertyDefinition])(node.parent) && node.parent.value === node && node.parent.key.type === NodeType.Identifier) {
    return Option_exports.some(node.parent.key);
  }
  if (node.parent.type === NodeType.AssignmentPattern && node.parent.right === node && node.parent.left.type === NodeType.Identifier) {
    return Option_exports.some(node.parent.left);
  }
  return Option_exports.none();
}
var isFunctionOfObjectMethod = tsPattern.isMatching({
  type: tsPattern.P.union([NodeType.FunctionExpression, NodeType.ArrowFunctionExpression]),
  parent: {
    type: NodeType.Property,
    parent: {
      type: NodeType.ObjectExpression
    }
  }
});
var isFunctionOfClassMethod = tsPattern.isMatching({
  type: tsPattern.P.union([NodeType.FunctionExpression, NodeType.ArrowFunctionExpression]),
  parent: {
    type: NodeType.MethodDefinition,
    parent: {
      type: NodeType.ClassBody
    }
  }
});
var isFunctionOfClassProperty = tsPattern.isMatching({
  type: tsPattern.P.union([NodeType.FunctionExpression, NodeType.ArrowFunctionExpression]),
  parent: {
    type: NodeType.Property,
    parent: {
      type: NodeType.ClassBody
    }
  }
});
var __defProp3 = Object.defineProperty;
var __export3 = (target, all62) => {
  for (var name in all62)
    __defProp3(target, name, { get: all62[name], enumerable: true });
};
var KEYS2 = {
  ArrayExpression: [
    "elements"
  ],
  ArrayPattern: [
    "elements"
  ],
  ArrowFunctionExpression: [
    "params",
    "body"
  ],
  AssignmentExpression: [
    "left",
    "right"
  ],
  AssignmentPattern: [
    "left",
    "right"
  ],
  AwaitExpression: [
    "argument"
  ],
  BinaryExpression: [
    "left",
    "right"
  ],
  BlockStatement: [
    "body"
  ],
  BreakStatement: [
    "label"
  ],
  CallExpression: [
    "callee",
    "arguments"
  ],
  CatchClause: [
    "param",
    "body"
  ],
  ChainExpression: [
    "expression"
  ],
  ClassBody: [
    "body"
  ],
  ClassDeclaration: [
    "id",
    "superClass",
    "body"
  ],
  ClassExpression: [
    "id",
    "superClass",
    "body"
  ],
  ConditionalExpression: [
    "test",
    "consequent",
    "alternate"
  ],
  ContinueStatement: [
    "label"
  ],
  DebuggerStatement: [],
  DoWhileStatement: [
    "body",
    "test"
  ],
  EmptyStatement: [],
  ExperimentalRestProperty: [
    "argument"
  ],
  ExperimentalSpreadProperty: [
    "argument"
  ],
  ExportAllDeclaration: [
    "exported",
    "source"
  ],
  ExportDefaultDeclaration: [
    "declaration"
  ],
  ExportNamedDeclaration: [
    "declaration",
    "specifiers",
    "source"
  ],
  ExportSpecifier: [
    "exported",
    "local"
  ],
  ExpressionStatement: [
    "expression"
  ],
  ForInStatement: [
    "left",
    "right",
    "body"
  ],
  ForOfStatement: [
    "left",
    "right",
    "body"
  ],
  ForStatement: [
    "init",
    "test",
    "update",
    "body"
  ],
  FunctionDeclaration: [
    "id",
    "params",
    "body"
  ],
  FunctionExpression: [
    "id",
    "params",
    "body"
  ],
  Identifier: [],
  IfStatement: [
    "test",
    "consequent",
    "alternate"
  ],
  ImportDeclaration: [
    "specifiers",
    "source"
  ],
  ImportDefaultSpecifier: [
    "local"
  ],
  ImportExpression: [
    "source"
  ],
  ImportNamespaceSpecifier: [
    "local"
  ],
  ImportSpecifier: [
    "imported",
    "local"
  ],
  JSXAttribute: [
    "name",
    "value"
  ],
  JSXClosingElement: [
    "name"
  ],
  JSXClosingFragment: [],
  JSXElement: [
    "openingElement",
    "children",
    "closingElement"
  ],
  JSXEmptyExpression: [],
  JSXExpressionContainer: [
    "expression"
  ],
  JSXFragment: [
    "openingFragment",
    "children",
    "closingFragment"
  ],
  JSXIdentifier: [],
  JSXMemberExpression: [
    "object",
    "property"
  ],
  JSXNamespacedName: [
    "namespace",
    "name"
  ],
  JSXOpeningElement: [
    "name",
    "attributes"
  ],
  JSXOpeningFragment: [],
  JSXSpreadAttribute: [
    "argument"
  ],
  JSXSpreadChild: [
    "expression"
  ],
  JSXText: [],
  LabeledStatement: [
    "label",
    "body"
  ],
  Literal: [],
  LogicalExpression: [
    "left",
    "right"
  ],
  MemberExpression: [
    "object",
    "property"
  ],
  MetaProperty: [
    "meta",
    "property"
  ],
  MethodDefinition: [
    "key",
    "value"
  ],
  NewExpression: [
    "callee",
    "arguments"
  ],
  ObjectExpression: [
    "properties"
  ],
  ObjectPattern: [
    "properties"
  ],
  PrivateIdentifier: [],
  Program: [
    "body"
  ],
  Property: [
    "key",
    "value"
  ],
  PropertyDefinition: [
    "key",
    "value"
  ],
  RestElement: [
    "argument"
  ],
  ReturnStatement: [
    "argument"
  ],
  SequenceExpression: [
    "expressions"
  ],
  SpreadElement: [
    "argument"
  ],
  StaticBlock: [
    "body"
  ],
  Super: [],
  SwitchCase: [
    "test",
    "consequent"
  ],
  SwitchStatement: [
    "discriminant",
    "cases"
  ],
  TaggedTemplateExpression: [
    "tag",
    "quasi"
  ],
  TemplateElement: [],
  TemplateLiteral: [
    "quasis",
    "expressions"
  ],
  ThisExpression: [],
  ThrowStatement: [
    "argument"
  ],
  TryStatement: [
    "block",
    "handler",
    "finalizer"
  ],
  UnaryExpression: [
    "argument"
  ],
  UpdateExpression: [
    "argument"
  ],
  VariableDeclaration: [
    "declarations"
  ],
  VariableDeclarator: [
    "id",
    "init"
  ],
  WhileStatement: [
    "test",
    "body"
  ],
  WithStatement: [
    "object",
    "body"
  ],
  YieldExpression: [
    "argument"
  ]
};
var NODE_TYPES2 = Object.keys(KEYS2);
for (const type of NODE_TYPES2) {
  Object.freeze(KEYS2[type]);
}
Object.freeze(KEYS2);
var visitor_keys_default2 = KEYS2;
var KEY_BLACKLIST2 = /* @__PURE__ */ new Set([
  "parent",
  "leadingComments",
  "trailingComments"
]);
function filterKey2(key) {
  return !KEY_BLACKLIST2.has(key) && key[0] !== "_";
}
function getKeys2(node) {
  return Object.keys(node).filter(filterKey2);
}
function getInnermostScope2(initialScope, node) {
  const location = node.range[0];
  let scope = initialScope;
  let found = false;
  do {
    found = false;
    for (const childScope of scope.childScopes) {
      const range2 = childScope.block.range;
      if (range2[0] <= location && location < range2[1]) {
        scope = childScope;
        found = true;
        break;
      }
    }
  } while (found);
  return scope;
}
function findVariable2(initialScope, nameOrNode) {
  let name = "";
  let scope = initialScope;
  if (typeof nameOrNode === "string") {
    name = nameOrNode;
  } else {
    name = nameOrNode.name;
    scope = getInnermostScope2(scope, nameOrNode);
  }
  while (scope != null) {
    const variable = scope.set.get(name);
    if (variable != null) {
      return variable;
    }
    scope = scope.upper;
  }
  return null;
}
function negate02(token) {
  return !this(token);
}
function negate2(f22) {
  return negate02.bind(f22);
}
function isPunctuatorTokenWithValue2(token, value) {
  return token.type === "Punctuator" && token.value === value;
}
function isArrowToken2(token) {
  return isPunctuatorTokenWithValue2(token, "=>");
}
function isCommaToken2(token) {
  return isPunctuatorTokenWithValue2(token, ",");
}
function isSemicolonToken2(token) {
  return isPunctuatorTokenWithValue2(token, ";");
}
function isColonToken2(token) {
  return isPunctuatorTokenWithValue2(token, ":");
}
function isOpeningParenToken2(token) {
  return isPunctuatorTokenWithValue2(token, "(");
}
function isClosingParenToken2(token) {
  return isPunctuatorTokenWithValue2(token, ")");
}
function isOpeningBracketToken2(token) {
  return isPunctuatorTokenWithValue2(token, "[");
}
function isClosingBracketToken2(token) {
  return isPunctuatorTokenWithValue2(token, "]");
}
function isOpeningBraceToken2(token) {
  return isPunctuatorTokenWithValue2(token, "{");
}
function isClosingBraceToken2(token) {
  return isPunctuatorTokenWithValue2(token, "}");
}
function isCommentToken2(token) {
  return ["Block", "Line", "Shebang"].includes(token.type);
}
negate2(isArrowToken2);
negate2(isCommaToken2);
negate2(isSemicolonToken2);
negate2(isColonToken2);
negate2(isOpeningParenToken2);
negate2(isClosingParenToken2);
negate2(isOpeningBracketToken2);
negate2(isClosingBracketToken2);
negate2(isOpeningBraceToken2);
negate2(isClosingBraceToken2);
negate2(isCommentToken2);
function getOpeningParenOfParams2(node, sourceCode) {
  return node.id ? sourceCode.getTokenAfter(node.id, isOpeningParenToken2) : sourceCode.getFirstToken(node, isOpeningParenToken2);
}
function getFunctionHeadLocation2(node, sourceCode) {
  const parent = node.parent;
  let start = null;
  let end = null;
  if (node.type === "ArrowFunctionExpression") {
    const arrowToken = sourceCode.getTokenBefore(node.body, isArrowToken2);
    start = arrowToken.loc.start;
    end = arrowToken.loc.end;
  } else if (parent.type === "Property" || parent.type === "MethodDefinition" || parent.type === "PropertyDefinition") {
    start = parent.loc.start;
    end = getOpeningParenOfParams2(node, sourceCode).loc.start;
  } else {
    start = node.loc.start;
    end = getOpeningParenOfParams2(node, sourceCode).loc.start;
  }
  return {
    start: { ...start },
    end: { ...end }
  };
}
var globalObject2 = typeof globalThis !== "undefined" ? globalThis : typeof self !== "undefined" ? self : typeof window !== "undefined" ? window : typeof global !== "undefined" ? global : {};
var builtinNames2 = Object.freeze(
  /* @__PURE__ */ new Set([
    "Array",
    "ArrayBuffer",
    "BigInt",
    "BigInt64Array",
    "BigUint64Array",
    "Boolean",
    "DataView",
    "Date",
    "decodeURI",
    "decodeURIComponent",
    "encodeURI",
    "encodeURIComponent",
    "escape",
    "Float32Array",
    "Float64Array",
    "Function",
    "Infinity",
    "Int16Array",
    "Int32Array",
    "Int8Array",
    "isFinite",
    "isNaN",
    "isPrototypeOf",
    "JSON",
    "Map",
    "Math",
    "NaN",
    "Number",
    "Object",
    "parseFloat",
    "parseInt",
    "Promise",
    "Proxy",
    "Reflect",
    "RegExp",
    "Set",
    "String",
    "Symbol",
    "Uint16Array",
    "Uint32Array",
    "Uint8Array",
    "Uint8ClampedArray",
    "undefined",
    "unescape",
    "WeakMap",
    "WeakSet"
  ])
);
var callAllowed2 = new Set(
  [
    Array.isArray,
    Array.of,
    Array.prototype.at,
    Array.prototype.concat,
    Array.prototype.entries,
    Array.prototype.every,
    Array.prototype.filter,
    Array.prototype.find,
    Array.prototype.findIndex,
    Array.prototype.flat,
    Array.prototype.includes,
    Array.prototype.indexOf,
    Array.prototype.join,
    Array.prototype.keys,
    Array.prototype.lastIndexOf,
    Array.prototype.slice,
    Array.prototype.some,
    Array.prototype.toString,
    Array.prototype.values,
    typeof BigInt === "function" ? BigInt : void 0,
    Boolean,
    Date,
    Date.parse,
    decodeURI,
    decodeURIComponent,
    encodeURI,
    encodeURIComponent,
    escape,
    isFinite,
    isNaN,
    isPrototypeOf,
    Map,
    Map.prototype.entries,
    Map.prototype.get,
    Map.prototype.has,
    Map.prototype.keys,
    Map.prototype.values,
    ...Object.getOwnPropertyNames(Math).filter((k22) => k22 !== "random").map((k22) => Math[k22]).filter((f22) => typeof f22 === "function"),
    Number,
    Number.isFinite,
    Number.isNaN,
    Number.parseFloat,
    Number.parseInt,
    Number.prototype.toExponential,
    Number.prototype.toFixed,
    Number.prototype.toPrecision,
    Number.prototype.toString,
    Object,
    Object.entries,
    Object.is,
    Object.isExtensible,
    Object.isFrozen,
    Object.isSealed,
    Object.keys,
    Object.values,
    parseFloat,
    parseInt,
    RegExp,
    Set,
    Set.prototype.entries,
    Set.prototype.has,
    Set.prototype.keys,
    Set.prototype.values,
    String,
    String.fromCharCode,
    String.fromCodePoint,
    String.raw,
    String.prototype.at,
    String.prototype.charAt,
    String.prototype.charCodeAt,
    String.prototype.codePointAt,
    String.prototype.concat,
    String.prototype.endsWith,
    String.prototype.includes,
    String.prototype.indexOf,
    String.prototype.lastIndexOf,
    String.prototype.normalize,
    String.prototype.padEnd,
    String.prototype.padStart,
    String.prototype.slice,
    String.prototype.startsWith,
    String.prototype.substr,
    String.prototype.substring,
    String.prototype.toLowerCase,
    String.prototype.toString,
    String.prototype.toUpperCase,
    String.prototype.trim,
    String.prototype.trimEnd,
    String.prototype.trimLeft,
    String.prototype.trimRight,
    String.prototype.trimStart,
    Symbol.for,
    Symbol.keyFor,
    unescape
  ].filter((f22) => typeof f22 === "function")
);
var callPassThrough2 = /* @__PURE__ */ new Set([
  Object.freeze,
  Object.preventExtensions,
  Object.seal
]);
var getterAllowed2 = [
  [Map, /* @__PURE__ */ new Set(["size"])],
  [
    RegExp,
    /* @__PURE__ */ new Set([
      "dotAll",
      "flags",
      "global",
      "hasIndices",
      "ignoreCase",
      "multiline",
      "source",
      "sticky",
      "unicode"
    ])
  ],
  [Set, /* @__PURE__ */ new Set(["size"])]
];
function getPropertyDescriptor2(object2, name) {
  let x22 = object2;
  while ((typeof x22 === "object" || typeof x22 === "function") && x22 !== null) {
    const d22 = Object.getOwnPropertyDescriptor(x22, name);
    if (d22) {
      return d22;
    }
    x22 = Object.getPrototypeOf(x22);
  }
  return null;
}
function isGetter2(object2, name) {
  const d22 = getPropertyDescriptor2(object2, name);
  return d22 != null && d22.get != null;
}
function getElementValues2(nodeList, initialScope) {
  const valueList = [];
  for (let i22 = 0; i22 < nodeList.length; ++i22) {
    const elementNode = nodeList[i22];
    if (elementNode == null) {
      valueList.length = i22 + 1;
    } else if (elementNode.type === "SpreadElement") {
      const argument = getStaticValueR2(elementNode.argument, initialScope);
      if (argument == null) {
        return null;
      }
      valueList.push(...argument.value);
    } else {
      const element = getStaticValueR2(elementNode, initialScope);
      if (element == null) {
        return null;
      }
      valueList.push(element.value);
    }
  }
  return valueList;
}
function isEffectivelyConst2(variable) {
  const refs = variable.references;
  const inits = refs.filter((r22) => r22.init).length;
  const reads = refs.filter((r22) => r22.isReadOnly()).length;
  if (inits === 1 && reads + inits === refs.length) {
    return true;
  }
  return false;
}
var operations2 = Object.freeze({
  ArrayExpression(node, initialScope) {
    const elements = getElementValues2(node.elements, initialScope);
    return elements != null ? { value: elements } : null;
  },
  AssignmentExpression(node, initialScope) {
    if (node.operator === "=") {
      return getStaticValueR2(node.right, initialScope);
    }
    return null;
  },
  //eslint-disable-next-line complexity
  BinaryExpression(node, initialScope) {
    if (node.operator === "in" || node.operator === "instanceof") {
      return null;
    }
    const left52 = getStaticValueR2(node.left, initialScope);
    const right52 = getStaticValueR2(node.right, initialScope);
    if (left52 != null && right52 != null) {
      switch (node.operator) {
        case "==":
          return { value: left52.value == right52.value };
        case "!=":
          return { value: left52.value != right52.value };
        case "===":
          return { value: left52.value === right52.value };
        case "!==":
          return { value: left52.value !== right52.value };
        case "<":
          return { value: left52.value < right52.value };
        case "<=":
          return { value: left52.value <= right52.value };
        case ">":
          return { value: left52.value > right52.value };
        case ">=":
          return { value: left52.value >= right52.value };
        case "<<":
          return { value: left52.value << right52.value };
        case ">>":
          return { value: left52.value >> right52.value };
        case ">>>":
          return { value: left52.value >>> right52.value };
        case "+":
          return { value: left52.value + right52.value };
        case "-":
          return { value: left52.value - right52.value };
        case "*":
          return { value: left52.value * right52.value };
        case "/":
          return { value: left52.value / right52.value };
        case "%":
          return { value: left52.value % right52.value };
        case "**":
          return { value: left52.value ** right52.value };
        case "|":
          return { value: left52.value | right52.value };
        case "^":
          return { value: left52.value ^ right52.value };
        case "&":
          return { value: left52.value & right52.value };
      }
    }
    return null;
  },
  CallExpression(node, initialScope) {
    const calleeNode = node.callee;
    const args = getElementValues2(node.arguments, initialScope);
    if (args != null) {
      if (calleeNode.type === "MemberExpression") {
        if (calleeNode.property.type === "PrivateIdentifier") {
          return null;
        }
        const object2 = getStaticValueR2(calleeNode.object, initialScope);
        if (object2 != null) {
          if (object2.value == null && (object2.optional || node.optional)) {
            return { value: void 0, optional: true };
          }
          const property = getStaticPropertyNameValue2(
            calleeNode,
            initialScope
          );
          if (property != null) {
            const receiver = object2.value;
            const methodName = property.value;
            if (callAllowed2.has(receiver[methodName])) {
              return { value: receiver[methodName](...args) };
            }
            if (callPassThrough2.has(receiver[methodName])) {
              return { value: args[0] };
            }
          }
        }
      } else {
        const callee = getStaticValueR2(calleeNode, initialScope);
        if (callee != null) {
          if (callee.value == null && node.optional) {
            return { value: void 0, optional: true };
          }
          const func = callee.value;
          if (callAllowed2.has(func)) {
            return { value: func(...args) };
          }
          if (callPassThrough2.has(func)) {
            return { value: args[0] };
          }
        }
      }
    }
    return null;
  },
  ConditionalExpression(node, initialScope) {
    const test = getStaticValueR2(node.test, initialScope);
    if (test != null) {
      return test.value ? getStaticValueR2(node.consequent, initialScope) : getStaticValueR2(node.alternate, initialScope);
    }
    return null;
  },
  ExpressionStatement(node, initialScope) {
    return getStaticValueR2(node.expression, initialScope);
  },
  Identifier(node, initialScope) {
    if (initialScope != null) {
      const variable = findVariable2(initialScope, node);
      if (variable != null && variable.defs.length === 0 && builtinNames2.has(variable.name) && variable.name in globalObject2) {
        return { value: globalObject2[variable.name] };
      }
      if (variable != null && variable.defs.length === 1) {
        const def = variable.defs[0];
        if (def.parent && def.type === "Variable" && (def.parent.kind === "const" || isEffectivelyConst2(variable)) && // TODO(mysticatea): don't support destructuring here.
        def.node.id.type === "Identifier") {
          return getStaticValueR2(def.node.init, initialScope);
        }
      }
    }
    return null;
  },
  Literal(node) {
    if ((node.regex != null || node.bigint != null) && node.value == null) {
      return null;
    }
    return { value: node.value };
  },
  LogicalExpression(node, initialScope) {
    const left52 = getStaticValueR2(node.left, initialScope);
    if (left52 != null) {
      if (node.operator === "||" && Boolean(left52.value) === true || node.operator === "&&" && Boolean(left52.value) === false || node.operator === "??" && left52.value != null) {
        return left52;
      }
      const right52 = getStaticValueR2(node.right, initialScope);
      if (right52 != null) {
        return right52;
      }
    }
    return null;
  },
  MemberExpression(node, initialScope) {
    if (node.property.type === "PrivateIdentifier") {
      return null;
    }
    const object2 = getStaticValueR2(node.object, initialScope);
    if (object2 != null) {
      if (object2.value == null && (object2.optional || node.optional)) {
        return { value: void 0, optional: true };
      }
      const property = getStaticPropertyNameValue2(node, initialScope);
      if (property != null) {
        if (!isGetter2(object2.value, property.value)) {
          return { value: object2.value[property.value] };
        }
        for (const [classFn, allowed] of getterAllowed2) {
          if (object2.value instanceof classFn && allowed.has(property.value)) {
            return { value: object2.value[property.value] };
          }
        }
      }
    }
    return null;
  },
  ChainExpression(node, initialScope) {
    const expression = getStaticValueR2(node.expression, initialScope);
    if (expression != null) {
      return { value: expression.value };
    }
    return null;
  },
  NewExpression(node, initialScope) {
    const callee = getStaticValueR2(node.callee, initialScope);
    const args = getElementValues2(node.arguments, initialScope);
    if (callee != null && args != null) {
      const Func = callee.value;
      if (callAllowed2.has(Func)) {
        return { value: new Func(...args) };
      }
    }
    return null;
  },
  ObjectExpression(node, initialScope) {
    const object2 = {};
    for (const propertyNode of node.properties) {
      if (propertyNode.type === "Property") {
        if (propertyNode.kind !== "init") {
          return null;
        }
        const key = getStaticPropertyNameValue2(
          propertyNode,
          initialScope
        );
        const value = getStaticValueR2(propertyNode.value, initialScope);
        if (key == null || value == null) {
          return null;
        }
        object2[key.value] = value.value;
      } else if (propertyNode.type === "SpreadElement" || propertyNode.type === "ExperimentalSpreadProperty") {
        const argument = getStaticValueR2(
          propertyNode.argument,
          initialScope
        );
        if (argument == null) {
          return null;
        }
        Object.assign(object2, argument.value);
      } else {
        return null;
      }
    }
    return { value: object2 };
  },
  SequenceExpression(node, initialScope) {
    const last2 = node.expressions[node.expressions.length - 1];
    return getStaticValueR2(last2, initialScope);
  },
  TaggedTemplateExpression(node, initialScope) {
    const tag = getStaticValueR2(node.tag, initialScope);
    const expressions = getElementValues2(
      node.quasi.expressions,
      initialScope
    );
    if (tag != null && expressions != null) {
      const func = tag.value;
      const strings = node.quasi.quasis.map((q) => q.value.cooked);
      strings.raw = node.quasi.quasis.map((q) => q.value.raw);
      if (func === String.raw) {
        return { value: func(strings, ...expressions) };
      }
    }
    return null;
  },
  TemplateLiteral(node, initialScope) {
    const expressions = getElementValues2(node.expressions, initialScope);
    if (expressions != null) {
      let value = node.quasis[0].value.cooked;
      for (let i22 = 0; i22 < expressions.length; ++i22) {
        value += expressions[i22];
        value += node.quasis[i22 + 1].value.cooked;
      }
      return { value };
    }
    return null;
  },
  UnaryExpression(node, initialScope) {
    if (node.operator === "delete") {
      return null;
    }
    if (node.operator === "void") {
      return { value: void 0 };
    }
    const arg = getStaticValueR2(node.argument, initialScope);
    if (arg != null) {
      switch (node.operator) {
        case "-":
          return { value: -arg.value };
        case "+":
          return { value: +arg.value };
        case "!":
          return { value: !arg.value };
        case "~":
          return { value: ~arg.value };
        case "typeof":
          return { value: typeof arg.value };
      }
    }
    return null;
  }
});
function getStaticValueR2(node, initialScope) {
  if (node != null && Object.hasOwnProperty.call(operations2, node.type)) {
    return operations2[node.type](node, initialScope);
  }
  return null;
}
function getStaticPropertyNameValue2(node, initialScope) {
  const nameNode = node.type === "Property" ? node.key : node.property;
  if (node.computed) {
    return getStaticValueR2(nameNode, initialScope);
  }
  if (nameNode.type === "Identifier") {
    return { value: nameNode.name };
  }
  if (nameNode.type === "Literal") {
    if (nameNode.bigint) {
      return { value: nameNode.bigint };
    }
    return { value: String(nameNode.value) };
  }
  return null;
}
function getStaticValue2(node, initialScope = null) {
  try {
    return getStaticValueR2(node, initialScope);
  } catch (_error) {
    return null;
  }
}
function getStringIfConstant2(node, initialScope = null) {
  if (node && node.type === "Literal" && node.value === null) {
    if (node.regex) {
      return `/${node.regex.pattern}/${node.regex.flags}`;
    }
    if (node.bigint) {
      return node.bigint;
    }
  }
  const evaluated = getStaticValue2(node, initialScope);
  return evaluated && String(evaluated.value);
}
function getPropertyName2(node, initialScope) {
  switch (node.type) {
    case "MemberExpression":
      if (node.computed) {
        return getStringIfConstant2(node.property, initialScope);
      }
      if (node.property.type === "PrivateIdentifier") {
        return null;
      }
      return node.property.name;
    case "Property":
    case "MethodDefinition":
    case "PropertyDefinition":
      if (node.computed) {
        return getStringIfConstant2(node.key, initialScope);
      }
      if (node.key.type === "Literal") {
        return String(node.key.value);
      }
      if (node.key.type === "PrivateIdentifier") {
        return null;
      }
      return node.key.name;
  }
  return null;
}
function getFunctionNameWithKind2(node, sourceCode) {
  const parent = node.parent;
  const tokens = [];
  const isObjectMethod = parent.type === "Property" && parent.value === node;
  const isClassMethod = parent.type === "MethodDefinition" && parent.value === node;
  const isClassFieldMethod = parent.type === "PropertyDefinition" && parent.value === node;
  if (isClassMethod || isClassFieldMethod) {
    if (parent.static) {
      tokens.push("static");
    }
    if (parent.key.type === "PrivateIdentifier") {
      tokens.push("private");
    }
  }
  if (node.async) {
    tokens.push("async");
  }
  if (node.generator) {
    tokens.push("generator");
  }
  if (isObjectMethod || isClassMethod) {
    if (parent.kind === "constructor") {
      return "constructor";
    }
    if (parent.kind === "get") {
      tokens.push("getter");
    } else if (parent.kind === "set") {
      tokens.push("setter");
    } else {
      tokens.push("method");
    }
  } else if (isClassFieldMethod) {
    tokens.push("method");
  } else {
    if (node.type === "ArrowFunctionExpression") {
      tokens.push("arrow");
    }
    tokens.push("function");
  }
  if (isObjectMethod || isClassMethod || isClassFieldMethod) {
    if (parent.key.type === "PrivateIdentifier") {
      tokens.push(`#${parent.key.name}`);
    } else {
      const name = getPropertyName2(parent);
      if (name) {
        tokens.push(`'${name}'`);
      } else if (sourceCode) {
        const keyText = sourceCode.getText(parent.key);
        if (!keyText.includes("\n")) {
          tokens.push(`[${keyText}]`);
        }
      }
    }
  } else if (node.id) {
    tokens.push(`'${node.id.name}'`);
  } else if (parent.type === "VariableDeclarator" && parent.id && parent.id.type === "Identifier") {
    tokens.push(`'${parent.id.name}'`);
  } else if ((parent.type === "AssignmentExpression" || parent.type === "AssignmentPattern") && parent.left && parent.left.type === "Identifier") {
    tokens.push(`'${parent.left.name}'`);
  } else if (parent.type === "ExportDefaultDeclaration" && parent.declaration === node) {
    tokens.push("'default'");
  }
  return tokens.join(" ");
}
var typeConversionBinaryOps2 = Object.freeze(
  /* @__PURE__ */ new Set([
    "==",
    "!=",
    "<",
    "<=",
    ">",
    ">=",
    "<<",
    ">>",
    ">>>",
    "+",
    "-",
    "*",
    "/",
    "%",
    "|",
    "^",
    "&",
    "in"
  ])
);
var typeConversionUnaryOps2 = Object.freeze(/* @__PURE__ */ new Set(["-", "+", "!", "~"]));
function isNode2(x22) {
  return x22 !== null && typeof x22 === "object" && typeof x22.type === "string";
}
var visitor2 = Object.freeze(
  Object.assign(/* @__PURE__ */ Object.create(null), {
    $visit(node, options, visitorKeys) {
      const { type } = node;
      if (typeof this[type] === "function") {
        return this[type](node, options, visitorKeys);
      }
      return this.$visitChildren(node, options, visitorKeys);
    },
    $visitChildren(node, options, visitorKeys) {
      const { type } = node;
      for (const key of visitorKeys[type] || getKeys2(node)) {
        const value = node[key];
        if (Array.isArray(value)) {
          for (const element of value) {
            if (isNode2(element) && this.$visit(element, options, visitorKeys)) {
              return true;
            }
          }
        } else if (isNode2(value) && this.$visit(value, options, visitorKeys)) {
          return true;
        }
      }
      return false;
    },
    ArrowFunctionExpression() {
      return false;
    },
    AssignmentExpression() {
      return true;
    },
    AwaitExpression() {
      return true;
    },
    BinaryExpression(node, options, visitorKeys) {
      if (options.considerImplicitTypeConversion && typeConversionBinaryOps2.has(node.operator) && (node.left.type !== "Literal" || node.right.type !== "Literal")) {
        return true;
      }
      return this.$visitChildren(node, options, visitorKeys);
    },
    CallExpression() {
      return true;
    },
    FunctionExpression() {
      return false;
    },
    ImportExpression() {
      return true;
    },
    MemberExpression(node, options, visitorKeys) {
      if (options.considerGetters) {
        return true;
      }
      if (options.considerImplicitTypeConversion && node.computed && node.property.type !== "Literal") {
        return true;
      }
      return this.$visitChildren(node, options, visitorKeys);
    },
    MethodDefinition(node, options, visitorKeys) {
      if (options.considerImplicitTypeConversion && node.computed && node.key.type !== "Literal") {
        return true;
      }
      return this.$visitChildren(node, options, visitorKeys);
    },
    NewExpression() {
      return true;
    },
    Property(node, options, visitorKeys) {
      if (options.considerImplicitTypeConversion && node.computed && node.key.type !== "Literal") {
        return true;
      }
      return this.$visitChildren(node, options, visitorKeys);
    },
    PropertyDefinition(node, options, visitorKeys) {
      if (options.considerImplicitTypeConversion && node.computed && node.key.type !== "Literal") {
        return true;
      }
      return this.$visitChildren(node, options, visitorKeys);
    },
    UnaryExpression(node, options, visitorKeys) {
      if (node.operator === "delete") {
        return true;
      }
      if (options.considerImplicitTypeConversion && typeConversionUnaryOps2.has(node.operator) && node.argument.type !== "Literal") {
        return true;
      }
      return this.$visitChildren(node, options, visitorKeys);
    },
    UpdateExpression() {
      return true;
    },
    YieldExpression() {
      return true;
    }
  })
);
function hasSideEffect2(node, sourceCode, { considerGetters = false, considerImplicitTypeConversion = false } = {}) {
  return visitor2.$visit(
    node,
    { considerGetters, considerImplicitTypeConversion },
    sourceCode.visitorKeys || visitor_keys_default2
  );
}
function getParentSyntaxParen2(node, sourceCode) {
  const parent = node.parent;
  switch (parent.type) {
    case "CallExpression":
    case "NewExpression":
      if (parent.arguments.length === 1 && parent.arguments[0] === node) {
        return sourceCode.getTokenAfter(
          parent.callee,
          isOpeningParenToken2
        );
      }
      return null;
    case "DoWhileStatement":
      if (parent.test === node) {
        return sourceCode.getTokenAfter(
          parent.body,
          isOpeningParenToken2
        );
      }
      return null;
    case "IfStatement":
    case "WhileStatement":
      if (parent.test === node) {
        return sourceCode.getFirstToken(parent, 1);
      }
      return null;
    case "ImportExpression":
      if (parent.source === node) {
        return sourceCode.getFirstToken(parent, 1);
      }
      return null;
    case "SwitchStatement":
      if (parent.discriminant === node) {
        return sourceCode.getFirstToken(parent, 1);
      }
      return null;
    case "WithStatement":
      if (parent.object === node) {
        return sourceCode.getFirstToken(parent, 1);
      }
      return null;
    default:
      return null;
  }
}
function isParenthesized2(timesOrNode, nodeOrSourceCode, optionalSourceCode) {
  let times, node, sourceCode, maybeLeftParen, maybeRightParen;
  if (typeof timesOrNode === "number") {
    times = timesOrNode | 0;
    node = nodeOrSourceCode;
    sourceCode = optionalSourceCode;
    if (!(times >= 1)) {
      throw new TypeError("'times' should be a positive integer.");
    }
  } else {
    times = 1;
    node = timesOrNode;
    sourceCode = nodeOrSourceCode;
  }
  if (node == null || // `Program` can't be parenthesized
  node.parent == null || // `CatchClause.param` can't be parenthesized, example `try {} catch (error) {}`
  node.parent.type === "CatchClause" && node.parent.param === node) {
    return false;
  }
  maybeLeftParen = maybeRightParen = node;
  do {
    maybeLeftParen = sourceCode.getTokenBefore(maybeLeftParen);
    maybeRightParen = sourceCode.getTokenAfter(maybeRightParen);
  } while (maybeLeftParen != null && maybeRightParen != null && isOpeningParenToken2(maybeLeftParen) && isClosingParenToken2(maybeRightParen) && // Avoid false positive such as `if (a) {}`
  maybeLeftParen !== getParentSyntaxParen2(node, sourceCode) && --times > 0);
  return times === 0;
}
Function.call.bind(Object.hasOwnProperty);
var __defProp22 = Object.defineProperty;
var __export22 = (target, all322) => {
  for (var name in all322)
    __defProp22(target, name, { get: all322[name], enumerable: true });
};
var NodeType2 = types.AST_NODE_TYPES;
var is2 = utils.ASTUtils.isNodeOfType;
var isOneOf2 = utils.ASTUtils.isNodeOfTypes;
isOneOf2([
  NodeType2.ArrowFunctionExpression,
  NodeType2.FunctionDeclaration,
  NodeType2.FunctionExpression
]);
isOneOf2([
  NodeType2.ArrowFunctionExpression,
  NodeType2.FunctionDeclaration,
  NodeType2.FunctionExpression,
  NodeType2.TSCallSignatureDeclaration,
  NodeType2.TSConstructSignatureDeclaration,
  NodeType2.TSDeclareFunction,
  NodeType2.TSEmptyBodyFunctionExpression,
  NodeType2.TSFunctionType,
  NodeType2.TSMethodSignature
]);
isOneOf2([NodeType2.ClassDeclaration, NodeType2.ClassExpression]);
isOneOf2([
  NodeType2.DoWhileStatement,
  NodeType2.ForInStatement,
  NodeType2.ForOfStatement,
  NodeType2.ForStatement,
  NodeType2.WhileStatement
]);
isOneOf2([NodeType2.TSArrayType, NodeType2.TSTupleType]);
isOneOf2([
  NodeType2.PropertyDefinition,
  NodeType2.TSIndexSignature,
  NodeType2.TSParameterProperty,
  NodeType2.TSPropertySignature
]);
is2(NodeType2.JSXElement);
is2(NodeType2.JSXFragment);
isOneOf2([
  NodeType2.JSXAttribute,
  NodeType2.JSXSpreadChild,
  NodeType2.JSXClosingElement,
  NodeType2.JSXClosingFragment,
  NodeType2.JSXElement,
  NodeType2.JSXEmptyExpression,
  NodeType2.JSXExpressionContainer,
  NodeType2.JSXFragment,
  NodeType2.JSXIdentifier,
  NodeType2.JSXMemberExpression,
  NodeType2.JSXNamespacedName,
  NodeType2.JSXOpeningElement,
  NodeType2.JSXOpeningFragment,
  NodeType2.JSXSpreadAttribute,
  NodeType2.JSXSpreadChild,
  NodeType2.JSXText
]);
var isJSXTagNameExpression2 = isOneOf2([
  NodeType2.JSXIdentifier,
  NodeType2.JSXMemberExpression,
  NodeType2.JSXNamespacedName
]);
isOneOf2([
  NodeType2.ArrayPattern,
  NodeType2.AssignmentPattern,
  NodeType2.ObjectPattern,
  NodeType2.RestElement
]);
isOneOf2([
  NodeType2.TSInterfaceDeclaration,
  NodeType2.TSTypeAliasDeclaration
]);
isOneOf2([
  NodeType2.ArrayExpression,
  NodeType2.ArrayPattern,
  NodeType2.ArrowFunctionExpression,
  NodeType2.CallExpression,
  NodeType2.ClassExpression,
  NodeType2.FunctionExpression,
  NodeType2.Identifier,
  NodeType2.JSXElement,
  NodeType2.JSXFragment,
  NodeType2.Literal,
  NodeType2.TemplateLiteral,
  NodeType2.MemberExpression,
  NodeType2.MetaProperty,
  NodeType2.ObjectExpression,
  NodeType2.ObjectPattern,
  NodeType2.SequenceExpression,
  NodeType2.Super,
  NodeType2.TaggedTemplateExpression,
  NodeType2.ThisExpression
]);
isOneOf2([
  NodeType2.ArrayExpression,
  NodeType2.ArrayPattern,
  NodeType2.ArrowFunctionExpression,
  NodeType2.CallExpression,
  NodeType2.ClassExpression,
  NodeType2.FunctionExpression,
  NodeType2.Identifier,
  NodeType2.JSXElement,
  NodeType2.JSXFragment,
  NodeType2.Literal,
  NodeType2.TemplateLiteral,
  NodeType2.MemberExpression,
  NodeType2.MetaProperty,
  NodeType2.ObjectExpression,
  NodeType2.ObjectPattern,
  NodeType2.SequenceExpression,
  NodeType2.Super,
  NodeType2.TaggedTemplateExpression,
  NodeType2.ThisExpression,
  NodeType2.TSAsExpression,
  NodeType2.TSNonNullExpression,
  NodeType2.TSTypeAssertion
]);
var Function_exports2 = {};
__export22(Function_exports2, {
  SK: () => SK2,
  absurd: () => absurd2,
  apply: () => apply2,
  compose: () => compose3,
  constFalse: () => constFalse2,
  constNull: () => constNull2,
  constTrue: () => constTrue2,
  constUndefined: () => constUndefined2,
  constVoid: () => constVoid2,
  constant: () => constant2,
  dual: () => dual2,
  flip: () => flip2,
  flow: () => flow2,
  hole: () => hole2,
  identity: () => identity2,
  isFunction: () => isFunction22,
  pipe: () => pipe2,
  satisfies: () => satisfies2,
  tupled: () => tupled2,
  unsafeCoerce: () => unsafeCoerce2,
  untupled: () => untupled2
});
var isFunction22 = (input) => typeof input === "function";
var dual2 = function(arity, body) {
  if (typeof arity === "function") {
    return function() {
      if (arity(arguments)) {
        return body.apply(this, arguments);
      }
      return (self2) => body(self2, ...arguments);
    };
  }
  switch (arity) {
    case 0:
    case 1:
      throw new RangeError(`Invalid arity ${arity}`);
    case 2:
      return function(a22, b22) {
        if (arguments.length >= 2) {
          return body(a22, b22);
        }
        return function(self2) {
          return body(self2, a22);
        };
      };
    case 3:
      return function(a22, b22, c22) {
        if (arguments.length >= 3) {
          return body(a22, b22, c22);
        }
        return function(self2) {
          return body(self2, a22, b22);
        };
      };
    case 4:
      return function(a22, b22, c22, d22) {
        if (arguments.length >= 4) {
          return body(a22, b22, c22, d22);
        }
        return function(self2) {
          return body(self2, a22, b22, c22);
        };
      };
    case 5:
      return function(a22, b22, c22, d22, e22) {
        if (arguments.length >= 5) {
          return body(a22, b22, c22, d22, e22);
        }
        return function(self2) {
          return body(self2, a22, b22, c22, d22);
        };
      };
    default:
      return function() {
        if (arguments.length >= arity) {
          return body.apply(this, arguments);
        }
        const args = arguments;
        return function(self2) {
          return body(self2, ...args);
        };
      };
  }
};
var apply2 = (a22) => (self2) => self2(a22);
var identity2 = (a22) => a22;
var satisfies2 = () => (b22) => b22;
var unsafeCoerce2 = identity2;
var constant2 = (value) => () => value;
var constTrue2 = /* @__PURE__ */ constant2(true);
var constFalse2 = /* @__PURE__ */ constant2(false);
var constNull2 = /* @__PURE__ */ constant2(null);
var constUndefined2 = /* @__PURE__ */ constant2(void 0);
var constVoid2 = constUndefined2;
var flip2 = (f22) => (...b22) => (...a22) => f22(...a22)(...b22);
var compose3 = /* @__PURE__ */ dual2(2, (ab, bc) => (a22) => bc(ab(a22)));
var absurd2 = (_22) => {
  throw new Error("Called `absurd` function which should be uncallable");
};
var tupled2 = (f22) => (a22) => f22(...a22);
var untupled2 = (f22) => (...a22) => f22(a22);
function pipe2(a22, ab, bc, cd, de, ef, fg, gh, hi) {
  switch (arguments.length) {
    case 1:
      return a22;
    case 2:
      return ab(a22);
    case 3:
      return bc(ab(a22));
    case 4:
      return cd(bc(ab(a22)));
    case 5:
      return de(cd(bc(ab(a22))));
    case 6:
      return ef(de(cd(bc(ab(a22)))));
    case 7:
      return fg(ef(de(cd(bc(ab(a22))))));
    case 8:
      return gh(fg(ef(de(cd(bc(ab(a22)))))));
    case 9:
      return hi(gh(fg(ef(de(cd(bc(ab(a22))))))));
    default: {
      let ret = arguments[0];
      for (let i22 = 1; i22 < arguments.length; i22++) {
        ret = arguments[i22](ret);
      }
      return ret;
    }
  }
}
function flow2(ab, bc, cd, de, ef, fg, gh, hi, ij) {
  switch (arguments.length) {
    case 1:
      return ab;
    case 2:
      return function() {
        return bc(ab.apply(this, arguments));
      };
    case 3:
      return function() {
        return cd(bc(ab.apply(this, arguments)));
      };
    case 4:
      return function() {
        return de(cd(bc(ab.apply(this, arguments))));
      };
    case 5:
      return function() {
        return ef(de(cd(bc(ab.apply(this, arguments)))));
      };
    case 6:
      return function() {
        return fg(ef(de(cd(bc(ab.apply(this, arguments))))));
      };
    case 7:
      return function() {
        return gh(fg(ef(de(cd(bc(ab.apply(this, arguments)))))));
      };
    case 8:
      return function() {
        return hi(gh(fg(ef(de(cd(bc(ab.apply(this, arguments))))))));
      };
    case 9:
      return function() {
        return ij(hi(gh(fg(ef(de(cd(bc(ab.apply(this, arguments)))))))));
      };
  }
  return;
}
var hole2 = /* @__PURE__ */ unsafeCoerce2(absurd2);
var SK2 = (_22, b22) => b22;
var make6 = (isEquivalent) => (self2, that) => self2 === that || isEquivalent(self2, that);
var let_3 = (map62) => dual2(3, (self2, name, f22) => map62(self2, (a22) => Object.assign({}, a22, {
  [name]: f22(a22)
})));
var bindTo3 = (map62) => dual2(2, (self2, name) => map62(self2, (a22) => ({
  [name]: a22
})));
var bind3 = (map62, flatMap42) => dual2(3, (self2, name, f22) => flatMap42(self2, (a22) => map62(f22(a22), (b22) => Object.assign({}, a22, {
  [name]: b22
}))));
var moduleVersion2 = "3.2.8";
var getCurrentVersion2 = () => moduleVersion2;
var globalStoreId2 = /* @__PURE__ */ Symbol.for(`effect/GlobalValue/globalStoreId/${/* @__PURE__ */ getCurrentVersion2()}`);
if (!(globalStoreId2 in globalThis)) {
  globalThis[globalStoreId2] = /* @__PURE__ */ new Map();
}
var globalStore2 = globalThis[globalStoreId2];
var globalValue2 = (id, compute) => {
  if (!globalStore2.has(id)) {
    globalStore2.set(id, compute());
  }
  return globalStore2.get(id);
};
var Predicate_exports2 = {};
__export22(Predicate_exports2, {
  all: () => all3,
  and: () => and2,
  compose: () => compose22,
  eqv: () => eqv2,
  every: () => every2,
  hasProperty: () => hasProperty2,
  implies: () => implies2,
  isBigInt: () => isBigInt2,
  isBoolean: () => isBoolean2,
  isDate: () => isDate2,
  isError: () => isError2,
  isFunction: () => isFunction32,
  isIterable: () => isIterable2,
  isMap: () => isMap2,
  isNever: () => isNever2,
  isNotNull: () => isNotNull2,
  isNotNullable: () => isNotNullable2,
  isNotUndefined: () => isNotUndefined2,
  isNull: () => isNull2,
  isNullable: () => isNullable2,
  isNumber: () => isNumber2,
  isObject: () => isObject2,
  isPromise: () => isPromise2,
  isPromiseLike: () => isPromiseLike2,
  isReadonlyRecord: () => isReadonlyRecord2,
  isRecord: () => isRecord2,
  isSet: () => isSet2,
  isString: () => isString2,
  isSymbol: () => isSymbol2,
  isTagged: () => isTagged2,
  isTruthy: () => isTruthy2,
  isUint8Array: () => isUint8Array2,
  isUndefined: () => isUndefined2,
  isUnknown: () => isUnknown2,
  mapInput: () => mapInput2,
  nand: () => nand2,
  nor: () => nor2,
  not: () => not2,
  or: () => or2,
  product: () => product3,
  productMany: () => productMany3,
  some: () => some4,
  struct: () => struct4,
  tuple: () => tuple3,
  xor: () => xor2
});
var mapInput2 = /* @__PURE__ */ dual2(2, (self2, f22) => (b22) => self2(f22(b22)));
var isTruthy2 = (input) => !!input;
var isSet2 = (input) => input instanceof Set;
var isMap2 = (input) => input instanceof Map;
var isString2 = (input) => typeof input === "string";
var isNumber2 = (input) => typeof input === "number";
var isBoolean2 = (input) => typeof input === "boolean";
var isBigInt2 = (input) => typeof input === "bigint";
var isSymbol2 = (input) => typeof input === "symbol";
var isFunction32 = isFunction22;
var isUndefined2 = (input) => input === void 0;
var isNotUndefined2 = (input) => input !== void 0;
var isNull2 = (input) => input === null;
var isNotNull2 = (input) => input !== null;
var isNever2 = (_22) => false;
var isUnknown2 = (_22) => true;
var isRecordOrArray2 = (input) => typeof input === "object" && input !== null;
var isObject2 = (input) => isRecordOrArray2(input) || isFunction32(input);
var hasProperty2 = /* @__PURE__ */ dual2(2, (self2, property) => isObject2(self2) && property in self2);
var isTagged2 = /* @__PURE__ */ dual2(2, (self2, tag) => hasProperty2(self2, "_tag") && self2["_tag"] === tag);
var isNullable2 = (input) => input === null || input === void 0;
var isNotNullable2 = (input) => input !== null && input !== void 0;
var isError2 = (input) => input instanceof Error;
var isUint8Array2 = (input) => input instanceof Uint8Array;
var isDate2 = (input) => input instanceof Date;
var isIterable2 = (input) => hasProperty2(input, Symbol.iterator);
var isRecord2 = (input) => isRecordOrArray2(input) && !Array.isArray(input);
var isReadonlyRecord2 = isRecord2;
var isPromise2 = (input) => hasProperty2(input, "then") && "catch" in input && isFunction32(input.then) && isFunction32(input.catch);
var isPromiseLike2 = (input) => hasProperty2(input, "then") && isFunction32(input.then);
var compose22 = /* @__PURE__ */ dual2(2, (ab, bc) => (a22) => ab(a22) && bc(a22));
var product3 = (self2, that) => ([a22, b22]) => self2(a22) && that(b22);
var all3 = (collection) => {
  return (as232) => {
    let collectionIndex = 0;
    for (const p22 of collection) {
      if (collectionIndex >= as232.length) {
        break;
      }
      if (p22(as232[collectionIndex]) === false) {
        return false;
      }
      collectionIndex++;
    }
    return true;
  };
};
var productMany3 = (self2, collection) => {
  const rest = all3(collection);
  return ([head22, ...tail22]) => self2(head22) === false ? false : rest(tail22);
};
var tuple3 = (...elements) => all3(elements);
var struct4 = (fields) => {
  const keys222 = Object.keys(fields);
  return (a22) => {
    for (const key of keys222) {
      if (!fields[key](a22[key])) {
        return false;
      }
    }
    return true;
  };
};
var not2 = (self2) => (a22) => !self2(a22);
var or2 = /* @__PURE__ */ dual2(2, (self2, that) => (a22) => self2(a22) || that(a22));
var and2 = /* @__PURE__ */ dual2(2, (self2, that) => (a22) => self2(a22) && that(a22));
var xor2 = /* @__PURE__ */ dual2(2, (self2, that) => (a22) => self2(a22) !== that(a22));
var eqv2 = /* @__PURE__ */ dual2(2, (self2, that) => (a22) => self2(a22) === that(a22));
var implies2 = /* @__PURE__ */ dual2(2, (self2, that) => (a22) => self2(a22) ? that(a22) : true);
var nor2 = /* @__PURE__ */ dual2(2, (self2, that) => (a22) => !(self2(a22) || that(a22)));
var nand2 = /* @__PURE__ */ dual2(2, (self2, that) => (a22) => !(self2(a22) && that(a22)));
var every2 = (collection) => (a22) => {
  for (const p22 of collection) {
    if (!p22(a22)) {
      return false;
    }
  }
  return true;
};
var some4 = (collection) => (a22) => {
  for (const p22 of collection) {
    if (p22(a22)) {
      return true;
    }
  }
  return false;
};
var getBugErrorMessage2 = (message) => `BUG: ${message} - please report an issue at https://github.com/Effect-TS/effect/issues`;
var GenKindTypeId2 = /* @__PURE__ */ Symbol.for("effect/Gen/GenKind");
var isGenKind2 = (u22) => isObject2(u22) && GenKindTypeId2 in u22;
var GenKindImpl2 = class {
  value;
  constructor(value) {
    this.value = value;
  }
  /**
   * @since 2.0.0
   */
  get _F() {
    return identity2;
  }
  /**
   * @since 2.0.0
   */
  get _R() {
    return (_22) => _22;
  }
  /**
   * @since 2.0.0
   */
  get _O() {
    return (_22) => _22;
  }
  /**
   * @since 2.0.0
   */
  get _E() {
    return (_22) => _22;
  }
  /**
   * @since 2.0.0
   */
  [GenKindTypeId2] = GenKindTypeId2;
  /**
   * @since 2.0.0
   */
  [Symbol.iterator]() {
    return new SingleShotGen3(this);
  }
};
var SingleShotGen3 = class _SingleShotGen3 {
  self;
  called = false;
  constructor(self2) {
    this.self = self2;
  }
  /**
   * @since 2.0.0
   */
  next(a22) {
    return this.called ? {
      value: a22,
      done: true
    } : (this.called = true, {
      value: this.self,
      done: false
    });
  }
  /**
   * @since 2.0.0
   */
  return(a22) {
    return {
      value: a22,
      done: true
    };
  }
  /**
   * @since 2.0.0
   */
  throw(e22) {
    throw e22;
  }
  /**
   * @since 2.0.0
   */
  [Symbol.iterator]() {
    return new _SingleShotGen3(this.self);
  }
};
var adapter3 = () => function() {
  let x22 = arguments[0];
  for (let i22 = 1; i22 < arguments.length; i22++) {
    x22 = arguments[i22](x22);
  }
  return new GenKindImpl2(x22);
};
var defaultIncHi2 = 335903614;
var defaultIncLo2 = 4150755663;
var MUL_HI2 = 1481765933 >>> 0;
var MUL_LO2 = 1284865837 >>> 0;
var BIT_532 = 9007199254740992;
var BIT_272 = 134217728;
var PCGRandom2 = class {
  _state;
  constructor(seedHi, seedLo, incHi, incLo) {
    if (isNullable2(seedLo) && isNullable2(seedHi)) {
      seedLo = Math.random() * 4294967295 >>> 0;
      seedHi = 0;
    } else if (isNullable2(seedLo)) {
      seedLo = seedHi;
      seedHi = 0;
    }
    if (isNullable2(incLo) && isNullable2(incHi)) {
      incLo = this._state ? this._state[3] : defaultIncLo2;
      incHi = this._state ? this._state[2] : defaultIncHi2;
    } else if (isNullable2(incLo)) {
      incLo = incHi;
      incHi = 0;
    }
    this._state = new Int32Array([0, 0, incHi >>> 0, ((incLo || 0) | 1) >>> 0]);
    this._next();
    add642(this._state, this._state[0], this._state[1], seedHi >>> 0, seedLo >>> 0);
    this._next();
    return this;
  }
  /**
   * Returns a copy of the internal state of this random number generator as a
   * JavaScript Array.
   *
   * @category getters
   * @since 2.0.0
   */
  getState() {
    return [this._state[0], this._state[1], this._state[2], this._state[3]];
  }
  /**
   * Restore state previously retrieved using `getState()`.
   *
   * @since 2.0.0
   */
  setState(state) {
    this._state[0] = state[0];
    this._state[1] = state[1];
    this._state[2] = state[2];
    this._state[3] = state[3] | 1;
  }
  /**
   * Get a uniformly distributed 32 bit integer between [0, max).
   *
   * @category getter
   * @since 2.0.0
   */
  integer(max3) {
    if (!max3) {
      return this._next();
    }
    max3 = max3 >>> 0;
    if ((max3 & max3 - 1) === 0) {
      return this._next() & max3 - 1;
    }
    let num = 0;
    const skew = (-max3 >>> 0) % max3 >>> 0;
    for (num = this._next(); num < skew; num = this._next()) {
    }
    return num % max3;
  }
  /**
   * Get a uniformly distributed IEEE-754 double between 0.0 and 1.0, with
   * 53 bits of precision (every bit of the mantissa is randomized).
   *
   * @category getters
   * @since 2.0.0
   */
  number() {
    const hi = (this._next() & 67108863) * 1;
    const lo = (this._next() & 134217727) * 1;
    return (hi * BIT_272 + lo) / BIT_532;
  }
  /** @internal */
  _next() {
    const oldHi = this._state[0] >>> 0;
    const oldLo = this._state[1] >>> 0;
    mul642(this._state, oldHi, oldLo, MUL_HI2, MUL_LO2);
    add642(this._state, this._state[0], this._state[1], this._state[2], this._state[3]);
    let xsHi = oldHi >>> 18;
    let xsLo = (oldLo >>> 18 | oldHi << 14) >>> 0;
    xsHi = (xsHi ^ oldHi) >>> 0;
    xsLo = (xsLo ^ oldLo) >>> 0;
    const xorshifted = (xsLo >>> 27 | xsHi << 5) >>> 0;
    const rot = oldHi >>> 27;
    const rot2 = (-rot >>> 0 & 31) >>> 0;
    return (xorshifted >>> rot | xorshifted << rot2) >>> 0;
  }
};
function mul642(out, aHi, aLo, bHi, bLo) {
  let c1 = (aLo >>> 16) * (bLo & 65535) >>> 0;
  let c0 = (aLo & 65535) * (bLo >>> 16) >>> 0;
  let lo = (aLo & 65535) * (bLo & 65535) >>> 0;
  let hi = (aLo >>> 16) * (bLo >>> 16) + ((c0 >>> 16) + (c1 >>> 16)) >>> 0;
  c0 = c0 << 16 >>> 0;
  lo = lo + c0 >>> 0;
  if (lo >>> 0 < c0 >>> 0) {
    hi = hi + 1 >>> 0;
  }
  c1 = c1 << 16 >>> 0;
  lo = lo + c1 >>> 0;
  if (lo >>> 0 < c1 >>> 0) {
    hi = hi + 1 >>> 0;
  }
  hi = hi + Math.imul(aLo, bHi) >>> 0;
  hi = hi + Math.imul(aHi, bLo) >>> 0;
  out[0] = hi;
  out[1] = lo;
}
function add642(out, aHi, aLo, bHi, bLo) {
  let hi = aHi + bHi >>> 0;
  const lo = aLo + bLo >>> 0;
  if (lo >>> 0 < aLo >>> 0) {
    hi = hi + 1 | 0;
  }
  out[0] = hi;
  out[1] = lo;
}
var YieldWrapTypeId2 = /* @__PURE__ */ Symbol.for("effect/Utils/YieldWrap");
var YieldWrap2 = class {
  /**
   * @since 3.0.6
   */
  #value;
  constructor(value) {
    this.#value = value;
  }
  /**
   * @since 3.0.6
   */
  [YieldWrapTypeId2]() {
    return this.#value;
  }
};
function yieldWrapGet2(self2) {
  if (typeof self2 === "object" && self2 !== null && YieldWrapTypeId2 in self2) {
    return self2[YieldWrapTypeId2]();
  }
  throw new Error(getBugErrorMessage2("yieldWrapGet"));
}
var structuralRegionState2 = /* @__PURE__ */ globalValue2("effect/Utils/isStructuralRegion", () => ({
  enabled: false,
  tester: void 0
}));
var randomHashCache2 = /* @__PURE__ */ globalValue2(/* @__PURE__ */ Symbol.for("effect/Hash/randomHashCache"), () => /* @__PURE__ */ new WeakMap());
var pcgr2 = /* @__PURE__ */ globalValue2(/* @__PURE__ */ Symbol.for("effect/Hash/pcgr"), () => new PCGRandom2());
var symbol3 = /* @__PURE__ */ Symbol.for("effect/Hash");
var hash2 = (self2) => {
  if (structuralRegionState2.enabled === true) {
    return 0;
  }
  switch (typeof self2) {
    case "number":
      return number2(self2);
    case "bigint":
      return string2(self2.toString(10));
    case "boolean":
      return string2(String(self2));
    case "symbol":
      return string2(String(self2));
    case "string":
      return string2(self2);
    case "undefined":
      return string2("undefined");
    case "function":
    case "object": {
      if (self2 === null) {
        return string2("null");
      } else if (self2 instanceof Date) {
        return hash2(self2.toISOString());
      } else if (isHash2(self2)) {
        return self2[symbol3]();
      } else {
        return random2(self2);
      }
    }
    default:
      throw new Error(`BUG: unhandled typeof ${typeof self2} - please report an issue at https://github.com/Effect-TS/effect/issues`);
  }
};
var random2 = (self2) => {
  if (!randomHashCache2.has(self2)) {
    randomHashCache2.set(self2, number2(pcgr2.integer(Number.MAX_SAFE_INTEGER)));
  }
  return randomHashCache2.get(self2);
};
var combine3 = (b22) => (self2) => self2 * 53 ^ b22;
var optimize2 = (n22) => n22 & 3221225471 | n22 >>> 1 & 1073741824;
var isHash2 = (u22) => hasProperty2(u22, symbol3);
var number2 = (n22) => {
  if (n22 !== n22 || n22 === Infinity) {
    return 0;
  }
  let h22 = n22 | 0;
  if (h22 !== n22) {
    h22 ^= n22 * 4294967295;
  }
  while (n22 > 4294967295) {
    h22 ^= n22 /= 4294967295;
  }
  return optimize2(n22);
};
var string2 = (str) => {
  let h22 = 5381, i22 = str.length;
  while (i22) {
    h22 = h22 * 33 ^ str.charCodeAt(--i22);
  }
  return optimize2(h22);
};
var structureKeys2 = (o22, keys222) => {
  let h22 = 12289;
  for (let i22 = 0; i22 < keys222.length; i22++) {
    h22 ^= pipe2(string2(keys222[i22]), combine3(hash2(o22[keys222[i22]])));
  }
  return optimize2(h22);
};
var structure2 = (o22) => structureKeys2(o22, Object.keys(o22));
var array3 = (arr) => {
  let h22 = 6151;
  for (let i22 = 0; i22 < arr.length; i22++) {
    h22 = pipe2(h22, combine3(hash2(arr[i22])));
  }
  return optimize2(h22);
};
var cached2 = function() {
  if (arguments.length === 1) {
    const self22 = arguments[0];
    return function(hash32) {
      Object.defineProperty(self22, symbol3, {
        value() {
          return hash32;
        },
        enumerable: false
      });
      return hash32;
    };
  }
  const self2 = arguments[0];
  const hash232 = arguments[1];
  Object.defineProperty(self2, symbol3, {
    value() {
      return hash232;
    },
    enumerable: false
  });
  return hash232;
};
var symbol22 = /* @__PURE__ */ Symbol.for("effect/Equal");
function equals2() {
  if (arguments.length === 1) {
    return (self2) => compareBoth2(self2, arguments[0]);
  }
  return compareBoth2(arguments[0], arguments[1]);
}
function compareBoth2(self2, that) {
  if (self2 === that) {
    return true;
  }
  const selfType = typeof self2;
  if (selfType !== typeof that) {
    return false;
  }
  if (selfType === "object" || selfType === "function") {
    if (self2 !== null && that !== null) {
      if (isEqual2(self2) && isEqual2(that)) {
        if (hash2(self2) === hash2(that) && self2[symbol22](that)) {
          return true;
        } else {
          return structuralRegionState2.enabled && structuralRegionState2.tester ? structuralRegionState2.tester(self2, that) : false;
        }
      } else if (self2 instanceof Date && that instanceof Date) {
        return self2.toISOString() === that.toISOString();
      }
    }
    if (structuralRegionState2.enabled) {
      if (Array.isArray(self2) && Array.isArray(that)) {
        return self2.length === that.length && self2.every((v22, i22) => compareBoth2(v22, that[i22]));
      }
      if (Object.getPrototypeOf(self2) === Object.prototype && Object.getPrototypeOf(self2) === Object.prototype) {
        const keysSelf = Object.keys(self2);
        const keysThat = Object.keys(that);
        if (keysSelf.length === keysThat.length) {
          for (const key of keysSelf) {
            if (!(key in that && compareBoth2(self2[key], that[key]))) {
              return structuralRegionState2.tester ? structuralRegionState2.tester(self2, that) : false;
            }
          }
          return true;
        }
      }
      return structuralRegionState2.tester ? structuralRegionState2.tester(self2, that) : false;
    }
  }
  return structuralRegionState2.enabled && structuralRegionState2.tester ? structuralRegionState2.tester(self2, that) : false;
}
var isEqual2 = (u22) => hasProperty2(u22, symbol22);
var equivalence2 = () => equals2;
var NodeInspectSymbol2 = /* @__PURE__ */ Symbol.for("nodejs.util.inspect.custom");
var toJSON2 = (x22) => {
  if (hasProperty2(x22, "toJSON") && isFunction32(x22["toJSON"]) && x22["toJSON"].length === 0) {
    return x22.toJSON();
  } else if (Array.isArray(x22)) {
    return x22.map(toJSON2);
  }
  return x22;
};
var format2 = (x22) => JSON.stringify(x22, null, 2);
var pipeArguments2 = (self2, args) => {
  switch (args.length) {
    case 1:
      return args[0](self2);
    case 2:
      return args[1](args[0](self2));
    case 3:
      return args[2](args[1](args[0](self2)));
    case 4:
      return args[3](args[2](args[1](args[0](self2))));
    case 5:
      return args[4](args[3](args[2](args[1](args[0](self2)))));
    case 6:
      return args[5](args[4](args[3](args[2](args[1](args[0](self2))))));
    case 7:
      return args[6](args[5](args[4](args[3](args[2](args[1](args[0](self2)))))));
    case 8:
      return args[7](args[6](args[5](args[4](args[3](args[2](args[1](args[0](self2))))))));
    case 9:
      return args[8](args[7](args[6](args[5](args[4](args[3](args[2](args[1](args[0](self2)))))))));
    default: {
      let ret = self2;
      for (let i22 = 0, len = args.length; i22 < len; i22++) {
        ret = args[i22](ret);
      }
      return ret;
    }
  }
};
var OP_COMMIT2 = "Commit";
var OP_FAILURE2 = "Failure";
var OP_WITH_RUNTIME2 = "WithRuntime";
var EffectTypeId3 = /* @__PURE__ */ Symbol.for("effect/Effect");
var StreamTypeId2 = /* @__PURE__ */ Symbol.for("effect/Stream");
var SinkTypeId2 = /* @__PURE__ */ Symbol.for("effect/Sink");
var ChannelTypeId2 = /* @__PURE__ */ Symbol.for("effect/Channel");
var effectVariance2 = {
  /* c8 ignore next */
  _R: (_22) => _22,
  /* c8 ignore next */
  _E: (_22) => _22,
  /* c8 ignore next */
  _A: (_22) => _22,
  _V: /* @__PURE__ */ getCurrentVersion2()
};
var sinkVariance2 = {
  /* c8 ignore next */
  _A: (_22) => _22,
  /* c8 ignore next */
  _In: (_22) => _22,
  /* c8 ignore next */
  _L: (_22) => _22,
  /* c8 ignore next */
  _E: (_22) => _22,
  /* c8 ignore next */
  _R: (_22) => _22
};
var channelVariance2 = {
  /* c8 ignore next */
  _Env: (_22) => _22,
  /* c8 ignore next */
  _InErr: (_22) => _22,
  /* c8 ignore next */
  _InElem: (_22) => _22,
  /* c8 ignore next */
  _InDone: (_22) => _22,
  /* c8 ignore next */
  _OutErr: (_22) => _22,
  /* c8 ignore next */
  _OutElem: (_22) => _22,
  /* c8 ignore next */
  _OutDone: (_22) => _22
};
var EffectPrototype2 = {
  [EffectTypeId3]: effectVariance2,
  [StreamTypeId2]: effectVariance2,
  [SinkTypeId2]: sinkVariance2,
  [ChannelTypeId2]: channelVariance2,
  [symbol22](that) {
    return this === that;
  },
  [symbol3]() {
    return cached2(this, random2(this));
  },
  [Symbol.iterator]() {
    return new SingleShotGen3(new YieldWrap2(this));
  },
  pipe() {
    return pipeArguments2(this, arguments);
  }
};
var StructuralPrototype2 = {
  [symbol3]() {
    return cached2(this, structure2(this));
  },
  [symbol22](that) {
    const selfKeys = Object.keys(this);
    const thatKeys = Object.keys(that);
    if (selfKeys.length !== thatKeys.length) {
      return false;
    }
    for (const key of selfKeys) {
      if (!(key in that && equals2(this[key], that[key]))) {
        return false;
      }
    }
    return true;
  }
};
var CommitPrototype2 = {
  ...EffectPrototype2,
  _op: OP_COMMIT2
};
var StructuralCommitPrototype2 = {
  ...CommitPrototype2,
  ...StructuralPrototype2
};
var TypeId6 = /* @__PURE__ */ Symbol.for("effect/Option");
var CommonProto3 = {
  ...EffectPrototype2,
  [TypeId6]: {
    _A: (_22) => _22
  },
  [NodeInspectSymbol2]() {
    return this.toJSON();
  },
  toString() {
    return format2(this.toJSON());
  }
};
var SomeProto2 = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(CommonProto3), {
  _tag: "Some",
  _op: "Some",
  [symbol22](that) {
    return isOption3(that) && isSome3(that) && equals2(this.value, that.value);
  },
  [symbol3]() {
    return cached2(this, combine3(hash2(this._tag))(hash2(this.value)));
  },
  toJSON() {
    return {
      _id: "Option",
      _tag: this._tag,
      value: toJSON2(this.value)
    };
  }
});
var NoneHash2 = /* @__PURE__ */ hash2("None");
var NoneProto2 = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(CommonProto3), {
  _tag: "None",
  _op: "None",
  [symbol22](that) {
    return isOption3(that) && isNone3(that);
  },
  [symbol3]() {
    return NoneHash2;
  },
  toJSON() {
    return {
      _id: "Option",
      _tag: this._tag
    };
  }
});
var isOption3 = (input) => hasProperty2(input, TypeId6);
var isNone3 = (fa) => fa._tag === "None";
var isSome3 = (fa) => fa._tag === "Some";
var none3 = /* @__PURE__ */ Object.create(NoneProto2);
var some22 = (value) => {
  const a22 = Object.create(SomeProto2);
  a22.value = value;
  return a22;
};
var TypeId22 = /* @__PURE__ */ Symbol.for("effect/Either");
var CommonProto22 = {
  ...EffectPrototype2,
  [TypeId22]: {
    _R: (_22) => _22
  },
  [NodeInspectSymbol2]() {
    return this.toJSON();
  },
  toString() {
    return format2(this.toJSON());
  }
};
var RightProto2 = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(CommonProto22), {
  _tag: "Right",
  _op: "Right",
  [symbol22](that) {
    return isEither2(that) && isRight2(that) && equals2(this.right, that.right);
  },
  [symbol3]() {
    return combine3(hash2(this._tag))(hash2(this.right));
  },
  toJSON() {
    return {
      _id: "Either",
      _tag: this._tag,
      right: toJSON2(this.right)
    };
  }
});
var LeftProto2 = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(CommonProto22), {
  _tag: "Left",
  _op: "Left",
  [symbol22](that) {
    return isEither2(that) && isLeft2(that) && equals2(this.left, that.left);
  },
  [symbol3]() {
    return combine3(hash2(this._tag))(hash2(this.left));
  },
  toJSON() {
    return {
      _id: "Either",
      _tag: this._tag,
      left: toJSON2(this.left)
    };
  }
});
var isEither2 = (input) => hasProperty2(input, TypeId22);
var isLeft2 = (ma) => ma._tag === "Left";
var isRight2 = (ma) => ma._tag === "Right";
var left3 = (left322) => {
  const a22 = Object.create(LeftProto2);
  a22.left = left322;
  return a22;
};
var right3 = (right322) => {
  const a22 = Object.create(RightProto2);
  a22.right = right322;
  return a22;
};
var getLeft3 = (self2) => isRight2(self2) ? none3 : some22(self2.left);
var getRight3 = (self2) => isLeft2(self2) ? none3 : some22(self2.right);
var right22 = right3;
var left22 = left3;
var Option_exports2 = {};
__export22(Option_exports2, {
  Do: () => Do2,
  TypeId: () => TypeId32,
  all: () => all22,
  andThen: () => andThen2,
  ap: () => ap2,
  as: () => as2,
  asVoid: () => asVoid2,
  bind: () => bind22,
  bindTo: () => bindTo22,
  composeK: () => composeK2,
  contains: () => contains2,
  containsWith: () => containsWith2,
  exists: () => exists2,
  filter: () => filter2,
  filterMap: () => filterMap2,
  firstSomeOf: () => firstSomeOf2,
  flatMap: () => flatMap2,
  flatMapNullable: () => flatMapNullable2,
  flatten: () => flatten2,
  fromIterable: () => fromIterable3,
  fromNullable: () => fromNullable2,
  gen: () => gen2,
  getEquivalence: () => getEquivalence3,
  getLeft: () => getLeft22,
  getOrElse: () => getOrElse2,
  getOrNull: () => getOrNull2,
  getOrThrow: () => getOrThrow2,
  getOrThrowWith: () => getOrThrowWith2,
  getOrUndefined: () => getOrUndefined2,
  getOrder: () => getOrder2,
  getRight: () => getRight22,
  isNone: () => isNone22,
  isOption: () => isOption22,
  isSome: () => isSome22,
  let: () => let_22,
  lift2: () => lift22,
  liftNullable: () => liftNullable2,
  liftPredicate: () => liftPredicate2,
  liftThrowable: () => liftThrowable2,
  map: () => map2,
  match: () => match22,
  none: () => none22,
  orElse: () => orElse2,
  orElseEither: () => orElseEither2,
  orElseSome: () => orElseSome2,
  partitionMap: () => partitionMap2,
  product: () => product22,
  productMany: () => productMany22,
  reduceCompact: () => reduceCompact2,
  some: () => some32,
  tap: () => tap2,
  toArray: () => toArray2,
  toRefinement: () => toRefinement2,
  void: () => void_2,
  zipLeft: () => zipLeft2,
  zipRight: () => zipRight2,
  zipWith: () => zipWith2
});
var make22 = (compare) => (self2, that) => self2 === that ? 0 : compare(self2, that);
var TypeId32 = /* @__PURE__ */ Symbol.for("effect/Option");
var none22 = () => none3;
var some32 = some22;
var isOption22 = isOption3;
var isNone22 = isNone3;
var isSome22 = isSome3;
var match22 = /* @__PURE__ */ dual2(2, (self2, {
  onNone,
  onSome
}) => isNone22(self2) ? onNone() : onSome(self2.value));
var toRefinement2 = (f22) => (a22) => isSome22(f22(a22));
var fromIterable3 = (collection) => {
  for (const a22 of collection) {
    return some32(a22);
  }
  return none22();
};
var getRight22 = getRight3;
var getLeft22 = getLeft3;
var getOrElse2 = /* @__PURE__ */ dual2(2, (self2, onNone) => isNone22(self2) ? onNone() : self2.value);
var orElse2 = /* @__PURE__ */ dual2(2, (self2, that) => isNone22(self2) ? that() : self2);
var orElseSome2 = /* @__PURE__ */ dual2(2, (self2, onNone) => isNone22(self2) ? some32(onNone()) : self2);
var orElseEither2 = /* @__PURE__ */ dual2(2, (self2, that) => isNone22(self2) ? map2(that(), right3) : map2(self2, left3));
var firstSomeOf2 = (collection) => {
  let out = none22();
  for (out of collection) {
    if (isSome22(out)) {
      return out;
    }
  }
  return out;
};
var fromNullable2 = (nullableValue) => nullableValue == null ? none22() : some32(nullableValue);
var liftNullable2 = (f22) => (...a22) => fromNullable2(f22(...a22));
var getOrNull2 = /* @__PURE__ */ getOrElse2(constNull2);
var getOrUndefined2 = /* @__PURE__ */ getOrElse2(constUndefined2);
var liftThrowable2 = (f22) => (...a22) => {
  try {
    return some32(f22(...a22));
  } catch (e22) {
    return none22();
  }
};
var getOrThrowWith2 = /* @__PURE__ */ dual2(2, (self2, onNone) => {
  if (isSome22(self2)) {
    return self2.value;
  }
  throw onNone();
});
var getOrThrow2 = /* @__PURE__ */ getOrThrowWith2(() => new Error("getOrThrow called on a None"));
var map2 = /* @__PURE__ */ dual2(2, (self2, f22) => isNone22(self2) ? none22() : some32(f22(self2.value)));
var as2 = /* @__PURE__ */ dual2(2, (self2, b22) => map2(self2, () => b22));
var asVoid2 = /* @__PURE__ */ as2(void 0);
var void_2 = /* @__PURE__ */ some32(void 0);
var flatMap2 = /* @__PURE__ */ dual2(2, (self2, f22) => isNone22(self2) ? none22() : f22(self2.value));
var andThen2 = /* @__PURE__ */ dual2(2, (self2, f22) => flatMap2(self2, (a22) => {
  const b22 = isFunction22(f22) ? f22(a22) : f22;
  return isOption22(b22) ? b22 : some32(b22);
}));
var flatMapNullable2 = /* @__PURE__ */ dual2(2, (self2, f22) => isNone22(self2) ? none22() : fromNullable2(f22(self2.value)));
var flatten2 = /* @__PURE__ */ flatMap2(identity2);
var zipRight2 = /* @__PURE__ */ dual2(2, (self2, that) => flatMap2(self2, () => that));
var composeK2 = /* @__PURE__ */ dual2(2, (afb, bfc) => (a22) => flatMap2(afb(a22), bfc));
var zipLeft2 = /* @__PURE__ */ dual2(2, (self2, that) => tap2(self2, () => that));
var tap2 = /* @__PURE__ */ dual2(2, (self2, f22) => flatMap2(self2, (a22) => map2(f22(a22), () => a22)));
var product22 = (self2, that) => isSome22(self2) && isSome22(that) ? some32([self2.value, that.value]) : none22();
var productMany22 = (self2, collection) => {
  if (isNone22(self2)) {
    return none22();
  }
  const out = [self2.value];
  for (const o22 of collection) {
    if (isNone22(o22)) {
      return none22();
    }
    out.push(o22.value);
  }
  return some32(out);
};
var all22 = (input) => {
  if (Symbol.iterator in input) {
    const out2 = [];
    for (const o22 of input) {
      if (isNone22(o22)) {
        return none22();
      }
      out2.push(o22.value);
    }
    return some32(out2);
  }
  const out = {};
  for (const key of Object.keys(input)) {
    const o22 = input[key];
    if (isNone22(o22)) {
      return none22();
    }
    out[key] = o22.value;
  }
  return some32(out);
};
var zipWith2 = /* @__PURE__ */ dual2(3, (self2, that, f22) => map2(product22(self2, that), ([a22, b22]) => f22(a22, b22)));
var ap2 = /* @__PURE__ */ dual2(2, (self2, that) => zipWith2(self2, that, (f22, a22) => f22(a22)));
var reduceCompact2 = /* @__PURE__ */ dual2(3, (self2, b22, f22) => {
  let out = b22;
  for (const oa of self2) {
    if (isSome22(oa)) {
      out = f22(out, oa.value);
    }
  }
  return out;
});
var toArray2 = (self2) => isNone22(self2) ? [] : [self2.value];
var partitionMap2 = /* @__PURE__ */ dual2(2, (self2, f22) => {
  if (isNone22(self2)) {
    return [none22(), none22()];
  }
  const e22 = f22(self2.value);
  return isLeft2(e22) ? [some32(e22.left), none22()] : [none22(), some32(e22.right)];
});
var filterMap2 = /* @__PURE__ */ dual2(2, (self2, f22) => isNone22(self2) ? none22() : f22(self2.value));
var filter2 = /* @__PURE__ */ dual2(2, (self2, predicate) => filterMap2(self2, (b22) => predicate(b22) ? some22(b22) : none3));
var getEquivalence3 = (isEquivalent) => make6((x22, y22) => x22 === y22 || (isNone22(x22) ? isNone22(y22) : isNone22(y22) ? false : isEquivalent(x22.value, y22.value)));
var getOrder2 = (O22) => make22((self2, that) => isSome22(self2) ? isSome22(that) ? O22(self2.value, that.value) : 1 : -1);
var lift22 = (f22) => dual2(2, (self2, that) => zipWith2(self2, that, f22));
var liftPredicate2 = (predicate) => (b22) => predicate(b22) ? some32(b22) : none22();
var containsWith2 = (isEquivalent) => dual2(2, (self2, a22) => isNone22(self2) ? false : isEquivalent(self2.value, a22));
var _equivalence3 = /* @__PURE__ */ equivalence2();
var contains2 = /* @__PURE__ */ containsWith2(_equivalence3);
var exists2 = /* @__PURE__ */ dual2(2, (self2, refinement) => isNone22(self2) ? false : refinement(self2.value));
var bindTo22 = /* @__PURE__ */ bindTo3(map2);
var let_22 = /* @__PURE__ */ let_3(map2);
var bind22 = /* @__PURE__ */ bind3(map2, flatMap2);
var Do2 = /* @__PURE__ */ some32({});
var adapter22 = /* @__PURE__ */ adapter3();
var gen2 = (f22) => {
  const iterator = f22(adapter22);
  let state = iterator.next();
  if (state.done) {
    return some32(state.value);
  } else {
    let current = state.value;
    if (isGenKind2(current)) {
      current = current.value;
    } else {
      current = yieldWrapGet2(current);
    }
    if (isNone22(current)) {
      return current;
    }
    while (!state.done) {
      state = iterator.next(current.value);
      if (!state.done) {
        current = state.value;
        if (isGenKind2(current)) {
          current = current.value;
        } else {
          current = yieldWrapGet2(current);
        }
        if (isNone22(current)) {
          return current;
        }
      }
    }
    return some32(state.value);
  }
};
var fromIterable22 = (collection) => Array.isArray(collection) ? collection : Array.from(collection);
var reverse3 = (self2) => Array.from(self2).reverse();
var reduce3 = /* @__PURE__ */ dual2(3, (self2, b22, f22) => fromIterable22(self2).reduce((b222, a22, i22) => f22(b222, a22, i22), b22));
var TagTypeId2 = /* @__PURE__ */ Symbol.for("effect/Context/Tag");
var STMSymbolKey2 = "effect/STM";
var STMTypeId2 = /* @__PURE__ */ Symbol.for(STMSymbolKey2);
var TagProto2 = {
  ...EffectPrototype2,
  _tag: "Tag",
  _op: "Tag",
  [STMTypeId2]: effectVariance2,
  [TagTypeId2]: {
    _Service: (_22) => _22,
    _Identifier: (_22) => _22
  },
  toString() {
    return format2(this.toJSON());
  },
  toJSON() {
    return {
      _id: "Tag",
      key: this.key,
      stack: this.stack
    };
  },
  [NodeInspectSymbol2]() {
    return this.toJSON();
  },
  of(self2) {
    return self2;
  },
  context(self2) {
    return make32(this, self2);
  }
};
var makeGenericTag2 = (key) => {
  const limit = Error.stackTraceLimit;
  Error.stackTraceLimit = 2;
  const creationError = new Error();
  Error.stackTraceLimit = limit;
  const tag = Object.create(TagProto2);
  Object.defineProperty(tag, "stack", {
    get() {
      return creationError.stack;
    }
  });
  tag.key = key;
  return tag;
};
var TypeId42 = /* @__PURE__ */ Symbol.for("effect/Context");
var ContextProto2 = {
  [TypeId42]: {
    _Services: (_22) => _22
  },
  [symbol22](that) {
    if (isContext2(that)) {
      if (this.unsafeMap.size === that.unsafeMap.size) {
        for (const k22 of this.unsafeMap.keys()) {
          if (!that.unsafeMap.has(k22) || !equals2(this.unsafeMap.get(k22), that.unsafeMap.get(k22))) {
            return false;
          }
        }
        return true;
      }
    }
    return false;
  },
  [symbol3]() {
    return cached2(this, number2(this.unsafeMap.size));
  },
  pipe() {
    return pipeArguments2(this, arguments);
  },
  toString() {
    return format2(this.toJSON());
  },
  toJSON() {
    return {
      _id: "Context",
      services: Array.from(this.unsafeMap).map(toJSON2)
    };
  },
  [NodeInspectSymbol2]() {
    return this.toJSON();
  }
};
var makeContext2 = (unsafeMap) => {
  const context = Object.create(ContextProto2);
  context.unsafeMap = unsafeMap;
  return context;
};
var isContext2 = (u22) => hasProperty2(u22, TypeId42);
var _empty6 = /* @__PURE__ */ makeContext2(/* @__PURE__ */ new Map());
var empty8 = () => _empty6;
var make32 = (tag, service) => makeContext2(/* @__PURE__ */ new Map([[tag.key, service]]));
var GenericTag2 = makeGenericTag2;
var empty22 = empty8;
var TypeId52 = /* @__PURE__ */ Symbol.for("effect/Chunk");
function copy2(src, srcPos, dest, destPos, len) {
  for (let i22 = srcPos; i22 < Math.min(src.length, srcPos + len); i22++) {
    dest[destPos + i22 - srcPos] = src[i22];
  }
  return dest;
}
var emptyArray2 = [];
var getEquivalence22 = (isEquivalent) => make6((self2, that) => self2.length === that.length && toReadonlyArray2(self2).every((value, i22) => isEquivalent(value, unsafeGet22(that, i22))));
var _equivalence22 = /* @__PURE__ */ getEquivalence22(equals2);
var ChunkProto2 = {
  [TypeId52]: {
    _A: (_22) => _22
  },
  toString() {
    return format2(this.toJSON());
  },
  toJSON() {
    return {
      _id: "Chunk",
      values: toReadonlyArray2(this).map(toJSON2)
    };
  },
  [NodeInspectSymbol2]() {
    return this.toJSON();
  },
  [symbol22](that) {
    return isChunk2(that) && _equivalence22(this, that);
  },
  [symbol3]() {
    return cached2(this, array3(toReadonlyArray2(this)));
  },
  [Symbol.iterator]() {
    switch (this.backing._tag) {
      case "IArray": {
        return this.backing.array[Symbol.iterator]();
      }
      case "IEmpty": {
        return emptyArray2[Symbol.iterator]();
      }
      default: {
        return toReadonlyArray2(this)[Symbol.iterator]();
      }
    }
  },
  pipe() {
    return pipeArguments2(this, arguments);
  }
};
var makeChunk2 = (backing) => {
  const chunk = Object.create(ChunkProto2);
  chunk.backing = backing;
  switch (backing._tag) {
    case "IEmpty": {
      chunk.length = 0;
      chunk.depth = 0;
      chunk.left = chunk;
      chunk.right = chunk;
      break;
    }
    case "IConcat": {
      chunk.length = backing.left.length + backing.right.length;
      chunk.depth = 1 + Math.max(backing.left.depth, backing.right.depth);
      chunk.left = backing.left;
      chunk.right = backing.right;
      break;
    }
    case "IArray": {
      chunk.length = backing.array.length;
      chunk.depth = 0;
      chunk.left = _empty22;
      chunk.right = _empty22;
      break;
    }
    case "ISingleton": {
      chunk.length = 1;
      chunk.depth = 0;
      chunk.left = _empty22;
      chunk.right = _empty22;
      break;
    }
    case "ISlice": {
      chunk.length = backing.length;
      chunk.depth = backing.chunk.depth + 1;
      chunk.left = _empty22;
      chunk.right = _empty22;
      break;
    }
  }
  return chunk;
};
var isChunk2 = (u22) => hasProperty2(u22, TypeId52);
var _empty22 = /* @__PURE__ */ makeChunk2({
  _tag: "IEmpty"
});
var empty32 = () => _empty22;
var make42 = (...as232) => as232.length === 1 ? of2(as232[0]) : unsafeFromNonEmptyArray2(as232);
var of2 = (a22) => makeChunk2({
  _tag: "ISingleton",
  a: a22
});
var copyToArray2 = (self2, array322, initial) => {
  switch (self2.backing._tag) {
    case "IArray": {
      copy2(self2.backing.array, 0, array322, initial, self2.length);
      break;
    }
    case "IConcat": {
      copyToArray2(self2.left, array322, initial);
      copyToArray2(self2.right, array322, initial + self2.left.length);
      break;
    }
    case "ISingleton": {
      array322[initial] = self2.backing.a;
      break;
    }
    case "ISlice": {
      let i22 = 0;
      let j22 = initial;
      while (i22 < self2.length) {
        array322[j22] = unsafeGet22(self2, i22);
        i22 += 1;
        j22 += 1;
      }
      break;
    }
  }
};
var toReadonlyArray2 = (self2) => {
  switch (self2.backing._tag) {
    case "IEmpty": {
      return emptyArray2;
    }
    case "IArray": {
      return self2.backing.array;
    }
    default: {
      const arr = new Array(self2.length);
      copyToArray2(self2, arr, 0);
      self2.backing = {
        _tag: "IArray",
        array: arr
      };
      self2.left = _empty22;
      self2.right = _empty22;
      self2.depth = 0;
      return arr;
    }
  }
};
var reverse22 = (self2) => {
  switch (self2.backing._tag) {
    case "IEmpty":
    case "ISingleton":
      return self2;
    case "IArray": {
      return makeChunk2({
        _tag: "IArray",
        array: reverse3(self2.backing.array)
      });
    }
    case "IConcat": {
      return makeChunk2({
        _tag: "IConcat",
        left: reverse22(self2.backing.right),
        right: reverse22(self2.backing.left)
      });
    }
    case "ISlice":
      return unsafeFromArray2(reverse3(toReadonlyArray2(self2)));
  }
};
var unsafeFromArray2 = (self2) => makeChunk2({
  _tag: "IArray",
  array: self2
});
var unsafeFromNonEmptyArray2 = (self2) => unsafeFromArray2(self2);
var unsafeGet22 = /* @__PURE__ */ dual2(2, (self2, index) => {
  switch (self2.backing._tag) {
    case "IEmpty": {
      throw new Error(`Index out of bounds`);
    }
    case "ISingleton": {
      if (index !== 0) {
        throw new Error(`Index out of bounds`);
      }
      return self2.backing.a;
    }
    case "IArray": {
      if (index >= self2.length || index < 0) {
        throw new Error(`Index out of bounds`);
      }
      return self2.backing.array[index];
    }
    case "IConcat": {
      return index < self2.left.length ? unsafeGet22(self2.left, index) : unsafeGet22(self2.right, index - self2.left.length);
    }
    case "ISlice": {
      return unsafeGet22(self2.backing.chunk, index + self2.backing.offset);
    }
  }
});
var prepend2 = /* @__PURE__ */ dual2(2, (self2, elem) => appendAll2(of2(elem), self2));
var drop2 = /* @__PURE__ */ dual2(2, (self2, n22) => {
  if (n22 <= 0) {
    return self2;
  } else if (n22 >= self2.length) {
    return _empty22;
  } else {
    switch (self2.backing._tag) {
      case "ISlice": {
        return makeChunk2({
          _tag: "ISlice",
          chunk: self2.backing.chunk,
          offset: self2.backing.offset + n22,
          length: self2.backing.length - n22
        });
      }
      case "IConcat": {
        if (n22 > self2.left.length) {
          return drop2(self2.right, n22 - self2.left.length);
        }
        return makeChunk2({
          _tag: "IConcat",
          left: drop2(self2.left, n22),
          right: self2.right
        });
      }
      default: {
        return makeChunk2({
          _tag: "ISlice",
          chunk: self2,
          offset: n22,
          length: self2.length - n22
        });
      }
    }
  }
});
var appendAll2 = /* @__PURE__ */ dual2(2, (self2, that) => {
  if (self2.backing._tag === "IEmpty") {
    return that;
  }
  if (that.backing._tag === "IEmpty") {
    return self2;
  }
  const diff222 = that.depth - self2.depth;
  if (Math.abs(diff222) <= 1) {
    return makeChunk2({
      _tag: "IConcat",
      left: self2,
      right: that
    });
  } else if (diff222 < -1) {
    if (self2.left.depth >= self2.right.depth) {
      const nr = appendAll2(self2.right, that);
      return makeChunk2({
        _tag: "IConcat",
        left: self2.left,
        right: nr
      });
    } else {
      const nrr = appendAll2(self2.right.right, that);
      if (nrr.depth === self2.depth - 3) {
        const nr = makeChunk2({
          _tag: "IConcat",
          left: self2.right.left,
          right: nrr
        });
        return makeChunk2({
          _tag: "IConcat",
          left: self2.left,
          right: nr
        });
      } else {
        const nl = makeChunk2({
          _tag: "IConcat",
          left: self2.left,
          right: self2.right.left
        });
        return makeChunk2({
          _tag: "IConcat",
          left: nl,
          right: nrr
        });
      }
    }
  } else {
    if (that.right.depth >= that.left.depth) {
      const nl = appendAll2(self2, that.left);
      return makeChunk2({
        _tag: "IConcat",
        left: nl,
        right: that.right
      });
    } else {
      const nll = appendAll2(self2, that.left.left);
      if (nll.depth === that.depth - 3) {
        const nl = makeChunk2({
          _tag: "IConcat",
          left: nll,
          right: that.left.right
        });
        return makeChunk2({
          _tag: "IConcat",
          left: nl,
          right: that.right
        });
      } else {
        const nr = makeChunk2({
          _tag: "IConcat",
          left: that.left.right,
          right: that.right
        });
        return makeChunk2({
          _tag: "IConcat",
          left: nll,
          right: nr
        });
      }
    }
  }
});
var isEmpty2 = (self2) => self2.length === 0;
var isNonEmpty2 = (self2) => self2.length > 0;
var unsafeHead2 = (self2) => unsafeGet22(self2, 0);
var headNonEmpty2 = unsafeHead2;
var tailNonEmpty2 = (self2) => drop2(self2, 1);
var SIZE2 = 5;
var BUCKET_SIZE2 = /* @__PURE__ */ Math.pow(2, SIZE2);
var MASK2 = BUCKET_SIZE2 - 1;
var MAX_INDEX_NODE2 = BUCKET_SIZE2 / 2;
var MIN_ARRAY_NODE2 = BUCKET_SIZE2 / 4;
function popcount2(x22) {
  x22 -= x22 >> 1 & 1431655765;
  x22 = (x22 & 858993459) + (x22 >> 2 & 858993459);
  x22 = x22 + (x22 >> 4) & 252645135;
  x22 += x22 >> 8;
  x22 += x22 >> 16;
  return x22 & 127;
}
function hashFragment2(shift2, h22) {
  return h22 >>> shift2 & MASK2;
}
function toBitmap2(x22) {
  return 1 << x22;
}
function fromBitmap2(bitmap, bit) {
  return popcount2(bitmap & bit - 1);
}
var make52 = (value, previous) => ({
  value,
  previous
});
function arrayUpdate2(mutate222, at, v22, arr) {
  let out = arr;
  if (!mutate222) {
    const len = arr.length;
    out = new Array(len);
    for (let i22 = 0; i22 < len; ++i22) out[i22] = arr[i22];
  }
  out[at] = v22;
  return out;
}
function arraySpliceOut2(mutate222, at, arr) {
  const newLen = arr.length - 1;
  let i22 = 0;
  let g22 = 0;
  let out = arr;
  if (mutate222) {
    i22 = g22 = at;
  } else {
    out = new Array(newLen);
    while (i22 < at) out[g22++] = arr[i22++];
  }
  ++i22;
  while (i22 <= newLen) out[g22++] = arr[i22++];
  if (mutate222) {
    out.length = newLen;
  }
  return out;
}
function arraySpliceIn2(mutate222, at, v22, arr) {
  const len = arr.length;
  if (mutate222) {
    let i222 = len;
    while (i222 >= at) arr[i222--] = arr[i222];
    arr[at] = v22;
    return arr;
  }
  let i22 = 0, g22 = 0;
  const out = new Array(len + 1);
  while (i22 < at) out[g22++] = arr[i22++];
  out[at] = v22;
  while (i22 < len) out[++g22] = arr[i22++];
  return out;
}
var EmptyNode2 = class _EmptyNode2 {
  _tag = "EmptyNode";
  modify(edit, _shift, f22, hash232, key, size422) {
    const v22 = f22(none22());
    if (isNone22(v22)) return new _EmptyNode2();
    ++size422.value;
    return new LeafNode2(edit, hash232, key, v22);
  }
};
function isEmptyNode2(a22) {
  return isTagged2(a22, "EmptyNode");
}
function isLeafNode2(node) {
  return isEmptyNode2(node) || node._tag === "LeafNode" || node._tag === "CollisionNode";
}
function canEditNode2(node, edit) {
  return isEmptyNode2(node) ? false : edit === node.edit;
}
var LeafNode2 = class _LeafNode2 {
  edit;
  hash;
  key;
  value;
  _tag = "LeafNode";
  constructor(edit, hash232, key, value) {
    this.edit = edit;
    this.hash = hash232;
    this.key = key;
    this.value = value;
  }
  modify(edit, shift2, f22, hash232, key, size422) {
    if (equals2(key, this.key)) {
      const v222 = f22(this.value);
      if (v222 === this.value) return this;
      else if (isNone22(v222)) {
        --size422.value;
        return new EmptyNode2();
      }
      if (canEditNode2(this, edit)) {
        this.value = v222;
        return this;
      }
      return new _LeafNode2(edit, hash232, key, v222);
    }
    const v22 = f22(none22());
    if (isNone22(v22)) return this;
    ++size422.value;
    return mergeLeaves2(edit, shift2, this.hash, this, hash232, new _LeafNode2(edit, hash232, key, v22));
  }
};
var CollisionNode2 = class _CollisionNode2 {
  edit;
  hash;
  children;
  _tag = "CollisionNode";
  constructor(edit, hash232, children) {
    this.edit = edit;
    this.hash = hash232;
    this.children = children;
  }
  modify(edit, shift2, f22, hash232, key, size422) {
    if (hash232 === this.hash) {
      const canEdit = canEditNode2(this, edit);
      const list = this.updateCollisionList(canEdit, edit, this.hash, this.children, f22, key, size422);
      if (list === this.children) return this;
      return list.length > 1 ? new _CollisionNode2(edit, this.hash, list) : list[0];
    }
    const v22 = f22(none22());
    if (isNone22(v22)) return this;
    ++size422.value;
    return mergeLeaves2(edit, shift2, this.hash, this, hash232, new LeafNode2(edit, hash232, key, v22));
  }
  updateCollisionList(mutate222, edit, hash232, list, f22, key, size422) {
    const len = list.length;
    for (let i22 = 0; i22 < len; ++i22) {
      const child = list[i22];
      if ("key" in child && equals2(key, child.key)) {
        const value = child.value;
        const newValue2 = f22(value);
        if (newValue2 === value) return list;
        if (isNone22(newValue2)) {
          --size422.value;
          return arraySpliceOut2(mutate222, i22, list);
        }
        return arrayUpdate2(mutate222, i22, new LeafNode2(edit, hash232, key, newValue2), list);
      }
    }
    const newValue = f22(none22());
    if (isNone22(newValue)) return list;
    ++size422.value;
    return arrayUpdate2(mutate222, len, new LeafNode2(edit, hash232, key, newValue), list);
  }
};
var IndexedNode2 = class _IndexedNode2 {
  edit;
  mask;
  children;
  _tag = "IndexedNode";
  constructor(edit, mask, children) {
    this.edit = edit;
    this.mask = mask;
    this.children = children;
  }
  modify(edit, shift2, f22, hash232, key, size422) {
    const mask = this.mask;
    const children = this.children;
    const frag = hashFragment2(shift2, hash232);
    const bit = toBitmap2(frag);
    const indx = fromBitmap2(mask, bit);
    const exists232 = mask & bit;
    const canEdit = canEditNode2(this, edit);
    if (!exists232) {
      const _newChild = new EmptyNode2().modify(edit, shift2 + SIZE2, f22, hash232, key, size422);
      if (!_newChild) return this;
      return children.length >= MAX_INDEX_NODE2 ? expand2(edit, frag, _newChild, mask, children) : new _IndexedNode2(edit, mask | bit, arraySpliceIn2(canEdit, indx, _newChild, children));
    }
    const current = children[indx];
    const child = current.modify(edit, shift2 + SIZE2, f22, hash232, key, size422);
    if (current === child) return this;
    let bitmap = mask;
    let newChildren;
    if (isEmptyNode2(child)) {
      bitmap &= ~bit;
      if (!bitmap) return new EmptyNode2();
      if (children.length <= 2 && isLeafNode2(children[indx ^ 1])) {
        return children[indx ^ 1];
      }
      newChildren = arraySpliceOut2(canEdit, indx, children);
    } else {
      newChildren = arrayUpdate2(canEdit, indx, child, children);
    }
    if (canEdit) {
      this.mask = bitmap;
      this.children = newChildren;
      return this;
    }
    return new _IndexedNode2(edit, bitmap, newChildren);
  }
};
var ArrayNode2 = class _ArrayNode2 {
  edit;
  size;
  children;
  _tag = "ArrayNode";
  constructor(edit, size422, children) {
    this.edit = edit;
    this.size = size422;
    this.children = children;
  }
  modify(edit, shift2, f22, hash232, key, size422) {
    let count = this.size;
    const children = this.children;
    const frag = hashFragment2(shift2, hash232);
    const child = children[frag];
    const newChild = (child || new EmptyNode2()).modify(edit, shift2 + SIZE2, f22, hash232, key, size422);
    if (child === newChild) return this;
    const canEdit = canEditNode2(this, edit);
    let newChildren;
    if (isEmptyNode2(child) && !isEmptyNode2(newChild)) {
      ++count;
      newChildren = arrayUpdate2(canEdit, frag, newChild, children);
    } else if (!isEmptyNode2(child) && isEmptyNode2(newChild)) {
      --count;
      if (count <= MIN_ARRAY_NODE2) {
        return pack2(edit, count, frag, children);
      }
      newChildren = arrayUpdate2(canEdit, frag, new EmptyNode2(), children);
    } else {
      newChildren = arrayUpdate2(canEdit, frag, newChild, children);
    }
    if (canEdit) {
      this.size = count;
      this.children = newChildren;
      return this;
    }
    return new _ArrayNode2(edit, count, newChildren);
  }
};
function pack2(edit, count, removed, elements) {
  const children = new Array(count - 1);
  let g22 = 0;
  let bitmap = 0;
  for (let i22 = 0, len = elements.length; i22 < len; ++i22) {
    if (i22 !== removed) {
      const elem = elements[i22];
      if (elem && !isEmptyNode2(elem)) {
        children[g22++] = elem;
        bitmap |= 1 << i22;
      }
    }
  }
  return new IndexedNode2(edit, bitmap, children);
}
function expand2(edit, frag, child, bitmap, subNodes) {
  const arr = [];
  let bit = bitmap;
  let count = 0;
  for (let i22 = 0; bit; ++i22) {
    if (bit & 1) arr[i22] = subNodes[count++];
    bit >>>= 1;
  }
  arr[frag] = child;
  return new ArrayNode2(edit, count + 1, arr);
}
function mergeLeavesInner2(edit, shift2, h1, n1, h22, n22) {
  if (h1 === h22) return new CollisionNode2(edit, h1, [n22, n1]);
  const subH1 = hashFragment2(shift2, h1);
  const subH2 = hashFragment2(shift2, h22);
  if (subH1 === subH2) {
    return (child) => new IndexedNode2(edit, toBitmap2(subH1) | toBitmap2(subH2), [child]);
  } else {
    const children = subH1 < subH2 ? [n1, n22] : [n22, n1];
    return new IndexedNode2(edit, toBitmap2(subH1) | toBitmap2(subH2), children);
  }
}
function mergeLeaves2(edit, shift2, h1, n1, h22, n22) {
  let stack = void 0;
  let currentShift = shift2;
  while (true) {
    const res = mergeLeavesInner2(edit, currentShift, h1, n1, h22, n22);
    if (typeof res === "function") {
      stack = make52(res, stack);
      currentShift = currentShift + SIZE2;
    } else {
      let final = res;
      while (stack != null) {
        final = stack.value(final);
        stack = stack.previous;
      }
      return final;
    }
  }
}
var HashMapSymbolKey2 = "effect/HashMap";
var HashMapTypeId2 = /* @__PURE__ */ Symbol.for(HashMapSymbolKey2);
var HashMapProto2 = {
  [HashMapTypeId2]: HashMapTypeId2,
  [Symbol.iterator]() {
    return new HashMapIterator2(this, (k22, v22) => [k22, v22]);
  },
  [symbol3]() {
    let hash232 = hash2(HashMapSymbolKey2);
    for (const item of this) {
      hash232 ^= pipe2(hash2(item[0]), combine3(hash2(item[1])));
    }
    return cached2(this, hash232);
  },
  [symbol22](that) {
    if (isHashMap2(that)) {
      if (that._size !== this._size) {
        return false;
      }
      for (const item of this) {
        const elem = pipe2(that, getHash2(item[0], hash2(item[0])));
        if (isNone22(elem)) {
          return false;
        } else {
          if (!equals2(item[1], elem.value)) {
            return false;
          }
        }
      }
      return true;
    }
    return false;
  },
  toString() {
    return format2(this.toJSON());
  },
  toJSON() {
    return {
      _id: "HashMap",
      values: Array.from(this).map(toJSON2)
    };
  },
  [NodeInspectSymbol2]() {
    return this.toJSON();
  },
  pipe() {
    return pipeArguments2(this, arguments);
  }
};
var makeImpl3 = (editable, edit, root, size422) => {
  const map62 = Object.create(HashMapProto2);
  map62._editable = editable;
  map62._edit = edit;
  map62._root = root;
  map62._size = size422;
  return map62;
};
var HashMapIterator2 = class _HashMapIterator2 {
  map;
  f;
  v;
  constructor(map62, f22) {
    this.map = map62;
    this.f = f22;
    this.v = visitLazy2(this.map._root, this.f, void 0);
  }
  next() {
    if (isNone22(this.v)) {
      return {
        done: true,
        value: void 0
      };
    }
    const v0 = this.v.value;
    this.v = applyCont2(v0.cont);
    return {
      done: false,
      value: v0.value
    };
  }
  [Symbol.iterator]() {
    return new _HashMapIterator2(this.map, this.f);
  }
};
var applyCont2 = (cont) => cont ? visitLazyChildren2(cont[0], cont[1], cont[2], cont[3], cont[4]) : none22();
var visitLazy2 = (node, f22, cont = void 0) => {
  switch (node._tag) {
    case "LeafNode": {
      if (isSome22(node.value)) {
        return some32({
          value: f22(node.key, node.value.value),
          cont
        });
      }
      return applyCont2(cont);
    }
    case "CollisionNode":
    case "ArrayNode":
    case "IndexedNode": {
      const children = node.children;
      return visitLazyChildren2(children.length, children, 0, f22, cont);
    }
    default: {
      return applyCont2(cont);
    }
  }
};
var visitLazyChildren2 = (len, children, i22, f22, cont) => {
  while (i22 < len) {
    const child = children[i22++];
    if (child && !isEmptyNode2(child)) {
      return visitLazy2(child, f22, [len, children, i22, f22, cont]);
    }
  }
  return applyCont2(cont);
};
var _empty32 = /* @__PURE__ */ makeImpl3(false, 0, /* @__PURE__ */ new EmptyNode2(), 0);
var empty42 = () => _empty32;
var isHashMap2 = (u22) => hasProperty2(u22, HashMapTypeId2);
var getHash2 = /* @__PURE__ */ dual2(3, (self2, key, hash232) => {
  let node = self2._root;
  let shift2 = 0;
  while (true) {
    switch (node._tag) {
      case "LeafNode": {
        return equals2(key, node.key) ? node.value : none22();
      }
      case "CollisionNode": {
        if (hash232 === node.hash) {
          const children = node.children;
          for (let i22 = 0, len = children.length; i22 < len; ++i22) {
            const child = children[i22];
            if ("key" in child && equals2(key, child.key)) {
              return child.value;
            }
          }
        }
        return none22();
      }
      case "IndexedNode": {
        const frag = hashFragment2(shift2, hash232);
        const bit = toBitmap2(frag);
        if (node.mask & bit) {
          node = node.children[fromBitmap2(node.mask, bit)];
          shift2 += SIZE2;
          break;
        }
        return none22();
      }
      case "ArrayNode": {
        node = node.children[hashFragment2(shift2, hash232)];
        if (node) {
          shift2 += SIZE2;
          break;
        }
        return none22();
      }
      default:
        return none22();
    }
  }
});
var set2 = /* @__PURE__ */ dual2(3, (self2, key, value) => modifyAt2(self2, key, () => some32(value)));
var setTree2 = /* @__PURE__ */ dual2(3, (self2, newRoot, newSize) => {
  if (self2._editable) {
    self2._root = newRoot;
    self2._size = newSize;
    return self2;
  }
  return newRoot === self2._root ? self2 : makeImpl3(self2._editable, self2._edit, newRoot, newSize);
});
var keys2 = (self2) => new HashMapIterator2(self2, (key) => key);
var size4 = (self2) => self2._size;
var beginMutation3 = (self2) => makeImpl3(true, self2._edit + 1, self2._root, self2._size);
var modifyAt2 = /* @__PURE__ */ dual2(3, (self2, key, f22) => modifyHash2(self2, key, hash2(key), f22));
var modifyHash2 = /* @__PURE__ */ dual2(4, (self2, key, hash232, f22) => {
  const size422 = {
    value: self2._size
  };
  const newRoot = self2._root.modify(self2._editable ? self2._edit : NaN, 0, f22, hash232, key, size422);
  return pipe2(self2, setTree2(newRoot, size422.value));
});
var forEach3 = /* @__PURE__ */ dual2(2, (self2, f22) => reduce22(self2, void 0, (_22, value, key) => f22(value, key)));
var reduce22 = /* @__PURE__ */ dual2(3, (self2, zero, f22) => {
  const root = self2._root;
  if (root._tag === "LeafNode") {
    return isSome22(root.value) ? f22(zero, root.value.value, root.key) : zero;
  }
  if (root._tag === "EmptyNode") {
    return zero;
  }
  const toVisit = [root.children];
  let children;
  while (children = toVisit.pop()) {
    for (let i22 = 0, len = children.length; i22 < len; ) {
      const child = children[i22++];
      if (child && !isEmptyNode2(child)) {
        if (child._tag === "LeafNode") {
          if (isSome22(child.value)) {
            zero = f22(zero, child.value.value, child.key);
          }
        } else {
          toVisit.push(child.children);
        }
      }
    }
  }
  return zero;
});
var HashSetSymbolKey2 = "effect/HashSet";
var HashSetTypeId2 = /* @__PURE__ */ Symbol.for(HashSetSymbolKey2);
var HashSetProto2 = {
  [HashSetTypeId2]: HashSetTypeId2,
  [Symbol.iterator]() {
    return keys2(this._keyMap);
  },
  [symbol3]() {
    return cached2(this, combine3(hash2(this._keyMap))(hash2(HashSetSymbolKey2)));
  },
  [symbol22](that) {
    if (isHashSet2(that)) {
      return size4(this._keyMap) === size4(that._keyMap) && equals2(this._keyMap, that._keyMap);
    }
    return false;
  },
  toString() {
    return format2(this.toJSON());
  },
  toJSON() {
    return {
      _id: "HashSet",
      values: Array.from(this).map(toJSON2)
    };
  },
  [NodeInspectSymbol2]() {
    return this.toJSON();
  },
  pipe() {
    return pipeArguments2(this, arguments);
  }
};
var makeImpl22 = (keyMap) => {
  const set232 = Object.create(HashSetProto2);
  set232._keyMap = keyMap;
  return set232;
};
var isHashSet2 = (u22) => hasProperty2(u22, HashSetTypeId2);
var _empty42 = /* @__PURE__ */ makeImpl22(/* @__PURE__ */ empty42());
var empty52 = () => _empty42;
var size22 = (self2) => size4(self2._keyMap);
var beginMutation22 = (self2) => makeImpl22(beginMutation3(self2._keyMap));
var endMutation2 = (self2) => {
  self2._keyMap._editable = false;
  return self2;
};
var mutate2 = /* @__PURE__ */ dual2(2, (self2, f22) => {
  const transient = beginMutation22(self2);
  f22(transient);
  return endMutation2(transient);
});
var add22 = /* @__PURE__ */ dual2(2, (self2, value) => self2._keyMap._editable ? (set2(value, true)(self2._keyMap), self2) : makeImpl22(set2(value, true)(self2._keyMap)));
var union22 = /* @__PURE__ */ dual2(2, (self2, that) => mutate2(empty52(), (set232) => {
  forEach22(self2, (value) => add22(set232, value));
  for (const value of that) {
    add22(set232, value);
  }
}));
var forEach22 = /* @__PURE__ */ dual2(2, (self2, f22) => forEach3(self2._keyMap, (_22, k22) => f22(k22)));
var empty62 = empty52;
var size32 = size22;
var add32 = add22;
var union32 = union22;
var ArrayProto2 = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(Array.prototype), {
  [symbol3]() {
    return cached2(this, array3(this));
  },
  [symbol22](that) {
    if (Array.isArray(that) && this.length === that.length) {
      return this.every((v22, i22) => equals2(v22, that[i22]));
    } else {
      return false;
    }
  }
});
var Structural3 = /* @__PURE__ */ function() {
  function Structural322(args) {
    if (args) {
      Object.assign(this, args);
    }
  }
  Structural322.prototype = StructuralPrototype2;
  return Structural322;
}();
var struct22 = (as232) => Object.assign(Object.create(StructuralPrototype2), as232);
var ContextPatchTypeId2 = /* @__PURE__ */ Symbol.for("effect/DifferContextPatch");
function variance3(a22) {
  return a22;
}
var PatchProto2 = {
  ...Structural3.prototype,
  [ContextPatchTypeId2]: {
    _Value: variance3,
    _Patch: variance3
  }
};
var EmptyProto2 = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(PatchProto2), {
  _tag: "Empty"
});
var _empty52 = /* @__PURE__ */ Object.create(EmptyProto2);
var empty72 = () => _empty52;
var AndThenProto2 = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(PatchProto2), {
  _tag: "AndThen"
});
var makeAndThen2 = (first, second) => {
  const o22 = Object.create(AndThenProto2);
  o22.first = first;
  o22.second = second;
  return o22;
};
var AddServiceProto2 = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(PatchProto2), {
  _tag: "AddService"
});
var makeAddService2 = (key, service) => {
  const o22 = Object.create(AddServiceProto2);
  o22.key = key;
  o22.service = service;
  return o22;
};
var RemoveServiceProto2 = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(PatchProto2), {
  _tag: "RemoveService"
});
var makeRemoveService2 = (key) => {
  const o22 = Object.create(RemoveServiceProto2);
  o22.key = key;
  return o22;
};
var UpdateServiceProto2 = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(PatchProto2), {
  _tag: "UpdateService"
});
var makeUpdateService2 = (key, update22) => {
  const o22 = Object.create(UpdateServiceProto2);
  o22.key = key;
  o22.update = update22;
  return o22;
};
var diff2 = (oldValue, newValue) => {
  const missingServices = new Map(oldValue.unsafeMap);
  let patch222 = empty72();
  for (const [tag, newService] of newValue.unsafeMap.entries()) {
    if (missingServices.has(tag)) {
      const old = missingServices.get(tag);
      missingServices.delete(tag);
      if (!equals2(old, newService)) {
        patch222 = combine22(makeUpdateService2(tag, () => newService))(patch222);
      }
    } else {
      missingServices.delete(tag);
      patch222 = combine22(makeAddService2(tag, newService))(patch222);
    }
  }
  for (const [tag] of missingServices.entries()) {
    patch222 = combine22(makeRemoveService2(tag))(patch222);
  }
  return patch222;
};
var combine22 = /* @__PURE__ */ dual2(2, (self2, that) => makeAndThen2(self2, that));
var patch2 = /* @__PURE__ */ dual2(2, (self2, context) => {
  if (self2._tag === "Empty") {
    return context;
  }
  let wasServiceUpdated = false;
  let patches = of2(self2);
  const updatedContext = new Map(context.unsafeMap);
  while (isNonEmpty2(patches)) {
    const head22 = headNonEmpty2(patches);
    const tail22 = tailNonEmpty2(patches);
    switch (head22._tag) {
      case "Empty": {
        patches = tail22;
        break;
      }
      case "AddService": {
        updatedContext.set(head22.key, head22.service);
        patches = tail22;
        break;
      }
      case "AndThen": {
        patches = prepend2(prepend2(tail22, head22.second), head22.first);
        break;
      }
      case "RemoveService": {
        updatedContext.delete(head22.key);
        patches = tail22;
        break;
      }
      case "UpdateService": {
        updatedContext.set(head22.key, head22.update(updatedContext.get(head22.key)));
        wasServiceUpdated = true;
        patches = tail22;
        break;
      }
    }
  }
  if (!wasServiceUpdated) {
    return makeContext2(updatedContext);
  }
  const map62 = /* @__PURE__ */ new Map();
  for (const [tag] of context.unsafeMap) {
    if (updatedContext.has(tag)) {
      map62.set(tag, updatedContext.get(tag));
      updatedContext.delete(tag);
    }
  }
  for (const [tag, s22] of updatedContext) {
    map62.set(tag, s22);
  }
  return makeContext2(map62);
});
var DifferTypeId2 = /* @__PURE__ */ Symbol.for("effect/Differ");
var DifferProto2 = {
  [DifferTypeId2]: {
    _P: identity2,
    _V: identity2
  }
};
var make72 = (params) => {
  const differ = Object.create(DifferProto2);
  differ.empty = params.empty;
  differ.diff = params.diff;
  differ.combine = params.combine;
  differ.patch = params.patch;
  return differ;
};
var environment2 = () => make72({
  empty: empty72(),
  combine: (first, second) => combine22(second)(first),
  diff: (oldValue, newValue) => diff2(oldValue, newValue),
  patch: (patch222, oldValue) => patch2(oldValue)(patch222)
});
var OP_DIE2 = "Die";
var OP_EMPTY2 = "Empty";
var OP_FAIL2 = "Fail";
var OP_INTERRUPT2 = "Interrupt";
var OP_PARALLEL2 = "Parallel";
var OP_SEQUENTIAL2 = "Sequential";
var CauseSymbolKey2 = "effect/Cause";
var CauseTypeId2 = /* @__PURE__ */ Symbol.for(CauseSymbolKey2);
var variance22 = {
  /* c8 ignore next */
  _E: (_22) => _22
};
var proto2 = {
  [CauseTypeId2]: variance22,
  [symbol3]() {
    return pipe2(hash2(CauseSymbolKey2), combine3(hash2(flattenCause2(this))), cached2(this));
  },
  [symbol22](that) {
    return isCause2(that) && causeEquals2(this, that);
  },
  pipe() {
    return pipeArguments2(this, arguments);
  },
  toJSON() {
    switch (this._tag) {
      case "Empty":
        return {
          _id: "Cause",
          _tag: this._tag
        };
      case "Die":
        return {
          _id: "Cause",
          _tag: this._tag,
          defect: toJSON2(this.defect)
        };
      case "Interrupt":
        return {
          _id: "Cause",
          _tag: this._tag,
          fiberId: this.fiberId.toJSON()
        };
      case "Fail":
        return {
          _id: "Cause",
          _tag: this._tag,
          failure: toJSON2(this.error)
        };
      case "Sequential":
      case "Parallel":
        return {
          _id: "Cause",
          _tag: this._tag,
          left: toJSON2(this.left),
          right: toJSON2(this.right)
        };
    }
  },
  toString() {
    return pretty2(this);
  },
  [NodeInspectSymbol2]() {
    return this.toJSON();
  }
};
var fail3 = (error) => {
  const o22 = Object.create(proto2);
  o22._tag = OP_FAIL2;
  o22.error = error;
  return o22;
};
var parallel2 = (left322, right322) => {
  const o22 = Object.create(proto2);
  o22._tag = OP_PARALLEL2;
  o22.left = left322;
  o22.right = right322;
  return o22;
};
var sequential2 = (left322, right322) => {
  const o22 = Object.create(proto2);
  o22._tag = OP_SEQUENTIAL2;
  o22.left = left322;
  o22.right = right322;
  return o22;
};
var isCause2 = (u22) => hasProperty2(u22, CauseTypeId2);
var isInterruptedOnly2 = (self2) => reduceWithContext2(void 0, IsInterruptedOnlyCauseReducer2)(self2);
var causeEquals2 = (left322, right322) => {
  let leftStack = of2(left322);
  let rightStack = of2(right322);
  while (isNonEmpty2(leftStack) && isNonEmpty2(rightStack)) {
    const [leftParallel, leftSequential] = pipe2(headNonEmpty2(leftStack), reduce42([empty62(), empty32()], ([parallel222, sequential222], cause) => {
      const [par, seq] = evaluateCause2(cause);
      return some32([pipe2(parallel222, union32(par)), pipe2(sequential222, appendAll2(seq))]);
    }));
    const [rightParallel, rightSequential] = pipe2(headNonEmpty2(rightStack), reduce42([empty62(), empty32()], ([parallel222, sequential222], cause) => {
      const [par, seq] = evaluateCause2(cause);
      return some32([pipe2(parallel222, union32(par)), pipe2(sequential222, appendAll2(seq))]);
    }));
    if (!equals2(leftParallel, rightParallel)) {
      return false;
    }
    leftStack = leftSequential;
    rightStack = rightSequential;
  }
  return true;
};
var flattenCause2 = (cause) => {
  return flattenCauseLoop2(of2(cause), empty32());
};
var flattenCauseLoop2 = (causes, flattened) => {
  while (1) {
    const [parallel222, sequential222] = pipe2(causes, reduce3([empty62(), empty32()], ([parallel32, sequential32], cause) => {
      const [par, seq] = evaluateCause2(cause);
      return [pipe2(parallel32, union32(par)), pipe2(sequential32, appendAll2(seq))];
    }));
    const updated = size32(parallel222) > 0 ? pipe2(flattened, prepend2(parallel222)) : flattened;
    if (isEmpty2(sequential222)) {
      return reverse22(updated);
    }
    causes = sequential222;
    flattened = updated;
  }
  throw new Error(getBugErrorMessage2("Cause.flattenCauseLoop"));
};
var evaluateCause2 = (self2) => {
  let cause = self2;
  const stack = [];
  let _parallel = empty62();
  let _sequential = empty32();
  while (cause !== void 0) {
    switch (cause._tag) {
      case OP_EMPTY2: {
        if (stack.length === 0) {
          return [_parallel, _sequential];
        }
        cause = stack.pop();
        break;
      }
      case OP_FAIL2: {
        _parallel = add32(_parallel, make42(cause._tag, cause.error));
        if (stack.length === 0) {
          return [_parallel, _sequential];
        }
        cause = stack.pop();
        break;
      }
      case OP_DIE2: {
        _parallel = add32(_parallel, make42(cause._tag, cause.defect));
        if (stack.length === 0) {
          return [_parallel, _sequential];
        }
        cause = stack.pop();
        break;
      }
      case OP_INTERRUPT2: {
        _parallel = add32(_parallel, make42(cause._tag, cause.fiberId));
        if (stack.length === 0) {
          return [_parallel, _sequential];
        }
        cause = stack.pop();
        break;
      }
      case OP_SEQUENTIAL2: {
        switch (cause.left._tag) {
          case OP_EMPTY2: {
            cause = cause.right;
            break;
          }
          case OP_SEQUENTIAL2: {
            cause = sequential2(cause.left.left, sequential2(cause.left.right, cause.right));
            break;
          }
          case OP_PARALLEL2: {
            cause = parallel2(sequential2(cause.left.left, cause.right), sequential2(cause.left.right, cause.right));
            break;
          }
          default: {
            _sequential = prepend2(_sequential, cause.right);
            cause = cause.left;
            break;
          }
        }
        break;
      }
      case OP_PARALLEL2: {
        stack.push(cause.right);
        cause = cause.left;
        break;
      }
    }
  }
  throw new Error(getBugErrorMessage2("Cause.evaluateCauseLoop"));
};
var IsInterruptedOnlyCauseReducer2 = {
  emptyCase: constTrue2,
  failCase: constFalse2,
  dieCase: constFalse2,
  interruptCase: constTrue2,
  sequentialCase: (_22, left322, right322) => left322 && right322,
  parallelCase: (_22, left322, right322) => left322 && right322
};
var OP_SEQUENTIAL_CASE2 = "SequentialCase";
var OP_PARALLEL_CASE2 = "ParallelCase";
var reduce42 = /* @__PURE__ */ dual2(3, (self2, zero, pf) => {
  let accumulator = zero;
  let cause = self2;
  const causes = [];
  while (cause !== void 0) {
    const option = pf(accumulator, cause);
    accumulator = isSome22(option) ? option.value : accumulator;
    switch (cause._tag) {
      case OP_SEQUENTIAL2: {
        causes.push(cause.right);
        cause = cause.left;
        break;
      }
      case OP_PARALLEL2: {
        causes.push(cause.right);
        cause = cause.left;
        break;
      }
      default: {
        cause = void 0;
        break;
      }
    }
    if (cause === void 0 && causes.length > 0) {
      cause = causes.pop();
    }
  }
  return accumulator;
});
var reduceWithContext2 = /* @__PURE__ */ dual2(3, (self2, context, reducer) => {
  const input = [self2];
  const output = [];
  while (input.length > 0) {
    const cause = input.pop();
    switch (cause._tag) {
      case OP_EMPTY2: {
        output.push(right22(reducer.emptyCase(context)));
        break;
      }
      case OP_FAIL2: {
        output.push(right22(reducer.failCase(context, cause.error)));
        break;
      }
      case OP_DIE2: {
        output.push(right22(reducer.dieCase(context, cause.defect)));
        break;
      }
      case OP_INTERRUPT2: {
        output.push(right22(reducer.interruptCase(context, cause.fiberId)));
        break;
      }
      case OP_SEQUENTIAL2: {
        input.push(cause.right);
        input.push(cause.left);
        output.push(left22({
          _tag: OP_SEQUENTIAL_CASE2
        }));
        break;
      }
      case OP_PARALLEL2: {
        input.push(cause.right);
        input.push(cause.left);
        output.push(left22({
          _tag: OP_PARALLEL_CASE2
        }));
        break;
      }
    }
  }
  const accumulator = [];
  while (output.length > 0) {
    const either = output.pop();
    switch (either._tag) {
      case "Left": {
        switch (either.left._tag) {
          case OP_SEQUENTIAL_CASE2: {
            const left322 = accumulator.pop();
            const right322 = accumulator.pop();
            const value = reducer.sequentialCase(context, left322, right322);
            accumulator.push(value);
            break;
          }
          case OP_PARALLEL_CASE2: {
            const left322 = accumulator.pop();
            const right322 = accumulator.pop();
            const value = reducer.parallelCase(context, left322, right322);
            accumulator.push(value);
            break;
          }
        }
        break;
      }
      case "Right": {
        accumulator.push(either.right);
        break;
      }
    }
  }
  if (accumulator.length === 0) {
    throw new Error("BUG: Cause.reduceWithContext - please report an issue at https://github.com/Effect-TS/effect/issues");
  }
  return accumulator.pop();
});
var pretty2 = (cause) => {
  if (isInterruptedOnly2(cause)) {
    return "All fibers interrupted without errors.";
  }
  return prettyErrors2(cause).map((e22) => e22.stack).join("\n");
};
var PrettyError2 = class extends globalThis.Error {
  span = void 0;
  constructor(originalError) {
    const prevLimit = Error.stackTraceLimit;
    Error.stackTraceLimit = 0;
    super(prettyErrorMessage2(originalError));
    Error.stackTraceLimit = prevLimit;
    this.name = originalError instanceof Error ? originalError.name : "Error";
    if (typeof originalError === "object" && originalError !== null) {
      if (spanSymbol3 in originalError) {
        this.span = originalError[spanSymbol3];
      }
      Object.keys(originalError).forEach((key) => {
        if (!(key in this)) {
          this[key] = originalError[key];
        }
      });
    }
    this.stack = prettyErrorStack2(this.message, originalError instanceof Error && originalError.stack ? originalError.stack : "", this.span);
  }
  toJSON() {
    const out = {
      message: this.message,
      stack: this.stack
    };
    if (this.span) {
      out.span = this.span;
    }
    return out;
  }
};
var prettyErrorMessage2 = (u22) => {
  if (typeof u22 === "string") {
    return `Error: ${u22}`;
  }
  try {
    if (hasProperty2(u22, "toString") && isFunction32(u22["toString"]) && u22["toString"] !== Object.prototype.toString && u22["toString"] !== globalThis.Array.prototype.toString) {
      return u22["toString"]();
    }
  } catch {
  }
  return `Error: ${JSON.stringify(u22)}`;
};
var locationRegex2 = /\((.*)\)/;
var spanToTrace2 = /* @__PURE__ */ globalValue2("effect/Tracer/spanToTrace", () => /* @__PURE__ */ new WeakMap());
var prettyErrorStack2 = (message, stack, span2) => {
  const out = [message];
  const lines = stack.split("\n");
  for (let i22 = 1; i22 < lines.length; i22++) {
    if (lines[i22].includes("Generator.next")) {
      break;
    }
    if (lines[i22].includes("effect_internal_function")) {
      out.pop();
      break;
    }
    out.push(lines[i22].replace(/at .*effect_instruction_i.*\((.*)\)/, "at $1").replace(/EffectPrimitive\.\w+/, "<anonymous>"));
  }
  if (span2) {
    let current = span2;
    let i22 = 0;
    while (current && current._tag === "Span" && i22 < 10) {
      const stackFn = spanToTrace2.get(current);
      if (typeof stackFn === "function") {
        const stack2 = stackFn();
        const locationMatch = stack2.match(locationRegex2);
        const location = locationMatch ? locationMatch[1] : stack2.replace(/^at /, "");
        out.push(`    at ${current.name} (${location})`);
      } else {
        out.push(`    at ${current.name}`);
      }
      current = getOrUndefined2(current.parent);
      i22++;
    }
  }
  return out.join("\n");
};
var spanSymbol3 = /* @__PURE__ */ Symbol.for("effect/SpanAnnotation");
var prettyErrors2 = (cause) => reduceWithContext2(cause, void 0, {
  emptyCase: () => [],
  dieCase: (_22, unknownError) => {
    return [new PrettyError2(unknownError)];
  },
  failCase: (_22, error) => {
    return [new PrettyError2(error)];
  },
  interruptCase: () => [],
  parallelCase: (_22, l22, r22) => [...l22, ...r22],
  sequentialCase: (_22, l22, r22) => [...l22, ...r22]
});
var SingleShotGen22 = class _SingleShotGen22 {
  self;
  called = false;
  constructor(self2) {
    this.self = self2;
  }
  next(a22) {
    return this.called ? {
      value: a22,
      done: true
    } : (this.called = true, {
      value: this.self,
      done: false
    });
  }
  return(a22) {
    return {
      value: a22,
      done: true
    };
  }
  throw(e22) {
    throw e22;
  }
  [Symbol.iterator]() {
    return new _SingleShotGen22(this.self);
  }
};
var spanTag2 = /* @__PURE__ */ GenericTag2("effect/ParentSpan");
var EffectTypeId22 = /* @__PURE__ */ Symbol.for("effect/Effect");
var EffectPrimitive2 = class {
  _op;
  effect_instruction_i0 = void 0;
  effect_instruction_i1 = void 0;
  effect_instruction_i2 = void 0;
  trace = void 0;
  [EffectTypeId22] = effectVariance2;
  constructor(_op) {
    this._op = _op;
  }
  [symbol22](that) {
    return this === that;
  }
  [symbol3]() {
    return cached2(this, random2(this));
  }
  pipe() {
    return pipeArguments2(this, arguments);
  }
  toJSON() {
    return {
      _id: "Effect",
      _op: this._op,
      effect_instruction_i0: toJSON2(this.effect_instruction_i0),
      effect_instruction_i1: toJSON2(this.effect_instruction_i1),
      effect_instruction_i2: toJSON2(this.effect_instruction_i2)
    };
  }
  toString() {
    return format2(this.toJSON());
  }
  [NodeInspectSymbol2]() {
    return this.toJSON();
  }
  [Symbol.iterator]() {
    return new SingleShotGen22(new YieldWrap2(this));
  }
};
var EffectPrimitiveFailure2 = class {
  _op;
  effect_instruction_i0 = void 0;
  effect_instruction_i1 = void 0;
  effect_instruction_i2 = void 0;
  trace = void 0;
  [EffectTypeId22] = effectVariance2;
  constructor(_op) {
    this._op = _op;
    this._tag = _op;
  }
  [symbol22](that) {
    return exitIsExit2(that) && that._op === "Failure" && // @ts-expect-error
    equals2(this.effect_instruction_i0, that.effect_instruction_i0);
  }
  [symbol3]() {
    return pipe2(
      // @ts-expect-error
      string2(this._tag),
      // @ts-expect-error
      combine3(hash2(this.effect_instruction_i0)),
      cached2(this)
    );
  }
  get cause() {
    return this.effect_instruction_i0;
  }
  pipe() {
    return pipeArguments2(this, arguments);
  }
  toJSON() {
    return {
      _id: "Exit",
      _tag: this._op,
      cause: this.cause.toJSON()
    };
  }
  toString() {
    return format2(this.toJSON());
  }
  [NodeInspectSymbol2]() {
    return this.toJSON();
  }
  [Symbol.iterator]() {
    return new SingleShotGen22(new YieldWrap2(this));
  }
};
var isEffect2 = (u22) => hasProperty2(u22, EffectTypeId22);
var withFiberRuntime2 = (withRuntime) => {
  const effect = new EffectPrimitive2(OP_WITH_RUNTIME2);
  effect.effect_instruction_i0 = withRuntime;
  return effect;
};
var spanSymbol22 = /* @__PURE__ */ Symbol.for("effect/SpanAnnotation");
var originalSymbol2 = /* @__PURE__ */ Symbol.for("effect/OriginalAnnotation");
var capture2 = (obj, span2) => {
  if (isSome22(span2)) {
    return new Proxy(obj, {
      has(target, p22) {
        return p22 === spanSymbol22 || p22 === originalSymbol2 || p22 in target;
      },
      get(target, p22) {
        if (p22 === spanSymbol22) {
          return span2.value;
        }
        if (p22 === originalSymbol2) {
          return obj;
        }
        return target[p22];
      }
    });
  }
  return obj;
};
var fail22 = (error) => isObject2(error) && !(spanSymbol22 in error) ? withFiberRuntime2((fiber) => failCause2(fail3(capture2(error, currentSpanFromFiber2(fiber))))) : failCause2(fail3(error));
var failCause2 = (cause) => {
  const effect = new EffectPrimitiveFailure2(OP_FAILURE2);
  effect.effect_instruction_i0 = cause;
  return effect;
};
var FiberRefSymbolKey2 = "effect/FiberRef";
var FiberRefTypeId2 = /* @__PURE__ */ Symbol.for(FiberRefSymbolKey2);
var fiberRefVariance2 = {
  /* c8 ignore next */
  _A: (_22) => _22
};
var fiberRefUnsafeMakeContext2 = (initial) => {
  const differ = environment2();
  return fiberRefUnsafeMakePatch2(initial, {
    differ,
    fork: differ.empty
  });
};
var fiberRefUnsafeMakePatch2 = (initial, options) => ({
  [FiberRefTypeId2]: fiberRefVariance2,
  initial,
  diff: (oldValue, newValue) => options.differ.diff(oldValue, newValue),
  combine: (first, second) => options.differ.combine(first, second),
  patch: (patch222) => (oldValue) => options.differ.patch(patch222, oldValue),
  fork: options.fork,
  join: options.join ?? ((_22, n22) => n22),
  pipe() {
    return pipeArguments2(this, arguments);
  }
});
var currentContext2 = /* @__PURE__ */ globalValue2(/* @__PURE__ */ Symbol.for("effect/FiberRef/currentContext"), () => fiberRefUnsafeMakeContext2(empty22()));
var YieldableError2 = /* @__PURE__ */ function() {
  class YieldableError222 extends globalThis.Error {
    commit() {
      return fail22(this);
    }
    toString() {
      return this.message ? `${this.name}: ${this.message}` : this.name;
    }
    toJSON() {
      return {
        ...this
      };
    }
    [NodeInspectSymbol2]() {
      const stack = this.stack;
      if (stack) {
        return `${this.toString()}
${stack.split("\n").slice(1).join("\n")}`;
      }
      return this.toString();
    }
  }
  Object.assign(YieldableError222.prototype, StructuralCommitPrototype2);
  return YieldableError222;
}();
var exitIsExit2 = (u22) => isEffect2(u22) && "_tag" in u22 && (u22._tag === "Success" || u22._tag === "Failure");
var currentSpanFromFiber2 = (fiber) => {
  const span2 = fiber.getFiberRef(currentContext2).unsafeMap.get(spanTag2.key);
  return span2 !== void 0 && span2._tag === "Span" ? some32(span2) : none22();
};
var Data_exports2 = {};
__export22(Data_exports2, {
  Class: () => Class22,
  Error: () => Error22,
  Structural: () => Structural22,
  TaggedClass: () => TaggedClass2,
  TaggedError: () => TaggedError2,
  array: () => array22,
  case: () => _case2,
  struct: () => struct32,
  tagged: () => tagged2,
  taggedEnum: () => taggedEnum2,
  tuple: () => tuple22,
  unsafeArray: () => unsafeArray2,
  unsafeStruct: () => unsafeStruct2
});
var struct32 = struct22;
var unsafeStruct2 = (as232) => Object.setPrototypeOf(as232, StructuralPrototype2);
var tuple22 = (...as232) => unsafeArray2(as232);
var array22 = (as232) => unsafeArray2(as232.slice(0));
var unsafeArray2 = (as232) => Object.setPrototypeOf(as232, ArrayProto2);
var _case2 = () => (args) => args === void 0 ? Object.create(StructuralPrototype2) : struct32(args);
var tagged2 = (tag) => (args) => {
  const value = args === void 0 ? Object.create(StructuralPrototype2) : struct32(args);
  value._tag = tag;
  return value;
};
var Class22 = Structural3;
var TaggedClass2 = (tag) => {
  class Base extends Class22 {
    _tag = tag;
  }
  return Base;
};
var Structural22 = Structural3;
var taggedEnum2 = () => new Proxy({}, {
  get(_target, tag, _receiver) {
    if (tag === "$is") {
      return isTagged2;
    } else if (tag === "$match") {
      return taggedMatch2;
    }
    return tagged2(tag);
  }
});
function taggedMatch2() {
  if (arguments.length === 1) {
    const cases2 = arguments[0];
    return function(value2) {
      return cases2[value2._tag](value2);
    };
  }
  const value = arguments[0];
  const cases = arguments[1];
  return cases[value._tag](value);
}
var Error22 = /* @__PURE__ */ function() {
  return class Base extends YieldableError2 {
    constructor(args) {
      super();
      if (args) {
        Object.assign(this, args);
      }
    }
  };
}();
var TaggedError2 = (tag) => {
  class Base extends Error22 {
    _tag = tag;
  }
  Base.prototype.name = tag;
  return Base;
};
var traverseUp2 = Function_exports2.dual(2, (node, predicate) => {
  const { parent } = node;
  if (!parent || parent.type === NodeType2.Program) return Option_exports2.none();
  return predicate(parent) ? Option_exports2.some(parent) : traverseUp2(parent, predicate);
});
var traverseUpGuard2 = Function_exports2.dual(2, (node, predicate) => {
  const { parent } = node;
  if (!parent || parent.type === NodeType2.Program) return Option_exports2.none();
  return predicate(parent) ? Option_exports2.some(parent) : traverseUpGuard2(parent, predicate);
});
var ESLintCommunityESLintUtils2;
((ESLintCommunityESLintUtils222) => {
  ESLintCommunityESLintUtils222.getFunctionHeadLocation = getFunctionHeadLocation2;
  ESLintCommunityESLintUtils222.getFunctionNameWithKind = getFunctionNameWithKind2;
  ESLintCommunityESLintUtils222.getPropertyName = getPropertyName2;
  ESLintCommunityESLintUtils222.getStaticValue = getStaticValue2;
  ESLintCommunityESLintUtils222.getStringIfConstant = getStringIfConstant2;
  ESLintCommunityESLintUtils222.hasSideEffect = hasSideEffect2;
  ESLintCommunityESLintUtils222.isParenthesized = isParenthesized2;
})(ESLintCommunityESLintUtils2 || (ESLintCommunityESLintUtils2 = {}));
var Construction2 = Data_exports2.taggedEnum();
Construction2.None();
tsPattern.isMatching({
  type: tsPattern.P.union([NodeType2.FunctionExpression, NodeType2.ArrowFunctionExpression]),
  parent: {
    type: NodeType2.Property,
    parent: {
      type: NodeType2.ObjectExpression
    }
  }
});
tsPattern.isMatching({
  type: tsPattern.P.union([NodeType2.FunctionExpression, NodeType2.ArrowFunctionExpression]),
  parent: {
    type: NodeType2.MethodDefinition,
    parent: {
      type: NodeType2.ClassBody
    }
  }
});
tsPattern.isMatching({
  type: tsPattern.P.union([NodeType2.FunctionExpression, NodeType2.ArrowFunctionExpression]),
  parent: {
    type: NodeType2.Property,
    parent: {
      type: NodeType2.ClassBody
    }
  }
});
var Function_exports22 = {};
__export3(Function_exports22, {
  SK: () => SK22,
  absurd: () => absurd22,
  apply: () => apply22,
  compose: () => compose32,
  constFalse: () => constFalse22,
  constNull: () => constNull22,
  constTrue: () => constTrue22,
  constUndefined: () => constUndefined22,
  constVoid: () => constVoid22,
  constant: () => constant22,
  dual: () => dual22,
  flip: () => flip22,
  flow: () => flow22,
  hole: () => hole22,
  identity: () => identity22,
  isFunction: () => isFunction4,
  pipe: () => pipe22,
  satisfies: () => satisfies22,
  tupled: () => tupled22,
  unsafeCoerce: () => unsafeCoerce22,
  untupled: () => untupled22
});
var isFunction4 = (input) => typeof input === "function";
var dual22 = function(arity, body) {
  if (typeof arity === "function") {
    return function() {
      if (arity(arguments)) {
        return body.apply(this, arguments);
      }
      return (self2) => body(self2, ...arguments);
    };
  }
  switch (arity) {
    case 0:
    case 1:
      throw new RangeError(`Invalid arity ${arity}`);
    case 2:
      return function(a22, b22) {
        if (arguments.length >= 2) {
          return body(a22, b22);
        }
        return function(self2) {
          return body(self2, a22);
        };
      };
    case 3:
      return function(a22, b22, c22) {
        if (arguments.length >= 3) {
          return body(a22, b22, c22);
        }
        return function(self2) {
          return body(self2, a22, b22);
        };
      };
    case 4:
      return function(a22, b22, c22, d22) {
        if (arguments.length >= 4) {
          return body(a22, b22, c22, d22);
        }
        return function(self2) {
          return body(self2, a22, b22, c22);
        };
      };
    case 5:
      return function(a22, b22, c22, d22, e22) {
        if (arguments.length >= 5) {
          return body(a22, b22, c22, d22, e22);
        }
        return function(self2) {
          return body(self2, a22, b22, c22, d22);
        };
      };
    default:
      return function() {
        if (arguments.length >= arity) {
          return body.apply(this, arguments);
        }
        const args = arguments;
        return function(self2) {
          return body(self2, ...args);
        };
      };
  }
};
var apply22 = (a22) => (self2) => self2(a22);
var identity22 = (a22) => a22;
var satisfies22 = () => (b22) => b22;
var unsafeCoerce22 = identity22;
var constant22 = (value) => () => value;
var constTrue22 = /* @__PURE__ */ constant22(true);
var constFalse22 = /* @__PURE__ */ constant22(false);
var constNull22 = /* @__PURE__ */ constant22(null);
var constUndefined22 = /* @__PURE__ */ constant22(void 0);
var constVoid22 = constUndefined22;
var flip22 = (f22) => (...b22) => (...a22) => f22(...a22)(...b22);
var compose32 = /* @__PURE__ */ dual22(2, (ab, bc) => (a22) => bc(ab(a22)));
var absurd22 = (_22) => {
  throw new Error("Called `absurd` function which should be uncallable");
};
var tupled22 = (f22) => (a22) => f22(...a22);
var untupled22 = (f22) => (...a22) => f22(a22);
function pipe22(a22, ab, bc, cd, de, ef, fg, gh, hi) {
  switch (arguments.length) {
    case 1:
      return a22;
    case 2:
      return ab(a22);
    case 3:
      return bc(ab(a22));
    case 4:
      return cd(bc(ab(a22)));
    case 5:
      return de(cd(bc(ab(a22))));
    case 6:
      return ef(de(cd(bc(ab(a22)))));
    case 7:
      return fg(ef(de(cd(bc(ab(a22))))));
    case 8:
      return gh(fg(ef(de(cd(bc(ab(a22)))))));
    case 9:
      return hi(gh(fg(ef(de(cd(bc(ab(a22))))))));
    default: {
      let ret = arguments[0];
      for (let i22 = 1; i22 < arguments.length; i22++) {
        ret = arguments[i22](ret);
      }
      return ret;
    }
  }
}
function flow22(ab, bc, cd, de, ef, fg, gh, hi, ij) {
  switch (arguments.length) {
    case 1:
      return ab;
    case 2:
      return function() {
        return bc(ab.apply(this, arguments));
      };
    case 3:
      return function() {
        return cd(bc(ab.apply(this, arguments)));
      };
    case 4:
      return function() {
        return de(cd(bc(ab.apply(this, arguments))));
      };
    case 5:
      return function() {
        return ef(de(cd(bc(ab.apply(this, arguments)))));
      };
    case 6:
      return function() {
        return fg(ef(de(cd(bc(ab.apply(this, arguments))))));
      };
    case 7:
      return function() {
        return gh(fg(ef(de(cd(bc(ab.apply(this, arguments)))))));
      };
    case 8:
      return function() {
        return hi(gh(fg(ef(de(cd(bc(ab.apply(this, arguments))))))));
      };
    case 9:
      return function() {
        return ij(hi(gh(fg(ef(de(cd(bc(ab.apply(this, arguments)))))))));
      };
  }
  return;
}
var hole22 = /* @__PURE__ */ unsafeCoerce22(absurd22);
var SK22 = (_22, b22) => b22;
var Array_exports = {};
__export3(Array_exports, {
  Do: () => Do3,
  allocate: () => allocate,
  append: () => append,
  appendAll: () => appendAll22,
  bind: () => bind5,
  bindTo: () => bindTo5,
  cartesian: () => cartesian,
  cartesianWith: () => cartesianWith,
  chop: () => chop,
  chunksOf: () => chunksOf,
  contains: () => contains3,
  containsWith: () => containsWith3,
  copy: () => copy22,
  dedupe: () => dedupe,
  dedupeAdjacent: () => dedupeAdjacent,
  dedupeAdjacentWith: () => dedupeAdjacentWith,
  dedupeWith: () => dedupeWith,
  difference: () => difference,
  differenceWith: () => differenceWith,
  drop: () => drop22,
  dropRight: () => dropRight,
  dropWhile: () => dropWhile,
  empty: () => empty9,
  every: () => every3,
  extend: () => extend,
  filter: () => filter3,
  filterMap: () => filterMap3,
  filterMapWhile: () => filterMapWhile,
  findFirst: () => findFirst2,
  findFirstIndex: () => findFirstIndex,
  findLast: () => findLast,
  findLastIndex: () => findLastIndex,
  flatMap: () => flatMap3,
  flatMapNullable: () => flatMapNullable3,
  flatten: () => flatten3,
  forEach: () => forEach32,
  fromIterable: () => fromIterable4,
  fromNullable: () => fromNullable3,
  fromOption: () => fromOption2,
  fromRecord: () => fromRecord,
  get: () => get,
  getEquivalence: () => getEquivalence4,
  getLefts: () => getLefts,
  getOrder: () => getOrder3,
  getRights: () => getRights,
  getSomes: () => getSomes,
  group: () => group,
  groupBy: () => groupBy,
  groupWith: () => groupWith,
  head: () => head,
  headNonEmpty: () => headNonEmpty22,
  init: () => init,
  initNonEmpty: () => initNonEmpty,
  insertAt: () => insertAt,
  intersection: () => intersection,
  intersectionWith: () => intersectionWith,
  intersperse: () => intersperse,
  isArray: () => isArray,
  isEmptyArray: () => isEmptyArray,
  isEmptyReadonlyArray: () => isEmptyReadonlyArray,
  isNonEmptyArray: () => isNonEmptyArray2,
  isNonEmptyReadonlyArray: () => isNonEmptyReadonlyArray,
  join: () => join,
  last: () => last,
  lastNonEmpty: () => lastNonEmpty,
  length: () => length,
  let: () => let_5,
  liftEither: () => liftEither,
  liftNullable: () => liftNullable3,
  liftOption: () => liftOption,
  liftPredicate: () => liftPredicate3,
  make: () => make10,
  makeBy: () => makeBy,
  map: () => map3,
  mapAccum: () => mapAccum,
  match: () => match4,
  matchLeft: () => matchLeft,
  matchRight: () => matchRight,
  max: () => max2,
  min: () => min2,
  modify: () => modify,
  modifyNonEmptyHead: () => modifyNonEmptyHead,
  modifyNonEmptyLast: () => modifyNonEmptyLast,
  modifyOption: () => modifyOption,
  of: () => of22,
  partition: () => partition,
  partitionMap: () => partitionMap3,
  prepend: () => prepend22,
  prependAll: () => prependAll,
  range: () => range,
  reduce: () => reduce32,
  reduceRight: () => reduceRight,
  remove: () => remove,
  replace: () => replace2,
  replaceOption: () => replaceOption,
  replicate: () => replicate,
  reverse: () => reverse32,
  rotate: () => rotate,
  scan: () => scan,
  scanRight: () => scanRight,
  separate: () => separate,
  setNonEmptyHead: () => setNonEmptyHead,
  setNonEmptyLast: () => setNonEmptyLast,
  some: () => some7,
  sort: () => sort,
  sortBy: () => sortBy,
  sortWith: () => sortWith,
  span: () => span,
  split: () => split,
  splitAt: () => splitAt,
  splitNonEmptyAt: () => splitNonEmptyAt,
  splitWhere: () => splitWhere,
  tail: () => tail,
  tailNonEmpty: () => tailNonEmpty22,
  take: () => take,
  takeRight: () => takeRight,
  takeWhile: () => takeWhile,
  unappend: () => unappend,
  unfold: () => unfold,
  union: () => union,
  unionWith: () => unionWith,
  unprepend: () => unprepend,
  unsafeGet: () => unsafeGet,
  unzip: () => unzip,
  zip: () => zip,
  zipWith: () => zipWith3
});
var make62 = (isEquivalent) => (self2, that) => self2 === that || isEquivalent(self2, that);
var array32 = (item) => make62((self2, that) => {
  if (self2.length !== that.length) {
    return false;
  }
  for (let i22 = 0; i22 < self2.length; i22++) {
    const isEq = item(self2[i22], that[i22]);
    if (!isEq) {
      return false;
    }
  }
  return true;
});
var let_32 = (map52) => dual22(3, (self2, name, f22) => map52(self2, (a22) => Object.assign({}, a22, {
  [name]: f22(a22)
})));
var bindTo32 = (map52) => dual22(2, (self2, name) => map52(self2, (a22) => ({
  [name]: a22
})));
var bind32 = (map52, flatMap52) => dual22(3, (self2, name, f22) => flatMap52(self2, (a22) => map52(f22(a22), (b22) => Object.assign({}, a22, {
  [name]: b22
}))));
var moduleVersion22 = "3.2.8";
var getCurrentVersion22 = () => moduleVersion22;
var globalStoreId22 = /* @__PURE__ */ Symbol.for(`effect/GlobalValue/globalStoreId/${/* @__PURE__ */ getCurrentVersion22()}`);
if (!(globalStoreId22 in globalThis)) {
  globalThis[globalStoreId22] = /* @__PURE__ */ new Map();
}
var globalStore22 = globalThis[globalStoreId22];
var globalValue22 = (id, compute) => {
  if (!globalStore22.has(id)) {
    globalStore22.set(id, compute());
  }
  return globalStore22.get(id);
};
var Predicate_exports22 = {};
__export3(Predicate_exports22, {
  all: () => all32,
  and: () => and22,
  compose: () => compose4,
  eqv: () => eqv22,
  every: () => every22,
  hasProperty: () => hasProperty22,
  implies: () => implies22,
  isBigInt: () => isBigInt22,
  isBoolean: () => isBoolean22,
  isDate: () => isDate22,
  isError: () => isError22,
  isFunction: () => isFunction5,
  isIterable: () => isIterable22,
  isMap: () => isMap22,
  isNever: () => isNever22,
  isNotNull: () => isNotNull22,
  isNotNullable: () => isNotNullable22,
  isNotUndefined: () => isNotUndefined22,
  isNull: () => isNull22,
  isNullable: () => isNullable22,
  isNumber: () => isNumber22,
  isObject: () => isObject22,
  isPromise: () => isPromise22,
  isPromiseLike: () => isPromiseLike22,
  isReadonlyRecord: () => isReadonlyRecord22,
  isRecord: () => isRecord22,
  isSet: () => isSet22,
  isString: () => isString22,
  isSymbol: () => isSymbol22,
  isTagged: () => isTagged22,
  isTruthy: () => isTruthy22,
  isUint8Array: () => isUint8Array22,
  isUndefined: () => isUndefined22,
  isUnknown: () => isUnknown22,
  mapInput: () => mapInput22,
  nand: () => nand22,
  nor: () => nor22,
  not: () => not22,
  or: () => or22,
  product: () => product32,
  productMany: () => productMany32,
  some: () => some42,
  struct: () => struct42,
  tuple: () => tuple32,
  xor: () => xor22
});
var mapInput22 = /* @__PURE__ */ dual22(2, (self2, f22) => (b22) => self2(f22(b22)));
var isTruthy22 = (input) => !!input;
var isSet22 = (input) => input instanceof Set;
var isMap22 = (input) => input instanceof Map;
var isString22 = (input) => typeof input === "string";
var isNumber22 = (input) => typeof input === "number";
var isBoolean22 = (input) => typeof input === "boolean";
var isBigInt22 = (input) => typeof input === "bigint";
var isSymbol22 = (input) => typeof input === "symbol";
var isFunction5 = isFunction4;
var isUndefined22 = (input) => input === void 0;
var isNotUndefined22 = (input) => input !== void 0;
var isNull22 = (input) => input === null;
var isNotNull22 = (input) => input !== null;
var isNever22 = (_22) => false;
var isUnknown22 = (_22) => true;
var isRecordOrArray22 = (input) => typeof input === "object" && input !== null;
var isObject22 = (input) => isRecordOrArray22(input) || isFunction5(input);
var hasProperty22 = /* @__PURE__ */ dual22(2, (self2, property) => isObject22(self2) && property in self2);
var isTagged22 = /* @__PURE__ */ dual22(2, (self2, tag) => hasProperty22(self2, "_tag") && self2["_tag"] === tag);
var isNullable22 = (input) => input === null || input === void 0;
var isNotNullable22 = (input) => input !== null && input !== void 0;
var isError22 = (input) => input instanceof Error;
var isUint8Array22 = (input) => input instanceof Uint8Array;
var isDate22 = (input) => input instanceof Date;
var isIterable22 = (input) => hasProperty22(input, Symbol.iterator);
var isRecord22 = (input) => isRecordOrArray22(input) && !Array.isArray(input);
var isReadonlyRecord22 = isRecord22;
var isPromise22 = (input) => hasProperty22(input, "then") && "catch" in input && isFunction5(input.then) && isFunction5(input.catch);
var isPromiseLike22 = (input) => hasProperty22(input, "then") && isFunction5(input.then);
var compose4 = /* @__PURE__ */ dual22(2, (ab, bc) => (a22) => ab(a22) && bc(a22));
var product32 = (self2, that) => ([a22, b22]) => self2(a22) && that(b22);
var all32 = (collection) => {
  return (as42) => {
    let collectionIndex = 0;
    for (const p22 of collection) {
      if (collectionIndex >= as42.length) {
        break;
      }
      if (p22(as42[collectionIndex]) === false) {
        return false;
      }
      collectionIndex++;
    }
    return true;
  };
};
var productMany32 = (self2, collection) => {
  const rest = all32(collection);
  return ([head22, ...tail22]) => self2(head22) === false ? false : rest(tail22);
};
var tuple32 = (...elements) => all32(elements);
var struct42 = (fields) => {
  const keys42 = Object.keys(fields);
  return (a22) => {
    for (const key of keys42) {
      if (!fields[key](a22[key])) {
        return false;
      }
    }
    return true;
  };
};
var not22 = (self2) => (a22) => !self2(a22);
var or22 = /* @__PURE__ */ dual22(2, (self2, that) => (a22) => self2(a22) || that(a22));
var and22 = /* @__PURE__ */ dual22(2, (self2, that) => (a22) => self2(a22) && that(a22));
var xor22 = /* @__PURE__ */ dual22(2, (self2, that) => (a22) => self2(a22) !== that(a22));
var eqv22 = /* @__PURE__ */ dual22(2, (self2, that) => (a22) => self2(a22) === that(a22));
var implies22 = /* @__PURE__ */ dual22(2, (self2, that) => (a22) => self2(a22) ? that(a22) : true);
var nor22 = /* @__PURE__ */ dual22(2, (self2, that) => (a22) => !(self2(a22) || that(a22)));
var nand22 = /* @__PURE__ */ dual22(2, (self2, that) => (a22) => !(self2(a22) && that(a22)));
var every22 = (collection) => (a22) => {
  for (const p22 of collection) {
    if (!p22(a22)) {
      return false;
    }
  }
  return true;
};
var some42 = (collection) => (a22) => {
  for (const p22 of collection) {
    if (p22(a22)) {
      return true;
    }
  }
  return false;
};
var getBugErrorMessage22 = (message) => `BUG: ${message} - please report an issue at https://github.com/Effect-TS/effect/issues`;
var GenKindTypeId22 = /* @__PURE__ */ Symbol.for("effect/Gen/GenKind");
var isGenKind22 = (u22) => isObject22(u22) && GenKindTypeId22 in u22;
var GenKindImpl22 = class {
  value;
  constructor(value) {
    this.value = value;
  }
  /**
   * @since 2.0.0
   */
  get _F() {
    return identity22;
  }
  /**
   * @since 2.0.0
   */
  get _R() {
    return (_22) => _22;
  }
  /**
   * @since 2.0.0
   */
  get _O() {
    return (_22) => _22;
  }
  /**
   * @since 2.0.0
   */
  get _E() {
    return (_22) => _22;
  }
  /**
   * @since 2.0.0
   */
  [GenKindTypeId22] = GenKindTypeId22;
  /**
   * @since 2.0.0
   */
  [Symbol.iterator]() {
    return new SingleShotGen32(this);
  }
};
var SingleShotGen32 = class _SingleShotGen5 {
  self;
  called = false;
  constructor(self2) {
    this.self = self2;
  }
  /**
   * @since 2.0.0
   */
  next(a22) {
    return this.called ? {
      value: a22,
      done: true
    } : (this.called = true, {
      value: this.self,
      done: false
    });
  }
  /**
   * @since 2.0.0
   */
  return(a22) {
    return {
      value: a22,
      done: true
    };
  }
  /**
   * @since 2.0.0
   */
  throw(e22) {
    throw e22;
  }
  /**
   * @since 2.0.0
   */
  [Symbol.iterator]() {
    return new _SingleShotGen5(this.self);
  }
};
var adapter32 = () => function() {
  let x22 = arguments[0];
  for (let i22 = 1; i22 < arguments.length; i22++) {
    x22 = arguments[i22](x22);
  }
  return new GenKindImpl22(x22);
};
var defaultIncHi22 = 335903614;
var defaultIncLo22 = 4150755663;
var MUL_HI22 = 1481765933 >>> 0;
var MUL_LO22 = 1284865837 >>> 0;
var BIT_5322 = 9007199254740992;
var BIT_2722 = 134217728;
var PCGRandom22 = class {
  _state;
  constructor(seedHi, seedLo, incHi, incLo) {
    if (isNullable22(seedLo) && isNullable22(seedHi)) {
      seedLo = Math.random() * 4294967295 >>> 0;
      seedHi = 0;
    } else if (isNullable22(seedLo)) {
      seedLo = seedHi;
      seedHi = 0;
    }
    if (isNullable22(incLo) && isNullable22(incHi)) {
      incLo = this._state ? this._state[3] : defaultIncLo22;
      incHi = this._state ? this._state[2] : defaultIncHi22;
    } else if (isNullable22(incLo)) {
      incLo = incHi;
      incHi = 0;
    }
    this._state = new Int32Array([0, 0, incHi >>> 0, ((incLo || 0) | 1) >>> 0]);
    this._next();
    add6422(this._state, this._state[0], this._state[1], seedHi >>> 0, seedLo >>> 0);
    this._next();
    return this;
  }
  /**
   * Returns a copy of the internal state of this random number generator as a
   * JavaScript Array.
   *
   * @category getters
   * @since 2.0.0
   */
  getState() {
    return [this._state[0], this._state[1], this._state[2], this._state[3]];
  }
  /**
   * Restore state previously retrieved using `getState()`.
   *
   * @since 2.0.0
   */
  setState(state) {
    this._state[0] = state[0];
    this._state[1] = state[1];
    this._state[2] = state[2];
    this._state[3] = state[3] | 1;
  }
  /**
   * Get a uniformly distributed 32 bit integer between [0, max).
   *
   * @category getter
   * @since 2.0.0
   */
  integer(max3) {
    if (!max3) {
      return this._next();
    }
    max3 = max3 >>> 0;
    if ((max3 & max3 - 1) === 0) {
      return this._next() & max3 - 1;
    }
    let num = 0;
    const skew = (-max3 >>> 0) % max3 >>> 0;
    for (num = this._next(); num < skew; num = this._next()) {
    }
    return num % max3;
  }
  /**
   * Get a uniformly distributed IEEE-754 double between 0.0 and 1.0, with
   * 53 bits of precision (every bit of the mantissa is randomized).
   *
   * @category getters
   * @since 2.0.0
   */
  number() {
    const hi = (this._next() & 67108863) * 1;
    const lo = (this._next() & 134217727) * 1;
    return (hi * BIT_2722 + lo) / BIT_5322;
  }
  /** @internal */
  _next() {
    const oldHi = this._state[0] >>> 0;
    const oldLo = this._state[1] >>> 0;
    mul6422(this._state, oldHi, oldLo, MUL_HI22, MUL_LO22);
    add6422(this._state, this._state[0], this._state[1], this._state[2], this._state[3]);
    let xsHi = oldHi >>> 18;
    let xsLo = (oldLo >>> 18 | oldHi << 14) >>> 0;
    xsHi = (xsHi ^ oldHi) >>> 0;
    xsLo = (xsLo ^ oldLo) >>> 0;
    const xorshifted = (xsLo >>> 27 | xsHi << 5) >>> 0;
    const rot = oldHi >>> 27;
    const rot2 = (-rot >>> 0 & 31) >>> 0;
    return (xorshifted >>> rot | xorshifted << rot2) >>> 0;
  }
};
function mul6422(out, aHi, aLo, bHi, bLo) {
  let c1 = (aLo >>> 16) * (bLo & 65535) >>> 0;
  let c0 = (aLo & 65535) * (bLo >>> 16) >>> 0;
  let lo = (aLo & 65535) * (bLo & 65535) >>> 0;
  let hi = (aLo >>> 16) * (bLo >>> 16) + ((c0 >>> 16) + (c1 >>> 16)) >>> 0;
  c0 = c0 << 16 >>> 0;
  lo = lo + c0 >>> 0;
  if (lo >>> 0 < c0 >>> 0) {
    hi = hi + 1 >>> 0;
  }
  c1 = c1 << 16 >>> 0;
  lo = lo + c1 >>> 0;
  if (lo >>> 0 < c1 >>> 0) {
    hi = hi + 1 >>> 0;
  }
  hi = hi + Math.imul(aLo, bHi) >>> 0;
  hi = hi + Math.imul(aHi, bLo) >>> 0;
  out[0] = hi;
  out[1] = lo;
}
function add6422(out, aHi, aLo, bHi, bLo) {
  let hi = aHi + bHi >>> 0;
  const lo = aLo + bLo >>> 0;
  if (lo >>> 0 < aLo >>> 0) {
    hi = hi + 1 | 0;
  }
  out[0] = hi;
  out[1] = lo;
}
var YieldWrapTypeId22 = /* @__PURE__ */ Symbol.for("effect/Utils/YieldWrap");
var YieldWrap22 = class {
  /**
   * @since 3.0.6
   */
  #value;
  constructor(value) {
    this.#value = value;
  }
  /**
   * @since 3.0.6
   */
  [YieldWrapTypeId22]() {
    return this.#value;
  }
};
function yieldWrapGet22(self2) {
  if (typeof self2 === "object" && self2 !== null && YieldWrapTypeId22 in self2) {
    return self2[YieldWrapTypeId22]();
  }
  throw new Error(getBugErrorMessage22("yieldWrapGet"));
}
var structuralRegionState22 = /* @__PURE__ */ globalValue22("effect/Utils/isStructuralRegion", () => ({
  enabled: false,
  tester: void 0
}));
var randomHashCache22 = /* @__PURE__ */ globalValue22(/* @__PURE__ */ Symbol.for("effect/Hash/randomHashCache"), () => /* @__PURE__ */ new WeakMap());
var pcgr22 = /* @__PURE__ */ globalValue22(/* @__PURE__ */ Symbol.for("effect/Hash/pcgr"), () => new PCGRandom22());
var symbol32 = /* @__PURE__ */ Symbol.for("effect/Hash");
var hash22 = (self2) => {
  if (structuralRegionState22.enabled === true) {
    return 0;
  }
  switch (typeof self2) {
    case "number":
      return number22(self2);
    case "bigint":
      return string22(self2.toString(10));
    case "boolean":
      return string22(String(self2));
    case "symbol":
      return string22(String(self2));
    case "string":
      return string22(self2);
    case "undefined":
      return string22("undefined");
    case "function":
    case "object": {
      if (self2 === null) {
        return string22("null");
      } else if (self2 instanceof Date) {
        return hash22(self2.toISOString());
      } else if (isHash22(self2)) {
        return self2[symbol32]();
      } else {
        return random22(self2);
      }
    }
    default:
      throw new Error(`BUG: unhandled typeof ${typeof self2} - please report an issue at https://github.com/Effect-TS/effect/issues`);
  }
};
var random22 = (self2) => {
  if (!randomHashCache22.has(self2)) {
    randomHashCache22.set(self2, number22(pcgr22.integer(Number.MAX_SAFE_INTEGER)));
  }
  return randomHashCache22.get(self2);
};
var combine32 = (b22) => (self2) => self2 * 53 ^ b22;
var optimize22 = (n22) => n22 & 3221225471 | n22 >>> 1 & 1073741824;
var isHash22 = (u22) => hasProperty22(u22, symbol32);
var number22 = (n22) => {
  if (n22 !== n22 || n22 === Infinity) {
    return 0;
  }
  let h22 = n22 | 0;
  if (h22 !== n22) {
    h22 ^= n22 * 4294967295;
  }
  while (n22 > 4294967295) {
    h22 ^= n22 /= 4294967295;
  }
  return optimize22(n22);
};
var string22 = (str) => {
  let h22 = 5381, i22 = str.length;
  while (i22) {
    h22 = h22 * 33 ^ str.charCodeAt(--i22);
  }
  return optimize22(h22);
};
var cached22 = function() {
  if (arguments.length === 1) {
    const self3 = arguments[0];
    return function(hash52) {
      Object.defineProperty(self3, symbol32, {
        value() {
          return hash52;
        },
        enumerable: false
      });
      return hash52;
    };
  }
  const self2 = arguments[0];
  const hash42 = arguments[1];
  Object.defineProperty(self2, symbol32, {
    value() {
      return hash42;
    },
    enumerable: false
  });
  return hash42;
};
var symbol4 = /* @__PURE__ */ Symbol.for("effect/Equal");
function equals22() {
  if (arguments.length === 1) {
    return (self2) => compareBoth22(self2, arguments[0]);
  }
  return compareBoth22(arguments[0], arguments[1]);
}
function compareBoth22(self2, that) {
  if (self2 === that) {
    return true;
  }
  const selfType = typeof self2;
  if (selfType !== typeof that) {
    return false;
  }
  if (selfType === "object" || selfType === "function") {
    if (self2 !== null && that !== null) {
      if (isEqual22(self2) && isEqual22(that)) {
        if (hash22(self2) === hash22(that) && self2[symbol4](that)) {
          return true;
        } else {
          return structuralRegionState22.enabled && structuralRegionState22.tester ? structuralRegionState22.tester(self2, that) : false;
        }
      } else if (self2 instanceof Date && that instanceof Date) {
        return self2.toISOString() === that.toISOString();
      }
    }
    if (structuralRegionState22.enabled) {
      if (Array.isArray(self2) && Array.isArray(that)) {
        return self2.length === that.length && self2.every((v22, i22) => compareBoth22(v22, that[i22]));
      }
      if (Object.getPrototypeOf(self2) === Object.prototype && Object.getPrototypeOf(self2) === Object.prototype) {
        const keysSelf = Object.keys(self2);
        const keysThat = Object.keys(that);
        if (keysSelf.length === keysThat.length) {
          for (const key of keysSelf) {
            if (!(key in that && compareBoth22(self2[key], that[key]))) {
              return structuralRegionState22.tester ? structuralRegionState22.tester(self2, that) : false;
            }
          }
          return true;
        }
      }
      return structuralRegionState22.tester ? structuralRegionState22.tester(self2, that) : false;
    }
  }
  return structuralRegionState22.enabled && structuralRegionState22.tester ? structuralRegionState22.tester(self2, that) : false;
}
var isEqual22 = (u22) => hasProperty22(u22, symbol4);
var equivalence22 = () => equals22;
var NodeInspectSymbol22 = /* @__PURE__ */ Symbol.for("nodejs.util.inspect.custom");
var toJSON22 = (x22) => {
  if (hasProperty22(x22, "toJSON") && isFunction5(x22["toJSON"]) && x22["toJSON"].length === 0) {
    return x22.toJSON();
  } else if (Array.isArray(x22)) {
    return x22.map(toJSON22);
  }
  return x22;
};
var format22 = (x22) => JSON.stringify(x22, null, 2);
var pipeArguments22 = (self2, args) => {
  switch (args.length) {
    case 1:
      return args[0](self2);
    case 2:
      return args[1](args[0](self2));
    case 3:
      return args[2](args[1](args[0](self2)));
    case 4:
      return args[3](args[2](args[1](args[0](self2))));
    case 5:
      return args[4](args[3](args[2](args[1](args[0](self2)))));
    case 6:
      return args[5](args[4](args[3](args[2](args[1](args[0](self2))))));
    case 7:
      return args[6](args[5](args[4](args[3](args[2](args[1](args[0](self2)))))));
    case 8:
      return args[7](args[6](args[5](args[4](args[3](args[2](args[1](args[0](self2))))))));
    case 9:
      return args[8](args[7](args[6](args[5](args[4](args[3](args[2](args[1](args[0](self2)))))))));
    default: {
      let ret = self2;
      for (let i22 = 0, len = args.length; i22 < len; i22++) {
        ret = args[i22](ret);
      }
      return ret;
    }
  }
};
var EffectTypeId32 = /* @__PURE__ */ Symbol.for("effect/Effect");
var StreamTypeId22 = /* @__PURE__ */ Symbol.for("effect/Stream");
var SinkTypeId22 = /* @__PURE__ */ Symbol.for("effect/Sink");
var ChannelTypeId22 = /* @__PURE__ */ Symbol.for("effect/Channel");
var effectVariance22 = {
  /* c8 ignore next */
  _R: (_22) => _22,
  /* c8 ignore next */
  _E: (_22) => _22,
  /* c8 ignore next */
  _A: (_22) => _22,
  _V: /* @__PURE__ */ getCurrentVersion22()
};
var sinkVariance22 = {
  /* c8 ignore next */
  _A: (_22) => _22,
  /* c8 ignore next */
  _In: (_22) => _22,
  /* c8 ignore next */
  _L: (_22) => _22,
  /* c8 ignore next */
  _E: (_22) => _22,
  /* c8 ignore next */
  _R: (_22) => _22
};
var channelVariance22 = {
  /* c8 ignore next */
  _Env: (_22) => _22,
  /* c8 ignore next */
  _InErr: (_22) => _22,
  /* c8 ignore next */
  _InElem: (_22) => _22,
  /* c8 ignore next */
  _InDone: (_22) => _22,
  /* c8 ignore next */
  _OutErr: (_22) => _22,
  /* c8 ignore next */
  _OutElem: (_22) => _22,
  /* c8 ignore next */
  _OutDone: (_22) => _22
};
var EffectPrototype22 = {
  [EffectTypeId32]: effectVariance22,
  [StreamTypeId22]: effectVariance22,
  [SinkTypeId22]: sinkVariance22,
  [ChannelTypeId22]: channelVariance22,
  [symbol4](that) {
    return this === that;
  },
  [symbol32]() {
    return cached22(this, random22(this));
  },
  [Symbol.iterator]() {
    return new SingleShotGen32(new YieldWrap22(this));
  },
  pipe() {
    return pipeArguments22(this, arguments);
  }
};
var TypeId62 = /* @__PURE__ */ Symbol.for("effect/Option");
var CommonProto32 = {
  ...EffectPrototype22,
  [TypeId62]: {
    _A: (_22) => _22
  },
  [NodeInspectSymbol22]() {
    return this.toJSON();
  },
  toString() {
    return format22(this.toJSON());
  }
};
var SomeProto22 = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(CommonProto32), {
  _tag: "Some",
  _op: "Some",
  [symbol4](that) {
    return isOption32(that) && isSome32(that) && equals22(this.value, that.value);
  },
  [symbol32]() {
    return cached22(this, combine32(hash22(this._tag))(hash22(this.value)));
  },
  toJSON() {
    return {
      _id: "Option",
      _tag: this._tag,
      value: toJSON22(this.value)
    };
  }
});
var NoneHash22 = /* @__PURE__ */ hash22("None");
var NoneProto22 = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(CommonProto32), {
  _tag: "None",
  _op: "None",
  [symbol4](that) {
    return isOption32(that) && isNone32(that);
  },
  [symbol32]() {
    return NoneHash22;
  },
  toJSON() {
    return {
      _id: "Option",
      _tag: this._tag
    };
  }
});
var isOption32 = (input) => hasProperty22(input, TypeId62);
var isNone32 = (fa) => fa._tag === "None";
var isSome32 = (fa) => fa._tag === "Some";
var none32 = /* @__PURE__ */ Object.create(NoneProto22);
var some5 = (value) => {
  const a22 = Object.create(SomeProto22);
  a22.value = value;
  return a22;
};
var TypeId7 = /* @__PURE__ */ Symbol.for("effect/Either");
var CommonProto4 = {
  ...EffectPrototype22,
  [TypeId7]: {
    _R: (_22) => _22
  },
  [NodeInspectSymbol22]() {
    return this.toJSON();
  },
  toString() {
    return format22(this.toJSON());
  }
};
var RightProto22 = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(CommonProto4), {
  _tag: "Right",
  _op: "Right",
  [symbol4](that) {
    return isEither22(that) && isRight22(that) && equals22(this.right, that.right);
  },
  [symbol32]() {
    return combine32(hash22(this._tag))(hash22(this.right));
  },
  toJSON() {
    return {
      _id: "Either",
      _tag: this._tag,
      right: toJSON22(this.right)
    };
  }
});
var LeftProto22 = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(CommonProto4), {
  _tag: "Left",
  _op: "Left",
  [symbol4](that) {
    return isEither22(that) && isLeft22(that) && equals22(this.left, that.left);
  },
  [symbol32]() {
    return combine32(hash22(this._tag))(hash22(this.left));
  },
  toJSON() {
    return {
      _id: "Either",
      _tag: this._tag,
      left: toJSON22(this.left)
    };
  }
});
var isEither22 = (input) => hasProperty22(input, TypeId7);
var isLeft22 = (ma) => ma._tag === "Left";
var isRight22 = (ma) => ma._tag === "Right";
var left32 = (left52) => {
  const a22 = Object.create(LeftProto22);
  a22.left = left52;
  return a22;
};
var right32 = (right52) => {
  const a22 = Object.create(RightProto22);
  a22.right = right52;
  return a22;
};
var getLeft32 = (self2) => isRight22(self2) ? none32 : some5(self2.left);
var getRight32 = (self2) => isLeft22(self2) ? none32 : some5(self2.right);
var isLeft3 = isLeft22;
var isRight3 = isRight22;
var isNonEmptyArray = (self2) => self2.length > 0;
var Option_exports22 = {};
__export3(Option_exports22, {
  Do: () => Do22,
  TypeId: () => TypeId8,
  all: () => all4,
  andThen: () => andThen22,
  ap: () => ap22,
  as: () => as22,
  asVoid: () => asVoid22,
  bind: () => bind4,
  bindTo: () => bindTo4,
  composeK: () => composeK22,
  contains: () => contains22,
  containsWith: () => containsWith22,
  exists: () => exists22,
  filter: () => filter22,
  filterMap: () => filterMap22,
  firstSomeOf: () => firstSomeOf22,
  flatMap: () => flatMap22,
  flatMapNullable: () => flatMapNullable22,
  flatten: () => flatten22,
  fromIterable: () => fromIterable32,
  fromNullable: () => fromNullable22,
  gen: () => gen22,
  getEquivalence: () => getEquivalence32,
  getLeft: () => getLeft4,
  getOrElse: () => getOrElse22,
  getOrNull: () => getOrNull22,
  getOrThrow: () => getOrThrow22,
  getOrThrowWith: () => getOrThrowWith22,
  getOrUndefined: () => getOrUndefined22,
  getOrder: () => getOrder22,
  getRight: () => getRight4,
  isNone: () => isNone4,
  isOption: () => isOption4,
  isSome: () => isSome4,
  let: () => let_4,
  lift2: () => lift222,
  liftNullable: () => liftNullable22,
  liftPredicate: () => liftPredicate22,
  liftThrowable: () => liftThrowable22,
  map: () => map22,
  match: () => match32,
  none: () => none4,
  orElse: () => orElse22,
  orElseEither: () => orElseEither22,
  orElseSome: () => orElseSome22,
  partitionMap: () => partitionMap22,
  product: () => product4,
  productMany: () => productMany4,
  reduceCompact: () => reduceCompact22,
  some: () => some6,
  tap: () => tap22,
  toArray: () => toArray22,
  toRefinement: () => toRefinement22,
  void: () => void_22,
  zipLeft: () => zipLeft22,
  zipRight: () => zipRight22,
  zipWith: () => zipWith22
});
var make8 = (compare) => (self2, that) => self2 === that ? 0 : compare(self2, that);
var number3 = /* @__PURE__ */ make8((self2, that) => self2 < that ? -1 : 1);
var combineMany = /* @__PURE__ */ dual22(2, (self2, collection) => make8((a1, a22) => {
  let out = self2(a1, a22);
  if (out !== 0) {
    return out;
  }
  for (const O22 of collection) {
    out = O22(a1, a22);
    if (out !== 0) {
      return out;
    }
  }
  return out;
}));
var empty82 = () => make8(() => 0);
var combineAll = (collection) => combineMany(empty82(), collection);
var mapInput3 = /* @__PURE__ */ dual22(2, (self2, f22) => make8((b1, b22) => self2(f22(b1), f22(b22))));
var array4 = (O22) => make8((self2, that) => {
  const aLen = self2.length;
  const bLen = that.length;
  const len = Math.min(aLen, bLen);
  for (let i22 = 0; i22 < len; i22++) {
    const o22 = O22(self2[i22], that[i22]);
    if (o22 !== 0) {
      return o22;
    }
  }
  return number3(aLen, bLen);
});
var min = (O22) => dual22(2, (self2, that) => self2 === that || O22(self2, that) < 1 ? self2 : that);
var max = (O22) => dual22(2, (self2, that) => self2 === that || O22(self2, that) > -1 ? self2 : that);
var TypeId8 = /* @__PURE__ */ Symbol.for("effect/Option");
var none4 = () => none32;
var some6 = some5;
var isOption4 = isOption32;
var isNone4 = isNone32;
var isSome4 = isSome32;
var match32 = /* @__PURE__ */ dual22(2, (self2, {
  onNone,
  onSome
}) => isNone4(self2) ? onNone() : onSome(self2.value));
var toRefinement22 = (f22) => (a22) => isSome4(f22(a22));
var fromIterable32 = (collection) => {
  for (const a22 of collection) {
    return some6(a22);
  }
  return none4();
};
var getRight4 = getRight32;
var getLeft4 = getLeft32;
var getOrElse22 = /* @__PURE__ */ dual22(2, (self2, onNone) => isNone4(self2) ? onNone() : self2.value);
var orElse22 = /* @__PURE__ */ dual22(2, (self2, that) => isNone4(self2) ? that() : self2);
var orElseSome22 = /* @__PURE__ */ dual22(2, (self2, onNone) => isNone4(self2) ? some6(onNone()) : self2);
var orElseEither22 = /* @__PURE__ */ dual22(2, (self2, that) => isNone4(self2) ? map22(that(), right32) : map22(self2, left32));
var firstSomeOf22 = (collection) => {
  let out = none4();
  for (out of collection) {
    if (isSome4(out)) {
      return out;
    }
  }
  return out;
};
var fromNullable22 = (nullableValue) => nullableValue == null ? none4() : some6(nullableValue);
var liftNullable22 = (f22) => (...a22) => fromNullable22(f22(...a22));
var getOrNull22 = /* @__PURE__ */ getOrElse22(constNull22);
var getOrUndefined22 = /* @__PURE__ */ getOrElse22(constUndefined22);
var liftThrowable22 = (f22) => (...a22) => {
  try {
    return some6(f22(...a22));
  } catch (e22) {
    return none4();
  }
};
var getOrThrowWith22 = /* @__PURE__ */ dual22(2, (self2, onNone) => {
  if (isSome4(self2)) {
    return self2.value;
  }
  throw onNone();
});
var getOrThrow22 = /* @__PURE__ */ getOrThrowWith22(() => new Error("getOrThrow called on a None"));
var map22 = /* @__PURE__ */ dual22(2, (self2, f22) => isNone4(self2) ? none4() : some6(f22(self2.value)));
var as22 = /* @__PURE__ */ dual22(2, (self2, b22) => map22(self2, () => b22));
var asVoid22 = /* @__PURE__ */ as22(void 0);
var void_22 = /* @__PURE__ */ some6(void 0);
var flatMap22 = /* @__PURE__ */ dual22(2, (self2, f22) => isNone4(self2) ? none4() : f22(self2.value));
var andThen22 = /* @__PURE__ */ dual22(2, (self2, f22) => flatMap22(self2, (a22) => {
  const b22 = isFunction4(f22) ? f22(a22) : f22;
  return isOption4(b22) ? b22 : some6(b22);
}));
var flatMapNullable22 = /* @__PURE__ */ dual22(2, (self2, f22) => isNone4(self2) ? none4() : fromNullable22(f22(self2.value)));
var flatten22 = /* @__PURE__ */ flatMap22(identity22);
var zipRight22 = /* @__PURE__ */ dual22(2, (self2, that) => flatMap22(self2, () => that));
var composeK22 = /* @__PURE__ */ dual22(2, (afb, bfc) => (a22) => flatMap22(afb(a22), bfc));
var zipLeft22 = /* @__PURE__ */ dual22(2, (self2, that) => tap22(self2, () => that));
var tap22 = /* @__PURE__ */ dual22(2, (self2, f22) => flatMap22(self2, (a22) => map22(f22(a22), () => a22)));
var product4 = (self2, that) => isSome4(self2) && isSome4(that) ? some6([self2.value, that.value]) : none4();
var productMany4 = (self2, collection) => {
  if (isNone4(self2)) {
    return none4();
  }
  const out = [self2.value];
  for (const o22 of collection) {
    if (isNone4(o22)) {
      return none4();
    }
    out.push(o22.value);
  }
  return some6(out);
};
var all4 = (input) => {
  if (Symbol.iterator in input) {
    const out2 = [];
    for (const o22 of input) {
      if (isNone4(o22)) {
        return none4();
      }
      out2.push(o22.value);
    }
    return some6(out2);
  }
  const out = {};
  for (const key of Object.keys(input)) {
    const o22 = input[key];
    if (isNone4(o22)) {
      return none4();
    }
    out[key] = o22.value;
  }
  return some6(out);
};
var zipWith22 = /* @__PURE__ */ dual22(3, (self2, that, f22) => map22(product4(self2, that), ([a22, b22]) => f22(a22, b22)));
var ap22 = /* @__PURE__ */ dual22(2, (self2, that) => zipWith22(self2, that, (f22, a22) => f22(a22)));
var reduceCompact22 = /* @__PURE__ */ dual22(3, (self2, b22, f22) => {
  let out = b22;
  for (const oa of self2) {
    if (isSome4(oa)) {
      out = f22(out, oa.value);
    }
  }
  return out;
});
var toArray22 = (self2) => isNone4(self2) ? [] : [self2.value];
var partitionMap22 = /* @__PURE__ */ dual22(2, (self2, f22) => {
  if (isNone4(self2)) {
    return [none4(), none4()];
  }
  const e22 = f22(self2.value);
  return isLeft22(e22) ? [some6(e22.left), none4()] : [none4(), some6(e22.right)];
});
var filterMap22 = /* @__PURE__ */ dual22(2, (self2, f22) => isNone4(self2) ? none4() : f22(self2.value));
var filter22 = /* @__PURE__ */ dual22(2, (self2, predicate) => filterMap22(self2, (b22) => predicate(b22) ? some5(b22) : none32));
var getEquivalence32 = (isEquivalent) => make62((x22, y22) => x22 === y22 || (isNone4(x22) ? isNone4(y22) : isNone4(y22) ? false : isEquivalent(x22.value, y22.value)));
var getOrder22 = (O22) => make8((self2, that) => isSome4(self2) ? isSome4(that) ? O22(self2.value, that.value) : 1 : -1);
var lift222 = (f22) => dual22(2, (self2, that) => zipWith22(self2, that, f22));
var liftPredicate22 = (predicate) => (b22) => predicate(b22) ? some6(b22) : none4();
var containsWith22 = (isEquivalent) => dual22(2, (self2, a22) => isNone4(self2) ? false : isEquivalent(self2.value, a22));
var _equivalence32 = /* @__PURE__ */ equivalence22();
var contains22 = /* @__PURE__ */ containsWith22(_equivalence32);
var exists22 = /* @__PURE__ */ dual22(2, (self2, refinement) => isNone4(self2) ? false : refinement(self2.value));
var bindTo4 = /* @__PURE__ */ bindTo32(map22);
var let_4 = /* @__PURE__ */ let_32(map22);
var bind4 = /* @__PURE__ */ bind32(map22, flatMap22);
var Do22 = /* @__PURE__ */ some6({});
var adapter4 = /* @__PURE__ */ adapter32();
var gen22 = (f22) => {
  const iterator = f22(adapter4);
  let state = iterator.next();
  if (state.done) {
    return some6(state.value);
  } else {
    let current = state.value;
    if (isGenKind22(current)) {
      current = current.value;
    } else {
      current = yieldWrapGet22(current);
    }
    if (isNone4(current)) {
      return current;
    }
    while (!state.done) {
      state = iterator.next(current.value);
      if (!state.done) {
        current = state.value;
        if (isGenKind22(current)) {
          current = current.value;
        } else {
          current = yieldWrapGet22(current);
        }
        if (isNone4(current)) {
          return current;
        }
      }
    }
    return some6(state.value);
  }
};
var make9 = (...elements) => elements;
var findFirst = /* @__PURE__ */ dual22(2, (self2, f22) => {
  let i22 = 0;
  for (const a22 of self2) {
    const o22 = f22(a22, i22);
    if (isBoolean22(o22)) {
      if (o22) {
        return some6(a22);
      }
    } else {
      if (isSome4(o22)) {
        return o22;
      }
    }
    i22++;
  }
  return none4();
});
var collect = /* @__PURE__ */ dual22(2, (self2, f22) => {
  const out = [];
  for (const key of keys22(self2)) {
    out.push(f22(key, self2[key]));
  }
  return out;
});
var toEntries = /* @__PURE__ */ collect((key, value) => [key, value]);
var keys22 = (self2) => Object.keys(self2);
var make10 = (...elements) => elements;
var allocate = (n22) => new Array(n22);
var makeBy = (n22, f22) => {
  const max3 = Math.max(1, Math.floor(n22));
  const out = new Array(max3);
  for (let i22 = 0; i22 < max3; i22++) {
    out[i22] = f22(i22);
  }
  return out;
};
var range = (start, end) => start <= end ? makeBy(end - start + 1, (i22) => start + i22) : [start];
var replicate = /* @__PURE__ */ dual22(2, (a22, n22) => makeBy(n22, () => a22));
var fromIterable4 = (collection) => Array.isArray(collection) ? collection : Array.from(collection);
var fromRecord = toEntries;
var fromOption2 = toArray22;
var match4 = /* @__PURE__ */ dual22(2, (self2, {
  onEmpty,
  onNonEmpty
}) => isNonEmptyReadonlyArray(self2) ? onNonEmpty(self2) : onEmpty());
var matchLeft = /* @__PURE__ */ dual22(2, (self2, {
  onEmpty,
  onNonEmpty
}) => isNonEmptyReadonlyArray(self2) ? onNonEmpty(headNonEmpty22(self2), tailNonEmpty22(self2)) : onEmpty());
var matchRight = /* @__PURE__ */ dual22(2, (self2, {
  onEmpty,
  onNonEmpty
}) => isNonEmptyReadonlyArray(self2) ? onNonEmpty(initNonEmpty(self2), lastNonEmpty(self2)) : onEmpty());
var prepend22 = /* @__PURE__ */ dual22(2, (self2, head22) => [head22, ...self2]);
var prependAll = /* @__PURE__ */ dual22(2, (self2, that) => fromIterable4(that).concat(fromIterable4(self2)));
var append = /* @__PURE__ */ dual22(2, (self2, last2) => [...self2, last2]);
var appendAll22 = /* @__PURE__ */ dual22(2, (self2, that) => fromIterable4(self2).concat(fromIterable4(that)));
var scan = /* @__PURE__ */ dual22(3, (self2, b22, f22) => {
  const out = [b22];
  let i22 = 0;
  for (const a22 of self2) {
    out[i22 + 1] = f22(out[i22], a22);
    i22++;
  }
  return out;
});
var scanRight = /* @__PURE__ */ dual22(3, (self2, b22, f22) => {
  const input = fromIterable4(self2);
  const out = new Array(input.length + 1);
  out[input.length] = b22;
  for (let i22 = input.length - 1; i22 >= 0; i22--) {
    out[i22] = f22(out[i22 + 1], input[i22]);
  }
  return out;
});
var isArray = Array.isArray;
var isEmptyArray = (self2) => self2.length === 0;
var isEmptyReadonlyArray = isEmptyArray;
var isNonEmptyArray2 = isNonEmptyArray;
var isNonEmptyReadonlyArray = isNonEmptyArray;
var length = (self2) => self2.length;
var isOutOfBound = (i22, as42) => i22 < 0 || i22 >= as42.length;
var clamp = (i22, as42) => Math.floor(Math.min(Math.max(0, i22), as42.length));
var get = /* @__PURE__ */ dual22(2, (self2, index) => {
  const i22 = Math.floor(index);
  return isOutOfBound(i22, self2) ? none4() : some6(self2[i22]);
});
var unsafeGet = /* @__PURE__ */ dual22(2, (self2, index) => {
  const i22 = Math.floor(index);
  if (isOutOfBound(i22, self2)) {
    throw new Error(`Index ${i22} out of bounds`);
  }
  return self2[i22];
});
var unprepend = (self2) => [headNonEmpty22(self2), tailNonEmpty22(self2)];
var unappend = (self2) => [initNonEmpty(self2), lastNonEmpty(self2)];
var head = /* @__PURE__ */ get(0);
var headNonEmpty22 = /* @__PURE__ */ unsafeGet(0);
var last = (self2) => isNonEmptyReadonlyArray(self2) ? some6(lastNonEmpty(self2)) : none4();
var lastNonEmpty = (self2) => self2[self2.length - 1];
var tail = (self2) => {
  const input = fromIterable4(self2);
  return isNonEmptyReadonlyArray(input) ? some6(tailNonEmpty22(input)) : none4();
};
var tailNonEmpty22 = (self2) => self2.slice(1);
var init = (self2) => {
  const input = fromIterable4(self2);
  return isNonEmptyReadonlyArray(input) ? some6(initNonEmpty(input)) : none4();
};
var initNonEmpty = (self2) => self2.slice(0, -1);
var take = /* @__PURE__ */ dual22(2, (self2, n22) => {
  const input = fromIterable4(self2);
  return input.slice(0, clamp(n22, input));
});
var takeRight = /* @__PURE__ */ dual22(2, (self2, n22) => {
  const input = fromIterable4(self2);
  const i22 = clamp(n22, input);
  return i22 === 0 ? [] : input.slice(-i22);
});
var takeWhile = /* @__PURE__ */ dual22(2, (self2, predicate) => {
  let i22 = 0;
  const out = [];
  for (const a22 of self2) {
    if (!predicate(a22, i22)) {
      break;
    }
    out.push(a22);
    i22++;
  }
  return out;
});
var spanIndex = (self2, predicate) => {
  let i22 = 0;
  for (const a22 of self2) {
    if (!predicate(a22, i22)) {
      break;
    }
    i22++;
  }
  return i22;
};
var span = /* @__PURE__ */ dual22(2, (self2, predicate) => splitAt(self2, spanIndex(self2, predicate)));
var drop22 = /* @__PURE__ */ dual22(2, (self2, n22) => {
  const input = fromIterable4(self2);
  return input.slice(clamp(n22, input), input.length);
});
var dropRight = /* @__PURE__ */ dual22(2, (self2, n22) => {
  const input = fromIterable4(self2);
  return input.slice(0, input.length - clamp(n22, input));
});
var dropWhile = /* @__PURE__ */ dual22(2, (self2, predicate) => fromIterable4(self2).slice(spanIndex(self2, predicate)));
var findFirstIndex = /* @__PURE__ */ dual22(2, (self2, predicate) => {
  let i22 = 0;
  for (const a22 of self2) {
    if (predicate(a22, i22)) {
      return some6(i22);
    }
    i22++;
  }
  return none4();
});
var findLastIndex = /* @__PURE__ */ dual22(2, (self2, predicate) => {
  const input = fromIterable4(self2);
  for (let i22 = input.length - 1; i22 >= 0; i22--) {
    if (predicate(input[i22], i22)) {
      return some6(i22);
    }
  }
  return none4();
});
var findFirst2 = findFirst;
var findLast = /* @__PURE__ */ dual22(2, (self2, f22) => {
  const input = fromIterable4(self2);
  for (let i22 = input.length - 1; i22 >= 0; i22--) {
    const a22 = input[i22];
    const o22 = f22(a22, i22);
    if (isBoolean22(o22)) {
      if (o22) {
        return some6(a22);
      }
    } else {
      if (isSome4(o22)) {
        return o22;
      }
    }
  }
  return none4();
});
var insertAt = /* @__PURE__ */ dual22(3, (self2, i22, b22) => {
  const out = Array.from(self2);
  if (i22 < 0 || i22 > out.length) {
    return none4();
  }
  out.splice(i22, 0, b22);
  return some6(out);
});
var replace2 = /* @__PURE__ */ dual22(3, (self2, i22, b22) => modify(self2, i22, () => b22));
var replaceOption = /* @__PURE__ */ dual22(3, (self2, i22, b22) => modifyOption(self2, i22, () => b22));
var modify = /* @__PURE__ */ dual22(3, (self2, i22, f22) => getOrElse22(modifyOption(self2, i22, f22), () => Array.from(self2)));
var modifyOption = /* @__PURE__ */ dual22(3, (self2, i22, f22) => {
  const out = Array.from(self2);
  if (isOutOfBound(i22, out)) {
    return none4();
  }
  const next = f22(out[i22]);
  out[i22] = next;
  return some6(out);
});
var remove = /* @__PURE__ */ dual22(2, (self2, i22) => {
  const out = Array.from(self2);
  if (isOutOfBound(i22, out)) {
    return out;
  }
  out.splice(i22, 1);
  return out;
});
var reverse32 = (self2) => Array.from(self2).reverse();
var sort = /* @__PURE__ */ dual22(2, (self2, O22) => {
  const out = Array.from(self2);
  out.sort(O22);
  return out;
});
var sortWith = /* @__PURE__ */ dual22(3, (self2, f22, order) => sort(self2, mapInput3(order, f22)));
var sortBy = (...orders) => {
  const sortByAll = sort(combineAll(orders));
  return (self2) => {
    const input = fromIterable4(self2);
    if (isNonEmptyReadonlyArray(input)) {
      return sortByAll(input);
    }
    return [];
  };
};
var zip = /* @__PURE__ */ dual22(2, (self2, that) => zipWith3(self2, that, make9));
var zipWith3 = /* @__PURE__ */ dual22(3, (self2, that, f22) => {
  const as42 = fromIterable4(self2);
  const bs = fromIterable4(that);
  if (isNonEmptyReadonlyArray(as42) && isNonEmptyReadonlyArray(bs)) {
    const out = [f22(headNonEmpty22(as42), headNonEmpty22(bs))];
    const len = Math.min(as42.length, bs.length);
    for (let i22 = 1; i22 < len; i22++) {
      out[i22] = f22(as42[i22], bs[i22]);
    }
    return out;
  }
  return [];
});
var unzip = (self2) => {
  const input = fromIterable4(self2);
  if (isNonEmptyReadonlyArray(input)) {
    const fa = [input[0][0]];
    const fb = [input[0][1]];
    for (let i22 = 1; i22 < input.length; i22++) {
      fa[i22] = input[i22][0];
      fb[i22] = input[i22][1];
    }
    return [fa, fb];
  }
  return [[], []];
};
var intersperse = /* @__PURE__ */ dual22(2, (self2, middle) => {
  const input = fromIterable4(self2);
  if (isNonEmptyReadonlyArray(input)) {
    const out = [headNonEmpty22(input)];
    const tail22 = tailNonEmpty22(input);
    for (let i22 = 0; i22 < tail22.length; i22++) {
      if (i22 < tail22.length) {
        out.push(middle);
      }
      out.push(tail22[i22]);
    }
    return out;
  }
  return [];
});
var modifyNonEmptyHead = /* @__PURE__ */ dual22(2, (self2, f22) => [f22(headNonEmpty22(self2)), ...tailNonEmpty22(self2)]);
var setNonEmptyHead = /* @__PURE__ */ dual22(2, (self2, b22) => modifyNonEmptyHead(self2, () => b22));
var modifyNonEmptyLast = /* @__PURE__ */ dual22(2, (self2, f22) => append(initNonEmpty(self2), f22(lastNonEmpty(self2))));
var setNonEmptyLast = /* @__PURE__ */ dual22(2, (self2, b22) => modifyNonEmptyLast(self2, () => b22));
var rotate = /* @__PURE__ */ dual22(2, (self2, n22) => {
  const input = fromIterable4(self2);
  if (isNonEmptyReadonlyArray(input)) {
    const len = input.length;
    const m22 = Math.round(n22) % len;
    if (isOutOfBound(Math.abs(m22), input) || m22 === 0) {
      return copy22(input);
    }
    if (m22 < 0) {
      const [f22, s22] = splitNonEmptyAt(input, -m22);
      return appendAll22(s22, f22);
    } else {
      return rotate(self2, m22 - len);
    }
  }
  return [];
});
var containsWith3 = (isEquivalent) => dual22(2, (self2, a22) => {
  for (const i22 of self2) {
    if (isEquivalent(a22, i22)) {
      return true;
    }
  }
  return false;
});
var _equivalence4 = /* @__PURE__ */ equivalence22();
var contains3 = /* @__PURE__ */ containsWith3(_equivalence4);
var chop = /* @__PURE__ */ dual22(2, (self2, f22) => {
  const input = fromIterable4(self2);
  if (isNonEmptyReadonlyArray(input)) {
    const [b22, rest] = f22(input);
    const out = [b22];
    let next = rest;
    while (isNonEmptyArray(next)) {
      const [b3, rest2] = f22(next);
      out.push(b3);
      next = rest2;
    }
    return out;
  }
  return [];
});
var splitAt = /* @__PURE__ */ dual22(2, (self2, n22) => {
  const input = Array.from(self2);
  const _n = Math.floor(n22);
  if (isNonEmptyReadonlyArray(input)) {
    if (_n >= 1) {
      return splitNonEmptyAt(input, _n);
    }
    return [[], input];
  }
  return [input, []];
});
var splitNonEmptyAt = /* @__PURE__ */ dual22(2, (self2, n22) => {
  const _n = Math.max(1, Math.floor(n22));
  return _n >= self2.length ? [copy22(self2), []] : [prepend22(self2.slice(1, _n), headNonEmpty22(self2)), self2.slice(_n)];
});
var split = /* @__PURE__ */ dual22(2, (self2, n22) => {
  const input = fromIterable4(self2);
  return chunksOf(input, Math.ceil(input.length / Math.floor(n22)));
});
var splitWhere = /* @__PURE__ */ dual22(2, (self2, predicate) => span(self2, (a22, i22) => !predicate(a22, i22)));
var copy22 = (self2) => self2.slice();
var chunksOf = /* @__PURE__ */ dual22(2, (self2, n22) => {
  const input = fromIterable4(self2);
  if (isNonEmptyReadonlyArray(input)) {
    return chop(input, splitNonEmptyAt(n22));
  }
  return [];
});
var groupWith = /* @__PURE__ */ dual22(2, (self2, isEquivalent) => chop(self2, (as42) => {
  const h22 = headNonEmpty22(as42);
  const out = [h22];
  let i22 = 1;
  for (; i22 < as42.length; i22++) {
    const a22 = as42[i22];
    if (isEquivalent(a22, h22)) {
      out.push(a22);
    } else {
      break;
    }
  }
  return [out, as42.slice(i22)];
}));
var group = /* @__PURE__ */ groupWith(/* @__PURE__ */ equivalence22());
var groupBy = /* @__PURE__ */ dual22(2, (self2, f22) => {
  const out = {};
  for (const a22 of self2) {
    const k22 = f22(a22);
    if (Object.prototype.hasOwnProperty.call(out, k22)) {
      out[k22].push(a22);
    } else {
      out[k22] = [a22];
    }
  }
  return out;
});
var unionWith = /* @__PURE__ */ dual22(3, (self2, that, isEquivalent) => {
  const a22 = fromIterable4(self2);
  const b22 = fromIterable4(that);
  if (isNonEmptyReadonlyArray(a22)) {
    if (isNonEmptyReadonlyArray(b22)) {
      const dedupe2 = dedupeWith(isEquivalent);
      return dedupe2(appendAll22(a22, b22));
    }
    return a22;
  }
  return b22;
});
var union = /* @__PURE__ */ dual22(2, (self2, that) => unionWith(self2, that, _equivalence4));
var intersectionWith = (isEquivalent) => {
  const has2 = containsWith3(isEquivalent);
  return dual22(2, (self2, that) => fromIterable4(self2).filter((a22) => has2(that, a22)));
};
var intersection = /* @__PURE__ */ intersectionWith(_equivalence4);
var differenceWith = (isEquivalent) => {
  const has2 = containsWith3(isEquivalent);
  return dual22(2, (self2, that) => fromIterable4(self2).filter((a22) => !has2(that, a22)));
};
var difference = /* @__PURE__ */ differenceWith(_equivalence4);
var empty9 = () => [];
var of22 = (a22) => [a22];
var map3 = /* @__PURE__ */ dual22(2, (self2, f22) => self2.map(f22));
var flatMap3 = /* @__PURE__ */ dual22(2, (self2, f22) => {
  if (isEmptyReadonlyArray(self2)) {
    return [];
  }
  const out = [];
  for (let i22 = 0; i22 < self2.length; i22++) {
    const inner = f22(self2[i22], i22);
    for (let j22 = 0; j22 < inner.length; j22++) {
      out.push(inner[j22]);
    }
  }
  return out;
});
var flatten3 = /* @__PURE__ */ flatMap3(identity22);
var filterMap3 = /* @__PURE__ */ dual22(2, (self2, f22) => {
  const as42 = fromIterable4(self2);
  const out = [];
  for (let i22 = 0; i22 < as42.length; i22++) {
    const o22 = f22(as42[i22], i22);
    if (isSome4(o22)) {
      out.push(o22.value);
    }
  }
  return out;
});
var filterMapWhile = /* @__PURE__ */ dual22(2, (self2, f22) => {
  let i22 = 0;
  const out = [];
  for (const a22 of self2) {
    const b22 = f22(a22, i22);
    if (isSome4(b22)) {
      out.push(b22.value);
    } else {
      break;
    }
    i22++;
  }
  return out;
});
var partitionMap3 = /* @__PURE__ */ dual22(2, (self2, f22) => {
  const left52 = [];
  const right52 = [];
  const as42 = fromIterable4(self2);
  for (let i22 = 0; i22 < as42.length; i22++) {
    const e22 = f22(as42[i22], i22);
    if (isLeft3(e22)) {
      left52.push(e22.left);
    } else {
      right52.push(e22.right);
    }
  }
  return [left52, right52];
});
var getSomes = /* @__PURE__ */ filterMap3(identity22);
var getLefts = (self2) => {
  const out = [];
  for (const a22 of self2) {
    if (isLeft3(a22)) {
      out.push(a22.left);
    }
  }
  return out;
};
var getRights = (self2) => {
  const out = [];
  for (const a22 of self2) {
    if (isRight3(a22)) {
      out.push(a22.right);
    }
  }
  return out;
};
var filter3 = /* @__PURE__ */ dual22(2, (self2, predicate) => {
  const as42 = fromIterable4(self2);
  const out = [];
  for (let i22 = 0; i22 < as42.length; i22++) {
    if (predicate(as42[i22], i22)) {
      out.push(as42[i22]);
    }
  }
  return out;
});
var partition = /* @__PURE__ */ dual22(2, (self2, predicate) => {
  const left52 = [];
  const right52 = [];
  const as42 = fromIterable4(self2);
  for (let i22 = 0; i22 < as42.length; i22++) {
    if (predicate(as42[i22], i22)) {
      right52.push(as42[i22]);
    } else {
      left52.push(as42[i22]);
    }
  }
  return [left52, right52];
});
var separate = /* @__PURE__ */ partitionMap3(identity22);
var reduce32 = /* @__PURE__ */ dual22(3, (self2, b22, f22) => fromIterable4(self2).reduce((b3, a22, i22) => f22(b3, a22, i22), b22));
var reduceRight = /* @__PURE__ */ dual22(3, (self2, b22, f22) => fromIterable4(self2).reduceRight((b3, a22, i22) => f22(b3, a22, i22), b22));
var liftPredicate3 = (predicate) => (b22) => predicate(b22) ? [b22] : [];
var liftOption = (f22) => (...a22) => fromOption2(f22(...a22));
var fromNullable3 = (a22) => a22 == null ? empty9() : [a22];
var liftNullable3 = (f22) => (...a22) => fromNullable3(f22(...a22));
var flatMapNullable3 = /* @__PURE__ */ dual22(2, (self2, f22) => flatMap3(self2, (a22) => fromNullable3(f22(a22))));
var liftEither = (f22) => (...a22) => {
  const e22 = f22(...a22);
  return isLeft3(e22) ? [] : [e22.right];
};
var every3 = /* @__PURE__ */ dual22(2, (self2, refinement) => self2.every(refinement));
var some7 = /* @__PURE__ */ dual22(2, (self2, predicate) => self2.some(predicate));
var extend = /* @__PURE__ */ dual22(2, (self2, f22) => self2.map((_22, i22, as42) => f22(as42.slice(i22))));
var min2 = /* @__PURE__ */ dual22(2, (self2, O22) => self2.reduce(min(O22)));
var max2 = /* @__PURE__ */ dual22(2, (self2, O22) => self2.reduce(max(O22)));
var unfold = (b22, f22) => {
  const out = [];
  let next = b22;
  let o22;
  while (isSome4(o22 = f22(next))) {
    const [a22, b3] = o22.value;
    out.push(a22);
    next = b3;
  }
  return out;
};
var getOrder3 = array4;
var getEquivalence4 = array32;
var forEach32 = /* @__PURE__ */ dual22(2, (self2, f22) => fromIterable4(self2).forEach((a22, i22) => f22(a22, i22)));
var dedupeWith = /* @__PURE__ */ dual22(2, (self2, isEquivalent) => {
  const input = fromIterable4(self2);
  if (isNonEmptyReadonlyArray(input)) {
    const out = [headNonEmpty22(input)];
    const rest = tailNonEmpty22(input);
    for (const r22 of rest) {
      if (out.every((a22) => !isEquivalent(r22, a22))) {
        out.push(r22);
      }
    }
    return out;
  }
  return [];
});
var dedupe = (self2) => dedupeWith(self2, equivalence22());
var dedupeAdjacentWith = /* @__PURE__ */ dual22(2, (self2, isEquivalent) => {
  const out = [];
  let lastA = none4();
  for (const a22 of self2) {
    if (isNone4(lastA) || !isEquivalent(a22, lastA.value)) {
      out.push(a22);
      lastA = some6(a22);
    }
  }
  return out;
});
var dedupeAdjacent = /* @__PURE__ */ dedupeAdjacentWith(/* @__PURE__ */ equivalence22());
var join = /* @__PURE__ */ dual22(2, (self2, sep) => fromIterable4(self2).join(sep));
var mapAccum = /* @__PURE__ */ dual22(3, (self2, s22, f22) => {
  let i22 = 0;
  let s1 = s22;
  const out = [];
  for (const a22 of self2) {
    const r22 = f22(s1, a22, i22);
    s1 = r22[0];
    out.push(r22[1]);
    i22++;
  }
  return [s1, out];
});
var cartesianWith = /* @__PURE__ */ dual22(3, (self2, that, f22) => flatMap3(self2, (a22) => map3(that, (b22) => f22(a22, b22))));
var cartesian = /* @__PURE__ */ dual22(2, (self2, that) => cartesianWith(self2, that, (a22, b22) => [a22, b22]));
var Do3 = /* @__PURE__ */ of22({});
var bind5 = /* @__PURE__ */ bind32(map3, flatMap3);
var bindTo5 = /* @__PURE__ */ bindTo32(map3);
var let_5 = /* @__PURE__ */ let_32(map3);
var __defProp32 = Object.defineProperty;
var __export32 = (target, all322) => {
  for (var name in all322)
    __defProp32(target, name, { get: all322[name], enumerable: true });
};
var Function_exports3 = {};
__export32(Function_exports3, {
  SK: () => SK3,
  absurd: () => absurd3,
  apply: () => apply3,
  compose: () => compose5,
  constFalse: () => constFalse3,
  constNull: () => constNull3,
  constTrue: () => constTrue3,
  constUndefined: () => constUndefined3,
  constVoid: () => constVoid3,
  constant: () => constant3,
  dual: () => dual3,
  flip: () => flip3,
  flow: () => flow3,
  hole: () => hole3,
  identity: () => identity3,
  isFunction: () => isFunction6,
  pipe: () => pipe3,
  satisfies: () => satisfies3,
  tupled: () => tupled3,
  unsafeCoerce: () => unsafeCoerce3,
  untupled: () => untupled3
});
var isFunction6 = (input) => typeof input === "function";
var dual3 = function(arity, body) {
  if (typeof arity === "function") {
    return function() {
      if (arity(arguments)) {
        return body.apply(this, arguments);
      }
      return (self2) => body(self2, ...arguments);
    };
  }
  switch (arity) {
    case 0:
    case 1:
      throw new RangeError(`Invalid arity ${arity}`);
    case 2:
      return function(a22, b22) {
        if (arguments.length >= 2) {
          return body(a22, b22);
        }
        return function(self2) {
          return body(self2, a22);
        };
      };
    case 3:
      return function(a22, b22, c22) {
        if (arguments.length >= 3) {
          return body(a22, b22, c22);
        }
        return function(self2) {
          return body(self2, a22, b22);
        };
      };
    case 4:
      return function(a22, b22, c22, d22) {
        if (arguments.length >= 4) {
          return body(a22, b22, c22, d22);
        }
        return function(self2) {
          return body(self2, a22, b22, c22);
        };
      };
    case 5:
      return function(a22, b22, c22, d22, e22) {
        if (arguments.length >= 5) {
          return body(a22, b22, c22, d22, e22);
        }
        return function(self2) {
          return body(self2, a22, b22, c22, d22);
        };
      };
    default:
      return function() {
        if (arguments.length >= arity) {
          return body.apply(this, arguments);
        }
        const args = arguments;
        return function(self2) {
          return body(self2, ...args);
        };
      };
  }
};
var apply3 = (a22) => (self2) => self2(a22);
var identity3 = (a22) => a22;
var satisfies3 = () => (b22) => b22;
var unsafeCoerce3 = identity3;
var constant3 = (value) => () => value;
var constTrue3 = /* @__PURE__ */ constant3(true);
var constFalse3 = /* @__PURE__ */ constant3(false);
var constNull3 = /* @__PURE__ */ constant3(null);
var constUndefined3 = /* @__PURE__ */ constant3(void 0);
var constVoid3 = constUndefined3;
var flip3 = (f22) => (...b22) => (...a22) => f22(...a22)(...b22);
var compose5 = /* @__PURE__ */ dual3(2, (ab, bc) => (a22) => bc(ab(a22)));
var absurd3 = (_22) => {
  throw new Error("Called `absurd` function which should be uncallable");
};
var tupled3 = (f22) => (a22) => f22(...a22);
var untupled3 = (f22) => (...a22) => f22(a22);
function pipe3(a22, ab, bc, cd, de, ef, fg, gh, hi) {
  switch (arguments.length) {
    case 1:
      return a22;
    case 2:
      return ab(a22);
    case 3:
      return bc(ab(a22));
    case 4:
      return cd(bc(ab(a22)));
    case 5:
      return de(cd(bc(ab(a22))));
    case 6:
      return ef(de(cd(bc(ab(a22)))));
    case 7:
      return fg(ef(de(cd(bc(ab(a22))))));
    case 8:
      return gh(fg(ef(de(cd(bc(ab(a22)))))));
    case 9:
      return hi(gh(fg(ef(de(cd(bc(ab(a22))))))));
    default: {
      let ret = arguments[0];
      for (let i22 = 1; i22 < arguments.length; i22++) {
        ret = arguments[i22](ret);
      }
      return ret;
    }
  }
}
function flow3(ab, bc, cd, de, ef, fg, gh, hi, ij) {
  switch (arguments.length) {
    case 1:
      return ab;
    case 2:
      return function() {
        return bc(ab.apply(this, arguments));
      };
    case 3:
      return function() {
        return cd(bc(ab.apply(this, arguments)));
      };
    case 4:
      return function() {
        return de(cd(bc(ab.apply(this, arguments))));
      };
    case 5:
      return function() {
        return ef(de(cd(bc(ab.apply(this, arguments)))));
      };
    case 6:
      return function() {
        return fg(ef(de(cd(bc(ab.apply(this, arguments))))));
      };
    case 7:
      return function() {
        return gh(fg(ef(de(cd(bc(ab.apply(this, arguments)))))));
      };
    case 8:
      return function() {
        return hi(gh(fg(ef(de(cd(bc(ab.apply(this, arguments))))))));
      };
    case 9:
      return function() {
        return ij(hi(gh(fg(ef(de(cd(bc(ab.apply(this, arguments)))))))));
      };
  }
  return;
}
var hole3 = /* @__PURE__ */ unsafeCoerce3(absurd3);
var SK3 = (_22, b22) => b22;
var make11 = (isEquivalent) => (self2, that) => self2 === that || isEquivalent(self2, that);
var let_6 = (map32) => dual3(3, (self2, name, f22) => map32(self2, (a22) => Object.assign({}, a22, {
  [name]: f22(a22)
})));
var bindTo6 = (map32) => dual3(2, (self2, name) => map32(self2, (a22) => ({
  [name]: a22
})));
var bind6 = (map32, flatMap32) => dual3(3, (self2, name, f22) => flatMap32(self2, (a22) => map32(f22(a22), (b22) => Object.assign({}, a22, {
  [name]: b22
}))));
var moduleVersion3 = "3.2.8";
var getCurrentVersion3 = () => moduleVersion3;
var globalStoreId3 = /* @__PURE__ */ Symbol.for(`effect/GlobalValue/globalStoreId/${/* @__PURE__ */ getCurrentVersion3()}`);
if (!(globalStoreId3 in globalThis)) {
  globalThis[globalStoreId3] = /* @__PURE__ */ new Map();
}
var globalStore3 = globalThis[globalStoreId3];
var globalValue3 = (id, compute) => {
  if (!globalStore3.has(id)) {
    globalStore3.set(id, compute());
  }
  return globalStore3.get(id);
};
var isFunction222 = isFunction6;
var isRecordOrArray3 = (input) => typeof input === "object" && input !== null;
var isObject3 = (input) => isRecordOrArray3(input) || isFunction222(input);
var hasProperty3 = /* @__PURE__ */ dual3(2, (self2, property) => isObject3(self2) && property in self2);
var isNullable3 = (input) => input === null || input === void 0;
var getBugErrorMessage3 = (message) => `BUG: ${message} - please report an issue at https://github.com/Effect-TS/effect/issues`;
var GenKindTypeId3 = /* @__PURE__ */ Symbol.for("effect/Gen/GenKind");
var isGenKind3 = (u22) => isObject3(u22) && GenKindTypeId3 in u22;
var GenKindImpl3 = class {
  value;
  constructor(value) {
    this.value = value;
  }
  /**
   * @since 2.0.0
   */
  get _F() {
    return identity3;
  }
  /**
   * @since 2.0.0
   */
  get _R() {
    return (_22) => _22;
  }
  /**
   * @since 2.0.0
   */
  get _O() {
    return (_22) => _22;
  }
  /**
   * @since 2.0.0
   */
  get _E() {
    return (_22) => _22;
  }
  /**
   * @since 2.0.0
   */
  [GenKindTypeId3] = GenKindTypeId3;
  /**
   * @since 2.0.0
   */
  [Symbol.iterator]() {
    return new SingleShotGen4(this);
  }
};
var SingleShotGen4 = class _SingleShotGen32 {
  self;
  called = false;
  constructor(self2) {
    this.self = self2;
  }
  /**
   * @since 2.0.0
   */
  next(a22) {
    return this.called ? {
      value: a22,
      done: true
    } : (this.called = true, {
      value: this.self,
      done: false
    });
  }
  /**
   * @since 2.0.0
   */
  return(a22) {
    return {
      value: a22,
      done: true
    };
  }
  /**
   * @since 2.0.0
   */
  throw(e22) {
    throw e22;
  }
  /**
   * @since 2.0.0
   */
  [Symbol.iterator]() {
    return new _SingleShotGen32(this.self);
  }
};
var adapter5 = () => function() {
  let x22 = arguments[0];
  for (let i22 = 1; i22 < arguments.length; i22++) {
    x22 = arguments[i22](x22);
  }
  return new GenKindImpl3(x22);
};
var defaultIncHi3 = 335903614;
var defaultIncLo3 = 4150755663;
var MUL_HI3 = 1481765933 >>> 0;
var MUL_LO3 = 1284865837 >>> 0;
var BIT_533 = 9007199254740992;
var BIT_273 = 134217728;
var PCGRandom3 = class {
  _state;
  constructor(seedHi, seedLo, incHi, incLo) {
    if (isNullable3(seedLo) && isNullable3(seedHi)) {
      seedLo = Math.random() * 4294967295 >>> 0;
      seedHi = 0;
    } else if (isNullable3(seedLo)) {
      seedLo = seedHi;
      seedHi = 0;
    }
    if (isNullable3(incLo) && isNullable3(incHi)) {
      incLo = this._state ? this._state[3] : defaultIncLo3;
      incHi = this._state ? this._state[2] : defaultIncHi3;
    } else if (isNullable3(incLo)) {
      incLo = incHi;
      incHi = 0;
    }
    this._state = new Int32Array([0, 0, incHi >>> 0, ((incLo || 0) | 1) >>> 0]);
    this._next();
    add643(this._state, this._state[0], this._state[1], seedHi >>> 0, seedLo >>> 0);
    this._next();
    return this;
  }
  /**
   * Returns a copy of the internal state of this random number generator as a
   * JavaScript Array.
   *
   * @category getters
   * @since 2.0.0
   */
  getState() {
    return [this._state[0], this._state[1], this._state[2], this._state[3]];
  }
  /**
   * Restore state previously retrieved using `getState()`.
   *
   * @since 2.0.0
   */
  setState(state) {
    this._state[0] = state[0];
    this._state[1] = state[1];
    this._state[2] = state[2];
    this._state[3] = state[3] | 1;
  }
  /**
   * Get a uniformly distributed 32 bit integer between [0, max).
   *
   * @category getter
   * @since 2.0.0
   */
  integer(max3) {
    if (!max3) {
      return this._next();
    }
    max3 = max3 >>> 0;
    if ((max3 & max3 - 1) === 0) {
      return this._next() & max3 - 1;
    }
    let num = 0;
    const skew = (-max3 >>> 0) % max3 >>> 0;
    for (num = this._next(); num < skew; num = this._next()) {
    }
    return num % max3;
  }
  /**
   * Get a uniformly distributed IEEE-754 double between 0.0 and 1.0, with
   * 53 bits of precision (every bit of the mantissa is randomized).
   *
   * @category getters
   * @since 2.0.0
   */
  number() {
    const hi = (this._next() & 67108863) * 1;
    const lo = (this._next() & 134217727) * 1;
    return (hi * BIT_273 + lo) / BIT_533;
  }
  /** @internal */
  _next() {
    const oldHi = this._state[0] >>> 0;
    const oldLo = this._state[1] >>> 0;
    mul643(this._state, oldHi, oldLo, MUL_HI3, MUL_LO3);
    add643(this._state, this._state[0], this._state[1], this._state[2], this._state[3]);
    let xsHi = oldHi >>> 18;
    let xsLo = (oldLo >>> 18 | oldHi << 14) >>> 0;
    xsHi = (xsHi ^ oldHi) >>> 0;
    xsLo = (xsLo ^ oldLo) >>> 0;
    const xorshifted = (xsLo >>> 27 | xsHi << 5) >>> 0;
    const rot = oldHi >>> 27;
    const rot2 = (-rot >>> 0 & 31) >>> 0;
    return (xorshifted >>> rot | xorshifted << rot2) >>> 0;
  }
};
function mul643(out, aHi, aLo, bHi, bLo) {
  let c1 = (aLo >>> 16) * (bLo & 65535) >>> 0;
  let c0 = (aLo & 65535) * (bLo >>> 16) >>> 0;
  let lo = (aLo & 65535) * (bLo & 65535) >>> 0;
  let hi = (aLo >>> 16) * (bLo >>> 16) + ((c0 >>> 16) + (c1 >>> 16)) >>> 0;
  c0 = c0 << 16 >>> 0;
  lo = lo + c0 >>> 0;
  if (lo >>> 0 < c0 >>> 0) {
    hi = hi + 1 >>> 0;
  }
  c1 = c1 << 16 >>> 0;
  lo = lo + c1 >>> 0;
  if (lo >>> 0 < c1 >>> 0) {
    hi = hi + 1 >>> 0;
  }
  hi = hi + Math.imul(aLo, bHi) >>> 0;
  hi = hi + Math.imul(aHi, bLo) >>> 0;
  out[0] = hi;
  out[1] = lo;
}
function add643(out, aHi, aLo, bHi, bLo) {
  let hi = aHi + bHi >>> 0;
  const lo = aLo + bLo >>> 0;
  if (lo >>> 0 < aLo >>> 0) {
    hi = hi + 1 | 0;
  }
  out[0] = hi;
  out[1] = lo;
}
var YieldWrapTypeId3 = /* @__PURE__ */ Symbol.for("effect/Utils/YieldWrap");
var YieldWrap3 = class {
  /**
   * @since 3.0.6
   */
  #value;
  constructor(value) {
    this.#value = value;
  }
  /**
   * @since 3.0.6
   */
  [YieldWrapTypeId3]() {
    return this.#value;
  }
};
function yieldWrapGet3(self2) {
  if (typeof self2 === "object" && self2 !== null && YieldWrapTypeId3 in self2) {
    return self2[YieldWrapTypeId3]();
  }
  throw new Error(getBugErrorMessage3("yieldWrapGet"));
}
var structuralRegionState3 = /* @__PURE__ */ globalValue3("effect/Utils/isStructuralRegion", () => ({
  enabled: false,
  tester: void 0
}));
var randomHashCache3 = /* @__PURE__ */ globalValue3(/* @__PURE__ */ Symbol.for("effect/Hash/randomHashCache"), () => /* @__PURE__ */ new WeakMap());
var pcgr3 = /* @__PURE__ */ globalValue3(/* @__PURE__ */ Symbol.for("effect/Hash/pcgr"), () => new PCGRandom3());
var symbol5 = /* @__PURE__ */ Symbol.for("effect/Hash");
var hash3 = (self2) => {
  if (structuralRegionState3.enabled === true) {
    return 0;
  }
  switch (typeof self2) {
    case "number":
      return number4(self2);
    case "bigint":
      return string3(self2.toString(10));
    case "boolean":
      return string3(String(self2));
    case "symbol":
      return string3(String(self2));
    case "string":
      return string3(self2);
    case "undefined":
      return string3("undefined");
    case "function":
    case "object": {
      if (self2 === null) {
        return string3("null");
      } else if (self2 instanceof Date) {
        return hash3(self2.toISOString());
      } else if (isHash3(self2)) {
        return self2[symbol5]();
      } else {
        return random3(self2);
      }
    }
    default:
      throw new Error(`BUG: unhandled typeof ${typeof self2} - please report an issue at https://github.com/Effect-TS/effect/issues`);
  }
};
var random3 = (self2) => {
  if (!randomHashCache3.has(self2)) {
    randomHashCache3.set(self2, number4(pcgr3.integer(Number.MAX_SAFE_INTEGER)));
  }
  return randomHashCache3.get(self2);
};
var combine4 = (b22) => (self2) => self2 * 53 ^ b22;
var optimize3 = (n22) => n22 & 3221225471 | n22 >>> 1 & 1073741824;
var isHash3 = (u22) => hasProperty3(u22, symbol5);
var number4 = (n22) => {
  if (n22 !== n22 || n22 === Infinity) {
    return 0;
  }
  let h22 = n22 | 0;
  if (h22 !== n22) {
    h22 ^= n22 * 4294967295;
  }
  while (n22 > 4294967295) {
    h22 ^= n22 /= 4294967295;
  }
  return optimize3(n22);
};
var string3 = (str) => {
  let h22 = 5381, i22 = str.length;
  while (i22) {
    h22 = h22 * 33 ^ str.charCodeAt(--i22);
  }
  return optimize3(h22);
};
var cached3 = function() {
  if (arguments.length === 1) {
    const self3 = arguments[0];
    return function(hash42) {
      Object.defineProperty(self3, symbol5, {
        value() {
          return hash42;
        },
        enumerable: false
      });
      return hash42;
    };
  }
  const self2 = arguments[0];
  const hash32 = arguments[1];
  Object.defineProperty(self2, symbol5, {
    value() {
      return hash32;
    },
    enumerable: false
  });
  return hash32;
};
var symbol222 = /* @__PURE__ */ Symbol.for("effect/Equal");
function equals3() {
  if (arguments.length === 1) {
    return (self2) => compareBoth3(self2, arguments[0]);
  }
  return compareBoth3(arguments[0], arguments[1]);
}
function compareBoth3(self2, that) {
  if (self2 === that) {
    return true;
  }
  const selfType = typeof self2;
  if (selfType !== typeof that) {
    return false;
  }
  if (selfType === "object" || selfType === "function") {
    if (self2 !== null && that !== null) {
      if (isEqual3(self2) && isEqual3(that)) {
        if (hash3(self2) === hash3(that) && self2[symbol222](that)) {
          return true;
        } else {
          return structuralRegionState3.enabled && structuralRegionState3.tester ? structuralRegionState3.tester(self2, that) : false;
        }
      } else if (self2 instanceof Date && that instanceof Date) {
        return self2.toISOString() === that.toISOString();
      }
    }
    if (structuralRegionState3.enabled) {
      if (Array.isArray(self2) && Array.isArray(that)) {
        return self2.length === that.length && self2.every((v22, i22) => compareBoth3(v22, that[i22]));
      }
      if (Object.getPrototypeOf(self2) === Object.prototype && Object.getPrototypeOf(self2) === Object.prototype) {
        const keysSelf = Object.keys(self2);
        const keysThat = Object.keys(that);
        if (keysSelf.length === keysThat.length) {
          for (const key of keysSelf) {
            if (!(key in that && compareBoth3(self2[key], that[key]))) {
              return structuralRegionState3.tester ? structuralRegionState3.tester(self2, that) : false;
            }
          }
          return true;
        }
      }
      return structuralRegionState3.tester ? structuralRegionState3.tester(self2, that) : false;
    }
  }
  return structuralRegionState3.enabled && structuralRegionState3.tester ? structuralRegionState3.tester(self2, that) : false;
}
var isEqual3 = (u22) => hasProperty3(u22, symbol222);
var equivalence3 = () => equals3;
var NodeInspectSymbol3 = /* @__PURE__ */ Symbol.for("nodejs.util.inspect.custom");
var toJSON3 = (x22) => {
  if (hasProperty3(x22, "toJSON") && isFunction222(x22["toJSON"]) && x22["toJSON"].length === 0) {
    return x22.toJSON();
  } else if (Array.isArray(x22)) {
    return x22.map(toJSON3);
  }
  return x22;
};
var format3 = (x22) => JSON.stringify(x22, null, 2);
var pipeArguments3 = (self2, args) => {
  switch (args.length) {
    case 1:
      return args[0](self2);
    case 2:
      return args[1](args[0](self2));
    case 3:
      return args[2](args[1](args[0](self2)));
    case 4:
      return args[3](args[2](args[1](args[0](self2))));
    case 5:
      return args[4](args[3](args[2](args[1](args[0](self2)))));
    case 6:
      return args[5](args[4](args[3](args[2](args[1](args[0](self2))))));
    case 7:
      return args[6](args[5](args[4](args[3](args[2](args[1](args[0](self2)))))));
    case 8:
      return args[7](args[6](args[5](args[4](args[3](args[2](args[1](args[0](self2))))))));
    case 9:
      return args[8](args[7](args[6](args[5](args[4](args[3](args[2](args[1](args[0](self2)))))))));
    default: {
      let ret = self2;
      for (let i22 = 0, len = args.length; i22 < len; i22++) {
        ret = args[i22](ret);
      }
      return ret;
    }
  }
};
var EffectTypeId4 = /* @__PURE__ */ Symbol.for("effect/Effect");
var StreamTypeId3 = /* @__PURE__ */ Symbol.for("effect/Stream");
var SinkTypeId3 = /* @__PURE__ */ Symbol.for("effect/Sink");
var ChannelTypeId3 = /* @__PURE__ */ Symbol.for("effect/Channel");
var effectVariance3 = {
  /* c8 ignore next */
  _R: (_22) => _22,
  /* c8 ignore next */
  _E: (_22) => _22,
  /* c8 ignore next */
  _A: (_22) => _22,
  _V: /* @__PURE__ */ getCurrentVersion3()
};
var sinkVariance3 = {
  /* c8 ignore next */
  _A: (_22) => _22,
  /* c8 ignore next */
  _In: (_22) => _22,
  /* c8 ignore next */
  _L: (_22) => _22,
  /* c8 ignore next */
  _E: (_22) => _22,
  /* c8 ignore next */
  _R: (_22) => _22
};
var channelVariance3 = {
  /* c8 ignore next */
  _Env: (_22) => _22,
  /* c8 ignore next */
  _InErr: (_22) => _22,
  /* c8 ignore next */
  _InElem: (_22) => _22,
  /* c8 ignore next */
  _InDone: (_22) => _22,
  /* c8 ignore next */
  _OutErr: (_22) => _22,
  /* c8 ignore next */
  _OutElem: (_22) => _22,
  /* c8 ignore next */
  _OutDone: (_22) => _22
};
var EffectPrototype3 = {
  [EffectTypeId4]: effectVariance3,
  [StreamTypeId3]: effectVariance3,
  [SinkTypeId3]: sinkVariance3,
  [ChannelTypeId3]: channelVariance3,
  [symbol222](that) {
    return this === that;
  },
  [symbol5]() {
    return cached3(this, random3(this));
  },
  [Symbol.iterator]() {
    return new SingleShotGen4(new YieldWrap3(this));
  },
  pipe() {
    return pipeArguments3(this, arguments);
  }
};
var TypeId9 = /* @__PURE__ */ Symbol.for("effect/Option");
var CommonProto5 = {
  ...EffectPrototype3,
  [TypeId9]: {
    _A: (_22) => _22
  },
  [NodeInspectSymbol3]() {
    return this.toJSON();
  },
  toString() {
    return format3(this.toJSON());
  }
};
var SomeProto3 = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(CommonProto5), {
  _tag: "Some",
  _op: "Some",
  [symbol222](that) {
    return isOption5(that) && isSome5(that) && equals3(this.value, that.value);
  },
  [symbol5]() {
    return cached3(this, combine4(hash3(this._tag))(hash3(this.value)));
  },
  toJSON() {
    return {
      _id: "Option",
      _tag: this._tag,
      value: toJSON3(this.value)
    };
  }
});
var NoneHash3 = /* @__PURE__ */ hash3("None");
var NoneProto3 = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(CommonProto5), {
  _tag: "None",
  _op: "None",
  [symbol222](that) {
    return isOption5(that) && isNone5(that);
  },
  [symbol5]() {
    return NoneHash3;
  },
  toJSON() {
    return {
      _id: "Option",
      _tag: this._tag
    };
  }
});
var isOption5 = (input) => hasProperty3(input, TypeId9);
var isNone5 = (fa) => fa._tag === "None";
var isSome5 = (fa) => fa._tag === "Some";
var none5 = /* @__PURE__ */ Object.create(NoneProto3);
var some8 = (value) => {
  const a22 = Object.create(SomeProto3);
  a22.value = value;
  return a22;
};
var TypeId222 = /* @__PURE__ */ Symbol.for("effect/Either");
var CommonProto222 = {
  ...EffectPrototype3,
  [TypeId222]: {
    _R: (_22) => _22
  },
  [NodeInspectSymbol3]() {
    return this.toJSON();
  },
  toString() {
    return format3(this.toJSON());
  }
};
var RightProto3 = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(CommonProto222), {
  _tag: "Right",
  _op: "Right",
  [symbol222](that) {
    return isEither3(that) && isRight4(that) && equals3(this.right, that.right);
  },
  [symbol5]() {
    return combine4(hash3(this._tag))(hash3(this.right));
  },
  toJSON() {
    return {
      _id: "Either",
      _tag: this._tag,
      right: toJSON3(this.right)
    };
  }
});
var LeftProto3 = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(CommonProto222), {
  _tag: "Left",
  _op: "Left",
  [symbol222](that) {
    return isEither3(that) && isLeft4(that) && equals3(this.left, that.left);
  },
  [symbol5]() {
    return combine4(hash3(this._tag))(hash3(this.left));
  },
  toJSON() {
    return {
      _id: "Either",
      _tag: this._tag,
      left: toJSON3(this.left)
    };
  }
});
var isEither3 = (input) => hasProperty3(input, TypeId222);
var isLeft4 = (ma) => ma._tag === "Left";
var isRight4 = (ma) => ma._tag === "Right";
var left4 = (left322) => {
  const a22 = Object.create(LeftProto3);
  a22.left = left322;
  return a22;
};
var right4 = (right322) => {
  const a22 = Object.create(RightProto3);
  a22.right = right322;
  return a22;
};
var getLeft5 = (self2) => isRight4(self2) ? none5 : some8(self2.left);
var getRight5 = (self2) => isLeft4(self2) ? none5 : some8(self2.right);
var Option_exports3 = {};
__export32(Option_exports3, {
  Do: () => Do4,
  TypeId: () => TypeId322,
  all: () => all5,
  andThen: () => andThen3,
  ap: () => ap3,
  as: () => as3,
  asVoid: () => asVoid3,
  bind: () => bind222,
  bindTo: () => bindTo222,
  composeK: () => composeK3,
  contains: () => contains4,
  containsWith: () => containsWith4,
  exists: () => exists3,
  filter: () => filter4,
  filterMap: () => filterMap4,
  firstSomeOf: () => firstSomeOf3,
  flatMap: () => flatMap4,
  flatMapNullable: () => flatMapNullable4,
  flatten: () => flatten4,
  fromIterable: () => fromIterable5,
  fromNullable: () => fromNullable4,
  gen: () => gen3,
  getEquivalence: () => getEquivalence5,
  getLeft: () => getLeft222,
  getOrElse: () => getOrElse3,
  getOrNull: () => getOrNull3,
  getOrThrow: () => getOrThrow3,
  getOrThrowWith: () => getOrThrowWith3,
  getOrUndefined: () => getOrUndefined3,
  getOrder: () => getOrder4,
  getRight: () => getRight222,
  isNone: () => isNone222,
  isOption: () => isOption222,
  isSome: () => isSome222,
  let: () => let_222,
  lift2: () => lift23,
  liftNullable: () => liftNullable4,
  liftPredicate: () => liftPredicate4,
  liftThrowable: () => liftThrowable3,
  map: () => map4,
  match: () => match5,
  none: () => none222,
  orElse: () => orElse3,
  orElseEither: () => orElseEither3,
  orElseSome: () => orElseSome3,
  partitionMap: () => partitionMap4,
  product: () => product5,
  productMany: () => productMany5,
  reduceCompact: () => reduceCompact3,
  some: () => some222,
  tap: () => tap3,
  toArray: () => toArray3,
  toRefinement: () => toRefinement3,
  void: () => void_3,
  zipLeft: () => zipLeft3,
  zipRight: () => zipRight3,
  zipWith: () => zipWith4
});
var make222 = (compare) => (self2, that) => self2 === that ? 0 : compare(self2, that);
var TypeId322 = /* @__PURE__ */ Symbol.for("effect/Option");
var none222 = () => none5;
var some222 = some8;
var isOption222 = isOption5;
var isNone222 = isNone5;
var isSome222 = isSome5;
var match5 = /* @__PURE__ */ dual3(2, (self2, {
  onNone,
  onSome
}) => isNone222(self2) ? onNone() : onSome(self2.value));
var toRefinement3 = (f22) => (a22) => isSome222(f22(a22));
var fromIterable5 = (collection) => {
  for (const a22 of collection) {
    return some222(a22);
  }
  return none222();
};
var getRight222 = getRight5;
var getLeft222 = getLeft5;
var getOrElse3 = /* @__PURE__ */ dual3(2, (self2, onNone) => isNone222(self2) ? onNone() : self2.value);
var orElse3 = /* @__PURE__ */ dual3(2, (self2, that) => isNone222(self2) ? that() : self2);
var orElseSome3 = /* @__PURE__ */ dual3(2, (self2, onNone) => isNone222(self2) ? some222(onNone()) : self2);
var orElseEither3 = /* @__PURE__ */ dual3(2, (self2, that) => isNone222(self2) ? map4(that(), right4) : map4(self2, left4));
var firstSomeOf3 = (collection) => {
  let out = none222();
  for (out of collection) {
    if (isSome222(out)) {
      return out;
    }
  }
  return out;
};
var fromNullable4 = (nullableValue) => nullableValue == null ? none222() : some222(nullableValue);
var liftNullable4 = (f22) => (...a22) => fromNullable4(f22(...a22));
var getOrNull3 = /* @__PURE__ */ getOrElse3(constNull3);
var getOrUndefined3 = /* @__PURE__ */ getOrElse3(constUndefined3);
var liftThrowable3 = (f22) => (...a22) => {
  try {
    return some222(f22(...a22));
  } catch (e22) {
    return none222();
  }
};
var getOrThrowWith3 = /* @__PURE__ */ dual3(2, (self2, onNone) => {
  if (isSome222(self2)) {
    return self2.value;
  }
  throw onNone();
});
var getOrThrow3 = /* @__PURE__ */ getOrThrowWith3(() => new Error("getOrThrow called on a None"));
var map4 = /* @__PURE__ */ dual3(2, (self2, f22) => isNone222(self2) ? none222() : some222(f22(self2.value)));
var as3 = /* @__PURE__ */ dual3(2, (self2, b22) => map4(self2, () => b22));
var asVoid3 = /* @__PURE__ */ as3(void 0);
var void_3 = /* @__PURE__ */ some222(void 0);
var flatMap4 = /* @__PURE__ */ dual3(2, (self2, f22) => isNone222(self2) ? none222() : f22(self2.value));
var andThen3 = /* @__PURE__ */ dual3(2, (self2, f22) => flatMap4(self2, (a22) => {
  const b22 = isFunction6(f22) ? f22(a22) : f22;
  return isOption222(b22) ? b22 : some222(b22);
}));
var flatMapNullable4 = /* @__PURE__ */ dual3(2, (self2, f22) => isNone222(self2) ? none222() : fromNullable4(f22(self2.value)));
var flatten4 = /* @__PURE__ */ flatMap4(identity3);
var zipRight3 = /* @__PURE__ */ dual3(2, (self2, that) => flatMap4(self2, () => that));
var composeK3 = /* @__PURE__ */ dual3(2, (afb, bfc) => (a22) => flatMap4(afb(a22), bfc));
var zipLeft3 = /* @__PURE__ */ dual3(2, (self2, that) => tap3(self2, () => that));
var tap3 = /* @__PURE__ */ dual3(2, (self2, f22) => flatMap4(self2, (a22) => map4(f22(a22), () => a22)));
var product5 = (self2, that) => isSome222(self2) && isSome222(that) ? some222([self2.value, that.value]) : none222();
var productMany5 = (self2, collection) => {
  if (isNone222(self2)) {
    return none222();
  }
  const out = [self2.value];
  for (const o22 of collection) {
    if (isNone222(o22)) {
      return none222();
    }
    out.push(o22.value);
  }
  return some222(out);
};
var all5 = (input) => {
  if (Symbol.iterator in input) {
    const out2 = [];
    for (const o22 of input) {
      if (isNone222(o22)) {
        return none222();
      }
      out2.push(o22.value);
    }
    return some222(out2);
  }
  const out = {};
  for (const key of Object.keys(input)) {
    const o22 = input[key];
    if (isNone222(o22)) {
      return none222();
    }
    out[key] = o22.value;
  }
  return some222(out);
};
var zipWith4 = /* @__PURE__ */ dual3(3, (self2, that, f22) => map4(product5(self2, that), ([a22, b22]) => f22(a22, b22)));
var ap3 = /* @__PURE__ */ dual3(2, (self2, that) => zipWith4(self2, that, (f22, a22) => f22(a22)));
var reduceCompact3 = /* @__PURE__ */ dual3(3, (self2, b22, f22) => {
  let out = b22;
  for (const oa of self2) {
    if (isSome222(oa)) {
      out = f22(out, oa.value);
    }
  }
  return out;
});
var toArray3 = (self2) => isNone222(self2) ? [] : [self2.value];
var partitionMap4 = /* @__PURE__ */ dual3(2, (self2, f22) => {
  if (isNone222(self2)) {
    return [none222(), none222()];
  }
  const e22 = f22(self2.value);
  return isLeft4(e22) ? [some222(e22.left), none222()] : [none222(), some222(e22.right)];
});
var filterMap4 = /* @__PURE__ */ dual3(2, (self2, f22) => isNone222(self2) ? none222() : f22(self2.value));
var filter4 = /* @__PURE__ */ dual3(2, (self2, predicate) => filterMap4(self2, (b22) => predicate(b22) ? some8(b22) : none5));
var getEquivalence5 = (isEquivalent) => make11((x22, y22) => x22 === y22 || (isNone222(x22) ? isNone222(y22) : isNone222(y22) ? false : isEquivalent(x22.value, y22.value)));
var getOrder4 = (O22) => make222((self2, that) => isSome222(self2) ? isSome222(that) ? O22(self2.value, that.value) : 1 : -1);
var lift23 = (f22) => dual3(2, (self2, that) => zipWith4(self2, that, f22));
var liftPredicate4 = (predicate) => (b22) => predicate(b22) ? some222(b22) : none222();
var containsWith4 = (isEquivalent) => dual3(2, (self2, a22) => isNone222(self2) ? false : isEquivalent(self2.value, a22));
var _equivalence5 = /* @__PURE__ */ equivalence3();
var contains4 = /* @__PURE__ */ containsWith4(_equivalence5);
var exists3 = /* @__PURE__ */ dual3(2, (self2, refinement) => isNone222(self2) ? false : refinement(self2.value));
var bindTo222 = /* @__PURE__ */ bindTo6(map4);
var let_222 = /* @__PURE__ */ let_6(map4);
var bind222 = /* @__PURE__ */ bind6(map4, flatMap4);
var Do4 = /* @__PURE__ */ some222({});
var adapter222 = /* @__PURE__ */ adapter5();
var gen3 = (f22) => {
  const iterator = f22(adapter222);
  let state = iterator.next();
  if (state.done) {
    return some222(state.value);
  } else {
    let current = state.value;
    if (isGenKind3(current)) {
      current = current.value;
    } else {
      current = yieldWrapGet3(current);
    }
    if (isNone222(current)) {
      return current;
    }
    while (!state.done) {
      state = iterator.next(current.value);
      if (!state.done) {
        current = state.value;
        if (isGenKind3(current)) {
          current = current.value;
        } else {
          current = yieldWrapGet3(current);
        }
        if (isNone222(current)) {
          return current;
        }
      }
    }
    return some222(state.value);
  }
};
var MutableRef_exports2 = {};
__export32(MutableRef_exports2, {
  compareAndSet: () => compareAndSet,
  decrement: () => decrement,
  decrementAndGet: () => decrementAndGet,
  get: () => get2,
  getAndDecrement: () => getAndDecrement,
  getAndIncrement: () => getAndIncrement,
  getAndSet: () => getAndSet,
  getAndUpdate: () => getAndUpdate,
  increment: () => increment,
  incrementAndGet: () => incrementAndGet,
  make: () => make322,
  set: () => set22,
  setAndGet: () => setAndGet,
  toggle: () => toggle,
  update: () => update,
  updateAndGet: () => updateAndGet
});
var TypeId422 = /* @__PURE__ */ Symbol.for("effect/MutableRef");
var MutableRefProto = {
  [TypeId422]: TypeId422,
  toString() {
    return format3(this.toJSON());
  },
  toJSON() {
    return {
      _id: "MutableRef",
      current: toJSON3(this.current)
    };
  },
  [NodeInspectSymbol3]() {
    return this.toJSON();
  },
  pipe() {
    return pipeArguments3(this, arguments);
  }
};
var make322 = (value) => {
  const ref = Object.create(MutableRefProto);
  ref.current = value;
  return ref;
};
var compareAndSet = /* @__PURE__ */ dual3(3, (self2, oldValue, newValue) => {
  if (equals3(oldValue, self2.current)) {
    self2.current = newValue;
    return true;
  }
  return false;
});
var decrement = (self2) => update(self2, (n22) => n22 - 1);
var decrementAndGet = (self2) => updateAndGet(self2, (n22) => n22 - 1);
var get2 = (self2) => self2.current;
var getAndDecrement = (self2) => getAndUpdate(self2, (n22) => n22 - 1);
var getAndIncrement = (self2) => getAndUpdate(self2, (n22) => n22 + 1);
var getAndSet = /* @__PURE__ */ dual3(2, (self2, value) => {
  const ret = self2.current;
  self2.current = value;
  return ret;
});
var getAndUpdate = /* @__PURE__ */ dual3(2, (self2, f22) => getAndSet(self2, f22(get2(self2))));
var increment = (self2) => update(self2, (n22) => n22 + 1);
var incrementAndGet = (self2) => updateAndGet(self2, (n22) => n22 + 1);
var set22 = /* @__PURE__ */ dual3(2, (self2, value) => {
  self2.current = value;
  return self2;
});
var setAndGet = /* @__PURE__ */ dual3(2, (self2, value) => {
  self2.current = value;
  return self2.current;
});
var update = /* @__PURE__ */ dual3(2, (self2, f22) => set22(self2, f22(get2(self2))));
var updateAndGet = /* @__PURE__ */ dual3(2, (self2, f22) => setAndGet(self2, f22(get2(self2))));
var toggle = (self2) => update(self2, (_22) => !_22);
function getVariables(initialScope) {
  const scopeRef = MutableRef_exports2.make(initialScope);
  const variablesRef = MutableRef_exports2.make(MutableRef_exports2.get(scopeRef).variables);
  while (MutableRef_exports2.get(scopeRef).type !== scopeManager.ScopeType.global) {
    MutableRef_exports2.set(scopeRef, MutableRef_exports2.get(scopeRef).upper);
    MutableRef_exports2.update(variablesRef, (variables) => variables.concat(MutableRef_exports2.get(scopeRef).variables));
  }
  return MutableRef_exports2.get(variablesRef).reverse();
}
var findVariable22 = Function_exports3.dual(2, (name, initialScope) => {
  return Option_exports3.fromNullable(getVariables(initialScope).find((variable) => variable.name === name));
});
var t = Symbol.for("@ts-pattern/matcher");
var e = Symbol.for("@ts-pattern/isVariadic");
var n = "@ts-pattern/anonymous-select-key";
var r = (t22) => Boolean(t22 && "object" == typeof t22);
var i = (e22) => e22 && !!e22[t];
var o = (n22, s22, c22) => {
  if (i(n22)) {
    const e22 = n22[t](), { matched: r22, selections: i22 } = e22.match(s22);
    return r22 && i22 && Object.keys(i22).forEach((t22) => c22(t22, i22[t22])), r22;
  }
  if (r(n22)) {
    if (!r(s22)) return false;
    if (Array.isArray(n22)) {
      if (!Array.isArray(s22)) return false;
      let t22 = [], r22 = [], a22 = [];
      for (const o22 of n22.keys()) {
        const s3 = n22[o22];
        i(s3) && s3[e] ? a22.push(s3) : a22.length ? r22.push(s3) : t22.push(s3);
      }
      if (a22.length) {
        if (a22.length > 1) throw new Error("Pattern error: Using `...P.array(...)` several times in a single pattern is not allowed.");
        if (s22.length < t22.length + r22.length) return false;
        const e22 = s22.slice(0, t22.length), n3 = 0 === r22.length ? [] : s22.slice(-r22.length), i22 = s22.slice(t22.length, 0 === r22.length ? Infinity : -r22.length);
        return t22.every((t3, n4) => o(t3, e22[n4], c22)) && r22.every((t3, e3) => o(t3, n3[e3], c22)) && (0 === a22.length || o(a22[0], i22, c22));
      }
      return n22.length === s22.length && n22.every((t3, e22) => o(t3, s22[e22], c22));
    }
    return Object.keys(n22).every((e22) => {
      const r22 = n22[e22];
      return (e22 in s22 || i(a22 = r22) && "optional" === a22[t]().matcherType) && o(r22, s22[e22], c22);
      var a22;
    });
  }
  return Object.is(s22, n22);
};
var s = (e22) => {
  var n22, o22, a22;
  return r(e22) ? i(e22) ? null != (n22 = null == (o22 = (a22 = e22[t]()).getSelectionKeys) ? void 0 : o22.call(a22)) ? n22 : [] : Array.isArray(e22) ? c(e22, s) : c(Object.values(e22), s) : [];
};
var c = (t22, e22) => t22.reduce((t3, n22) => t3.concat(e22(n22)), []);
function a(...t22) {
  if (1 === t22.length) {
    const [e22] = t22;
    return (t3) => o(e22, t3, () => {
    });
  }
  if (2 === t22.length) {
    const [e22, n22] = t22;
    return o(e22, n22, () => {
    });
  }
  throw new Error(`isMatching wasn't given the right number of arguments: expected 1 or 2, received ${t22.length}.`);
}
function u(t22) {
  return Object.assign(t22, { optional: () => l(t22), and: (e22) => m(t22, e22), or: (e22) => d(t22, e22), select: (e22) => void 0 === e22 ? p(t22) : p(e22, t22) });
}
function h(t22) {
  return Object.assign(((t3) => Object.assign(t3, { [Symbol.iterator]() {
    let n22 = 0;
    const r22 = [{ value: Object.assign(t3, { [e]: true }), done: false }, { done: true, value: void 0 }];
    return { next: () => {
      var t4;
      return null != (t4 = r22[n22++]) ? t4 : r22.at(-1);
    } };
  } }))(t22), { optional: () => h(l(t22)), select: (e22) => h(void 0 === e22 ? p(t22) : p(e22, t22)) });
}
function l(e22) {
  return u({ [t]: () => ({ match: (t22) => {
    let n22 = {};
    const r22 = (t3, e3) => {
      n22[t3] = e3;
    };
    return void 0 === t22 ? (s(e22).forEach((t3) => r22(t3, void 0)), { matched: true, selections: n22 }) : { matched: o(e22, t22, r22), selections: n22 };
  }, getSelectionKeys: () => s(e22), matcherType: "optional" }) });
}
var f = (t22, e22) => {
  for (const n22 of t22) if (!e22(n22)) return false;
  return true;
};
var g = (t22, e22) => {
  for (const [n22, r22] of t22.entries()) if (!e22(r22, n22)) return false;
  return true;
};
function m(...e22) {
  return u({ [t]: () => ({ match: (t22) => {
    let n22 = {};
    const r22 = (t3, e3) => {
      n22[t3] = e3;
    };
    return { matched: e22.every((e3) => o(e3, t22, r22)), selections: n22 };
  }, getSelectionKeys: () => c(e22, s), matcherType: "and" }) });
}
function d(...e22) {
  return u({ [t]: () => ({ match: (t22) => {
    let n22 = {};
    const r22 = (t3, e3) => {
      n22[t3] = e3;
    };
    return c(e22, s).forEach((t3) => r22(t3, void 0)), { matched: e22.some((e3) => o(e3, t22, r22)), selections: n22 };
  }, getSelectionKeys: () => c(e22, s), matcherType: "or" }) });
}
function y(e22) {
  return { [t]: () => ({ match: (t22) => ({ matched: Boolean(e22(t22)) }) }) };
}
function p(...e22) {
  const r22 = "string" == typeof e22[0] ? e22[0] : void 0, i22 = 2 === e22.length ? e22[1] : "string" == typeof e22[0] ? void 0 : e22[0];
  return u({ [t]: () => ({ match: (t22) => {
    let e3 = { [null != r22 ? r22 : n]: t22 };
    return { matched: void 0 === i22 || o(i22, t22, (t3, n22) => {
      e3[t3] = n22;
    }), selections: e3 };
  }, getSelectionKeys: () => [null != r22 ? r22 : n].concat(void 0 === i22 ? [] : s(i22)) }) });
}
function v(t22) {
  return "number" == typeof t22;
}
function b(t22) {
  return "string" == typeof t22;
}
function w(t22) {
  return "bigint" == typeof t22;
}
var S = u(y(function(t22) {
  return true;
}));
var O = S;
var j = (t22) => Object.assign(u(t22), { startsWith: (e22) => {
  return j(m(t22, (n22 = e22, y((t3) => b(t3) && t3.startsWith(n22)))));
  var n22;
}, endsWith: (e22) => {
  return j(m(t22, (n22 = e22, y((t3) => b(t3) && t3.endsWith(n22)))));
  var n22;
}, minLength: (e22) => j(m(t22, ((t3) => y((e3) => b(e3) && e3.length >= t3))(e22))), maxLength: (e22) => j(m(t22, ((t3) => y((e3) => b(e3) && e3.length <= t3))(e22))), includes: (e22) => {
  return j(m(t22, (n22 = e22, y((t3) => b(t3) && t3.includes(n22)))));
  var n22;
}, regex: (e22) => {
  return j(m(t22, (n22 = e22, y((t3) => b(t3) && Boolean(t3.match(n22))))));
  var n22;
} });
var E = j(y(b));
var K = (t22) => Object.assign(u(t22), { between: (e22, n22) => K(m(t22, ((t3, e3) => y((n3) => v(n3) && t3 <= n3 && e3 >= n3))(e22, n22))), lt: (e22) => K(m(t22, ((t3) => y((e3) => v(e3) && e3 < t3))(e22))), gt: (e22) => K(m(t22, ((t3) => y((e3) => v(e3) && e3 > t3))(e22))), lte: (e22) => K(m(t22, ((t3) => y((e3) => v(e3) && e3 <= t3))(e22))), gte: (e22) => K(m(t22, ((t3) => y((e3) => v(e3) && e3 >= t3))(e22))), int: () => K(m(t22, y((t3) => v(t3) && Number.isInteger(t3)))), finite: () => K(m(t22, y((t3) => v(t3) && Number.isFinite(t3)))), positive: () => K(m(t22, y((t3) => v(t3) && t3 > 0))), negative: () => K(m(t22, y((t3) => v(t3) && t3 < 0))) });
var x = K(y(v));
var A = (t22) => Object.assign(u(t22), { between: (e22, n22) => A(m(t22, ((t3, e3) => y((n3) => w(n3) && t3 <= n3 && e3 >= n3))(e22, n22))), lt: (e22) => A(m(t22, ((t3) => y((e3) => w(e3) && e3 < t3))(e22))), gt: (e22) => A(m(t22, ((t3) => y((e3) => w(e3) && e3 > t3))(e22))), lte: (e22) => A(m(t22, ((t3) => y((e3) => w(e3) && e3 <= t3))(e22))), gte: (e22) => A(m(t22, ((t3) => y((e3) => w(e3) && e3 >= t3))(e22))), positive: () => A(m(t22, y((t3) => w(t3) && t3 > 0))), negative: () => A(m(t22, y((t3) => w(t3) && t3 < 0))) });
var P22 = A(y(w));
var T = u(y(function(t22) {
  return "boolean" == typeof t22;
}));
var k = u(y(function(t22) {
  return "symbol" == typeof t22;
}));
var B = u(y(function(t22) {
  return null == t22;
}));
var _ = u(y(function(t22) {
  return null != t22;
}));
var N = { __proto__: null, matcher: t, optional: l, array: function(...e22) {
  return h({ [t]: () => ({ match: (t22) => {
    if (!Array.isArray(t22)) return { matched: false };
    if (0 === e22.length) return { matched: true };
    const n22 = e22[0];
    let r22 = {};
    if (0 === t22.length) return s(n22).forEach((t3) => {
      r22[t3] = [];
    }), { matched: true, selections: r22 };
    const i22 = (t3, e3) => {
      r22[t3] = (r22[t3] || []).concat([e3]);
    };
    return { matched: t22.every((t3) => o(n22, t3, i22)), selections: r22 };
  }, getSelectionKeys: () => 0 === e22.length ? [] : s(e22[0]) }) });
}, set: function(...e22) {
  return u({ [t]: () => ({ match: (t22) => {
    if (!(t22 instanceof Set)) return { matched: false };
    let n22 = {};
    if (0 === t22.size) return { matched: true, selections: n22 };
    if (0 === e22.length) return { matched: true };
    const r22 = (t3, e3) => {
      n22[t3] = (n22[t3] || []).concat([e3]);
    }, i22 = e22[0];
    return { matched: f(t22, (t3) => o(i22, t3, r22)), selections: n22 };
  }, getSelectionKeys: () => 0 === e22.length ? [] : s(e22[0]) }) });
}, map: function(...e22) {
  return u({ [t]: () => ({ match: (t22) => {
    if (!(t22 instanceof Map)) return { matched: false };
    let n22 = {};
    if (0 === t22.size) return { matched: true, selections: n22 };
    const r22 = (t3, e3) => {
      n22[t3] = (n22[t3] || []).concat([e3]);
    };
    if (0 === e22.length) return { matched: true };
    var i22;
    if (1 === e22.length) throw new Error(`\`P.map\` wasn't given enough arguments. Expected (key, value), received ${null == (i22 = e22[0]) ? void 0 : i22.toString()}`);
    const [s22, c22] = e22;
    return { matched: g(t22, (t3, e3) => {
      const n3 = o(s22, e3, r22), i3 = o(c22, t3, r22);
      return n3 && i3;
    }), selections: n22 };
  }, getSelectionKeys: () => 0 === e22.length ? [] : [...s(e22[0]), ...s(e22[1])] }) });
}, intersection: m, union: d, not: function(e22) {
  return u({ [t]: () => ({ match: (t22) => ({ matched: !o(e22, t22, () => {
  }) }), getSelectionKeys: () => [], matcherType: "not" }) });
}, when: y, select: p, any: S, _: O, string: E, number: x, bigint: P22, boolean: T, symbol: k, nullish: B, nonNullable: _, instanceOf: function(t22) {
  return u(y(/* @__PURE__ */ function(t3) {
    return (e22) => e22 instanceof t3;
  }(t22)));
}, shape: function(t22) {
  return u(y(a(t22)));
} };
var KEYS22 = {
  ArrayExpression: [
    "elements"
  ],
  ArrayPattern: [
    "elements"
  ],
  ArrowFunctionExpression: [
    "params",
    "body"
  ],
  AssignmentExpression: [
    "left",
    "right"
  ],
  AssignmentPattern: [
    "left",
    "right"
  ],
  AwaitExpression: [
    "argument"
  ],
  BinaryExpression: [
    "left",
    "right"
  ],
  BlockStatement: [
    "body"
  ],
  BreakStatement: [
    "label"
  ],
  CallExpression: [
    "callee",
    "arguments"
  ],
  CatchClause: [
    "param",
    "body"
  ],
  ChainExpression: [
    "expression"
  ],
  ClassBody: [
    "body"
  ],
  ClassDeclaration: [
    "id",
    "superClass",
    "body"
  ],
  ClassExpression: [
    "id",
    "superClass",
    "body"
  ],
  ConditionalExpression: [
    "test",
    "consequent",
    "alternate"
  ],
  ContinueStatement: [
    "label"
  ],
  DebuggerStatement: [],
  DoWhileStatement: [
    "body",
    "test"
  ],
  EmptyStatement: [],
  ExperimentalRestProperty: [
    "argument"
  ],
  ExperimentalSpreadProperty: [
    "argument"
  ],
  ExportAllDeclaration: [
    "exported",
    "source"
  ],
  ExportDefaultDeclaration: [
    "declaration"
  ],
  ExportNamedDeclaration: [
    "declaration",
    "specifiers",
    "source"
  ],
  ExportSpecifier: [
    "exported",
    "local"
  ],
  ExpressionStatement: [
    "expression"
  ],
  ForInStatement: [
    "left",
    "right",
    "body"
  ],
  ForOfStatement: [
    "left",
    "right",
    "body"
  ],
  ForStatement: [
    "init",
    "test",
    "update",
    "body"
  ],
  FunctionDeclaration: [
    "id",
    "params",
    "body"
  ],
  FunctionExpression: [
    "id",
    "params",
    "body"
  ],
  Identifier: [],
  IfStatement: [
    "test",
    "consequent",
    "alternate"
  ],
  ImportDeclaration: [
    "specifiers",
    "source"
  ],
  ImportDefaultSpecifier: [
    "local"
  ],
  ImportExpression: [
    "source"
  ],
  ImportNamespaceSpecifier: [
    "local"
  ],
  ImportSpecifier: [
    "imported",
    "local"
  ],
  JSXAttribute: [
    "name",
    "value"
  ],
  JSXClosingElement: [
    "name"
  ],
  JSXClosingFragment: [],
  JSXElement: [
    "openingElement",
    "children",
    "closingElement"
  ],
  JSXEmptyExpression: [],
  JSXExpressionContainer: [
    "expression"
  ],
  JSXFragment: [
    "openingFragment",
    "children",
    "closingFragment"
  ],
  JSXIdentifier: [],
  JSXMemberExpression: [
    "object",
    "property"
  ],
  JSXNamespacedName: [
    "namespace",
    "name"
  ],
  JSXOpeningElement: [
    "name",
    "attributes"
  ],
  JSXOpeningFragment: [],
  JSXSpreadAttribute: [
    "argument"
  ],
  JSXSpreadChild: [
    "expression"
  ],
  JSXText: [],
  LabeledStatement: [
    "label",
    "body"
  ],
  Literal: [],
  LogicalExpression: [
    "left",
    "right"
  ],
  MemberExpression: [
    "object",
    "property"
  ],
  MetaProperty: [
    "meta",
    "property"
  ],
  MethodDefinition: [
    "key",
    "value"
  ],
  NewExpression: [
    "callee",
    "arguments"
  ],
  ObjectExpression: [
    "properties"
  ],
  ObjectPattern: [
    "properties"
  ],
  PrivateIdentifier: [],
  Program: [
    "body"
  ],
  Property: [
    "key",
    "value"
  ],
  PropertyDefinition: [
    "key",
    "value"
  ],
  RestElement: [
    "argument"
  ],
  ReturnStatement: [
    "argument"
  ],
  SequenceExpression: [
    "expressions"
  ],
  SpreadElement: [
    "argument"
  ],
  StaticBlock: [
    "body"
  ],
  Super: [],
  SwitchCase: [
    "test",
    "consequent"
  ],
  SwitchStatement: [
    "discriminant",
    "cases"
  ],
  TaggedTemplateExpression: [
    "tag",
    "quasi"
  ],
  TemplateElement: [],
  TemplateLiteral: [
    "quasis",
    "expressions"
  ],
  ThisExpression: [],
  ThrowStatement: [
    "argument"
  ],
  TryStatement: [
    "block",
    "handler",
    "finalizer"
  ],
  UnaryExpression: [
    "argument"
  ],
  UpdateExpression: [
    "argument"
  ],
  VariableDeclaration: [
    "declarations"
  ],
  VariableDeclarator: [
    "id",
    "init"
  ],
  WhileStatement: [
    "test",
    "body"
  ],
  WithStatement: [
    "object",
    "body"
  ],
  YieldExpression: [
    "argument"
  ]
};
var NODE_TYPES22 = Object.keys(KEYS22);
for (const type of NODE_TYPES22) {
  Object.freeze(KEYS22[type]);
}
Object.freeze(KEYS22);
var visitor_keys_default22 = KEYS22;
var KEY_BLACKLIST22 = /* @__PURE__ */ new Set([
  "parent",
  "leadingComments",
  "trailingComments"
]);
function filterKey22(key) {
  return !KEY_BLACKLIST22.has(key) && key[0] !== "_";
}
function getKeys22(node) {
  return Object.keys(node).filter(filterKey22);
}
function getInnermostScope22(initialScope, node) {
  const location = node.range[0];
  let scope = initialScope;
  let found = false;
  do {
    found = false;
    for (const childScope of scope.childScopes) {
      const range2 = childScope.block.range;
      if (range2[0] <= location && location < range2[1]) {
        scope = childScope;
        found = true;
        break;
      }
    }
  } while (found);
  return scope;
}
function findVariable222(initialScope, nameOrNode) {
  let name = "";
  let scope = initialScope;
  if (typeof nameOrNode === "string") {
    name = nameOrNode;
  } else {
    name = nameOrNode.name;
    scope = getInnermostScope22(scope, nameOrNode);
  }
  while (scope != null) {
    const variable = scope.set.get(name);
    if (variable != null) {
      return variable;
    }
    scope = scope.upper;
  }
  return null;
}
function negate022(token) {
  return !this(token);
}
function negate22(f22) {
  return negate022.bind(f22);
}
function isPunctuatorTokenWithValue22(token, value) {
  return token.type === "Punctuator" && token.value === value;
}
function isArrowToken22(token) {
  return isPunctuatorTokenWithValue22(token, "=>");
}
function isCommaToken22(token) {
  return isPunctuatorTokenWithValue22(token, ",");
}
function isSemicolonToken22(token) {
  return isPunctuatorTokenWithValue22(token, ";");
}
function isColonToken22(token) {
  return isPunctuatorTokenWithValue22(token, ":");
}
function isOpeningParenToken22(token) {
  return isPunctuatorTokenWithValue22(token, "(");
}
function isClosingParenToken22(token) {
  return isPunctuatorTokenWithValue22(token, ")");
}
function isOpeningBracketToken22(token) {
  return isPunctuatorTokenWithValue22(token, "[");
}
function isClosingBracketToken22(token) {
  return isPunctuatorTokenWithValue22(token, "]");
}
function isOpeningBraceToken22(token) {
  return isPunctuatorTokenWithValue22(token, "{");
}
function isClosingBraceToken22(token) {
  return isPunctuatorTokenWithValue22(token, "}");
}
function isCommentToken22(token) {
  return ["Block", "Line", "Shebang"].includes(token.type);
}
negate22(isArrowToken22);
negate22(isCommaToken22);
negate22(isSemicolonToken22);
negate22(isColonToken22);
negate22(isOpeningParenToken22);
negate22(isClosingParenToken22);
negate22(isOpeningBracketToken22);
negate22(isClosingBracketToken22);
negate22(isOpeningBraceToken22);
negate22(isClosingBraceToken22);
negate22(isCommentToken22);
function getOpeningParenOfParams22(node, sourceCode) {
  return node.id ? sourceCode.getTokenAfter(node.id, isOpeningParenToken22) : sourceCode.getFirstToken(node, isOpeningParenToken22);
}
function getFunctionHeadLocation22(node, sourceCode) {
  const parent = node.parent;
  let start = null;
  let end = null;
  if (node.type === "ArrowFunctionExpression") {
    const arrowToken = sourceCode.getTokenBefore(node.body, isArrowToken22);
    start = arrowToken.loc.start;
    end = arrowToken.loc.end;
  } else if (parent.type === "Property" || parent.type === "MethodDefinition" || parent.type === "PropertyDefinition") {
    start = parent.loc.start;
    end = getOpeningParenOfParams22(node, sourceCode).loc.start;
  } else {
    start = node.loc.start;
    end = getOpeningParenOfParams22(node, sourceCode).loc.start;
  }
  return {
    start: { ...start },
    end: { ...end }
  };
}
var globalObject22 = typeof globalThis !== "undefined" ? globalThis : typeof self !== "undefined" ? self : typeof window !== "undefined" ? window : typeof global !== "undefined" ? global : {};
var builtinNames22 = Object.freeze(
  /* @__PURE__ */ new Set([
    "Array",
    "ArrayBuffer",
    "BigInt",
    "BigInt64Array",
    "BigUint64Array",
    "Boolean",
    "DataView",
    "Date",
    "decodeURI",
    "decodeURIComponent",
    "encodeURI",
    "encodeURIComponent",
    "escape",
    "Float32Array",
    "Float64Array",
    "Function",
    "Infinity",
    "Int16Array",
    "Int32Array",
    "Int8Array",
    "isFinite",
    "isNaN",
    "isPrototypeOf",
    "JSON",
    "Map",
    "Math",
    "NaN",
    "Number",
    "Object",
    "parseFloat",
    "parseInt",
    "Promise",
    "Proxy",
    "Reflect",
    "RegExp",
    "Set",
    "String",
    "Symbol",
    "Uint16Array",
    "Uint32Array",
    "Uint8Array",
    "Uint8ClampedArray",
    "undefined",
    "unescape",
    "WeakMap",
    "WeakSet"
  ])
);
var callAllowed22 = new Set(
  [
    Array.isArray,
    Array.of,
    Array.prototype.at,
    Array.prototype.concat,
    Array.prototype.entries,
    Array.prototype.every,
    Array.prototype.filter,
    Array.prototype.find,
    Array.prototype.findIndex,
    Array.prototype.flat,
    Array.prototype.includes,
    Array.prototype.indexOf,
    Array.prototype.join,
    Array.prototype.keys,
    Array.prototype.lastIndexOf,
    Array.prototype.slice,
    Array.prototype.some,
    Array.prototype.toString,
    Array.prototype.values,
    typeof BigInt === "function" ? BigInt : void 0,
    Boolean,
    Date,
    Date.parse,
    decodeURI,
    decodeURIComponent,
    encodeURI,
    encodeURIComponent,
    escape,
    isFinite,
    isNaN,
    isPrototypeOf,
    Map,
    Map.prototype.entries,
    Map.prototype.get,
    Map.prototype.has,
    Map.prototype.keys,
    Map.prototype.values,
    ...Object.getOwnPropertyNames(Math).filter((k22) => k22 !== "random").map((k22) => Math[k22]).filter((f22) => typeof f22 === "function"),
    Number,
    Number.isFinite,
    Number.isNaN,
    Number.parseFloat,
    Number.parseInt,
    Number.prototype.toExponential,
    Number.prototype.toFixed,
    Number.prototype.toPrecision,
    Number.prototype.toString,
    Object,
    Object.entries,
    Object.is,
    Object.isExtensible,
    Object.isFrozen,
    Object.isSealed,
    Object.keys,
    Object.values,
    parseFloat,
    parseInt,
    RegExp,
    Set,
    Set.prototype.entries,
    Set.prototype.has,
    Set.prototype.keys,
    Set.prototype.values,
    String,
    String.fromCharCode,
    String.fromCodePoint,
    String.raw,
    String.prototype.at,
    String.prototype.charAt,
    String.prototype.charCodeAt,
    String.prototype.codePointAt,
    String.prototype.concat,
    String.prototype.endsWith,
    String.prototype.includes,
    String.prototype.indexOf,
    String.prototype.lastIndexOf,
    String.prototype.normalize,
    String.prototype.padEnd,
    String.prototype.padStart,
    String.prototype.slice,
    String.prototype.startsWith,
    String.prototype.substr,
    String.prototype.substring,
    String.prototype.toLowerCase,
    String.prototype.toString,
    String.prototype.toUpperCase,
    String.prototype.trim,
    String.prototype.trimEnd,
    String.prototype.trimLeft,
    String.prototype.trimRight,
    String.prototype.trimStart,
    Symbol.for,
    Symbol.keyFor,
    unescape
  ].filter((f22) => typeof f22 === "function")
);
var callPassThrough22 = /* @__PURE__ */ new Set([
  Object.freeze,
  Object.preventExtensions,
  Object.seal
]);
var getterAllowed22 = [
  [Map, /* @__PURE__ */ new Set(["size"])],
  [
    RegExp,
    /* @__PURE__ */ new Set([
      "dotAll",
      "flags",
      "global",
      "hasIndices",
      "ignoreCase",
      "multiline",
      "source",
      "sticky",
      "unicode"
    ])
  ],
  [Set, /* @__PURE__ */ new Set(["size"])]
];
function getPropertyDescriptor22(object2, name) {
  let x22 = object2;
  while ((typeof x22 === "object" || typeof x22 === "function") && x22 !== null) {
    const d22 = Object.getOwnPropertyDescriptor(x22, name);
    if (d22) {
      return d22;
    }
    x22 = Object.getPrototypeOf(x22);
  }
  return null;
}
function isGetter22(object2, name) {
  const d22 = getPropertyDescriptor22(object2, name);
  return d22 != null && d22.get != null;
}
function getElementValues22(nodeList, initialScope) {
  const valueList = [];
  for (let i22 = 0; i22 < nodeList.length; ++i22) {
    const elementNode = nodeList[i22];
    if (elementNode == null) {
      valueList.length = i22 + 1;
    } else if (elementNode.type === "SpreadElement") {
      const argument = getStaticValueR22(elementNode.argument, initialScope);
      if (argument == null) {
        return null;
      }
      valueList.push(...argument.value);
    } else {
      const element = getStaticValueR22(elementNode, initialScope);
      if (element == null) {
        return null;
      }
      valueList.push(element.value);
    }
  }
  return valueList;
}
function isEffectivelyConst22(variable) {
  const refs = variable.references;
  const inits = refs.filter((r22) => r22.init).length;
  const reads = refs.filter((r22) => r22.isReadOnly()).length;
  if (inits === 1 && reads + inits === refs.length) {
    return true;
  }
  return false;
}
var operations22 = Object.freeze({
  ArrayExpression(node, initialScope) {
    const elements = getElementValues22(node.elements, initialScope);
    return elements != null ? { value: elements } : null;
  },
  AssignmentExpression(node, initialScope) {
    if (node.operator === "=") {
      return getStaticValueR22(node.right, initialScope);
    }
    return null;
  },
  //eslint-disable-next-line complexity
  BinaryExpression(node, initialScope) {
    if (node.operator === "in" || node.operator === "instanceof") {
      return null;
    }
    const left322 = getStaticValueR22(node.left, initialScope);
    const right322 = getStaticValueR22(node.right, initialScope);
    if (left322 != null && right322 != null) {
      switch (node.operator) {
        case "==":
          return { value: left322.value == right322.value };
        case "!=":
          return { value: left322.value != right322.value };
        case "===":
          return { value: left322.value === right322.value };
        case "!==":
          return { value: left322.value !== right322.value };
        case "<":
          return { value: left322.value < right322.value };
        case "<=":
          return { value: left322.value <= right322.value };
        case ">":
          return { value: left322.value > right322.value };
        case ">=":
          return { value: left322.value >= right322.value };
        case "<<":
          return { value: left322.value << right322.value };
        case ">>":
          return { value: left322.value >> right322.value };
        case ">>>":
          return { value: left322.value >>> right322.value };
        case "+":
          return { value: left322.value + right322.value };
        case "-":
          return { value: left322.value - right322.value };
        case "*":
          return { value: left322.value * right322.value };
        case "/":
          return { value: left322.value / right322.value };
        case "%":
          return { value: left322.value % right322.value };
        case "**":
          return { value: left322.value ** right322.value };
        case "|":
          return { value: left322.value | right322.value };
        case "^":
          return { value: left322.value ^ right322.value };
        case "&":
          return { value: left322.value & right322.value };
      }
    }
    return null;
  },
  CallExpression(node, initialScope) {
    const calleeNode = node.callee;
    const args = getElementValues22(node.arguments, initialScope);
    if (args != null) {
      if (calleeNode.type === "MemberExpression") {
        if (calleeNode.property.type === "PrivateIdentifier") {
          return null;
        }
        const object2 = getStaticValueR22(calleeNode.object, initialScope);
        if (object2 != null) {
          if (object2.value == null && (object2.optional || node.optional)) {
            return { value: void 0, optional: true };
          }
          const property = getStaticPropertyNameValue22(
            calleeNode,
            initialScope
          );
          if (property != null) {
            const receiver = object2.value;
            const methodName = property.value;
            if (callAllowed22.has(receiver[methodName])) {
              return { value: receiver[methodName](...args) };
            }
            if (callPassThrough22.has(receiver[methodName])) {
              return { value: args[0] };
            }
          }
        }
      } else {
        const callee = getStaticValueR22(calleeNode, initialScope);
        if (callee != null) {
          if (callee.value == null && node.optional) {
            return { value: void 0, optional: true };
          }
          const func = callee.value;
          if (callAllowed22.has(func)) {
            return { value: func(...args) };
          }
          if (callPassThrough22.has(func)) {
            return { value: args[0] };
          }
        }
      }
    }
    return null;
  },
  ConditionalExpression(node, initialScope) {
    const test = getStaticValueR22(node.test, initialScope);
    if (test != null) {
      return test.value ? getStaticValueR22(node.consequent, initialScope) : getStaticValueR22(node.alternate, initialScope);
    }
    return null;
  },
  ExpressionStatement(node, initialScope) {
    return getStaticValueR22(node.expression, initialScope);
  },
  Identifier(node, initialScope) {
    if (initialScope != null) {
      const variable = findVariable222(initialScope, node);
      if (variable != null && variable.defs.length === 0 && builtinNames22.has(variable.name) && variable.name in globalObject22) {
        return { value: globalObject22[variable.name] };
      }
      if (variable != null && variable.defs.length === 1) {
        const def = variable.defs[0];
        if (def.parent && def.type === "Variable" && (def.parent.kind === "const" || isEffectivelyConst22(variable)) && // TODO(mysticatea): don't support destructuring here.
        def.node.id.type === "Identifier") {
          return getStaticValueR22(def.node.init, initialScope);
        }
      }
    }
    return null;
  },
  Literal(node) {
    if ((node.regex != null || node.bigint != null) && node.value == null) {
      return null;
    }
    return { value: node.value };
  },
  LogicalExpression(node, initialScope) {
    const left322 = getStaticValueR22(node.left, initialScope);
    if (left322 != null) {
      if (node.operator === "||" && Boolean(left322.value) === true || node.operator === "&&" && Boolean(left322.value) === false || node.operator === "??" && left322.value != null) {
        return left322;
      }
      const right322 = getStaticValueR22(node.right, initialScope);
      if (right322 != null) {
        return right322;
      }
    }
    return null;
  },
  MemberExpression(node, initialScope) {
    if (node.property.type === "PrivateIdentifier") {
      return null;
    }
    const object2 = getStaticValueR22(node.object, initialScope);
    if (object2 != null) {
      if (object2.value == null && (object2.optional || node.optional)) {
        return { value: void 0, optional: true };
      }
      const property = getStaticPropertyNameValue22(node, initialScope);
      if (property != null) {
        if (!isGetter22(object2.value, property.value)) {
          return { value: object2.value[property.value] };
        }
        for (const [classFn, allowed] of getterAllowed22) {
          if (object2.value instanceof classFn && allowed.has(property.value)) {
            return { value: object2.value[property.value] };
          }
        }
      }
    }
    return null;
  },
  ChainExpression(node, initialScope) {
    const expression = getStaticValueR22(node.expression, initialScope);
    if (expression != null) {
      return { value: expression.value };
    }
    return null;
  },
  NewExpression(node, initialScope) {
    const callee = getStaticValueR22(node.callee, initialScope);
    const args = getElementValues22(node.arguments, initialScope);
    if (callee != null && args != null) {
      const Func = callee.value;
      if (callAllowed22.has(Func)) {
        return { value: new Func(...args) };
      }
    }
    return null;
  },
  ObjectExpression(node, initialScope) {
    const object2 = {};
    for (const propertyNode of node.properties) {
      if (propertyNode.type === "Property") {
        if (propertyNode.kind !== "init") {
          return null;
        }
        const key = getStaticPropertyNameValue22(
          propertyNode,
          initialScope
        );
        const value = getStaticValueR22(propertyNode.value, initialScope);
        if (key == null || value == null) {
          return null;
        }
        object2[key.value] = value.value;
      } else if (propertyNode.type === "SpreadElement" || propertyNode.type === "ExperimentalSpreadProperty") {
        const argument = getStaticValueR22(
          propertyNode.argument,
          initialScope
        );
        if (argument == null) {
          return null;
        }
        Object.assign(object2, argument.value);
      } else {
        return null;
      }
    }
    return { value: object2 };
  },
  SequenceExpression(node, initialScope) {
    const last2 = node.expressions[node.expressions.length - 1];
    return getStaticValueR22(last2, initialScope);
  },
  TaggedTemplateExpression(node, initialScope) {
    const tag = getStaticValueR22(node.tag, initialScope);
    const expressions = getElementValues22(
      node.quasi.expressions,
      initialScope
    );
    if (tag != null && expressions != null) {
      const func = tag.value;
      const strings = node.quasi.quasis.map((q) => q.value.cooked);
      strings.raw = node.quasi.quasis.map((q) => q.value.raw);
      if (func === String.raw) {
        return { value: func(strings, ...expressions) };
      }
    }
    return null;
  },
  TemplateLiteral(node, initialScope) {
    const expressions = getElementValues22(node.expressions, initialScope);
    if (expressions != null) {
      let value = node.quasis[0].value.cooked;
      for (let i22 = 0; i22 < expressions.length; ++i22) {
        value += expressions[i22];
        value += node.quasis[i22 + 1].value.cooked;
      }
      return { value };
    }
    return null;
  },
  UnaryExpression(node, initialScope) {
    if (node.operator === "delete") {
      return null;
    }
    if (node.operator === "void") {
      return { value: void 0 };
    }
    const arg = getStaticValueR22(node.argument, initialScope);
    if (arg != null) {
      switch (node.operator) {
        case "-":
          return { value: -arg.value };
        case "+":
          return { value: +arg.value };
        case "!":
          return { value: !arg.value };
        case "~":
          return { value: ~arg.value };
        case "typeof":
          return { value: typeof arg.value };
      }
    }
    return null;
  }
});
function getStaticValueR22(node, initialScope) {
  if (node != null && Object.hasOwnProperty.call(operations22, node.type)) {
    return operations22[node.type](node, initialScope);
  }
  return null;
}
function getStaticPropertyNameValue22(node, initialScope) {
  const nameNode = node.type === "Property" ? node.key : node.property;
  if (node.computed) {
    return getStaticValueR22(nameNode, initialScope);
  }
  if (nameNode.type === "Identifier") {
    return { value: nameNode.name };
  }
  if (nameNode.type === "Literal") {
    if (nameNode.bigint) {
      return { value: nameNode.bigint };
    }
    return { value: String(nameNode.value) };
  }
  return null;
}
function getStaticValue22(node, initialScope = null) {
  try {
    return getStaticValueR22(node, initialScope);
  } catch (_error) {
    return null;
  }
}
function getStringIfConstant22(node, initialScope = null) {
  if (node && node.type === "Literal" && node.value === null) {
    if (node.regex) {
      return `/${node.regex.pattern}/${node.regex.flags}`;
    }
    if (node.bigint) {
      return node.bigint;
    }
  }
  const evaluated = getStaticValue22(node, initialScope);
  return evaluated && String(evaluated.value);
}
function getPropertyName22(node, initialScope) {
  switch (node.type) {
    case "MemberExpression":
      if (node.computed) {
        return getStringIfConstant22(node.property, initialScope);
      }
      if (node.property.type === "PrivateIdentifier") {
        return null;
      }
      return node.property.name;
    case "Property":
    case "MethodDefinition":
    case "PropertyDefinition":
      if (node.computed) {
        return getStringIfConstant22(node.key, initialScope);
      }
      if (node.key.type === "Literal") {
        return String(node.key.value);
      }
      if (node.key.type === "PrivateIdentifier") {
        return null;
      }
      return node.key.name;
  }
  return null;
}
function getFunctionNameWithKind22(node, sourceCode) {
  const parent = node.parent;
  const tokens = [];
  const isObjectMethod = parent.type === "Property" && parent.value === node;
  const isClassMethod = parent.type === "MethodDefinition" && parent.value === node;
  const isClassFieldMethod = parent.type === "PropertyDefinition" && parent.value === node;
  if (isClassMethod || isClassFieldMethod) {
    if (parent.static) {
      tokens.push("static");
    }
    if (parent.key.type === "PrivateIdentifier") {
      tokens.push("private");
    }
  }
  if (node.async) {
    tokens.push("async");
  }
  if (node.generator) {
    tokens.push("generator");
  }
  if (isObjectMethod || isClassMethod) {
    if (parent.kind === "constructor") {
      return "constructor";
    }
    if (parent.kind === "get") {
      tokens.push("getter");
    } else if (parent.kind === "set") {
      tokens.push("setter");
    } else {
      tokens.push("method");
    }
  } else if (isClassFieldMethod) {
    tokens.push("method");
  } else {
    if (node.type === "ArrowFunctionExpression") {
      tokens.push("arrow");
    }
    tokens.push("function");
  }
  if (isObjectMethod || isClassMethod || isClassFieldMethod) {
    if (parent.key.type === "PrivateIdentifier") {
      tokens.push(`#${parent.key.name}`);
    } else {
      const name = getPropertyName22(parent);
      if (name) {
        tokens.push(`'${name}'`);
      } else if (sourceCode) {
        const keyText = sourceCode.getText(parent.key);
        if (!keyText.includes("\n")) {
          tokens.push(`[${keyText}]`);
        }
      }
    }
  } else if (node.id) {
    tokens.push(`'${node.id.name}'`);
  } else if (parent.type === "VariableDeclarator" && parent.id && parent.id.type === "Identifier") {
    tokens.push(`'${parent.id.name}'`);
  } else if ((parent.type === "AssignmentExpression" || parent.type === "AssignmentPattern") && parent.left && parent.left.type === "Identifier") {
    tokens.push(`'${parent.left.name}'`);
  } else if (parent.type === "ExportDefaultDeclaration" && parent.declaration === node) {
    tokens.push("'default'");
  }
  return tokens.join(" ");
}
var typeConversionBinaryOps22 = Object.freeze(
  /* @__PURE__ */ new Set([
    "==",
    "!=",
    "<",
    "<=",
    ">",
    ">=",
    "<<",
    ">>",
    ">>>",
    "+",
    "-",
    "*",
    "/",
    "%",
    "|",
    "^",
    "&",
    "in"
  ])
);
var typeConversionUnaryOps22 = Object.freeze(/* @__PURE__ */ new Set(["-", "+", "!", "~"]));
function isNode22(x22) {
  return x22 !== null && typeof x22 === "object" && typeof x22.type === "string";
}
var visitor22 = Object.freeze(
  Object.assign(/* @__PURE__ */ Object.create(null), {
    $visit(node, options, visitorKeys) {
      const { type } = node;
      if (typeof this[type] === "function") {
        return this[type](node, options, visitorKeys);
      }
      return this.$visitChildren(node, options, visitorKeys);
    },
    $visitChildren(node, options, visitorKeys) {
      const { type } = node;
      for (const key of visitorKeys[type] || getKeys22(node)) {
        const value = node[key];
        if (Array.isArray(value)) {
          for (const element of value) {
            if (isNode22(element) && this.$visit(element, options, visitorKeys)) {
              return true;
            }
          }
        } else if (isNode22(value) && this.$visit(value, options, visitorKeys)) {
          return true;
        }
      }
      return false;
    },
    ArrowFunctionExpression() {
      return false;
    },
    AssignmentExpression() {
      return true;
    },
    AwaitExpression() {
      return true;
    },
    BinaryExpression(node, options, visitorKeys) {
      if (options.considerImplicitTypeConversion && typeConversionBinaryOps22.has(node.operator) && (node.left.type !== "Literal" || node.right.type !== "Literal")) {
        return true;
      }
      return this.$visitChildren(node, options, visitorKeys);
    },
    CallExpression() {
      return true;
    },
    FunctionExpression() {
      return false;
    },
    ImportExpression() {
      return true;
    },
    MemberExpression(node, options, visitorKeys) {
      if (options.considerGetters) {
        return true;
      }
      if (options.considerImplicitTypeConversion && node.computed && node.property.type !== "Literal") {
        return true;
      }
      return this.$visitChildren(node, options, visitorKeys);
    },
    MethodDefinition(node, options, visitorKeys) {
      if (options.considerImplicitTypeConversion && node.computed && node.key.type !== "Literal") {
        return true;
      }
      return this.$visitChildren(node, options, visitorKeys);
    },
    NewExpression() {
      return true;
    },
    Property(node, options, visitorKeys) {
      if (options.considerImplicitTypeConversion && node.computed && node.key.type !== "Literal") {
        return true;
      }
      return this.$visitChildren(node, options, visitorKeys);
    },
    PropertyDefinition(node, options, visitorKeys) {
      if (options.considerImplicitTypeConversion && node.computed && node.key.type !== "Literal") {
        return true;
      }
      return this.$visitChildren(node, options, visitorKeys);
    },
    UnaryExpression(node, options, visitorKeys) {
      if (node.operator === "delete") {
        return true;
      }
      if (options.considerImplicitTypeConversion && typeConversionUnaryOps22.has(node.operator) && node.argument.type !== "Literal") {
        return true;
      }
      return this.$visitChildren(node, options, visitorKeys);
    },
    UpdateExpression() {
      return true;
    },
    YieldExpression() {
      return true;
    }
  })
);
function hasSideEffect22(node, sourceCode, { considerGetters = false, considerImplicitTypeConversion = false } = {}) {
  return visitor22.$visit(
    node,
    { considerGetters, considerImplicitTypeConversion },
    sourceCode.visitorKeys || visitor_keys_default22
  );
}
function getParentSyntaxParen22(node, sourceCode) {
  const parent = node.parent;
  switch (parent.type) {
    case "CallExpression":
    case "NewExpression":
      if (parent.arguments.length === 1 && parent.arguments[0] === node) {
        return sourceCode.getTokenAfter(
          parent.callee,
          isOpeningParenToken22
        );
      }
      return null;
    case "DoWhileStatement":
      if (parent.test === node) {
        return sourceCode.getTokenAfter(
          parent.body,
          isOpeningParenToken22
        );
      }
      return null;
    case "IfStatement":
    case "WhileStatement":
      if (parent.test === node) {
        return sourceCode.getFirstToken(parent, 1);
      }
      return null;
    case "ImportExpression":
      if (parent.source === node) {
        return sourceCode.getFirstToken(parent, 1);
      }
      return null;
    case "SwitchStatement":
      if (parent.discriminant === node) {
        return sourceCode.getFirstToken(parent, 1);
      }
      return null;
    case "WithStatement":
      if (parent.object === node) {
        return sourceCode.getFirstToken(parent, 1);
      }
      return null;
    default:
      return null;
  }
}
function isParenthesized22(timesOrNode, nodeOrSourceCode, optionalSourceCode) {
  let times, node, sourceCode, maybeLeftParen, maybeRightParen;
  if (typeof timesOrNode === "number") {
    times = timesOrNode | 0;
    node = nodeOrSourceCode;
    sourceCode = optionalSourceCode;
    if (!(times >= 1)) {
      throw new TypeError("'times' should be a positive integer.");
    }
  } else {
    times = 1;
    node = timesOrNode;
    sourceCode = nodeOrSourceCode;
  }
  if (node == null || // `Program` can't be parenthesized
  node.parent == null || // `CatchClause.param` can't be parenthesized, example `try {} catch (error) {}`
  node.parent.type === "CatchClause" && node.parent.param === node) {
    return false;
  }
  maybeLeftParen = maybeRightParen = node;
  do {
    maybeLeftParen = sourceCode.getTokenBefore(maybeLeftParen);
    maybeRightParen = sourceCode.getTokenAfter(maybeRightParen);
  } while (maybeLeftParen != null && maybeRightParen != null && isOpeningParenToken22(maybeLeftParen) && isClosingParenToken22(maybeRightParen) && // Avoid false positive such as `if (a) {}`
  maybeLeftParen !== getParentSyntaxParen22(node, sourceCode) && --times > 0);
  return times === 0;
}
Function.call.bind(Object.hasOwnProperty);
var __defProp222 = Object.defineProperty;
var __export222 = (target, all322) => {
  for (var name in all322)
    __defProp222(target, name, { get: all322[name], enumerable: true });
};
var NodeType22 = types.AST_NODE_TYPES;
var is22 = utils.ASTUtils.isNodeOfType;
var isOneOf22 = utils.ASTUtils.isNodeOfTypes;
isOneOf22([
  NodeType22.ArrowFunctionExpression,
  NodeType22.FunctionDeclaration,
  NodeType22.FunctionExpression
]);
isOneOf22([
  NodeType22.ArrowFunctionExpression,
  NodeType22.FunctionDeclaration,
  NodeType22.FunctionExpression,
  NodeType22.TSCallSignatureDeclaration,
  NodeType22.TSConstructSignatureDeclaration,
  NodeType22.TSDeclareFunction,
  NodeType22.TSEmptyBodyFunctionExpression,
  NodeType22.TSFunctionType,
  NodeType22.TSMethodSignature
]);
isOneOf22([NodeType22.ClassDeclaration, NodeType22.ClassExpression]);
isOneOf22([
  NodeType22.DoWhileStatement,
  NodeType22.ForInStatement,
  NodeType22.ForOfStatement,
  NodeType22.ForStatement,
  NodeType22.WhileStatement
]);
isOneOf22([NodeType22.TSArrayType, NodeType22.TSTupleType]);
isOneOf22([
  NodeType22.PropertyDefinition,
  NodeType22.TSIndexSignature,
  NodeType22.TSParameterProperty,
  NodeType22.TSPropertySignature
]);
is22(NodeType22.JSXElement);
is22(NodeType22.JSXFragment);
isOneOf22([
  NodeType22.JSXAttribute,
  NodeType22.JSXSpreadChild,
  NodeType22.JSXClosingElement,
  NodeType22.JSXClosingFragment,
  NodeType22.JSXElement,
  NodeType22.JSXEmptyExpression,
  NodeType22.JSXExpressionContainer,
  NodeType22.JSXFragment,
  NodeType22.JSXIdentifier,
  NodeType22.JSXMemberExpression,
  NodeType22.JSXNamespacedName,
  NodeType22.JSXOpeningElement,
  NodeType22.JSXOpeningFragment,
  NodeType22.JSXSpreadAttribute,
  NodeType22.JSXSpreadChild,
  NodeType22.JSXText
]);
isOneOf22([
  NodeType22.JSXIdentifier,
  NodeType22.JSXMemberExpression,
  NodeType22.JSXNamespacedName
]);
isOneOf22([
  NodeType22.ArrayPattern,
  NodeType22.AssignmentPattern,
  NodeType22.ObjectPattern,
  NodeType22.RestElement
]);
isOneOf22([
  NodeType22.TSInterfaceDeclaration,
  NodeType22.TSTypeAliasDeclaration
]);
isOneOf22([
  NodeType22.ArrayExpression,
  NodeType22.ArrayPattern,
  NodeType22.ArrowFunctionExpression,
  NodeType22.CallExpression,
  NodeType22.ClassExpression,
  NodeType22.FunctionExpression,
  NodeType22.Identifier,
  NodeType22.JSXElement,
  NodeType22.JSXFragment,
  NodeType22.Literal,
  NodeType22.TemplateLiteral,
  NodeType22.MemberExpression,
  NodeType22.MetaProperty,
  NodeType22.ObjectExpression,
  NodeType22.ObjectPattern,
  NodeType22.SequenceExpression,
  NodeType22.Super,
  NodeType22.TaggedTemplateExpression,
  NodeType22.ThisExpression
]);
isOneOf22([
  NodeType22.ArrayExpression,
  NodeType22.ArrayPattern,
  NodeType22.ArrowFunctionExpression,
  NodeType22.CallExpression,
  NodeType22.ClassExpression,
  NodeType22.FunctionExpression,
  NodeType22.Identifier,
  NodeType22.JSXElement,
  NodeType22.JSXFragment,
  NodeType22.Literal,
  NodeType22.TemplateLiteral,
  NodeType22.MemberExpression,
  NodeType22.MetaProperty,
  NodeType22.ObjectExpression,
  NodeType22.ObjectPattern,
  NodeType22.SequenceExpression,
  NodeType22.Super,
  NodeType22.TaggedTemplateExpression,
  NodeType22.ThisExpression,
  NodeType22.TSAsExpression,
  NodeType22.TSNonNullExpression,
  NodeType22.TSTypeAssertion
]);
var Function_exports222 = {};
__export222(Function_exports222, {
  SK: () => SK222,
  absurd: () => absurd222,
  apply: () => apply222,
  compose: () => compose222,
  constFalse: () => constFalse222,
  constNull: () => constNull222,
  constTrue: () => constTrue222,
  constUndefined: () => constUndefined222,
  constVoid: () => constVoid222,
  constant: () => constant222,
  dual: () => dual222,
  flip: () => flip222,
  flow: () => flow222,
  hole: () => hole222,
  identity: () => identity222,
  isFunction: () => isFunction2222,
  pipe: () => pipe222,
  satisfies: () => satisfies222,
  tupled: () => tupled222,
  unsafeCoerce: () => unsafeCoerce222,
  untupled: () => untupled222
});
var isFunction2222 = (input) => typeof input === "function";
var dual222 = function(arity, body) {
  if (typeof arity === "function") {
    return function() {
      if (arity(arguments)) {
        return body.apply(this, arguments);
      }
      return (self2) => body(self2, ...arguments);
    };
  }
  switch (arity) {
    case 0:
    case 1:
      throw new RangeError(`Invalid arity ${arity}`);
    case 2:
      return function(a22, b22) {
        if (arguments.length >= 2) {
          return body(a22, b22);
        }
        return function(self2) {
          return body(self2, a22);
        };
      };
    case 3:
      return function(a22, b22, c22) {
        if (arguments.length >= 3) {
          return body(a22, b22, c22);
        }
        return function(self2) {
          return body(self2, a22, b22);
        };
      };
    case 4:
      return function(a22, b22, c22, d22) {
        if (arguments.length >= 4) {
          return body(a22, b22, c22, d22);
        }
        return function(self2) {
          return body(self2, a22, b22, c22);
        };
      };
    case 5:
      return function(a22, b22, c22, d22, e22) {
        if (arguments.length >= 5) {
          return body(a22, b22, c22, d22, e22);
        }
        return function(self2) {
          return body(self2, a22, b22, c22, d22);
        };
      };
    default:
      return function() {
        if (arguments.length >= arity) {
          return body.apply(this, arguments);
        }
        const args = arguments;
        return function(self2) {
          return body(self2, ...args);
        };
      };
  }
};
var apply222 = (a22) => (self2) => self2(a22);
var identity222 = (a22) => a22;
var satisfies222 = () => (b22) => b22;
var unsafeCoerce222 = identity222;
var constant222 = (value) => () => value;
var constTrue222 = /* @__PURE__ */ constant222(true);
var constFalse222 = /* @__PURE__ */ constant222(false);
var constNull222 = /* @__PURE__ */ constant222(null);
var constUndefined222 = /* @__PURE__ */ constant222(void 0);
var constVoid222 = constUndefined222;
var flip222 = (f22) => (...b22) => (...a22) => f22(...a22)(...b22);
var compose222 = /* @__PURE__ */ dual222(2, (ab, bc) => (a22) => bc(ab(a22)));
var absurd222 = (_22) => {
  throw new Error("Called `absurd` function which should be uncallable");
};
var tupled222 = (f22) => (a22) => f22(...a22);
var untupled222 = (f22) => (...a22) => f22(a22);
function pipe222(a22, ab, bc, cd, de, ef, fg, gh, hi) {
  switch (arguments.length) {
    case 1:
      return a22;
    case 2:
      return ab(a22);
    case 3:
      return bc(ab(a22));
    case 4:
      return cd(bc(ab(a22)));
    case 5:
      return de(cd(bc(ab(a22))));
    case 6:
      return ef(de(cd(bc(ab(a22)))));
    case 7:
      return fg(ef(de(cd(bc(ab(a22))))));
    case 8:
      return gh(fg(ef(de(cd(bc(ab(a22)))))));
    case 9:
      return hi(gh(fg(ef(de(cd(bc(ab(a22))))))));
    default: {
      let ret = arguments[0];
      for (let i22 = 1; i22 < arguments.length; i22++) {
        ret = arguments[i22](ret);
      }
      return ret;
    }
  }
}
function flow222(ab, bc, cd, de, ef, fg, gh, hi, ij) {
  switch (arguments.length) {
    case 1:
      return ab;
    case 2:
      return function() {
        return bc(ab.apply(this, arguments));
      };
    case 3:
      return function() {
        return cd(bc(ab.apply(this, arguments)));
      };
    case 4:
      return function() {
        return de(cd(bc(ab.apply(this, arguments))));
      };
    case 5:
      return function() {
        return ef(de(cd(bc(ab.apply(this, arguments)))));
      };
    case 6:
      return function() {
        return fg(ef(de(cd(bc(ab.apply(this, arguments))))));
      };
    case 7:
      return function() {
        return gh(fg(ef(de(cd(bc(ab.apply(this, arguments)))))));
      };
    case 8:
      return function() {
        return hi(gh(fg(ef(de(cd(bc(ab.apply(this, arguments))))))));
      };
    case 9:
      return function() {
        return ij(hi(gh(fg(ef(de(cd(bc(ab.apply(this, arguments)))))))));
      };
  }
  return;
}
var hole222 = /* @__PURE__ */ unsafeCoerce222(absurd222);
var SK222 = (_22, b22) => b22;
var make422 = (isEquivalent) => (self2, that) => self2 === that || isEquivalent(self2, that);
var let_322 = (map62) => dual222(3, (self2, name, f22) => map62(self2, (a22) => Object.assign({}, a22, {
  [name]: f22(a22)
})));
var bindTo322 = (map62) => dual222(2, (self2, name) => map62(self2, (a22) => ({
  [name]: a22
})));
var bind322 = (map62, flatMap42) => dual222(3, (self2, name, f22) => flatMap42(self2, (a22) => map62(f22(a22), (b22) => Object.assign({}, a22, {
  [name]: b22
}))));
var moduleVersion222 = "3.2.8";
var getCurrentVersion222 = () => moduleVersion222;
var globalStoreId222 = /* @__PURE__ */ Symbol.for(`effect/GlobalValue/globalStoreId/${/* @__PURE__ */ getCurrentVersion222()}`);
if (!(globalStoreId222 in globalThis)) {
  globalThis[globalStoreId222] = /* @__PURE__ */ new Map();
}
var globalStore222 = globalThis[globalStoreId222];
var globalValue222 = (id, compute) => {
  if (!globalStore222.has(id)) {
    globalStore222.set(id, compute());
  }
  return globalStore222.get(id);
};
var Predicate_exports222 = {};
__export222(Predicate_exports222, {
  all: () => all222,
  and: () => and3,
  compose: () => compose2222,
  eqv: () => eqv3,
  every: () => every4,
  hasProperty: () => hasProperty222,
  implies: () => implies3,
  isBigInt: () => isBigInt3,
  isBoolean: () => isBoolean3,
  isDate: () => isDate3,
  isError: () => isError3,
  isFunction: () => isFunction322,
  isIterable: () => isIterable3,
  isMap: () => isMap3,
  isNever: () => isNever3,
  isNotNull: () => isNotNull3,
  isNotNullable: () => isNotNullable3,
  isNotUndefined: () => isNotUndefined3,
  isNull: () => isNull3,
  isNullable: () => isNullable222,
  isNumber: () => isNumber3,
  isObject: () => isObject222,
  isPromise: () => isPromise3,
  isPromiseLike: () => isPromiseLike3,
  isReadonlyRecord: () => isReadonlyRecord3,
  isRecord: () => isRecord3,
  isSet: () => isSet3,
  isString: () => isString3,
  isSymbol: () => isSymbol3,
  isTagged: () => isTagged3,
  isTruthy: () => isTruthy3,
  isUint8Array: () => isUint8Array3,
  isUndefined: () => isUndefined3,
  isUnknown: () => isUnknown3,
  mapInput: () => mapInput4,
  nand: () => nand3,
  nor: () => nor3,
  not: () => not3,
  or: () => or3,
  product: () => product222,
  productMany: () => productMany222,
  some: () => some322,
  struct: () => struct5,
  tuple: () => tuple4,
  xor: () => xor3
});
var mapInput4 = /* @__PURE__ */ dual222(2, (self2, f22) => (b22) => self2(f22(b22)));
var isTruthy3 = (input) => !!input;
var isSet3 = (input) => input instanceof Set;
var isMap3 = (input) => input instanceof Map;
var isString3 = (input) => typeof input === "string";
var isNumber3 = (input) => typeof input === "number";
var isBoolean3 = (input) => typeof input === "boolean";
var isBigInt3 = (input) => typeof input === "bigint";
var isSymbol3 = (input) => typeof input === "symbol";
var isFunction322 = isFunction2222;
var isUndefined3 = (input) => input === void 0;
var isNotUndefined3 = (input) => input !== void 0;
var isNull3 = (input) => input === null;
var isNotNull3 = (input) => input !== null;
var isNever3 = (_22) => false;
var isUnknown3 = (_22) => true;
var isRecordOrArray222 = (input) => typeof input === "object" && input !== null;
var isObject222 = (input) => isRecordOrArray222(input) || isFunction322(input);
var hasProperty222 = /* @__PURE__ */ dual222(2, (self2, property) => isObject222(self2) && property in self2);
var isTagged3 = /* @__PURE__ */ dual222(2, (self2, tag) => hasProperty222(self2, "_tag") && self2["_tag"] === tag);
var isNullable222 = (input) => input === null || input === void 0;
var isNotNullable3 = (input) => input !== null && input !== void 0;
var isError3 = (input) => input instanceof Error;
var isUint8Array3 = (input) => input instanceof Uint8Array;
var isDate3 = (input) => input instanceof Date;
var isIterable3 = (input) => hasProperty222(input, Symbol.iterator);
var isRecord3 = (input) => isRecordOrArray222(input) && !Array.isArray(input);
var isReadonlyRecord3 = isRecord3;
var isPromise3 = (input) => hasProperty222(input, "then") && "catch" in input && isFunction322(input.then) && isFunction322(input.catch);
var isPromiseLike3 = (input) => hasProperty222(input, "then") && isFunction322(input.then);
var compose2222 = /* @__PURE__ */ dual222(2, (ab, bc) => (a22) => ab(a22) && bc(a22));
var product222 = (self2, that) => ([a22, b22]) => self2(a22) && that(b22);
var all222 = (collection) => {
  return (as2222) => {
    let collectionIndex = 0;
    for (const p22 of collection) {
      if (collectionIndex >= as2222.length) {
        break;
      }
      if (p22(as2222[collectionIndex]) === false) {
        return false;
      }
      collectionIndex++;
    }
    return true;
  };
};
var productMany222 = (self2, collection) => {
  const rest = all222(collection);
  return ([head22, ...tail22]) => self2(head22) === false ? false : rest(tail22);
};
var tuple4 = (...elements) => all222(elements);
var struct5 = (fields) => {
  const keys222 = Object.keys(fields);
  return (a22) => {
    for (const key of keys222) {
      if (!fields[key](a22[key])) {
        return false;
      }
    }
    return true;
  };
};
var not3 = (self2) => (a22) => !self2(a22);
var or3 = /* @__PURE__ */ dual222(2, (self2, that) => (a22) => self2(a22) || that(a22));
var and3 = /* @__PURE__ */ dual222(2, (self2, that) => (a22) => self2(a22) && that(a22));
var xor3 = /* @__PURE__ */ dual222(2, (self2, that) => (a22) => self2(a22) !== that(a22));
var eqv3 = /* @__PURE__ */ dual222(2, (self2, that) => (a22) => self2(a22) === that(a22));
var implies3 = /* @__PURE__ */ dual222(2, (self2, that) => (a22) => self2(a22) ? that(a22) : true);
var nor3 = /* @__PURE__ */ dual222(2, (self2, that) => (a22) => !(self2(a22) || that(a22)));
var nand3 = /* @__PURE__ */ dual222(2, (self2, that) => (a22) => !(self2(a22) && that(a22)));
var every4 = (collection) => (a22) => {
  for (const p22 of collection) {
    if (!p22(a22)) {
      return false;
    }
  }
  return true;
};
var some322 = (collection) => (a22) => {
  for (const p22 of collection) {
    if (p22(a22)) {
      return true;
    }
  }
  return false;
};
var getBugErrorMessage222 = (message) => `BUG: ${message} - please report an issue at https://github.com/Effect-TS/effect/issues`;
var GenKindTypeId222 = /* @__PURE__ */ Symbol.for("effect/Gen/GenKind");
var isGenKind222 = (u22) => isObject222(u22) && GenKindTypeId222 in u22;
var GenKindImpl222 = class {
  value;
  constructor(value) {
    this.value = value;
  }
  /**
   * @since 2.0.0
   */
  get _F() {
    return identity222;
  }
  /**
   * @since 2.0.0
   */
  get _R() {
    return (_22) => _22;
  }
  /**
   * @since 2.0.0
   */
  get _O() {
    return (_22) => _22;
  }
  /**
   * @since 2.0.0
   */
  get _E() {
    return (_22) => _22;
  }
  /**
   * @since 2.0.0
   */
  [GenKindTypeId222] = GenKindTypeId222;
  /**
   * @since 2.0.0
   */
  [Symbol.iterator]() {
    return new SingleShotGen222(this);
  }
};
var SingleShotGen222 = class _SingleShotGen4 {
  self;
  called = false;
  constructor(self2) {
    this.self = self2;
  }
  /**
   * @since 2.0.0
   */
  next(a22) {
    return this.called ? {
      value: a22,
      done: true
    } : (this.called = true, {
      value: this.self,
      done: false
    });
  }
  /**
   * @since 2.0.0
   */
  return(a22) {
    return {
      value: a22,
      done: true
    };
  }
  /**
   * @since 2.0.0
   */
  throw(e22) {
    throw e22;
  }
  /**
   * @since 2.0.0
   */
  [Symbol.iterator]() {
    return new _SingleShotGen4(this.self);
  }
};
var adapter322 = () => function() {
  let x22 = arguments[0];
  for (let i22 = 1; i22 < arguments.length; i22++) {
    x22 = arguments[i22](x22);
  }
  return new GenKindImpl222(x22);
};
var defaultIncHi222 = 335903614;
var defaultIncLo222 = 4150755663;
var MUL_HI222 = 1481765933 >>> 0;
var MUL_LO222 = 1284865837 >>> 0;
var BIT_53222 = 9007199254740992;
var BIT_27222 = 134217728;
var PCGRandom222 = class {
  _state;
  constructor(seedHi, seedLo, incHi, incLo) {
    if (isNullable222(seedLo) && isNullable222(seedHi)) {
      seedLo = Math.random() * 4294967295 >>> 0;
      seedHi = 0;
    } else if (isNullable222(seedLo)) {
      seedLo = seedHi;
      seedHi = 0;
    }
    if (isNullable222(incLo) && isNullable222(incHi)) {
      incLo = this._state ? this._state[3] : defaultIncLo222;
      incHi = this._state ? this._state[2] : defaultIncHi222;
    } else if (isNullable222(incLo)) {
      incLo = incHi;
      incHi = 0;
    }
    this._state = new Int32Array([0, 0, incHi >>> 0, ((incLo || 0) | 1) >>> 0]);
    this._next();
    add64222(this._state, this._state[0], this._state[1], seedHi >>> 0, seedLo >>> 0);
    this._next();
    return this;
  }
  /**
   * Returns a copy of the internal state of this random number generator as a
   * JavaScript Array.
   *
   * @category getters
   * @since 2.0.0
   */
  getState() {
    return [this._state[0], this._state[1], this._state[2], this._state[3]];
  }
  /**
   * Restore state previously retrieved using `getState()`.
   *
   * @since 2.0.0
   */
  setState(state) {
    this._state[0] = state[0];
    this._state[1] = state[1];
    this._state[2] = state[2];
    this._state[3] = state[3] | 1;
  }
  /**
   * Get a uniformly distributed 32 bit integer between [0, max).
   *
   * @category getter
   * @since 2.0.0
   */
  integer(max3) {
    if (!max3) {
      return this._next();
    }
    max3 = max3 >>> 0;
    if ((max3 & max3 - 1) === 0) {
      return this._next() & max3 - 1;
    }
    let num = 0;
    const skew = (-max3 >>> 0) % max3 >>> 0;
    for (num = this._next(); num < skew; num = this._next()) {
    }
    return num % max3;
  }
  /**
   * Get a uniformly distributed IEEE-754 double between 0.0 and 1.0, with
   * 53 bits of precision (every bit of the mantissa is randomized).
   *
   * @category getters
   * @since 2.0.0
   */
  number() {
    const hi = (this._next() & 67108863) * 1;
    const lo = (this._next() & 134217727) * 1;
    return (hi * BIT_27222 + lo) / BIT_53222;
  }
  /** @internal */
  _next() {
    const oldHi = this._state[0] >>> 0;
    const oldLo = this._state[1] >>> 0;
    mul64222(this._state, oldHi, oldLo, MUL_HI222, MUL_LO222);
    add64222(this._state, this._state[0], this._state[1], this._state[2], this._state[3]);
    let xsHi = oldHi >>> 18;
    let xsLo = (oldLo >>> 18 | oldHi << 14) >>> 0;
    xsHi = (xsHi ^ oldHi) >>> 0;
    xsLo = (xsLo ^ oldLo) >>> 0;
    const xorshifted = (xsLo >>> 27 | xsHi << 5) >>> 0;
    const rot = oldHi >>> 27;
    const rot2 = (-rot >>> 0 & 31) >>> 0;
    return (xorshifted >>> rot | xorshifted << rot2) >>> 0;
  }
};
function mul64222(out, aHi, aLo, bHi, bLo) {
  let c1 = (aLo >>> 16) * (bLo & 65535) >>> 0;
  let c0 = (aLo & 65535) * (bLo >>> 16) >>> 0;
  let lo = (aLo & 65535) * (bLo & 65535) >>> 0;
  let hi = (aLo >>> 16) * (bLo >>> 16) + ((c0 >>> 16) + (c1 >>> 16)) >>> 0;
  c0 = c0 << 16 >>> 0;
  lo = lo + c0 >>> 0;
  if (lo >>> 0 < c0 >>> 0) {
    hi = hi + 1 >>> 0;
  }
  c1 = c1 << 16 >>> 0;
  lo = lo + c1 >>> 0;
  if (lo >>> 0 < c1 >>> 0) {
    hi = hi + 1 >>> 0;
  }
  hi = hi + Math.imul(aLo, bHi) >>> 0;
  hi = hi + Math.imul(aHi, bLo) >>> 0;
  out[0] = hi;
  out[1] = lo;
}
function add64222(out, aHi, aLo, bHi, bLo) {
  let hi = aHi + bHi >>> 0;
  const lo = aLo + bLo >>> 0;
  if (lo >>> 0 < aLo >>> 0) {
    hi = hi + 1 | 0;
  }
  out[0] = hi;
  out[1] = lo;
}
var YieldWrapTypeId222 = /* @__PURE__ */ Symbol.for("effect/Utils/YieldWrap");
var YieldWrap222 = class {
  /**
   * @since 3.0.6
   */
  #value;
  constructor(value) {
    this.#value = value;
  }
  /**
   * @since 3.0.6
   */
  [YieldWrapTypeId222]() {
    return this.#value;
  }
};
function yieldWrapGet222(self2) {
  if (typeof self2 === "object" && self2 !== null && YieldWrapTypeId222 in self2) {
    return self2[YieldWrapTypeId222]();
  }
  throw new Error(getBugErrorMessage222("yieldWrapGet"));
}
var structuralRegionState222 = /* @__PURE__ */ globalValue222("effect/Utils/isStructuralRegion", () => ({
  enabled: false,
  tester: void 0
}));
var randomHashCache222 = /* @__PURE__ */ globalValue222(/* @__PURE__ */ Symbol.for("effect/Hash/randomHashCache"), () => /* @__PURE__ */ new WeakMap());
var pcgr222 = /* @__PURE__ */ globalValue222(/* @__PURE__ */ Symbol.for("effect/Hash/pcgr"), () => new PCGRandom222());
var symbol322 = /* @__PURE__ */ Symbol.for("effect/Hash");
var hash222 = (self2) => {
  if (structuralRegionState222.enabled === true) {
    return 0;
  }
  switch (typeof self2) {
    case "number":
      return number222(self2);
    case "bigint":
      return string222(self2.toString(10));
    case "boolean":
      return string222(String(self2));
    case "symbol":
      return string222(String(self2));
    case "string":
      return string222(self2);
    case "undefined":
      return string222("undefined");
    case "function":
    case "object": {
      if (self2 === null) {
        return string222("null");
      } else if (self2 instanceof Date) {
        return hash222(self2.toISOString());
      } else if (isHash222(self2)) {
        return self2[symbol322]();
      } else {
        return random222(self2);
      }
    }
    default:
      throw new Error(`BUG: unhandled typeof ${typeof self2} - please report an issue at https://github.com/Effect-TS/effect/issues`);
  }
};
var random222 = (self2) => {
  if (!randomHashCache222.has(self2)) {
    randomHashCache222.set(self2, number222(pcgr222.integer(Number.MAX_SAFE_INTEGER)));
  }
  return randomHashCache222.get(self2);
};
var combine222 = (b22) => (self2) => self2 * 53 ^ b22;
var optimize222 = (n22) => n22 & 3221225471 | n22 >>> 1 & 1073741824;
var isHash222 = (u22) => hasProperty222(u22, symbol322);
var number222 = (n22) => {
  if (n22 !== n22 || n22 === Infinity) {
    return 0;
  }
  let h22 = n22 | 0;
  if (h22 !== n22) {
    h22 ^= n22 * 4294967295;
  }
  while (n22 > 4294967295) {
    h22 ^= n22 /= 4294967295;
  }
  return optimize222(n22);
};
var string222 = (str) => {
  let h22 = 5381, i22 = str.length;
  while (i22) {
    h22 = h22 * 33 ^ str.charCodeAt(--i22);
  }
  return optimize222(h22);
};
var structureKeys22 = (o22, keys222) => {
  let h22 = 12289;
  for (let i22 = 0; i22 < keys222.length; i22++) {
    h22 ^= pipe222(string222(keys222[i22]), combine222(hash222(o22[keys222[i22]])));
  }
  return optimize222(h22);
};
var structure22 = (o22) => structureKeys22(o22, Object.keys(o22));
var array5 = (arr) => {
  let h22 = 6151;
  for (let i22 = 0; i22 < arr.length; i22++) {
    h22 = pipe222(h22, combine222(hash222(arr[i22])));
  }
  return optimize222(h22);
};
var cached222 = function() {
  if (arguments.length === 1) {
    const self22 = arguments[0];
    return function(hash32) {
      Object.defineProperty(self22, symbol322, {
        value() {
          return hash32;
        },
        enumerable: false
      });
      return hash32;
    };
  }
  const self2 = arguments[0];
  const hash2222 = arguments[1];
  Object.defineProperty(self2, symbol322, {
    value() {
      return hash2222;
    },
    enumerable: false
  });
  return hash2222;
};
var symbol2222 = /* @__PURE__ */ Symbol.for("effect/Equal");
function equals222() {
  if (arguments.length === 1) {
    return (self2) => compareBoth222(self2, arguments[0]);
  }
  return compareBoth222(arguments[0], arguments[1]);
}
function compareBoth222(self2, that) {
  if (self2 === that) {
    return true;
  }
  const selfType = typeof self2;
  if (selfType !== typeof that) {
    return false;
  }
  if (selfType === "object" || selfType === "function") {
    if (self2 !== null && that !== null) {
      if (isEqual222(self2) && isEqual222(that)) {
        if (hash222(self2) === hash222(that) && self2[symbol2222](that)) {
          return true;
        } else {
          return structuralRegionState222.enabled && structuralRegionState222.tester ? structuralRegionState222.tester(self2, that) : false;
        }
      } else if (self2 instanceof Date && that instanceof Date) {
        return self2.toISOString() === that.toISOString();
      }
    }
    if (structuralRegionState222.enabled) {
      if (Array.isArray(self2) && Array.isArray(that)) {
        return self2.length === that.length && self2.every((v22, i22) => compareBoth222(v22, that[i22]));
      }
      if (Object.getPrototypeOf(self2) === Object.prototype && Object.getPrototypeOf(self2) === Object.prototype) {
        const keysSelf = Object.keys(self2);
        const keysThat = Object.keys(that);
        if (keysSelf.length === keysThat.length) {
          for (const key of keysSelf) {
            if (!(key in that && compareBoth222(self2[key], that[key]))) {
              return structuralRegionState222.tester ? structuralRegionState222.tester(self2, that) : false;
            }
          }
          return true;
        }
      }
      return structuralRegionState222.tester ? structuralRegionState222.tester(self2, that) : false;
    }
  }
  return structuralRegionState222.enabled && structuralRegionState222.tester ? structuralRegionState222.tester(self2, that) : false;
}
var isEqual222 = (u22) => hasProperty222(u22, symbol2222);
var equivalence222 = () => equals222;
var NodeInspectSymbol222 = /* @__PURE__ */ Symbol.for("nodejs.util.inspect.custom");
var toJSON222 = (x22) => {
  if (hasProperty222(x22, "toJSON") && isFunction322(x22["toJSON"]) && x22["toJSON"].length === 0) {
    return x22.toJSON();
  } else if (Array.isArray(x22)) {
    return x22.map(toJSON222);
  }
  return x22;
};
var format222 = (x22) => JSON.stringify(x22, null, 2);
var pipeArguments222 = (self2, args) => {
  switch (args.length) {
    case 1:
      return args[0](self2);
    case 2:
      return args[1](args[0](self2));
    case 3:
      return args[2](args[1](args[0](self2)));
    case 4:
      return args[3](args[2](args[1](args[0](self2))));
    case 5:
      return args[4](args[3](args[2](args[1](args[0](self2)))));
    case 6:
      return args[5](args[4](args[3](args[2](args[1](args[0](self2))))));
    case 7:
      return args[6](args[5](args[4](args[3](args[2](args[1](args[0](self2)))))));
    case 8:
      return args[7](args[6](args[5](args[4](args[3](args[2](args[1](args[0](self2))))))));
    case 9:
      return args[8](args[7](args[6](args[5](args[4](args[3](args[2](args[1](args[0](self2)))))))));
    default: {
      let ret = self2;
      for (let i22 = 0, len = args.length; i22 < len; i22++) {
        ret = args[i22](ret);
      }
      return ret;
    }
  }
};
var OP_COMMIT22 = "Commit";
var OP_FAILURE22 = "Failure";
var OP_WITH_RUNTIME22 = "WithRuntime";
var EffectTypeId222 = /* @__PURE__ */ Symbol.for("effect/Effect");
var StreamTypeId222 = /* @__PURE__ */ Symbol.for("effect/Stream");
var SinkTypeId222 = /* @__PURE__ */ Symbol.for("effect/Sink");
var ChannelTypeId222 = /* @__PURE__ */ Symbol.for("effect/Channel");
var effectVariance222 = {
  /* c8 ignore next */
  _R: (_22) => _22,
  /* c8 ignore next */
  _E: (_22) => _22,
  /* c8 ignore next */
  _A: (_22) => _22,
  _V: /* @__PURE__ */ getCurrentVersion222()
};
var sinkVariance222 = {
  /* c8 ignore next */
  _A: (_22) => _22,
  /* c8 ignore next */
  _In: (_22) => _22,
  /* c8 ignore next */
  _L: (_22) => _22,
  /* c8 ignore next */
  _E: (_22) => _22,
  /* c8 ignore next */
  _R: (_22) => _22
};
var channelVariance222 = {
  /* c8 ignore next */
  _Env: (_22) => _22,
  /* c8 ignore next */
  _InErr: (_22) => _22,
  /* c8 ignore next */
  _InElem: (_22) => _22,
  /* c8 ignore next */
  _InDone: (_22) => _22,
  /* c8 ignore next */
  _OutErr: (_22) => _22,
  /* c8 ignore next */
  _OutElem: (_22) => _22,
  /* c8 ignore next */
  _OutDone: (_22) => _22
};
var EffectPrototype222 = {
  [EffectTypeId222]: effectVariance222,
  [StreamTypeId222]: effectVariance222,
  [SinkTypeId222]: sinkVariance222,
  [ChannelTypeId222]: channelVariance222,
  [symbol2222](that) {
    return this === that;
  },
  [symbol322]() {
    return cached222(this, random222(this));
  },
  [Symbol.iterator]() {
    return new SingleShotGen222(new YieldWrap222(this));
  },
  pipe() {
    return pipeArguments222(this, arguments);
  }
};
var StructuralPrototype22 = {
  [symbol322]() {
    return cached222(this, structure22(this));
  },
  [symbol2222](that) {
    const selfKeys = Object.keys(this);
    const thatKeys = Object.keys(that);
    if (selfKeys.length !== thatKeys.length) {
      return false;
    }
    for (const key of selfKeys) {
      if (!(key in that && equals222(this[key], that[key]))) {
        return false;
      }
    }
    return true;
  }
};
var CommitPrototype22 = {
  ...EffectPrototype222,
  _op: OP_COMMIT22
};
var StructuralCommitPrototype22 = {
  ...CommitPrototype22,
  ...StructuralPrototype22
};
var TypeId522 = /* @__PURE__ */ Symbol.for("effect/Option");
var CommonProto322 = {
  ...EffectPrototype222,
  [TypeId522]: {
    _A: (_22) => _22
  },
  [NodeInspectSymbol222]() {
    return this.toJSON();
  },
  toString() {
    return format222(this.toJSON());
  }
};
var SomeProto222 = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(CommonProto322), {
  _tag: "Some",
  _op: "Some",
  [symbol2222](that) {
    return isOption322(that) && isSome322(that) && equals222(this.value, that.value);
  },
  [symbol322]() {
    return cached222(this, combine222(hash222(this._tag))(hash222(this.value)));
  },
  toJSON() {
    return {
      _id: "Option",
      _tag: this._tag,
      value: toJSON222(this.value)
    };
  }
});
var NoneHash222 = /* @__PURE__ */ hash222("None");
var NoneProto222 = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(CommonProto322), {
  _tag: "None",
  _op: "None",
  [symbol2222](that) {
    return isOption322(that) && isNone322(that);
  },
  [symbol322]() {
    return NoneHash222;
  },
  toJSON() {
    return {
      _id: "Option",
      _tag: this._tag
    };
  }
});
var isOption322 = (input) => hasProperty222(input, TypeId522);
var isNone322 = (fa) => fa._tag === "None";
var isSome322 = (fa) => fa._tag === "Some";
var none322 = /* @__PURE__ */ Object.create(NoneProto222);
var some2222 = (value) => {
  const a22 = Object.create(SomeProto222);
  a22.value = value;
  return a22;
};
var TypeId2222 = /* @__PURE__ */ Symbol.for("effect/Either");
var CommonProto2222 = {
  ...EffectPrototype222,
  [TypeId2222]: {
    _R: (_22) => _22
  },
  [NodeInspectSymbol222]() {
    return this.toJSON();
  },
  toString() {
    return format222(this.toJSON());
  }
};
var RightProto222 = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(CommonProto2222), {
  _tag: "Right",
  _op: "Right",
  [symbol2222](that) {
    return isEither222(that) && isRight222(that) && equals222(this.right, that.right);
  },
  [symbol322]() {
    return combine222(hash222(this._tag))(hash222(this.right));
  },
  toJSON() {
    return {
      _id: "Either",
      _tag: this._tag,
      right: toJSON222(this.right)
    };
  }
});
var LeftProto222 = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(CommonProto2222), {
  _tag: "Left",
  _op: "Left",
  [symbol2222](that) {
    return isEither222(that) && isLeft222(that) && equals222(this.left, that.left);
  },
  [symbol322]() {
    return combine222(hash222(this._tag))(hash222(this.left));
  },
  toJSON() {
    return {
      _id: "Either",
      _tag: this._tag,
      left: toJSON222(this.left)
    };
  }
});
var isEither222 = (input) => hasProperty222(input, TypeId2222);
var isLeft222 = (ma) => ma._tag === "Left";
var isRight222 = (ma) => ma._tag === "Right";
var left222 = (left322) => {
  const a22 = Object.create(LeftProto222);
  a22.left = left322;
  return a22;
};
var right222 = (right322) => {
  const a22 = Object.create(RightProto222);
  a22.right = right322;
  return a22;
};
var getLeft322 = (self2) => isRight222(self2) ? none322 : some2222(self2.left);
var getRight322 = (self2) => isLeft222(self2) ? none322 : some2222(self2.right);
var right2222 = right222;
var left2222 = left222;
var Option_exports222 = {};
__export222(Option_exports222, {
  Do: () => Do222,
  TypeId: () => TypeId3222,
  all: () => all2222,
  andThen: () => andThen222,
  ap: () => ap222,
  as: () => as222,
  asVoid: () => asVoid222,
  bind: () => bind2222,
  bindTo: () => bindTo2222,
  composeK: () => composeK222,
  contains: () => contains222,
  containsWith: () => containsWith222,
  exists: () => exists222,
  filter: () => filter222,
  filterMap: () => filterMap222,
  firstSomeOf: () => firstSomeOf222,
  flatMap: () => flatMap222,
  flatMapNullable: () => flatMapNullable222,
  flatten: () => flatten222,
  fromIterable: () => fromIterable222,
  fromNullable: () => fromNullable222,
  gen: () => gen222,
  getEquivalence: () => getEquivalence222,
  getLeft: () => getLeft2222,
  getOrElse: () => getOrElse222,
  getOrNull: () => getOrNull222,
  getOrThrow: () => getOrThrow222,
  getOrThrowWith: () => getOrThrowWith222,
  getOrUndefined: () => getOrUndefined222,
  getOrder: () => getOrder222,
  getRight: () => getRight2222,
  isNone: () => isNone2222,
  isOption: () => isOption2222,
  isSome: () => isSome2222,
  let: () => let_2222,
  lift2: () => lift2222,
  liftNullable: () => liftNullable222,
  liftPredicate: () => liftPredicate222,
  liftThrowable: () => liftThrowable222,
  map: () => map222,
  match: () => match222,
  none: () => none2222,
  orElse: () => orElse222,
  orElseEither: () => orElseEither222,
  orElseSome: () => orElseSome222,
  partitionMap: () => partitionMap222,
  product: () => product2222,
  productMany: () => productMany2222,
  reduceCompact: () => reduceCompact222,
  some: () => some3222,
  tap: () => tap222,
  toArray: () => toArray222,
  toRefinement: () => toRefinement222,
  void: () => void_222,
  zipLeft: () => zipLeft222,
  zipRight: () => zipRight222,
  zipWith: () => zipWith222
});
var make2222 = (compare) => (self2, that) => self2 === that ? 0 : compare(self2, that);
var TypeId3222 = /* @__PURE__ */ Symbol.for("effect/Option");
var none2222 = () => none322;
var some3222 = some2222;
var isOption2222 = isOption322;
var isNone2222 = isNone322;
var isSome2222 = isSome322;
var match222 = /* @__PURE__ */ dual222(2, (self2, {
  onNone,
  onSome
}) => isNone2222(self2) ? onNone() : onSome(self2.value));
var toRefinement222 = (f22) => (a22) => isSome2222(f22(a22));
var fromIterable222 = (collection) => {
  for (const a22 of collection) {
    return some3222(a22);
  }
  return none2222();
};
var getRight2222 = getRight322;
var getLeft2222 = getLeft322;
var getOrElse222 = /* @__PURE__ */ dual222(2, (self2, onNone) => isNone2222(self2) ? onNone() : self2.value);
var orElse222 = /* @__PURE__ */ dual222(2, (self2, that) => isNone2222(self2) ? that() : self2);
var orElseSome222 = /* @__PURE__ */ dual222(2, (self2, onNone) => isNone2222(self2) ? some3222(onNone()) : self2);
var orElseEither222 = /* @__PURE__ */ dual222(2, (self2, that) => isNone2222(self2) ? map222(that(), right222) : map222(self2, left222));
var firstSomeOf222 = (collection) => {
  let out = none2222();
  for (out of collection) {
    if (isSome2222(out)) {
      return out;
    }
  }
  return out;
};
var fromNullable222 = (nullableValue) => nullableValue == null ? none2222() : some3222(nullableValue);
var liftNullable222 = (f22) => (...a22) => fromNullable222(f22(...a22));
var getOrNull222 = /* @__PURE__ */ getOrElse222(constNull222);
var getOrUndefined222 = /* @__PURE__ */ getOrElse222(constUndefined222);
var liftThrowable222 = (f22) => (...a22) => {
  try {
    return some3222(f22(...a22));
  } catch (e22) {
    return none2222();
  }
};
var getOrThrowWith222 = /* @__PURE__ */ dual222(2, (self2, onNone) => {
  if (isSome2222(self2)) {
    return self2.value;
  }
  throw onNone();
});
var getOrThrow222 = /* @__PURE__ */ getOrThrowWith222(() => new Error("getOrThrow called on a None"));
var map222 = /* @__PURE__ */ dual222(2, (self2, f22) => isNone2222(self2) ? none2222() : some3222(f22(self2.value)));
var as222 = /* @__PURE__ */ dual222(2, (self2, b22) => map222(self2, () => b22));
var asVoid222 = /* @__PURE__ */ as222(void 0);
var void_222 = /* @__PURE__ */ some3222(void 0);
var flatMap222 = /* @__PURE__ */ dual222(2, (self2, f22) => isNone2222(self2) ? none2222() : f22(self2.value));
var andThen222 = /* @__PURE__ */ dual222(2, (self2, f22) => flatMap222(self2, (a22) => {
  const b22 = isFunction2222(f22) ? f22(a22) : f22;
  return isOption2222(b22) ? b22 : some3222(b22);
}));
var flatMapNullable222 = /* @__PURE__ */ dual222(2, (self2, f22) => isNone2222(self2) ? none2222() : fromNullable222(f22(self2.value)));
var flatten222 = /* @__PURE__ */ flatMap222(identity222);
var zipRight222 = /* @__PURE__ */ dual222(2, (self2, that) => flatMap222(self2, () => that));
var composeK222 = /* @__PURE__ */ dual222(2, (afb, bfc) => (a22) => flatMap222(afb(a22), bfc));
var zipLeft222 = /* @__PURE__ */ dual222(2, (self2, that) => tap222(self2, () => that));
var tap222 = /* @__PURE__ */ dual222(2, (self2, f22) => flatMap222(self2, (a22) => map222(f22(a22), () => a22)));
var product2222 = (self2, that) => isSome2222(self2) && isSome2222(that) ? some3222([self2.value, that.value]) : none2222();
var productMany2222 = (self2, collection) => {
  if (isNone2222(self2)) {
    return none2222();
  }
  const out = [self2.value];
  for (const o22 of collection) {
    if (isNone2222(o22)) {
      return none2222();
    }
    out.push(o22.value);
  }
  return some3222(out);
};
var all2222 = (input) => {
  if (Symbol.iterator in input) {
    const out2 = [];
    for (const o22 of input) {
      if (isNone2222(o22)) {
        return none2222();
      }
      out2.push(o22.value);
    }
    return some3222(out2);
  }
  const out = {};
  for (const key of Object.keys(input)) {
    const o22 = input[key];
    if (isNone2222(o22)) {
      return none2222();
    }
    out[key] = o22.value;
  }
  return some3222(out);
};
var zipWith222 = /* @__PURE__ */ dual222(3, (self2, that, f22) => map222(product2222(self2, that), ([a22, b22]) => f22(a22, b22)));
var ap222 = /* @__PURE__ */ dual222(2, (self2, that) => zipWith222(self2, that, (f22, a22) => f22(a22)));
var reduceCompact222 = /* @__PURE__ */ dual222(3, (self2, b22, f22) => {
  let out = b22;
  for (const oa of self2) {
    if (isSome2222(oa)) {
      out = f22(out, oa.value);
    }
  }
  return out;
});
var toArray222 = (self2) => isNone2222(self2) ? [] : [self2.value];
var partitionMap222 = /* @__PURE__ */ dual222(2, (self2, f22) => {
  if (isNone2222(self2)) {
    return [none2222(), none2222()];
  }
  const e22 = f22(self2.value);
  return isLeft222(e22) ? [some3222(e22.left), none2222()] : [none2222(), some3222(e22.right)];
});
var filterMap222 = /* @__PURE__ */ dual222(2, (self2, f22) => isNone2222(self2) ? none2222() : f22(self2.value));
var filter222 = /* @__PURE__ */ dual222(2, (self2, predicate) => filterMap222(self2, (b22) => predicate(b22) ? some2222(b22) : none322));
var getEquivalence222 = (isEquivalent) => make422((x22, y22) => x22 === y22 || (isNone2222(x22) ? isNone2222(y22) : isNone2222(y22) ? false : isEquivalent(x22.value, y22.value)));
var getOrder222 = (O22) => make2222((self2, that) => isSome2222(self2) ? isSome2222(that) ? O22(self2.value, that.value) : 1 : -1);
var lift2222 = (f22) => dual222(2, (self2, that) => zipWith222(self2, that, f22));
var liftPredicate222 = (predicate) => (b22) => predicate(b22) ? some3222(b22) : none2222();
var containsWith222 = (isEquivalent) => dual222(2, (self2, a22) => isNone2222(self2) ? false : isEquivalent(self2.value, a22));
var _equivalence222 = /* @__PURE__ */ equivalence222();
var contains222 = /* @__PURE__ */ containsWith222(_equivalence222);
var exists222 = /* @__PURE__ */ dual222(2, (self2, refinement) => isNone2222(self2) ? false : refinement(self2.value));
var bindTo2222 = /* @__PURE__ */ bindTo322(map222);
var let_2222 = /* @__PURE__ */ let_322(map222);
var bind2222 = /* @__PURE__ */ bind322(map222, flatMap222);
var Do222 = /* @__PURE__ */ some3222({});
var adapter2222 = /* @__PURE__ */ adapter322();
var gen222 = (f22) => {
  const iterator = f22(adapter2222);
  let state = iterator.next();
  if (state.done) {
    return some3222(state.value);
  } else {
    let current = state.value;
    if (isGenKind222(current)) {
      current = current.value;
    } else {
      current = yieldWrapGet222(current);
    }
    if (isNone2222(current)) {
      return current;
    }
    while (!state.done) {
      state = iterator.next(current.value);
      if (!state.done) {
        current = state.value;
        if (isGenKind222(current)) {
          current = current.value;
        } else {
          current = yieldWrapGet222(current);
        }
        if (isNone2222(current)) {
          return current;
        }
      }
    }
    return some3222(state.value);
  }
};
var fromIterable2222 = (collection) => Array.isArray(collection) ? collection : Array.from(collection);
var reverse4 = (self2) => Array.from(self2).reverse();
var reduce5 = /* @__PURE__ */ dual222(3, (self2, b22, f22) => fromIterable2222(self2).reduce((b222, a22, i22) => f22(b222, a22, i22), b22));
var TagTypeId22 = /* @__PURE__ */ Symbol.for("effect/Context/Tag");
var STMSymbolKey22 = "effect/STM";
var STMTypeId22 = /* @__PURE__ */ Symbol.for(STMSymbolKey22);
var TagProto22 = {
  ...EffectPrototype222,
  _tag: "Tag",
  _op: "Tag",
  [STMTypeId22]: effectVariance222,
  [TagTypeId22]: {
    _Service: (_22) => _22,
    _Identifier: (_22) => _22
  },
  toString() {
    return format222(this.toJSON());
  },
  toJSON() {
    return {
      _id: "Tag",
      key: this.key,
      stack: this.stack
    };
  },
  [NodeInspectSymbol222]() {
    return this.toJSON();
  },
  of(self2) {
    return self2;
  },
  context(self2) {
    return make3222(this, self2);
  }
};
var makeGenericTag22 = (key) => {
  const limit = Error.stackTraceLimit;
  Error.stackTraceLimit = 2;
  const creationError = new Error();
  Error.stackTraceLimit = limit;
  const tag = Object.create(TagProto22);
  Object.defineProperty(tag, "stack", {
    get() {
      return creationError.stack;
    }
  });
  tag.key = key;
  return tag;
};
var TypeId4222 = /* @__PURE__ */ Symbol.for("effect/Context");
var ContextProto22 = {
  [TypeId4222]: {
    _Services: (_22) => _22
  },
  [symbol2222](that) {
    if (isContext22(that)) {
      if (this.unsafeMap.size === that.unsafeMap.size) {
        for (const k22 of this.unsafeMap.keys()) {
          if (!that.unsafeMap.has(k22) || !equals222(this.unsafeMap.get(k22), that.unsafeMap.get(k22))) {
            return false;
          }
        }
        return true;
      }
    }
    return false;
  },
  [symbol322]() {
    return cached222(this, number222(this.unsafeMap.size));
  },
  pipe() {
    return pipeArguments222(this, arguments);
  },
  toString() {
    return format222(this.toJSON());
  },
  toJSON() {
    return {
      _id: "Context",
      services: Array.from(this.unsafeMap).map(toJSON222)
    };
  },
  [NodeInspectSymbol222]() {
    return this.toJSON();
  }
};
var makeContext22 = (unsafeMap) => {
  const context = Object.create(ContextProto22);
  context.unsafeMap = unsafeMap;
  return context;
};
var isContext22 = (u22) => hasProperty222(u22, TypeId4222);
var _empty62 = /* @__PURE__ */ makeContext22(/* @__PURE__ */ new Map());
var empty10 = () => _empty62;
var make3222 = (tag, service) => makeContext22(/* @__PURE__ */ new Map([[tag.key, service]]));
var GenericTag22 = makeGenericTag22;
var empty222 = empty10;
var TypeId5222 = /* @__PURE__ */ Symbol.for("effect/Chunk");
function copy3(src, srcPos, dest, destPos, len) {
  for (let i22 = srcPos; i22 < Math.min(src.length, srcPos + len); i22++) {
    dest[destPos + i22 - srcPos] = src[i22];
  }
  return dest;
}
var emptyArray22 = [];
var getEquivalence2222 = (isEquivalent) => make422((self2, that) => self2.length === that.length && toReadonlyArray22(self2).every((value, i22) => isEquivalent(value, unsafeGet222(that, i22))));
var _equivalence2222 = /* @__PURE__ */ getEquivalence2222(equals222);
var ChunkProto22 = {
  [TypeId5222]: {
    _A: (_22) => _22
  },
  toString() {
    return format222(this.toJSON());
  },
  toJSON() {
    return {
      _id: "Chunk",
      values: toReadonlyArray22(this).map(toJSON222)
    };
  },
  [NodeInspectSymbol222]() {
    return this.toJSON();
  },
  [symbol2222](that) {
    return isChunk22(that) && _equivalence2222(this, that);
  },
  [symbol322]() {
    return cached222(this, array5(toReadonlyArray22(this)));
  },
  [Symbol.iterator]() {
    switch (this.backing._tag) {
      case "IArray": {
        return this.backing.array[Symbol.iterator]();
      }
      case "IEmpty": {
        return emptyArray22[Symbol.iterator]();
      }
      default: {
        return toReadonlyArray22(this)[Symbol.iterator]();
      }
    }
  },
  pipe() {
    return pipeArguments222(this, arguments);
  }
};
var makeChunk22 = (backing) => {
  const chunk = Object.create(ChunkProto22);
  chunk.backing = backing;
  switch (backing._tag) {
    case "IEmpty": {
      chunk.length = 0;
      chunk.depth = 0;
      chunk.left = chunk;
      chunk.right = chunk;
      break;
    }
    case "IConcat": {
      chunk.length = backing.left.length + backing.right.length;
      chunk.depth = 1 + Math.max(backing.left.depth, backing.right.depth);
      chunk.left = backing.left;
      chunk.right = backing.right;
      break;
    }
    case "IArray": {
      chunk.length = backing.array.length;
      chunk.depth = 0;
      chunk.left = _empty222;
      chunk.right = _empty222;
      break;
    }
    case "ISingleton": {
      chunk.length = 1;
      chunk.depth = 0;
      chunk.left = _empty222;
      chunk.right = _empty222;
      break;
    }
    case "ISlice": {
      chunk.length = backing.length;
      chunk.depth = backing.chunk.depth + 1;
      chunk.left = _empty222;
      chunk.right = _empty222;
      break;
    }
  }
  return chunk;
};
var isChunk22 = (u22) => hasProperty222(u22, TypeId5222);
var _empty222 = /* @__PURE__ */ makeChunk22({
  _tag: "IEmpty"
});
var empty322 = () => _empty222;
var make4222 = (...as2222) => as2222.length === 1 ? of3(as2222[0]) : unsafeFromNonEmptyArray22(as2222);
var of3 = (a22) => makeChunk22({
  _tag: "ISingleton",
  a: a22
});
var copyToArray22 = (self2, array322, initial) => {
  switch (self2.backing._tag) {
    case "IArray": {
      copy3(self2.backing.array, 0, array322, initial, self2.length);
      break;
    }
    case "IConcat": {
      copyToArray22(self2.left, array322, initial);
      copyToArray22(self2.right, array322, initial + self2.left.length);
      break;
    }
    case "ISingleton": {
      array322[initial] = self2.backing.a;
      break;
    }
    case "ISlice": {
      let i22 = 0;
      let j22 = initial;
      while (i22 < self2.length) {
        array322[j22] = unsafeGet222(self2, i22);
        i22 += 1;
        j22 += 1;
      }
      break;
    }
  }
};
var toReadonlyArray22 = (self2) => {
  switch (self2.backing._tag) {
    case "IEmpty": {
      return emptyArray22;
    }
    case "IArray": {
      return self2.backing.array;
    }
    default: {
      const arr = new Array(self2.length);
      copyToArray22(self2, arr, 0);
      self2.backing = {
        _tag: "IArray",
        array: arr
      };
      self2.left = _empty222;
      self2.right = _empty222;
      self2.depth = 0;
      return arr;
    }
  }
};
var reverse222 = (self2) => {
  switch (self2.backing._tag) {
    case "IEmpty":
    case "ISingleton":
      return self2;
    case "IArray": {
      return makeChunk22({
        _tag: "IArray",
        array: reverse4(self2.backing.array)
      });
    }
    case "IConcat": {
      return makeChunk22({
        _tag: "IConcat",
        left: reverse222(self2.backing.right),
        right: reverse222(self2.backing.left)
      });
    }
    case "ISlice":
      return unsafeFromArray22(reverse4(toReadonlyArray22(self2)));
  }
};
var unsafeFromArray22 = (self2) => makeChunk22({
  _tag: "IArray",
  array: self2
});
var unsafeFromNonEmptyArray22 = (self2) => unsafeFromArray22(self2);
var unsafeGet222 = /* @__PURE__ */ dual222(2, (self2, index) => {
  switch (self2.backing._tag) {
    case "IEmpty": {
      throw new Error(`Index out of bounds`);
    }
    case "ISingleton": {
      if (index !== 0) {
        throw new Error(`Index out of bounds`);
      }
      return self2.backing.a;
    }
    case "IArray": {
      if (index >= self2.length || index < 0) {
        throw new Error(`Index out of bounds`);
      }
      return self2.backing.array[index];
    }
    case "IConcat": {
      return index < self2.left.length ? unsafeGet222(self2.left, index) : unsafeGet222(self2.right, index - self2.left.length);
    }
    case "ISlice": {
      return unsafeGet222(self2.backing.chunk, index + self2.backing.offset);
    }
  }
});
var prepend3 = /* @__PURE__ */ dual222(2, (self2, elem) => appendAll3(of3(elem), self2));
var drop3 = /* @__PURE__ */ dual222(2, (self2, n22) => {
  if (n22 <= 0) {
    return self2;
  } else if (n22 >= self2.length) {
    return _empty222;
  } else {
    switch (self2.backing._tag) {
      case "ISlice": {
        return makeChunk22({
          _tag: "ISlice",
          chunk: self2.backing.chunk,
          offset: self2.backing.offset + n22,
          length: self2.backing.length - n22
        });
      }
      case "IConcat": {
        if (n22 > self2.left.length) {
          return drop3(self2.right, n22 - self2.left.length);
        }
        return makeChunk22({
          _tag: "IConcat",
          left: drop3(self2.left, n22),
          right: self2.right
        });
      }
      default: {
        return makeChunk22({
          _tag: "ISlice",
          chunk: self2,
          offset: n22,
          length: self2.length - n22
        });
      }
    }
  }
});
var appendAll3 = /* @__PURE__ */ dual222(2, (self2, that) => {
  if (self2.backing._tag === "IEmpty") {
    return that;
  }
  if (that.backing._tag === "IEmpty") {
    return self2;
  }
  const diff222 = that.depth - self2.depth;
  if (Math.abs(diff222) <= 1) {
    return makeChunk22({
      _tag: "IConcat",
      left: self2,
      right: that
    });
  } else if (diff222 < -1) {
    if (self2.left.depth >= self2.right.depth) {
      const nr = appendAll3(self2.right, that);
      return makeChunk22({
        _tag: "IConcat",
        left: self2.left,
        right: nr
      });
    } else {
      const nrr = appendAll3(self2.right.right, that);
      if (nrr.depth === self2.depth - 3) {
        const nr = makeChunk22({
          _tag: "IConcat",
          left: self2.right.left,
          right: nrr
        });
        return makeChunk22({
          _tag: "IConcat",
          left: self2.left,
          right: nr
        });
      } else {
        const nl = makeChunk22({
          _tag: "IConcat",
          left: self2.left,
          right: self2.right.left
        });
        return makeChunk22({
          _tag: "IConcat",
          left: nl,
          right: nrr
        });
      }
    }
  } else {
    if (that.right.depth >= that.left.depth) {
      const nl = appendAll3(self2, that.left);
      return makeChunk22({
        _tag: "IConcat",
        left: nl,
        right: that.right
      });
    } else {
      const nll = appendAll3(self2, that.left.left);
      if (nll.depth === that.depth - 3) {
        const nl = makeChunk22({
          _tag: "IConcat",
          left: nll,
          right: that.left.right
        });
        return makeChunk22({
          _tag: "IConcat",
          left: nl,
          right: that.right
        });
      } else {
        const nr = makeChunk22({
          _tag: "IConcat",
          left: that.left.right,
          right: that.right
        });
        return makeChunk22({
          _tag: "IConcat",
          left: nll,
          right: nr
        });
      }
    }
  }
});
var isEmpty22 = (self2) => self2.length === 0;
var isNonEmpty22 = (self2) => self2.length > 0;
var unsafeHead22 = (self2) => unsafeGet222(self2, 0);
var headNonEmpty3 = unsafeHead22;
var tailNonEmpty3 = (self2) => drop3(self2, 1);
var SIZE22 = 5;
var BUCKET_SIZE22 = /* @__PURE__ */ Math.pow(2, SIZE22);
var MASK22 = BUCKET_SIZE22 - 1;
var MAX_INDEX_NODE22 = BUCKET_SIZE22 / 2;
var MIN_ARRAY_NODE22 = BUCKET_SIZE22 / 4;
function popcount22(x22) {
  x22 -= x22 >> 1 & 1431655765;
  x22 = (x22 & 858993459) + (x22 >> 2 & 858993459);
  x22 = x22 + (x22 >> 4) & 252645135;
  x22 += x22 >> 8;
  x22 += x22 >> 16;
  return x22 & 127;
}
function hashFragment22(shift2, h22) {
  return h22 >>> shift2 & MASK22;
}
function toBitmap22(x22) {
  return 1 << x22;
}
function fromBitmap22(bitmap, bit) {
  return popcount22(bitmap & bit - 1);
}
var make522 = (value, previous) => ({
  value,
  previous
});
function arrayUpdate22(mutate222, at, v22, arr) {
  let out = arr;
  if (!mutate222) {
    const len = arr.length;
    out = new Array(len);
    for (let i22 = 0; i22 < len; ++i22) out[i22] = arr[i22];
  }
  out[at] = v22;
  return out;
}
function arraySpliceOut22(mutate222, at, arr) {
  const newLen = arr.length - 1;
  let i22 = 0;
  let g22 = 0;
  let out = arr;
  if (mutate222) {
    i22 = g22 = at;
  } else {
    out = new Array(newLen);
    while (i22 < at) out[g22++] = arr[i22++];
  }
  ++i22;
  while (i22 <= newLen) out[g22++] = arr[i22++];
  if (mutate222) {
    out.length = newLen;
  }
  return out;
}
function arraySpliceIn22(mutate222, at, v22, arr) {
  const len = arr.length;
  if (mutate222) {
    let i222 = len;
    while (i222 >= at) arr[i222--] = arr[i222];
    arr[at] = v22;
    return arr;
  }
  let i22 = 0, g22 = 0;
  const out = new Array(len + 1);
  while (i22 < at) out[g22++] = arr[i22++];
  out[at] = v22;
  while (i22 < len) out[++g22] = arr[i22++];
  return out;
}
var EmptyNode22 = class _EmptyNode22 {
  _tag = "EmptyNode";
  modify(edit, _shift, f22, hash2222, key, size422) {
    const v22 = f22(none2222());
    if (isNone2222(v22)) return new _EmptyNode22();
    ++size422.value;
    return new LeafNode22(edit, hash2222, key, v22);
  }
};
function isEmptyNode22(a22) {
  return isTagged3(a22, "EmptyNode");
}
function isLeafNode22(node) {
  return isEmptyNode22(node) || node._tag === "LeafNode" || node._tag === "CollisionNode";
}
function canEditNode22(node, edit) {
  return isEmptyNode22(node) ? false : edit === node.edit;
}
var LeafNode22 = class _LeafNode22 {
  edit;
  hash;
  key;
  value;
  _tag = "LeafNode";
  constructor(edit, hash2222, key, value) {
    this.edit = edit;
    this.hash = hash2222;
    this.key = key;
    this.value = value;
  }
  modify(edit, shift2, f22, hash2222, key, size422) {
    if (equals222(key, this.key)) {
      const v222 = f22(this.value);
      if (v222 === this.value) return this;
      else if (isNone2222(v222)) {
        --size422.value;
        return new EmptyNode22();
      }
      if (canEditNode22(this, edit)) {
        this.value = v222;
        return this;
      }
      return new _LeafNode22(edit, hash2222, key, v222);
    }
    const v22 = f22(none2222());
    if (isNone2222(v22)) return this;
    ++size422.value;
    return mergeLeaves22(edit, shift2, this.hash, this, hash2222, new _LeafNode22(edit, hash2222, key, v22));
  }
};
var CollisionNode22 = class _CollisionNode22 {
  edit;
  hash;
  children;
  _tag = "CollisionNode";
  constructor(edit, hash2222, children) {
    this.edit = edit;
    this.hash = hash2222;
    this.children = children;
  }
  modify(edit, shift2, f22, hash2222, key, size422) {
    if (hash2222 === this.hash) {
      const canEdit = canEditNode22(this, edit);
      const list = this.updateCollisionList(canEdit, edit, this.hash, this.children, f22, key, size422);
      if (list === this.children) return this;
      return list.length > 1 ? new _CollisionNode22(edit, this.hash, list) : list[0];
    }
    const v22 = f22(none2222());
    if (isNone2222(v22)) return this;
    ++size422.value;
    return mergeLeaves22(edit, shift2, this.hash, this, hash2222, new LeafNode22(edit, hash2222, key, v22));
  }
  updateCollisionList(mutate222, edit, hash2222, list, f22, key, size422) {
    const len = list.length;
    for (let i22 = 0; i22 < len; ++i22) {
      const child = list[i22];
      if ("key" in child && equals222(key, child.key)) {
        const value = child.value;
        const newValue2 = f22(value);
        if (newValue2 === value) return list;
        if (isNone2222(newValue2)) {
          --size422.value;
          return arraySpliceOut22(mutate222, i22, list);
        }
        return arrayUpdate22(mutate222, i22, new LeafNode22(edit, hash2222, key, newValue2), list);
      }
    }
    const newValue = f22(none2222());
    if (isNone2222(newValue)) return list;
    ++size422.value;
    return arrayUpdate22(mutate222, len, new LeafNode22(edit, hash2222, key, newValue), list);
  }
};
var IndexedNode22 = class _IndexedNode22 {
  edit;
  mask;
  children;
  _tag = "IndexedNode";
  constructor(edit, mask, children) {
    this.edit = edit;
    this.mask = mask;
    this.children = children;
  }
  modify(edit, shift2, f22, hash2222, key, size422) {
    const mask = this.mask;
    const children = this.children;
    const frag = hashFragment22(shift2, hash2222);
    const bit = toBitmap22(frag);
    const indx = fromBitmap22(mask, bit);
    const exists2222 = mask & bit;
    const canEdit = canEditNode22(this, edit);
    if (!exists2222) {
      const _newChild = new EmptyNode22().modify(edit, shift2 + SIZE22, f22, hash2222, key, size422);
      if (!_newChild) return this;
      return children.length >= MAX_INDEX_NODE22 ? expand22(edit, frag, _newChild, mask, children) : new _IndexedNode22(edit, mask | bit, arraySpliceIn22(canEdit, indx, _newChild, children));
    }
    const current = children[indx];
    const child = current.modify(edit, shift2 + SIZE22, f22, hash2222, key, size422);
    if (current === child) return this;
    let bitmap = mask;
    let newChildren;
    if (isEmptyNode22(child)) {
      bitmap &= ~bit;
      if (!bitmap) return new EmptyNode22();
      if (children.length <= 2 && isLeafNode22(children[indx ^ 1])) {
        return children[indx ^ 1];
      }
      newChildren = arraySpliceOut22(canEdit, indx, children);
    } else {
      newChildren = arrayUpdate22(canEdit, indx, child, children);
    }
    if (canEdit) {
      this.mask = bitmap;
      this.children = newChildren;
      return this;
    }
    return new _IndexedNode22(edit, bitmap, newChildren);
  }
};
var ArrayNode22 = class _ArrayNode22 {
  edit;
  size;
  children;
  _tag = "ArrayNode";
  constructor(edit, size422, children) {
    this.edit = edit;
    this.size = size422;
    this.children = children;
  }
  modify(edit, shift2, f22, hash2222, key, size422) {
    let count = this.size;
    const children = this.children;
    const frag = hashFragment22(shift2, hash2222);
    const child = children[frag];
    const newChild = (child || new EmptyNode22()).modify(edit, shift2 + SIZE22, f22, hash2222, key, size422);
    if (child === newChild) return this;
    const canEdit = canEditNode22(this, edit);
    let newChildren;
    if (isEmptyNode22(child) && !isEmptyNode22(newChild)) {
      ++count;
      newChildren = arrayUpdate22(canEdit, frag, newChild, children);
    } else if (!isEmptyNode22(child) && isEmptyNode22(newChild)) {
      --count;
      if (count <= MIN_ARRAY_NODE22) {
        return pack22(edit, count, frag, children);
      }
      newChildren = arrayUpdate22(canEdit, frag, new EmptyNode22(), children);
    } else {
      newChildren = arrayUpdate22(canEdit, frag, newChild, children);
    }
    if (canEdit) {
      this.size = count;
      this.children = newChildren;
      return this;
    }
    return new _ArrayNode22(edit, count, newChildren);
  }
};
function pack22(edit, count, removed, elements) {
  const children = new Array(count - 1);
  let g22 = 0;
  let bitmap = 0;
  for (let i22 = 0, len = elements.length; i22 < len; ++i22) {
    if (i22 !== removed) {
      const elem = elements[i22];
      if (elem && !isEmptyNode22(elem)) {
        children[g22++] = elem;
        bitmap |= 1 << i22;
      }
    }
  }
  return new IndexedNode22(edit, bitmap, children);
}
function expand22(edit, frag, child, bitmap, subNodes) {
  const arr = [];
  let bit = bitmap;
  let count = 0;
  for (let i22 = 0; bit; ++i22) {
    if (bit & 1) arr[i22] = subNodes[count++];
    bit >>>= 1;
  }
  arr[frag] = child;
  return new ArrayNode22(edit, count + 1, arr);
}
function mergeLeavesInner22(edit, shift2, h1, n1, h22, n22) {
  if (h1 === h22) return new CollisionNode22(edit, h1, [n22, n1]);
  const subH1 = hashFragment22(shift2, h1);
  const subH2 = hashFragment22(shift2, h22);
  if (subH1 === subH2) {
    return (child) => new IndexedNode22(edit, toBitmap22(subH1) | toBitmap22(subH2), [child]);
  } else {
    const children = subH1 < subH2 ? [n1, n22] : [n22, n1];
    return new IndexedNode22(edit, toBitmap22(subH1) | toBitmap22(subH2), children);
  }
}
function mergeLeaves22(edit, shift2, h1, n1, h22, n22) {
  let stack = void 0;
  let currentShift = shift2;
  while (true) {
    const res = mergeLeavesInner22(edit, currentShift, h1, n1, h22, n22);
    if (typeof res === "function") {
      stack = make522(res, stack);
      currentShift = currentShift + SIZE22;
    } else {
      let final = res;
      while (stack != null) {
        final = stack.value(final);
        stack = stack.previous;
      }
      return final;
    }
  }
}
var HashMapSymbolKey22 = "effect/HashMap";
var HashMapTypeId22 = /* @__PURE__ */ Symbol.for(HashMapSymbolKey22);
var HashMapProto22 = {
  [HashMapTypeId22]: HashMapTypeId22,
  [Symbol.iterator]() {
    return new HashMapIterator22(this, (k22, v22) => [k22, v22]);
  },
  [symbol322]() {
    let hash2222 = hash222(HashMapSymbolKey22);
    for (const item of this) {
      hash2222 ^= pipe222(hash222(item[0]), combine222(hash222(item[1])));
    }
    return cached222(this, hash2222);
  },
  [symbol2222](that) {
    if (isHashMap22(that)) {
      if (that._size !== this._size) {
        return false;
      }
      for (const item of this) {
        const elem = pipe222(that, getHash22(item[0], hash222(item[0])));
        if (isNone2222(elem)) {
          return false;
        } else {
          if (!equals222(item[1], elem.value)) {
            return false;
          }
        }
      }
      return true;
    }
    return false;
  },
  toString() {
    return format222(this.toJSON());
  },
  toJSON() {
    return {
      _id: "HashMap",
      values: Array.from(this).map(toJSON222)
    };
  },
  [NodeInspectSymbol222]() {
    return this.toJSON();
  },
  pipe() {
    return pipeArguments222(this, arguments);
  }
};
var makeImpl32 = (editable, edit, root, size422) => {
  const map62 = Object.create(HashMapProto22);
  map62._editable = editable;
  map62._edit = edit;
  map62._root = root;
  map62._size = size422;
  return map62;
};
var HashMapIterator22 = class _HashMapIterator22 {
  map;
  f;
  v;
  constructor(map62, f22) {
    this.map = map62;
    this.f = f22;
    this.v = visitLazy22(this.map._root, this.f, void 0);
  }
  next() {
    if (isNone2222(this.v)) {
      return {
        done: true,
        value: void 0
      };
    }
    const v0 = this.v.value;
    this.v = applyCont22(v0.cont);
    return {
      done: false,
      value: v0.value
    };
  }
  [Symbol.iterator]() {
    return new _HashMapIterator22(this.map, this.f);
  }
};
var applyCont22 = (cont) => cont ? visitLazyChildren22(cont[0], cont[1], cont[2], cont[3], cont[4]) : none2222();
var visitLazy22 = (node, f22, cont = void 0) => {
  switch (node._tag) {
    case "LeafNode": {
      if (isSome2222(node.value)) {
        return some3222({
          value: f22(node.key, node.value.value),
          cont
        });
      }
      return applyCont22(cont);
    }
    case "CollisionNode":
    case "ArrayNode":
    case "IndexedNode": {
      const children = node.children;
      return visitLazyChildren22(children.length, children, 0, f22, cont);
    }
    default: {
      return applyCont22(cont);
    }
  }
};
var visitLazyChildren22 = (len, children, i22, f22, cont) => {
  while (i22 < len) {
    const child = children[i22++];
    if (child && !isEmptyNode22(child)) {
      return visitLazy22(child, f22, [len, children, i22, f22, cont]);
    }
  }
  return applyCont22(cont);
};
var _empty322 = /* @__PURE__ */ makeImpl32(false, 0, /* @__PURE__ */ new EmptyNode22(), 0);
var empty422 = () => _empty322;
var isHashMap22 = (u22) => hasProperty222(u22, HashMapTypeId22);
var getHash22 = /* @__PURE__ */ dual222(3, (self2, key, hash2222) => {
  let node = self2._root;
  let shift2 = 0;
  while (true) {
    switch (node._tag) {
      case "LeafNode": {
        return equals222(key, node.key) ? node.value : none2222();
      }
      case "CollisionNode": {
        if (hash2222 === node.hash) {
          const children = node.children;
          for (let i22 = 0, len = children.length; i22 < len; ++i22) {
            const child = children[i22];
            if ("key" in child && equals222(key, child.key)) {
              return child.value;
            }
          }
        }
        return none2222();
      }
      case "IndexedNode": {
        const frag = hashFragment22(shift2, hash2222);
        const bit = toBitmap22(frag);
        if (node.mask & bit) {
          node = node.children[fromBitmap22(node.mask, bit)];
          shift2 += SIZE22;
          break;
        }
        return none2222();
      }
      case "ArrayNode": {
        node = node.children[hashFragment22(shift2, hash2222)];
        if (node) {
          shift2 += SIZE22;
          break;
        }
        return none2222();
      }
      default:
        return none2222();
    }
  }
});
var set222 = /* @__PURE__ */ dual222(3, (self2, key, value) => modifyAt22(self2, key, () => some3222(value)));
var setTree22 = /* @__PURE__ */ dual222(3, (self2, newRoot, newSize) => {
  if (self2._editable) {
    self2._root = newRoot;
    self2._size = newSize;
    return self2;
  }
  return newRoot === self2._root ? self2 : makeImpl32(self2._editable, self2._edit, newRoot, newSize);
});
var keys3 = (self2) => new HashMapIterator22(self2, (key) => key);
var size42 = (self2) => self2._size;
var beginMutation32 = (self2) => makeImpl32(true, self2._edit + 1, self2._root, self2._size);
var modifyAt22 = /* @__PURE__ */ dual222(3, (self2, key, f22) => modifyHash22(self2, key, hash222(key), f22));
var modifyHash22 = /* @__PURE__ */ dual222(4, (self2, key, hash2222, f22) => {
  const size422 = {
    value: self2._size
  };
  const newRoot = self2._root.modify(self2._editable ? self2._edit : NaN, 0, f22, hash2222, key, size422);
  return pipe222(self2, setTree22(newRoot, size422.value));
});
var forEach4 = /* @__PURE__ */ dual222(2, (self2, f22) => reduce222(self2, void 0, (_22, value, key) => f22(value, key)));
var reduce222 = /* @__PURE__ */ dual222(3, (self2, zero, f22) => {
  const root = self2._root;
  if (root._tag === "LeafNode") {
    return isSome2222(root.value) ? f22(zero, root.value.value, root.key) : zero;
  }
  if (root._tag === "EmptyNode") {
    return zero;
  }
  const toVisit = [root.children];
  let children;
  while (children = toVisit.pop()) {
    for (let i22 = 0, len = children.length; i22 < len; ) {
      const child = children[i22++];
      if (child && !isEmptyNode22(child)) {
        if (child._tag === "LeafNode") {
          if (isSome2222(child.value)) {
            zero = f22(zero, child.value.value, child.key);
          }
        } else {
          toVisit.push(child.children);
        }
      }
    }
  }
  return zero;
});
var HashSetSymbolKey22 = "effect/HashSet";
var HashSetTypeId22 = /* @__PURE__ */ Symbol.for(HashSetSymbolKey22);
var HashSetProto22 = {
  [HashSetTypeId22]: HashSetTypeId22,
  [Symbol.iterator]() {
    return keys3(this._keyMap);
  },
  [symbol322]() {
    return cached222(this, combine222(hash222(this._keyMap))(hash222(HashSetSymbolKey22)));
  },
  [symbol2222](that) {
    if (isHashSet22(that)) {
      return size42(this._keyMap) === size42(that._keyMap) && equals222(this._keyMap, that._keyMap);
    }
    return false;
  },
  toString() {
    return format222(this.toJSON());
  },
  toJSON() {
    return {
      _id: "HashSet",
      values: Array.from(this).map(toJSON222)
    };
  },
  [NodeInspectSymbol222]() {
    return this.toJSON();
  },
  pipe() {
    return pipeArguments222(this, arguments);
  }
};
var makeImpl222 = (keyMap) => {
  const set2222 = Object.create(HashSetProto22);
  set2222._keyMap = keyMap;
  return set2222;
};
var isHashSet22 = (u22) => hasProperty222(u22, HashSetTypeId22);
var _empty422 = /* @__PURE__ */ makeImpl222(/* @__PURE__ */ empty422());
var empty522 = () => _empty422;
var size222 = (self2) => size42(self2._keyMap);
var beginMutation222 = (self2) => makeImpl222(beginMutation32(self2._keyMap));
var endMutation22 = (self2) => {
  self2._keyMap._editable = false;
  return self2;
};
var mutate22 = /* @__PURE__ */ dual222(2, (self2, f22) => {
  const transient = beginMutation222(self2);
  f22(transient);
  return endMutation22(transient);
});
var add222 = /* @__PURE__ */ dual222(2, (self2, value) => self2._keyMap._editable ? (set222(value, true)(self2._keyMap), self2) : makeImpl222(set222(value, true)(self2._keyMap)));
var union222 = /* @__PURE__ */ dual222(2, (self2, that) => mutate22(empty522(), (set2222) => {
  forEach222(self2, (value) => add222(set2222, value));
  for (const value of that) {
    add222(set2222, value);
  }
}));
var forEach222 = /* @__PURE__ */ dual222(2, (self2, f22) => forEach4(self2._keyMap, (_22, k22) => f22(k22)));
var empty622 = empty522;
var size322 = size222;
var add322 = add222;
var union322 = union222;
var ArrayProto22 = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(Array.prototype), {
  [symbol322]() {
    return cached222(this, array5(this));
  },
  [symbol2222](that) {
    if (Array.isArray(that) && this.length === that.length) {
      return this.every((v22, i22) => equals222(v22, that[i22]));
    } else {
      return false;
    }
  }
});
var Structural32 = /* @__PURE__ */ function() {
  function Structural322(args) {
    if (args) {
      Object.assign(this, args);
    }
  }
  Structural322.prototype = StructuralPrototype22;
  return Structural322;
}();
var struct222 = (as2222) => Object.assign(Object.create(StructuralPrototype22), as2222);
var ContextPatchTypeId22 = /* @__PURE__ */ Symbol.for("effect/DifferContextPatch");
function variance32(a22) {
  return a22;
}
var PatchProto22 = {
  ...Structural32.prototype,
  [ContextPatchTypeId22]: {
    _Value: variance32,
    _Patch: variance32
  }
};
var EmptyProto22 = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(PatchProto22), {
  _tag: "Empty"
});
var _empty522 = /* @__PURE__ */ Object.create(EmptyProto22);
var empty722 = () => _empty522;
var AndThenProto22 = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(PatchProto22), {
  _tag: "AndThen"
});
var makeAndThen22 = (first, second) => {
  const o22 = Object.create(AndThenProto22);
  o22.first = first;
  o22.second = second;
  return o22;
};
var AddServiceProto22 = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(PatchProto22), {
  _tag: "AddService"
});
var makeAddService22 = (key, service) => {
  const o22 = Object.create(AddServiceProto22);
  o22.key = key;
  o22.service = service;
  return o22;
};
var RemoveServiceProto22 = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(PatchProto22), {
  _tag: "RemoveService"
});
var makeRemoveService22 = (key) => {
  const o22 = Object.create(RemoveServiceProto22);
  o22.key = key;
  return o22;
};
var UpdateServiceProto22 = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(PatchProto22), {
  _tag: "UpdateService"
});
var makeUpdateService22 = (key, update22) => {
  const o22 = Object.create(UpdateServiceProto22);
  o22.key = key;
  o22.update = update22;
  return o22;
};
var diff22 = (oldValue, newValue) => {
  const missingServices = new Map(oldValue.unsafeMap);
  let patch222 = empty722();
  for (const [tag, newService] of newValue.unsafeMap.entries()) {
    if (missingServices.has(tag)) {
      const old = missingServices.get(tag);
      missingServices.delete(tag);
      if (!equals222(old, newService)) {
        patch222 = combine2222(makeUpdateService22(tag, () => newService))(patch222);
      }
    } else {
      missingServices.delete(tag);
      patch222 = combine2222(makeAddService22(tag, newService))(patch222);
    }
  }
  for (const [tag] of missingServices.entries()) {
    patch222 = combine2222(makeRemoveService22(tag))(patch222);
  }
  return patch222;
};
var combine2222 = /* @__PURE__ */ dual222(2, (self2, that) => makeAndThen22(self2, that));
var patch22 = /* @__PURE__ */ dual222(2, (self2, context) => {
  if (self2._tag === "Empty") {
    return context;
  }
  let wasServiceUpdated = false;
  let patches = of3(self2);
  const updatedContext = new Map(context.unsafeMap);
  while (isNonEmpty22(patches)) {
    const head22 = headNonEmpty3(patches);
    const tail22 = tailNonEmpty3(patches);
    switch (head22._tag) {
      case "Empty": {
        patches = tail22;
        break;
      }
      case "AddService": {
        updatedContext.set(head22.key, head22.service);
        patches = tail22;
        break;
      }
      case "AndThen": {
        patches = prepend3(prepend3(tail22, head22.second), head22.first);
        break;
      }
      case "RemoveService": {
        updatedContext.delete(head22.key);
        patches = tail22;
        break;
      }
      case "UpdateService": {
        updatedContext.set(head22.key, head22.update(updatedContext.get(head22.key)));
        wasServiceUpdated = true;
        patches = tail22;
        break;
      }
    }
  }
  if (!wasServiceUpdated) {
    return makeContext22(updatedContext);
  }
  const map62 = /* @__PURE__ */ new Map();
  for (const [tag] of context.unsafeMap) {
    if (updatedContext.has(tag)) {
      map62.set(tag, updatedContext.get(tag));
      updatedContext.delete(tag);
    }
  }
  for (const [tag, s22] of updatedContext) {
    map62.set(tag, s22);
  }
  return makeContext22(map62);
});
var DifferTypeId22 = /* @__PURE__ */ Symbol.for("effect/Differ");
var DifferProto22 = {
  [DifferTypeId22]: {
    _P: identity222,
    _V: identity222
  }
};
var make722 = (params) => {
  const differ = Object.create(DifferProto22);
  differ.empty = params.empty;
  differ.diff = params.diff;
  differ.combine = params.combine;
  differ.patch = params.patch;
  return differ;
};
var environment22 = () => make722({
  empty: empty722(),
  combine: (first, second) => combine2222(second)(first),
  diff: (oldValue, newValue) => diff22(oldValue, newValue),
  patch: (patch222, oldValue) => patch22(oldValue)(patch222)
});
var OP_DIE22 = "Die";
var OP_EMPTY22 = "Empty";
var OP_FAIL22 = "Fail";
var OP_INTERRUPT22 = "Interrupt";
var OP_PARALLEL22 = "Parallel";
var OP_SEQUENTIAL22 = "Sequential";
var CauseSymbolKey22 = "effect/Cause";
var CauseTypeId22 = /* @__PURE__ */ Symbol.for(CauseSymbolKey22);
var variance222 = {
  /* c8 ignore next */
  _E: (_22) => _22
};
var proto22 = {
  [CauseTypeId22]: variance222,
  [symbol322]() {
    return pipe222(hash222(CauseSymbolKey22), combine222(hash222(flattenCause22(this))), cached222(this));
  },
  [symbol2222](that) {
    return isCause22(that) && causeEquals22(this, that);
  },
  pipe() {
    return pipeArguments222(this, arguments);
  },
  toJSON() {
    switch (this._tag) {
      case "Empty":
        return {
          _id: "Cause",
          _tag: this._tag
        };
      case "Die":
        return {
          _id: "Cause",
          _tag: this._tag,
          defect: toJSON222(this.defect)
        };
      case "Interrupt":
        return {
          _id: "Cause",
          _tag: this._tag,
          fiberId: this.fiberId.toJSON()
        };
      case "Fail":
        return {
          _id: "Cause",
          _tag: this._tag,
          failure: toJSON222(this.error)
        };
      case "Sequential":
      case "Parallel":
        return {
          _id: "Cause",
          _tag: this._tag,
          left: toJSON222(this.left),
          right: toJSON222(this.right)
        };
    }
  },
  toString() {
    return pretty22(this);
  },
  [NodeInspectSymbol222]() {
    return this.toJSON();
  }
};
var fail32 = (error) => {
  const o22 = Object.create(proto22);
  o22._tag = OP_FAIL22;
  o22.error = error;
  return o22;
};
var parallel22 = (left322, right322) => {
  const o22 = Object.create(proto22);
  o22._tag = OP_PARALLEL22;
  o22.left = left322;
  o22.right = right322;
  return o22;
};
var sequential22 = (left322, right322) => {
  const o22 = Object.create(proto22);
  o22._tag = OP_SEQUENTIAL22;
  o22.left = left322;
  o22.right = right322;
  return o22;
};
var isCause22 = (u22) => hasProperty222(u22, CauseTypeId22);
var isInterruptedOnly22 = (self2) => reduceWithContext22(void 0, IsInterruptedOnlyCauseReducer22)(self2);
var causeEquals22 = (left322, right322) => {
  let leftStack = of3(left322);
  let rightStack = of3(right322);
  while (isNonEmpty22(leftStack) && isNonEmpty22(rightStack)) {
    const [leftParallel, leftSequential] = pipe222(headNonEmpty3(leftStack), reduce422([empty622(), empty322()], ([parallel222, sequential222], cause) => {
      const [par, seq] = evaluateCause22(cause);
      return some3222([pipe222(parallel222, union322(par)), pipe222(sequential222, appendAll3(seq))]);
    }));
    const [rightParallel, rightSequential] = pipe222(headNonEmpty3(rightStack), reduce422([empty622(), empty322()], ([parallel222, sequential222], cause) => {
      const [par, seq] = evaluateCause22(cause);
      return some3222([pipe222(parallel222, union322(par)), pipe222(sequential222, appendAll3(seq))]);
    }));
    if (!equals222(leftParallel, rightParallel)) {
      return false;
    }
    leftStack = leftSequential;
    rightStack = rightSequential;
  }
  return true;
};
var flattenCause22 = (cause) => {
  return flattenCauseLoop22(of3(cause), empty322());
};
var flattenCauseLoop22 = (causes, flattened) => {
  while (1) {
    const [parallel222, sequential222] = pipe222(causes, reduce5([empty622(), empty322()], ([parallel32, sequential32], cause) => {
      const [par, seq] = evaluateCause22(cause);
      return [pipe222(parallel32, union322(par)), pipe222(sequential32, appendAll3(seq))];
    }));
    const updated = size322(parallel222) > 0 ? pipe222(flattened, prepend3(parallel222)) : flattened;
    if (isEmpty22(sequential222)) {
      return reverse222(updated);
    }
    causes = sequential222;
    flattened = updated;
  }
  throw new Error(getBugErrorMessage222("Cause.flattenCauseLoop"));
};
var evaluateCause22 = (self2) => {
  let cause = self2;
  const stack = [];
  let _parallel = empty622();
  let _sequential = empty322();
  while (cause !== void 0) {
    switch (cause._tag) {
      case OP_EMPTY22: {
        if (stack.length === 0) {
          return [_parallel, _sequential];
        }
        cause = stack.pop();
        break;
      }
      case OP_FAIL22: {
        _parallel = add322(_parallel, make4222(cause._tag, cause.error));
        if (stack.length === 0) {
          return [_parallel, _sequential];
        }
        cause = stack.pop();
        break;
      }
      case OP_DIE22: {
        _parallel = add322(_parallel, make4222(cause._tag, cause.defect));
        if (stack.length === 0) {
          return [_parallel, _sequential];
        }
        cause = stack.pop();
        break;
      }
      case OP_INTERRUPT22: {
        _parallel = add322(_parallel, make4222(cause._tag, cause.fiberId));
        if (stack.length === 0) {
          return [_parallel, _sequential];
        }
        cause = stack.pop();
        break;
      }
      case OP_SEQUENTIAL22: {
        switch (cause.left._tag) {
          case OP_EMPTY22: {
            cause = cause.right;
            break;
          }
          case OP_SEQUENTIAL22: {
            cause = sequential22(cause.left.left, sequential22(cause.left.right, cause.right));
            break;
          }
          case OP_PARALLEL22: {
            cause = parallel22(sequential22(cause.left.left, cause.right), sequential22(cause.left.right, cause.right));
            break;
          }
          default: {
            _sequential = prepend3(_sequential, cause.right);
            cause = cause.left;
            break;
          }
        }
        break;
      }
      case OP_PARALLEL22: {
        stack.push(cause.right);
        cause = cause.left;
        break;
      }
    }
  }
  throw new Error(getBugErrorMessage222("Cause.evaluateCauseLoop"));
};
var IsInterruptedOnlyCauseReducer22 = {
  emptyCase: constTrue222,
  failCase: constFalse222,
  dieCase: constFalse222,
  interruptCase: constTrue222,
  sequentialCase: (_22, left322, right322) => left322 && right322,
  parallelCase: (_22, left322, right322) => left322 && right322
};
var OP_SEQUENTIAL_CASE22 = "SequentialCase";
var OP_PARALLEL_CASE22 = "ParallelCase";
var reduce422 = /* @__PURE__ */ dual222(3, (self2, zero, pf) => {
  let accumulator = zero;
  let cause = self2;
  const causes = [];
  while (cause !== void 0) {
    const option = pf(accumulator, cause);
    accumulator = isSome2222(option) ? option.value : accumulator;
    switch (cause._tag) {
      case OP_SEQUENTIAL22: {
        causes.push(cause.right);
        cause = cause.left;
        break;
      }
      case OP_PARALLEL22: {
        causes.push(cause.right);
        cause = cause.left;
        break;
      }
      default: {
        cause = void 0;
        break;
      }
    }
    if (cause === void 0 && causes.length > 0) {
      cause = causes.pop();
    }
  }
  return accumulator;
});
var reduceWithContext22 = /* @__PURE__ */ dual222(3, (self2, context, reducer) => {
  const input = [self2];
  const output = [];
  while (input.length > 0) {
    const cause = input.pop();
    switch (cause._tag) {
      case OP_EMPTY22: {
        output.push(right2222(reducer.emptyCase(context)));
        break;
      }
      case OP_FAIL22: {
        output.push(right2222(reducer.failCase(context, cause.error)));
        break;
      }
      case OP_DIE22: {
        output.push(right2222(reducer.dieCase(context, cause.defect)));
        break;
      }
      case OP_INTERRUPT22: {
        output.push(right2222(reducer.interruptCase(context, cause.fiberId)));
        break;
      }
      case OP_SEQUENTIAL22: {
        input.push(cause.right);
        input.push(cause.left);
        output.push(left2222({
          _tag: OP_SEQUENTIAL_CASE22
        }));
        break;
      }
      case OP_PARALLEL22: {
        input.push(cause.right);
        input.push(cause.left);
        output.push(left2222({
          _tag: OP_PARALLEL_CASE22
        }));
        break;
      }
    }
  }
  const accumulator = [];
  while (output.length > 0) {
    const either = output.pop();
    switch (either._tag) {
      case "Left": {
        switch (either.left._tag) {
          case OP_SEQUENTIAL_CASE22: {
            const left322 = accumulator.pop();
            const right322 = accumulator.pop();
            const value = reducer.sequentialCase(context, left322, right322);
            accumulator.push(value);
            break;
          }
          case OP_PARALLEL_CASE22: {
            const left322 = accumulator.pop();
            const right322 = accumulator.pop();
            const value = reducer.parallelCase(context, left322, right322);
            accumulator.push(value);
            break;
          }
        }
        break;
      }
      case "Right": {
        accumulator.push(either.right);
        break;
      }
    }
  }
  if (accumulator.length === 0) {
    throw new Error("BUG: Cause.reduceWithContext - please report an issue at https://github.com/Effect-TS/effect/issues");
  }
  return accumulator.pop();
});
var pretty22 = (cause) => {
  if (isInterruptedOnly22(cause)) {
    return "All fibers interrupted without errors.";
  }
  return prettyErrors22(cause).map((e22) => e22.stack).join("\n");
};
var PrettyError22 = class extends globalThis.Error {
  span = void 0;
  constructor(originalError) {
    const prevLimit = Error.stackTraceLimit;
    Error.stackTraceLimit = 0;
    super(prettyErrorMessage22(originalError));
    Error.stackTraceLimit = prevLimit;
    this.name = originalError instanceof Error ? originalError.name : "Error";
    if (typeof originalError === "object" && originalError !== null) {
      if (spanSymbol32 in originalError) {
        this.span = originalError[spanSymbol32];
      }
      Object.keys(originalError).forEach((key) => {
        if (!(key in this)) {
          this[key] = originalError[key];
        }
      });
    }
    this.stack = prettyErrorStack22(this.message, originalError instanceof Error && originalError.stack ? originalError.stack : "", this.span);
  }
  toJSON() {
    const out = {
      message: this.message,
      stack: this.stack
    };
    if (this.span) {
      out.span = this.span;
    }
    return out;
  }
};
var prettyErrorMessage22 = (u22) => {
  if (typeof u22 === "string") {
    return `Error: ${u22}`;
  }
  try {
    if (hasProperty222(u22, "toString") && isFunction322(u22["toString"]) && u22["toString"] !== Object.prototype.toString && u22["toString"] !== globalThis.Array.prototype.toString) {
      return u22["toString"]();
    }
  } catch {
  }
  return `Error: ${JSON.stringify(u22)}`;
};
var locationRegex22 = /\((.*)\)/;
var spanToTrace22 = /* @__PURE__ */ globalValue222("effect/Tracer/spanToTrace", () => /* @__PURE__ */ new WeakMap());
var prettyErrorStack22 = (message, stack, span2) => {
  const out = [message];
  const lines = stack.split("\n");
  for (let i22 = 1; i22 < lines.length; i22++) {
    if (lines[i22].includes("Generator.next")) {
      break;
    }
    if (lines[i22].includes("effect_internal_function")) {
      out.pop();
      break;
    }
    out.push(lines[i22].replace(/at .*effect_instruction_i.*\((.*)\)/, "at $1").replace(/EffectPrimitive\.\w+/, "<anonymous>"));
  }
  if (span2) {
    let current = span2;
    let i22 = 0;
    while (current && current._tag === "Span" && i22 < 10) {
      const stackFn = spanToTrace22.get(current);
      if (typeof stackFn === "function") {
        const stack2 = stackFn();
        const locationMatch = stack2.match(locationRegex22);
        const location = locationMatch ? locationMatch[1] : stack2.replace(/^at /, "");
        out.push(`    at ${current.name} (${location})`);
      } else {
        out.push(`    at ${current.name}`);
      }
      current = getOrUndefined222(current.parent);
      i22++;
    }
  }
  return out.join("\n");
};
var spanSymbol32 = /* @__PURE__ */ Symbol.for("effect/SpanAnnotation");
var prettyErrors22 = (cause) => reduceWithContext22(cause, void 0, {
  emptyCase: () => [],
  dieCase: (_22, unknownError) => {
    return [new PrettyError22(unknownError)];
  },
  failCase: (_22, error) => {
    return [new PrettyError22(error)];
  },
  interruptCase: () => [],
  parallelCase: (_22, l22, r22) => [...l22, ...r22],
  sequentialCase: (_22, l22, r22) => [...l22, ...r22]
});
var SingleShotGen2222 = class _SingleShotGen222 {
  self;
  called = false;
  constructor(self2) {
    this.self = self2;
  }
  next(a22) {
    return this.called ? {
      value: a22,
      done: true
    } : (this.called = true, {
      value: this.self,
      done: false
    });
  }
  return(a22) {
    return {
      value: a22,
      done: true
    };
  }
  throw(e22) {
    throw e22;
  }
  [Symbol.iterator]() {
    return new _SingleShotGen222(this.self);
  }
};
var spanTag22 = /* @__PURE__ */ GenericTag22("effect/ParentSpan");
var EffectTypeId2222 = /* @__PURE__ */ Symbol.for("effect/Effect");
var EffectPrimitive22 = class {
  _op;
  effect_instruction_i0 = void 0;
  effect_instruction_i1 = void 0;
  effect_instruction_i2 = void 0;
  trace = void 0;
  [EffectTypeId2222] = effectVariance222;
  constructor(_op) {
    this._op = _op;
  }
  [symbol2222](that) {
    return this === that;
  }
  [symbol322]() {
    return cached222(this, random222(this));
  }
  pipe() {
    return pipeArguments222(this, arguments);
  }
  toJSON() {
    return {
      _id: "Effect",
      _op: this._op,
      effect_instruction_i0: toJSON222(this.effect_instruction_i0),
      effect_instruction_i1: toJSON222(this.effect_instruction_i1),
      effect_instruction_i2: toJSON222(this.effect_instruction_i2)
    };
  }
  toString() {
    return format222(this.toJSON());
  }
  [NodeInspectSymbol222]() {
    return this.toJSON();
  }
  [Symbol.iterator]() {
    return new SingleShotGen2222(new YieldWrap222(this));
  }
};
var EffectPrimitiveFailure22 = class {
  _op;
  effect_instruction_i0 = void 0;
  effect_instruction_i1 = void 0;
  effect_instruction_i2 = void 0;
  trace = void 0;
  [EffectTypeId2222] = effectVariance222;
  constructor(_op) {
    this._op = _op;
    this._tag = _op;
  }
  [symbol2222](that) {
    return exitIsExit22(that) && that._op === "Failure" && // @ts-expect-error
    equals222(this.effect_instruction_i0, that.effect_instruction_i0);
  }
  [symbol322]() {
    return pipe222(
      // @ts-expect-error
      string222(this._tag),
      // @ts-expect-error
      combine222(hash222(this.effect_instruction_i0)),
      cached222(this)
    );
  }
  get cause() {
    return this.effect_instruction_i0;
  }
  pipe() {
    return pipeArguments222(this, arguments);
  }
  toJSON() {
    return {
      _id: "Exit",
      _tag: this._op,
      cause: this.cause.toJSON()
    };
  }
  toString() {
    return format222(this.toJSON());
  }
  [NodeInspectSymbol222]() {
    return this.toJSON();
  }
  [Symbol.iterator]() {
    return new SingleShotGen2222(new YieldWrap222(this));
  }
};
var isEffect22 = (u22) => hasProperty222(u22, EffectTypeId2222);
var withFiberRuntime22 = (withRuntime) => {
  const effect = new EffectPrimitive22(OP_WITH_RUNTIME22);
  effect.effect_instruction_i0 = withRuntime;
  return effect;
};
var spanSymbol222 = /* @__PURE__ */ Symbol.for("effect/SpanAnnotation");
var originalSymbol22 = /* @__PURE__ */ Symbol.for("effect/OriginalAnnotation");
var capture22 = (obj, span2) => {
  if (isSome2222(span2)) {
    return new Proxy(obj, {
      has(target, p22) {
        return p22 === spanSymbol222 || p22 === originalSymbol22 || p22 in target;
      },
      get(target, p22) {
        if (p22 === spanSymbol222) {
          return span2.value;
        }
        if (p22 === originalSymbol22) {
          return obj;
        }
        return target[p22];
      }
    });
  }
  return obj;
};
var fail222 = (error) => isObject222(error) && !(spanSymbol222 in error) ? withFiberRuntime22((fiber) => failCause22(fail32(capture22(error, currentSpanFromFiber22(fiber))))) : failCause22(fail32(error));
var failCause22 = (cause) => {
  const effect = new EffectPrimitiveFailure22(OP_FAILURE22);
  effect.effect_instruction_i0 = cause;
  return effect;
};
var FiberRefSymbolKey22 = "effect/FiberRef";
var FiberRefTypeId22 = /* @__PURE__ */ Symbol.for(FiberRefSymbolKey22);
var fiberRefVariance22 = {
  /* c8 ignore next */
  _A: (_22) => _22
};
var fiberRefUnsafeMakeContext22 = (initial) => {
  const differ = environment22();
  return fiberRefUnsafeMakePatch22(initial, {
    differ,
    fork: differ.empty
  });
};
var fiberRefUnsafeMakePatch22 = (initial, options) => ({
  [FiberRefTypeId22]: fiberRefVariance22,
  initial,
  diff: (oldValue, newValue) => options.differ.diff(oldValue, newValue),
  combine: (first, second) => options.differ.combine(first, second),
  patch: (patch222) => (oldValue) => options.differ.patch(patch222, oldValue),
  fork: options.fork,
  join: options.join ?? ((_22, n22) => n22),
  pipe() {
    return pipeArguments222(this, arguments);
  }
});
var currentContext22 = /* @__PURE__ */ globalValue222(/* @__PURE__ */ Symbol.for("effect/FiberRef/currentContext"), () => fiberRefUnsafeMakeContext22(empty222()));
var YieldableError22 = /* @__PURE__ */ function() {
  class YieldableError222 extends globalThis.Error {
    commit() {
      return fail222(this);
    }
    toString() {
      return this.message ? `${this.name}: ${this.message}` : this.name;
    }
    toJSON() {
      return {
        ...this
      };
    }
    [NodeInspectSymbol222]() {
      const stack = this.stack;
      if (stack) {
        return `${this.toString()}
${stack.split("\n").slice(1).join("\n")}`;
      }
      return this.toString();
    }
  }
  Object.assign(YieldableError222.prototype, StructuralCommitPrototype22);
  return YieldableError222;
}();
var exitIsExit22 = (u22) => isEffect22(u22) && "_tag" in u22 && (u22._tag === "Success" || u22._tag === "Failure");
var currentSpanFromFiber22 = (fiber) => {
  const span2 = fiber.getFiberRef(currentContext22).unsafeMap.get(spanTag22.key);
  return span2 !== void 0 && span2._tag === "Span" ? some3222(span2) : none2222();
};
var Data_exports22 = {};
__export222(Data_exports22, {
  Class: () => Class222,
  Error: () => Error222,
  Structural: () => Structural222,
  TaggedClass: () => TaggedClass22,
  TaggedError: () => TaggedError22,
  array: () => array222,
  case: () => _case22,
  struct: () => struct322,
  tagged: () => tagged22,
  taggedEnum: () => taggedEnum22,
  tuple: () => tuple222,
  unsafeArray: () => unsafeArray22,
  unsafeStruct: () => unsafeStruct22
});
var struct322 = struct222;
var unsafeStruct22 = (as2222) => Object.setPrototypeOf(as2222, StructuralPrototype22);
var tuple222 = (...as2222) => unsafeArray22(as2222);
var array222 = (as2222) => unsafeArray22(as2222.slice(0));
var unsafeArray22 = (as2222) => Object.setPrototypeOf(as2222, ArrayProto22);
var _case22 = () => (args) => args === void 0 ? Object.create(StructuralPrototype22) : struct322(args);
var tagged22 = (tag) => (args) => {
  const value = args === void 0 ? Object.create(StructuralPrototype22) : struct322(args);
  value._tag = tag;
  return value;
};
var Class222 = Structural32;
var TaggedClass22 = (tag) => {
  class Base extends Class222 {
    _tag = tag;
  }
  return Base;
};
var Structural222 = Structural32;
var taggedEnum22 = () => new Proxy({}, {
  get(_target, tag, _receiver) {
    if (tag === "$is") {
      return isTagged3;
    } else if (tag === "$match") {
      return taggedMatch22;
    }
    return tagged22(tag);
  }
});
function taggedMatch22() {
  if (arguments.length === 1) {
    const cases2 = arguments[0];
    return function(value2) {
      return cases2[value2._tag](value2);
    };
  }
  const value = arguments[0];
  const cases = arguments[1];
  return cases[value._tag](value);
}
var Error222 = /* @__PURE__ */ function() {
  return class Base extends YieldableError22 {
    constructor(args) {
      super();
      if (args) {
        Object.assign(this, args);
      }
    }
  };
}();
var TaggedError22 = (tag) => {
  class Base extends Error222 {
    _tag = tag;
  }
  Base.prototype.name = tag;
  return Base;
};
var traverseUp22 = Function_exports222.dual(2, (node, predicate) => {
  const { parent } = node;
  if (!parent || parent.type === NodeType22.Program) return Option_exports222.none();
  return predicate(parent) ? Option_exports222.some(parent) : traverseUp22(parent, predicate);
});
var traverseUpGuard22 = Function_exports222.dual(2, (node, predicate) => {
  const { parent } = node;
  if (!parent || parent.type === NodeType22.Program) return Option_exports222.none();
  return predicate(parent) ? Option_exports222.some(parent) : traverseUpGuard22(parent, predicate);
});
var ESLintCommunityESLintUtils22;
((ESLintCommunityESLintUtils222) => {
  ESLintCommunityESLintUtils222.getFunctionHeadLocation = getFunctionHeadLocation22;
  ESLintCommunityESLintUtils222.getFunctionNameWithKind = getFunctionNameWithKind22;
  ESLintCommunityESLintUtils222.getPropertyName = getPropertyName22;
  ESLintCommunityESLintUtils222.getStaticValue = getStaticValue22;
  ESLintCommunityESLintUtils222.getStringIfConstant = getStringIfConstant22;
  ESLintCommunityESLintUtils222.hasSideEffect = hasSideEffect22;
  ESLintCommunityESLintUtils222.isParenthesized = isParenthesized22;
})(ESLintCommunityESLintUtils22 || (ESLintCommunityESLintUtils22 = {}));
var Construction22 = Data_exports22.taggedEnum();
Construction22.None();
a({
  type: N.union([NodeType22.FunctionExpression, NodeType22.ArrowFunctionExpression]),
  parent: {
    type: NodeType22.Property,
    parent: {
      type: NodeType22.ObjectExpression
    }
  }
});
a({
  type: N.union([NodeType22.FunctionExpression, NodeType22.ArrowFunctionExpression]),
  parent: {
    type: NodeType22.MethodDefinition,
    parent: {
      type: NodeType22.ClassBody
    }
  }
});
a({
  type: N.union([NodeType22.FunctionExpression, NodeType22.ArrowFunctionExpression]),
  parent: {
    type: NodeType22.Property,
    parent: {
      type: NodeType22.ClassBody
    }
  }
});
function getVariableInit(at) {
  return (variable) => {
    return Function_exports3.pipe(
      Option_exports3.some(variable),
      Option_exports3.flatMapNullable((v22) => v22.defs.at(at)),
      Option_exports3.flatMap(
        (d22) => "init" in d22.node ? Option_exports3.fromNullable(d22.node.init) : Option_exports3.none()
      )
    );
  };
}
isOneOf2([NodeType2.Literal, NodeType2.JSXText]);
var JSXValueHint = {
  None: 0n,
  SkipNullLiteral: 1n << 0n,
  SkipUndefinedLiteral: 1n << 1n,
  SkipBooleanLiteral: 1n << 2n,
  SkipStringLiteral: 1n << 3n,
  SkipNumberLiteral: 1n << 4n,
  SkipCreateElement: 1n << 5n,
  StrictArray: 1n << 6n,
  StrictLogical: 1n << 7n,
  StrictConditional: 1n << 8n
};
var DEFAULT_JSX_VALUE_HINT = JSXValueHint.SkipUndefinedLiteral | JSXValueHint.SkipBooleanLiteral;
function isJSXValue(node, context, hint = DEFAULT_JSX_VALUE_HINT) {
  if (!node) return false;
  return tsPattern.match(node).with({ type: NodeType2.JSXElement }, Function_exports22.constTrue).with({ type: NodeType2.JSXFragment }, Function_exports22.constTrue).with({ type: NodeType2.JSXMemberExpression }, Function_exports22.constTrue).with({ type: NodeType2.JSXNamespacedName }, Function_exports22.constTrue).with({ type: NodeType2.Literal }, (node2) => {
    return tsPattern.match(node2.value).with(null, () => !(hint & JSXValueHint.SkipNullLiteral)).with(tsPattern.P.boolean, () => !(hint & JSXValueHint.SkipBooleanLiteral)).with(tsPattern.P.string, () => !(hint & JSXValueHint.SkipStringLiteral)).with(tsPattern.P.number, () => !(hint & JSXValueHint.SkipNumberLiteral)).otherwise(Function_exports22.constFalse);
  }).with({ type: NodeType2.TemplateLiteral }, () => !(hint & JSXValueHint.SkipStringLiteral)).with({ type: NodeType2.ArrayExpression }, (node2) => {
    if (hint & JSXValueHint.StrictArray) return node2.elements.every((n22) => isJSXValue(n22, context, hint));
    return node2.elements.some((n22) => isJSXValue(n22, context, hint));
  }).with({ type: NodeType2.ConditionalExpression }, (node2) => {
    function leftHasJSX(node3) {
      if (Array.isArray(node3.consequent)) {
        if (hint & JSXValueHint.StrictArray) {
          return node3.consequent.every((n22) => isJSXValue(n22, context, hint));
        }
        return node3.consequent.some((n22) => isJSXValue(n22, context, hint));
      }
      return isJSXValue(node3.consequent, context, hint);
    }
    function rightHasJSX(node3) {
      return isJSXValue(node3.alternate, context, hint);
    }
    if (hint & JSXValueHint.StrictConditional) {
      return leftHasJSX(node2) && rightHasJSX(node2);
    }
    return leftHasJSX(node2) || rightHasJSX(node2);
  }).with({ type: NodeType2.LogicalExpression }, (node2) => {
    return isJSXValue(node2.left, context, hint) || isJSXValue(node2.right, context, hint);
  }).with({ type: NodeType2.SequenceExpression }, (node2) => {
    const exp = node2.expressions.at(-1);
    return isJSXValue(exp, context, hint);
  }).with({ type: NodeType2.CallExpression }, (node2) => {
    if (hint & JSXValueHint.SkipCreateElement) return false;
    return tsPattern.match(node2.callee).with({ type: NodeType2.Identifier, name: "createElement" }, Function_exports22.constTrue).with({ type: NodeType2.MemberExpression, property: { name: "createElement" } }, Function_exports22.constTrue).otherwise(Function_exports22.constFalse);
  }).with({ type: NodeType2.Identifier }, (node2) => {
    const { name } = node2;
    if (name === "undefined") return !(hint & JSXValueHint.SkipUndefinedLiteral);
    if (isJSXTagNameExpression2(node2)) return true;
    const initialScope = context.sourceCode.getScope(node2);
    const maybeVariable = findVariable22(name, initialScope);
    return Function_exports22.pipe(
      maybeVariable,
      Option_exports22.flatMap(getVariableInit(0)),
      Option_exports22.exists((n22) => isJSXValue(n22, context, hint))
    );
  }).otherwise(Function_exports22.constFalse);
}

// ../../node_modules/.pnpm/effect@3.2.8/node_modules/effect/dist/esm/Function.js
var Function_exports4 = {};
__export(Function_exports4, {
  SK: () => SK4,
  absurd: () => absurd4,
  apply: () => apply4,
  compose: () => compose6,
  constFalse: () => constFalse4,
  constNull: () => constNull4,
  constTrue: () => constTrue4,
  constUndefined: () => constUndefined4,
  constVoid: () => constVoid4,
  constant: () => constant4,
  dual: () => dual4,
  flip: () => flip4,
  flow: () => flow4,
  hole: () => hole4,
  identity: () => identity4,
  isFunction: () => isFunction7,
  pipe: () => pipe4,
  satisfies: () => satisfies4,
  tupled: () => tupled4,
  unsafeCoerce: () => unsafeCoerce4,
  untupled: () => untupled4
});
var isFunction7 = (input) => typeof input === "function";
var dual4 = function(arity, body) {
  if (typeof arity === "function") {
    return function() {
      if (arity(arguments)) {
        return body.apply(this, arguments);
      }
      return (self2) => body(self2, ...arguments);
    };
  }
  switch (arity) {
    case 0:
    case 1:
      throw new RangeError(`Invalid arity ${arity}`);
    case 2:
      return function(a3, b3) {
        if (arguments.length >= 2) {
          return body(a3, b3);
        }
        return function(self2) {
          return body(self2, a3);
        };
      };
    case 3:
      return function(a3, b3, c3) {
        if (arguments.length >= 3) {
          return body(a3, b3, c3);
        }
        return function(self2) {
          return body(self2, a3, b3);
        };
      };
    case 4:
      return function(a3, b3, c3, d3) {
        if (arguments.length >= 4) {
          return body(a3, b3, c3, d3);
        }
        return function(self2) {
          return body(self2, a3, b3, c3);
        };
      };
    case 5:
      return function(a3, b3, c3, d3, e3) {
        if (arguments.length >= 5) {
          return body(a3, b3, c3, d3, e3);
        }
        return function(self2) {
          return body(self2, a3, b3, c3, d3);
        };
      };
    default:
      return function() {
        if (arguments.length >= arity) {
          return body.apply(this, arguments);
        }
        const args = arguments;
        return function(self2) {
          return body(self2, ...args);
        };
      };
  }
};
var apply4 = (a3) => (self2) => self2(a3);
var identity4 = (a3) => a3;
var satisfies4 = () => (b3) => b3;
var unsafeCoerce4 = identity4;
var constant4 = (value) => () => value;
var constTrue4 = /* @__PURE__ */ constant4(true);
var constFalse4 = /* @__PURE__ */ constant4(false);
var constNull4 = /* @__PURE__ */ constant4(null);
var constUndefined4 = /* @__PURE__ */ constant4(void 0);
var constVoid4 = constUndefined4;
var flip4 = (f3) => (...b3) => (...a3) => f3(...a3)(...b3);
var compose6 = /* @__PURE__ */ dual4(2, (ab, bc) => (a3) => bc(ab(a3)));
var absurd4 = (_3) => {
  throw new Error("Called `absurd` function which should be uncallable");
};
var tupled4 = (f3) => (a3) => f3(...a3);
var untupled4 = (f3) => (...a3) => f3(a3);
function pipe4(a3, ab, bc, cd, de, ef, fg, gh, hi) {
  switch (arguments.length) {
    case 1:
      return a3;
    case 2:
      return ab(a3);
    case 3:
      return bc(ab(a3));
    case 4:
      return cd(bc(ab(a3)));
    case 5:
      return de(cd(bc(ab(a3))));
    case 6:
      return ef(de(cd(bc(ab(a3)))));
    case 7:
      return fg(ef(de(cd(bc(ab(a3))))));
    case 8:
      return gh(fg(ef(de(cd(bc(ab(a3)))))));
    case 9:
      return hi(gh(fg(ef(de(cd(bc(ab(a3))))))));
    default: {
      let ret = arguments[0];
      for (let i3 = 1; i3 < arguments.length; i3++) {
        ret = arguments[i3](ret);
      }
      return ret;
    }
  }
}
function flow4(ab, bc, cd, de, ef, fg, gh, hi, ij) {
  switch (arguments.length) {
    case 1:
      return ab;
    case 2:
      return function() {
        return bc(ab.apply(this, arguments));
      };
    case 3:
      return function() {
        return cd(bc(ab.apply(this, arguments)));
      };
    case 4:
      return function() {
        return de(cd(bc(ab.apply(this, arguments))));
      };
    case 5:
      return function() {
        return ef(de(cd(bc(ab.apply(this, arguments)))));
      };
    case 6:
      return function() {
        return fg(ef(de(cd(bc(ab.apply(this, arguments))))));
      };
    case 7:
      return function() {
        return gh(fg(ef(de(cd(bc(ab.apply(this, arguments)))))));
      };
    case 8:
      return function() {
        return hi(gh(fg(ef(de(cd(bc(ab.apply(this, arguments))))))));
      };
    case 9:
      return function() {
        return ij(hi(gh(fg(ef(de(cd(bc(ab.apply(this, arguments)))))))));
      };
  }
  return;
}
var hole4 = /* @__PURE__ */ unsafeCoerce4(absurd4);
var SK4 = (_3, b3) => b3;

// ../../node_modules/.pnpm/effect@3.2.8/node_modules/effect/dist/esm/Equivalence.js
var make12 = (isEquivalent) => (self2, that) => self2 === that || isEquivalent(self2, that);

// ../../node_modules/.pnpm/effect@3.2.8/node_modules/effect/dist/esm/internal/doNotation.js
var let_7 = (map7) => dual4(3, (self2, name, f3) => map7(self2, (a3) => Object.assign({}, a3, {
  [name]: f3(a3)
})));
var bindTo7 = (map7) => dual4(2, (self2, name) => map7(self2, (a3) => ({
  [name]: a3
})));
var bind7 = (map7, flatMap7) => dual4(3, (self2, name, f3) => flatMap7(self2, (a3) => map7(f3(a3), (b3) => Object.assign({}, a3, {
  [name]: b3
}))));

// ../../node_modules/.pnpm/effect@3.2.8/node_modules/effect/dist/esm/internal/version.js
var moduleVersion4 = "3.2.8";
var getCurrentVersion4 = () => moduleVersion4;

// ../../node_modules/.pnpm/effect@3.2.8/node_modules/effect/dist/esm/GlobalValue.js
var globalStoreId4 = /* @__PURE__ */ Symbol.for(`effect/GlobalValue/globalStoreId/${/* @__PURE__ */ getCurrentVersion4()}`);
if (!(globalStoreId4 in globalThis)) {
  globalThis[globalStoreId4] = /* @__PURE__ */ new Map();
}
var globalStore4 = globalThis[globalStoreId4];
var globalValue4 = (id, compute) => {
  if (!globalStore4.has(id)) {
    globalStore4.set(id, compute());
  }
  return globalStore4.get(id);
};

// ../../node_modules/.pnpm/effect@3.2.8/node_modules/effect/dist/esm/Predicate.js
var Predicate_exports3 = {};
__export(Predicate_exports3, {
  all: () => all6,
  and: () => and4,
  compose: () => compose7,
  eqv: () => eqv4,
  every: () => every5,
  hasProperty: () => hasProperty4,
  implies: () => implies4,
  isBigInt: () => isBigInt4,
  isBoolean: () => isBoolean4,
  isDate: () => isDate4,
  isError: () => isError4,
  isFunction: () => isFunction8,
  isIterable: () => isIterable4,
  isMap: () => isMap4,
  isNever: () => isNever4,
  isNotNull: () => isNotNull4,
  isNotNullable: () => isNotNullable4,
  isNotUndefined: () => isNotUndefined4,
  isNull: () => isNull4,
  isNullable: () => isNullable4,
  isNumber: () => isNumber4,
  isObject: () => isObject4,
  isPromise: () => isPromise4,
  isPromiseLike: () => isPromiseLike4,
  isReadonlyRecord: () => isReadonlyRecord4,
  isRecord: () => isRecord4,
  isSet: () => isSet4,
  isString: () => isString4,
  isSymbol: () => isSymbol4,
  isTagged: () => isTagged4,
  isTruthy: () => isTruthy4,
  isUint8Array: () => isUint8Array4,
  isUndefined: () => isUndefined4,
  isUnknown: () => isUnknown4,
  mapInput: () => mapInput5,
  nand: () => nand4,
  nor: () => nor4,
  not: () => not4,
  or: () => or4,
  product: () => product6,
  productMany: () => productMany6,
  some: () => some9,
  struct: () => struct6,
  tuple: () => tuple5,
  xor: () => xor4
});
var mapInput5 = /* @__PURE__ */ dual4(2, (self2, f3) => (b3) => self2(f3(b3)));
var isTruthy4 = (input) => !!input;
var isSet4 = (input) => input instanceof Set;
var isMap4 = (input) => input instanceof Map;
var isString4 = (input) => typeof input === "string";
var isNumber4 = (input) => typeof input === "number";
var isBoolean4 = (input) => typeof input === "boolean";
var isBigInt4 = (input) => typeof input === "bigint";
var isSymbol4 = (input) => typeof input === "symbol";
var isFunction8 = isFunction7;
var isUndefined4 = (input) => input === void 0;
var isNotUndefined4 = (input) => input !== void 0;
var isNull4 = (input) => input === null;
var isNotNull4 = (input) => input !== null;
var isNever4 = (_3) => false;
var isUnknown4 = (_3) => true;
var isRecordOrArray4 = (input) => typeof input === "object" && input !== null;
var isObject4 = (input) => isRecordOrArray4(input) || isFunction8(input);
var hasProperty4 = /* @__PURE__ */ dual4(2, (self2, property) => isObject4(self2) && property in self2);
var isTagged4 = /* @__PURE__ */ dual4(2, (self2, tag) => hasProperty4(self2, "_tag") && self2["_tag"] === tag);
var isNullable4 = (input) => input === null || input === void 0;
var isNotNullable4 = (input) => input !== null && input !== void 0;
var isError4 = (input) => input instanceof Error;
var isUint8Array4 = (input) => input instanceof Uint8Array;
var isDate4 = (input) => input instanceof Date;
var isIterable4 = (input) => hasProperty4(input, Symbol.iterator);
var isRecord4 = (input) => isRecordOrArray4(input) && !Array.isArray(input);
var isReadonlyRecord4 = isRecord4;
var isPromise4 = (input) => hasProperty4(input, "then") && "catch" in input && isFunction8(input.then) && isFunction8(input.catch);
var isPromiseLike4 = (input) => hasProperty4(input, "then") && isFunction8(input.then);
var compose7 = /* @__PURE__ */ dual4(2, (ab, bc) => (a3) => ab(a3) && bc(a3));
var product6 = (self2, that) => ([a3, b3]) => self2(a3) && that(b3);
var all6 = (collection) => {
  return (as6) => {
    let collectionIndex = 0;
    for (const p3 of collection) {
      if (collectionIndex >= as6.length) {
        break;
      }
      if (p3(as6[collectionIndex]) === false) {
        return false;
      }
      collectionIndex++;
    }
    return true;
  };
};
var productMany6 = (self2, collection) => {
  const rest = all6(collection);
  return ([head3, ...tail3]) => self2(head3) === false ? false : rest(tail3);
};
var tuple5 = (...elements) => all6(elements);
var struct6 = (fields) => {
  const keys5 = Object.keys(fields);
  return (a3) => {
    for (const key of keys5) {
      if (!fields[key](a3[key])) {
        return false;
      }
    }
    return true;
  };
};
var not4 = (self2) => (a3) => !self2(a3);
var or4 = /* @__PURE__ */ dual4(2, (self2, that) => (a3) => self2(a3) || that(a3));
var and4 = /* @__PURE__ */ dual4(2, (self2, that) => (a3) => self2(a3) && that(a3));
var xor4 = /* @__PURE__ */ dual4(2, (self2, that) => (a3) => self2(a3) !== that(a3));
var eqv4 = /* @__PURE__ */ dual4(2, (self2, that) => (a3) => self2(a3) === that(a3));
var implies4 = /* @__PURE__ */ dual4(2, (self2, that) => (a3) => self2(a3) ? that(a3) : true);
var nor4 = /* @__PURE__ */ dual4(2, (self2, that) => (a3) => !(self2(a3) || that(a3)));
var nand4 = /* @__PURE__ */ dual4(2, (self2, that) => (a3) => !(self2(a3) && that(a3)));
var every5 = (collection) => (a3) => {
  for (const p3 of collection) {
    if (!p3(a3)) {
      return false;
    }
  }
  return true;
};
var some9 = (collection) => (a3) => {
  for (const p3 of collection) {
    if (p3(a3)) {
      return true;
    }
  }
  return false;
};

// ../../node_modules/.pnpm/effect@3.2.8/node_modules/effect/dist/esm/internal/errors.js
var getBugErrorMessage4 = (message) => `BUG: ${message} - please report an issue at https://github.com/Effect-TS/effect/issues`;

// ../../node_modules/.pnpm/effect@3.2.8/node_modules/effect/dist/esm/Utils.js
var GenKindTypeId4 = /* @__PURE__ */ Symbol.for("effect/Gen/GenKind");
var isGenKind4 = (u3) => isObject4(u3) && GenKindTypeId4 in u3;
var GenKindImpl4 = class {
  value;
  constructor(value) {
    this.value = value;
  }
  /**
   * @since 2.0.0
   */
  get _F() {
    return identity4;
  }
  /**
   * @since 2.0.0
   */
  get _R() {
    return (_3) => _3;
  }
  /**
   * @since 2.0.0
   */
  get _O() {
    return (_3) => _3;
  }
  /**
   * @since 2.0.0
   */
  get _E() {
    return (_3) => _3;
  }
  /**
   * @since 2.0.0
   */
  [GenKindTypeId4] = GenKindTypeId4;
  /**
   * @since 2.0.0
   */
  [Symbol.iterator]() {
    return new SingleShotGen5(this);
  }
};
var SingleShotGen5 = class _SingleShotGen7 {
  self;
  called = false;
  constructor(self2) {
    this.self = self2;
  }
  /**
   * @since 2.0.0
   */
  next(a3) {
    return this.called ? {
      value: a3,
      done: true
    } : (this.called = true, {
      value: this.self,
      done: false
    });
  }
  /**
   * @since 2.0.0
   */
  return(a3) {
    return {
      value: a3,
      done: true
    };
  }
  /**
   * @since 2.0.0
   */
  throw(e3) {
    throw e3;
  }
  /**
   * @since 2.0.0
   */
  [Symbol.iterator]() {
    return new _SingleShotGen7(this.self);
  }
};
var adapter6 = () => function() {
  let x3 = arguments[0];
  for (let i3 = 1; i3 < arguments.length; i3++) {
    x3 = arguments[i3](x3);
  }
  return new GenKindImpl4(x3);
};
var defaultIncHi4 = 335903614;
var defaultIncLo4 = 4150755663;
var MUL_HI4 = 1481765933 >>> 0;
var MUL_LO4 = 1284865837 >>> 0;
var BIT_534 = 9007199254740992;
var BIT_274 = 134217728;
var PCGRandom4 = class {
  _state;
  constructor(seedHi, seedLo, incHi, incLo) {
    if (isNullable4(seedLo) && isNullable4(seedHi)) {
      seedLo = Math.random() * 4294967295 >>> 0;
      seedHi = 0;
    } else if (isNullable4(seedLo)) {
      seedLo = seedHi;
      seedHi = 0;
    }
    if (isNullable4(incLo) && isNullable4(incHi)) {
      incLo = this._state ? this._state[3] : defaultIncLo4;
      incHi = this._state ? this._state[2] : defaultIncHi4;
    } else if (isNullable4(incLo)) {
      incLo = incHi;
      incHi = 0;
    }
    this._state = new Int32Array([0, 0, incHi >>> 0, ((incLo || 0) | 1) >>> 0]);
    this._next();
    add644(this._state, this._state[0], this._state[1], seedHi >>> 0, seedLo >>> 0);
    this._next();
    return this;
  }
  /**
   * Returns a copy of the internal state of this random number generator as a
   * JavaScript Array.
   *
   * @category getters
   * @since 2.0.0
   */
  getState() {
    return [this._state[0], this._state[1], this._state[2], this._state[3]];
  }
  /**
   * Restore state previously retrieved using `getState()`.
   *
   * @since 2.0.0
   */
  setState(state) {
    this._state[0] = state[0];
    this._state[1] = state[1];
    this._state[2] = state[2];
    this._state[3] = state[3] | 1;
  }
  /**
   * Get a uniformly distributed 32 bit integer between [0, max).
   *
   * @category getter
   * @since 2.0.0
   */
  integer(max3) {
    if (!max3) {
      return this._next();
    }
    max3 = max3 >>> 0;
    if ((max3 & max3 - 1) === 0) {
      return this._next() & max3 - 1;
    }
    let num = 0;
    const skew = (-max3 >>> 0) % max3 >>> 0;
    for (num = this._next(); num < skew; num = this._next()) {
    }
    return num % max3;
  }
  /**
   * Get a uniformly distributed IEEE-754 double between 0.0 and 1.0, with
   * 53 bits of precision (every bit of the mantissa is randomized).
   *
   * @category getters
   * @since 2.0.0
   */
  number() {
    const hi = (this._next() & 67108863) * 1;
    const lo = (this._next() & 134217727) * 1;
    return (hi * BIT_274 + lo) / BIT_534;
  }
  /** @internal */
  _next() {
    const oldHi = this._state[0] >>> 0;
    const oldLo = this._state[1] >>> 0;
    mul644(this._state, oldHi, oldLo, MUL_HI4, MUL_LO4);
    add644(this._state, this._state[0], this._state[1], this._state[2], this._state[3]);
    let xsHi = oldHi >>> 18;
    let xsLo = (oldLo >>> 18 | oldHi << 14) >>> 0;
    xsHi = (xsHi ^ oldHi) >>> 0;
    xsLo = (xsLo ^ oldLo) >>> 0;
    const xorshifted = (xsLo >>> 27 | xsHi << 5) >>> 0;
    const rot = oldHi >>> 27;
    const rot2 = (-rot >>> 0 & 31) >>> 0;
    return (xorshifted >>> rot | xorshifted << rot2) >>> 0;
  }
};
function mul644(out, aHi, aLo, bHi, bLo) {
  let c1 = (aLo >>> 16) * (bLo & 65535) >>> 0;
  let c0 = (aLo & 65535) * (bLo >>> 16) >>> 0;
  let lo = (aLo & 65535) * (bLo & 65535) >>> 0;
  let hi = (aLo >>> 16) * (bLo >>> 16) + ((c0 >>> 16) + (c1 >>> 16)) >>> 0;
  c0 = c0 << 16 >>> 0;
  lo = lo + c0 >>> 0;
  if (lo >>> 0 < c0 >>> 0) {
    hi = hi + 1 >>> 0;
  }
  c1 = c1 << 16 >>> 0;
  lo = lo + c1 >>> 0;
  if (lo >>> 0 < c1 >>> 0) {
    hi = hi + 1 >>> 0;
  }
  hi = hi + Math.imul(aLo, bHi) >>> 0;
  hi = hi + Math.imul(aHi, bLo) >>> 0;
  out[0] = hi;
  out[1] = lo;
}
function add644(out, aHi, aLo, bHi, bLo) {
  let hi = aHi + bHi >>> 0;
  const lo = aLo + bLo >>> 0;
  if (lo >>> 0 < aLo >>> 0) {
    hi = hi + 1 | 0;
  }
  out[0] = hi;
  out[1] = lo;
}
var YieldWrapTypeId4 = /* @__PURE__ */ Symbol.for("effect/Utils/YieldWrap");
var YieldWrap4 = class {
  /**
   * @since 3.0.6
   */
  #value;
  constructor(value) {
    this.#value = value;
  }
  /**
   * @since 3.0.6
   */
  [YieldWrapTypeId4]() {
    return this.#value;
  }
};
function yieldWrapGet4(self2) {
  if (typeof self2 === "object" && self2 !== null && YieldWrapTypeId4 in self2) {
    return self2[YieldWrapTypeId4]();
  }
  throw new Error(getBugErrorMessage4("yieldWrapGet"));
}
var structuralRegionState4 = /* @__PURE__ */ globalValue4("effect/Utils/isStructuralRegion", () => ({
  enabled: false,
  tester: void 0
}));

// ../../node_modules/.pnpm/effect@3.2.8/node_modules/effect/dist/esm/Hash.js
var randomHashCache4 = /* @__PURE__ */ globalValue4(/* @__PURE__ */ Symbol.for("effect/Hash/randomHashCache"), () => /* @__PURE__ */ new WeakMap());
var pcgr4 = /* @__PURE__ */ globalValue4(/* @__PURE__ */ Symbol.for("effect/Hash/pcgr"), () => new PCGRandom4());
var symbol6 = /* @__PURE__ */ Symbol.for("effect/Hash");
var hash4 = (self2) => {
  if (structuralRegionState4.enabled === true) {
    return 0;
  }
  switch (typeof self2) {
    case "number":
      return number5(self2);
    case "bigint":
      return string4(self2.toString(10));
    case "boolean":
      return string4(String(self2));
    case "symbol":
      return string4(String(self2));
    case "string":
      return string4(self2);
    case "undefined":
      return string4("undefined");
    case "function":
    case "object": {
      if (self2 === null) {
        return string4("null");
      } else if (self2 instanceof Date) {
        return hash4(self2.toISOString());
      } else if (isHash4(self2)) {
        return self2[symbol6]();
      } else {
        return random4(self2);
      }
    }
    default:
      throw new Error(`BUG: unhandled typeof ${typeof self2} - please report an issue at https://github.com/Effect-TS/effect/issues`);
  }
};
var random4 = (self2) => {
  if (!randomHashCache4.has(self2)) {
    randomHashCache4.set(self2, number5(pcgr4.integer(Number.MAX_SAFE_INTEGER)));
  }
  return randomHashCache4.get(self2);
};
var combine5 = (b3) => (self2) => self2 * 53 ^ b3;
var optimize4 = (n3) => n3 & 3221225471 | n3 >>> 1 & 1073741824;
var isHash4 = (u3) => hasProperty4(u3, symbol6);
var number5 = (n3) => {
  if (n3 !== n3 || n3 === Infinity) {
    return 0;
  }
  let h3 = n3 | 0;
  if (h3 !== n3) {
    h3 ^= n3 * 4294967295;
  }
  while (n3 > 4294967295) {
    h3 ^= n3 /= 4294967295;
  }
  return optimize4(n3);
};
var string4 = (str) => {
  let h3 = 5381, i3 = str.length;
  while (i3) {
    h3 = h3 * 33 ^ str.charCodeAt(--i3);
  }
  return optimize4(h3);
};
var cached4 = function() {
  if (arguments.length === 1) {
    const self3 = arguments[0];
    return function(hash7) {
      Object.defineProperty(self3, symbol6, {
        value() {
          return hash7;
        },
        enumerable: false
      });
      return hash7;
    };
  }
  const self2 = arguments[0];
  const hash6 = arguments[1];
  Object.defineProperty(self2, symbol6, {
    value() {
      return hash6;
    },
    enumerable: false
  });
  return hash6;
};

// ../../node_modules/.pnpm/effect@3.2.8/node_modules/effect/dist/esm/Equal.js
var symbol7 = /* @__PURE__ */ Symbol.for("effect/Equal");
function equals4() {
  if (arguments.length === 1) {
    return (self2) => compareBoth4(self2, arguments[0]);
  }
  return compareBoth4(arguments[0], arguments[1]);
}
function compareBoth4(self2, that) {
  if (self2 === that) {
    return true;
  }
  const selfType = typeof self2;
  if (selfType !== typeof that) {
    return false;
  }
  if (selfType === "object" || selfType === "function") {
    if (self2 !== null && that !== null) {
      if (isEqual4(self2) && isEqual4(that)) {
        if (hash4(self2) === hash4(that) && self2[symbol7](that)) {
          return true;
        } else {
          return structuralRegionState4.enabled && structuralRegionState4.tester ? structuralRegionState4.tester(self2, that) : false;
        }
      } else if (self2 instanceof Date && that instanceof Date) {
        return self2.toISOString() === that.toISOString();
      }
    }
    if (structuralRegionState4.enabled) {
      if (Array.isArray(self2) && Array.isArray(that)) {
        return self2.length === that.length && self2.every((v3, i3) => compareBoth4(v3, that[i3]));
      }
      if (Object.getPrototypeOf(self2) === Object.prototype && Object.getPrototypeOf(self2) === Object.prototype) {
        const keysSelf = Object.keys(self2);
        const keysThat = Object.keys(that);
        if (keysSelf.length === keysThat.length) {
          for (const key of keysSelf) {
            if (!(key in that && compareBoth4(self2[key], that[key]))) {
              return structuralRegionState4.tester ? structuralRegionState4.tester(self2, that) : false;
            }
          }
          return true;
        }
      }
      return structuralRegionState4.tester ? structuralRegionState4.tester(self2, that) : false;
    }
  }
  return structuralRegionState4.enabled && structuralRegionState4.tester ? structuralRegionState4.tester(self2, that) : false;
}
var isEqual4 = (u3) => hasProperty4(u3, symbol7);
var equivalence4 = () => equals4;

// ../../node_modules/.pnpm/effect@3.2.8/node_modules/effect/dist/esm/Inspectable.js
var NodeInspectSymbol4 = /* @__PURE__ */ Symbol.for("nodejs.util.inspect.custom");
var toJSON4 = (x3) => {
  if (hasProperty4(x3, "toJSON") && isFunction8(x3["toJSON"]) && x3["toJSON"].length === 0) {
    return x3.toJSON();
  } else if (Array.isArray(x3)) {
    return x3.map(toJSON4);
  }
  return x3;
};
var format4 = (x3) => JSON.stringify(x3, null, 2);

// ../../node_modules/.pnpm/effect@3.2.8/node_modules/effect/dist/esm/Pipeable.js
var pipeArguments4 = (self2, args) => {
  switch (args.length) {
    case 1:
      return args[0](self2);
    case 2:
      return args[1](args[0](self2));
    case 3:
      return args[2](args[1](args[0](self2)));
    case 4:
      return args[3](args[2](args[1](args[0](self2))));
    case 5:
      return args[4](args[3](args[2](args[1](args[0](self2)))));
    case 6:
      return args[5](args[4](args[3](args[2](args[1](args[0](self2))))));
    case 7:
      return args[6](args[5](args[4](args[3](args[2](args[1](args[0](self2)))))));
    case 8:
      return args[7](args[6](args[5](args[4](args[3](args[2](args[1](args[0](self2))))))));
    case 9:
      return args[8](args[7](args[6](args[5](args[4](args[3](args[2](args[1](args[0](self2)))))))));
    default: {
      let ret = self2;
      for (let i3 = 0, len = args.length; i3 < len; i3++) {
        ret = args[i3](ret);
      }
      return ret;
    }
  }
};

// ../../node_modules/.pnpm/effect@3.2.8/node_modules/effect/dist/esm/internal/effectable.js
var EffectTypeId5 = /* @__PURE__ */ Symbol.for("effect/Effect");
var StreamTypeId4 = /* @__PURE__ */ Symbol.for("effect/Stream");
var SinkTypeId4 = /* @__PURE__ */ Symbol.for("effect/Sink");
var ChannelTypeId4 = /* @__PURE__ */ Symbol.for("effect/Channel");
var effectVariance4 = {
  /* c8 ignore next */
  _R: (_3) => _3,
  /* c8 ignore next */
  _E: (_3) => _3,
  /* c8 ignore next */
  _A: (_3) => _3,
  _V: /* @__PURE__ */ getCurrentVersion4()
};
var sinkVariance4 = {
  /* c8 ignore next */
  _A: (_3) => _3,
  /* c8 ignore next */
  _In: (_3) => _3,
  /* c8 ignore next */
  _L: (_3) => _3,
  /* c8 ignore next */
  _E: (_3) => _3,
  /* c8 ignore next */
  _R: (_3) => _3
};
var channelVariance4 = {
  /* c8 ignore next */
  _Env: (_3) => _3,
  /* c8 ignore next */
  _InErr: (_3) => _3,
  /* c8 ignore next */
  _InElem: (_3) => _3,
  /* c8 ignore next */
  _InDone: (_3) => _3,
  /* c8 ignore next */
  _OutErr: (_3) => _3,
  /* c8 ignore next */
  _OutElem: (_3) => _3,
  /* c8 ignore next */
  _OutDone: (_3) => _3
};
var EffectPrototype4 = {
  [EffectTypeId5]: effectVariance4,
  [StreamTypeId4]: effectVariance4,
  [SinkTypeId4]: sinkVariance4,
  [ChannelTypeId4]: channelVariance4,
  [symbol7](that) {
    return this === that;
  },
  [symbol6]() {
    return cached4(this, random4(this));
  },
  [Symbol.iterator]() {
    return new SingleShotGen5(new YieldWrap4(this));
  },
  pipe() {
    return pipeArguments4(this, arguments);
  }
};

// ../../node_modules/.pnpm/effect@3.2.8/node_modules/effect/dist/esm/internal/option.js
var TypeId10 = /* @__PURE__ */ Symbol.for("effect/Option");
var CommonProto6 = {
  ...EffectPrototype4,
  [TypeId10]: {
    _A: (_3) => _3
  },
  [NodeInspectSymbol4]() {
    return this.toJSON();
  },
  toString() {
    return format4(this.toJSON());
  }
};
var SomeProto4 = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(CommonProto6), {
  _tag: "Some",
  _op: "Some",
  [symbol7](that) {
    return isOption6(that) && isSome6(that) && equals4(this.value, that.value);
  },
  [symbol6]() {
    return cached4(this, combine5(hash4(this._tag))(hash4(this.value)));
  },
  toJSON() {
    return {
      _id: "Option",
      _tag: this._tag,
      value: toJSON4(this.value)
    };
  }
});
var NoneHash4 = /* @__PURE__ */ hash4("None");
var NoneProto4 = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(CommonProto6), {
  _tag: "None",
  _op: "None",
  [symbol7](that) {
    return isOption6(that) && isNone6(that);
  },
  [symbol6]() {
    return NoneHash4;
  },
  toJSON() {
    return {
      _id: "Option",
      _tag: this._tag
    };
  }
});
var isOption6 = (input) => hasProperty4(input, TypeId10);
var isNone6 = (fa) => fa._tag === "None";
var isSome6 = (fa) => fa._tag === "Some";
var none6 = /* @__PURE__ */ Object.create(NoneProto4);
var some10 = (value) => {
  const a3 = Object.create(SomeProto4);
  a3.value = value;
  return a3;
};

// ../../node_modules/.pnpm/effect@3.2.8/node_modules/effect/dist/esm/internal/either.js
var TypeId11 = /* @__PURE__ */ Symbol.for("effect/Either");
var CommonProto7 = {
  ...EffectPrototype4,
  [TypeId11]: {
    _R: (_3) => _3
  },
  [NodeInspectSymbol4]() {
    return this.toJSON();
  },
  toString() {
    return format4(this.toJSON());
  }
};
var RightProto4 = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(CommonProto7), {
  _tag: "Right",
  _op: "Right",
  [symbol7](that) {
    return isEither4(that) && isRight5(that) && equals4(this.right, that.right);
  },
  [symbol6]() {
    return combine5(hash4(this._tag))(hash4(this.right));
  },
  toJSON() {
    return {
      _id: "Either",
      _tag: this._tag,
      right: toJSON4(this.right)
    };
  }
});
var LeftProto4 = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(CommonProto7), {
  _tag: "Left",
  _op: "Left",
  [symbol7](that) {
    return isEither4(that) && isLeft5(that) && equals4(this.left, that.left);
  },
  [symbol6]() {
    return combine5(hash4(this._tag))(hash4(this.left));
  },
  toJSON() {
    return {
      _id: "Either",
      _tag: this._tag,
      left: toJSON4(this.left)
    };
  }
});
var isEither4 = (input) => hasProperty4(input, TypeId11);
var isLeft5 = (ma) => ma._tag === "Left";
var isRight5 = (ma) => ma._tag === "Right";
var left5 = (left7) => {
  const a3 = Object.create(LeftProto4);
  a3.left = left7;
  return a3;
};
var right5 = (right7) => {
  const a3 = Object.create(RightProto4);
  a3.right = right7;
  return a3;
};
var getLeft6 = (self2) => isRight5(self2) ? none6 : some10(self2.left);
var getRight6 = (self2) => isLeft5(self2) ? none6 : some10(self2.right);

// ../../node_modules/.pnpm/effect@3.2.8/node_modules/effect/dist/esm/Option.js
var Option_exports4 = {};
__export(Option_exports4, {
  Do: () => Do5,
  TypeId: () => TypeId12,
  all: () => all7,
  andThen: () => andThen4,
  ap: () => ap4,
  as: () => as4,
  asVoid: () => asVoid4,
  bind: () => bind8,
  bindTo: () => bindTo8,
  composeK: () => composeK4,
  contains: () => contains5,
  containsWith: () => containsWith5,
  exists: () => exists4,
  filter: () => filter5,
  filterMap: () => filterMap5,
  firstSomeOf: () => firstSomeOf4,
  flatMap: () => flatMap5,
  flatMapNullable: () => flatMapNullable5,
  flatten: () => flatten5,
  fromIterable: () => fromIterable6,
  fromNullable: () => fromNullable5,
  gen: () => gen4,
  getEquivalence: () => getEquivalence6,
  getLeft: () => getLeft7,
  getOrElse: () => getOrElse4,
  getOrNull: () => getOrNull4,
  getOrThrow: () => getOrThrow4,
  getOrThrowWith: () => getOrThrowWith4,
  getOrUndefined: () => getOrUndefined4,
  getOrder: () => getOrder5,
  getRight: () => getRight7,
  isNone: () => isNone7,
  isOption: () => isOption7,
  isSome: () => isSome7,
  let: () => let_8,
  lift2: () => lift24,
  liftNullable: () => liftNullable5,
  liftPredicate: () => liftPredicate5,
  liftThrowable: () => liftThrowable4,
  map: () => map5,
  match: () => match6,
  none: () => none7,
  orElse: () => orElse4,
  orElseEither: () => orElseEither4,
  orElseSome: () => orElseSome4,
  partitionMap: () => partitionMap5,
  product: () => product7,
  productMany: () => productMany7,
  reduceCompact: () => reduceCompact4,
  some: () => some11,
  tap: () => tap4,
  toArray: () => toArray4,
  toRefinement: () => toRefinement4,
  void: () => void_4,
  zipLeft: () => zipLeft4,
  zipRight: () => zipRight4,
  zipWith: () => zipWith5
});

// ../../node_modules/.pnpm/effect@3.2.8/node_modules/effect/dist/esm/Order.js
var make13 = (compare) => (self2, that) => self2 === that ? 0 : compare(self2, that);

// ../../node_modules/.pnpm/effect@3.2.8/node_modules/effect/dist/esm/Option.js
var TypeId12 = /* @__PURE__ */ Symbol.for("effect/Option");
var none7 = () => none6;
var some11 = some10;
var isOption7 = isOption6;
var isNone7 = isNone6;
var isSome7 = isSome6;
var match6 = /* @__PURE__ */ dual4(2, (self2, {
  onNone,
  onSome
}) => isNone7(self2) ? onNone() : onSome(self2.value));
var toRefinement4 = (f3) => (a3) => isSome7(f3(a3));
var fromIterable6 = (collection) => {
  for (const a3 of collection) {
    return some11(a3);
  }
  return none7();
};
var getRight7 = getRight6;
var getLeft7 = getLeft6;
var getOrElse4 = /* @__PURE__ */ dual4(2, (self2, onNone) => isNone7(self2) ? onNone() : self2.value);
var orElse4 = /* @__PURE__ */ dual4(2, (self2, that) => isNone7(self2) ? that() : self2);
var orElseSome4 = /* @__PURE__ */ dual4(2, (self2, onNone) => isNone7(self2) ? some11(onNone()) : self2);
var orElseEither4 = /* @__PURE__ */ dual4(2, (self2, that) => isNone7(self2) ? map5(that(), right5) : map5(self2, left5));
var firstSomeOf4 = (collection) => {
  let out = none7();
  for (out of collection) {
    if (isSome7(out)) {
      return out;
    }
  }
  return out;
};
var fromNullable5 = (nullableValue) => nullableValue == null ? none7() : some11(nullableValue);
var liftNullable5 = (f3) => (...a3) => fromNullable5(f3(...a3));
var getOrNull4 = /* @__PURE__ */ getOrElse4(constNull4);
var getOrUndefined4 = /* @__PURE__ */ getOrElse4(constUndefined4);
var liftThrowable4 = (f3) => (...a3) => {
  try {
    return some11(f3(...a3));
  } catch (e3) {
    return none7();
  }
};
var getOrThrowWith4 = /* @__PURE__ */ dual4(2, (self2, onNone) => {
  if (isSome7(self2)) {
    return self2.value;
  }
  throw onNone();
});
var getOrThrow4 = /* @__PURE__ */ getOrThrowWith4(() => new Error("getOrThrow called on a None"));
var map5 = /* @__PURE__ */ dual4(2, (self2, f3) => isNone7(self2) ? none7() : some11(f3(self2.value)));
var as4 = /* @__PURE__ */ dual4(2, (self2, b3) => map5(self2, () => b3));
var asVoid4 = /* @__PURE__ */ as4(void 0);
var void_4 = /* @__PURE__ */ some11(void 0);
var flatMap5 = /* @__PURE__ */ dual4(2, (self2, f3) => isNone7(self2) ? none7() : f3(self2.value));
var andThen4 = /* @__PURE__ */ dual4(2, (self2, f3) => flatMap5(self2, (a3) => {
  const b3 = isFunction7(f3) ? f3(a3) : f3;
  return isOption7(b3) ? b3 : some11(b3);
}));
var flatMapNullable5 = /* @__PURE__ */ dual4(2, (self2, f3) => isNone7(self2) ? none7() : fromNullable5(f3(self2.value)));
var flatten5 = /* @__PURE__ */ flatMap5(identity4);
var zipRight4 = /* @__PURE__ */ dual4(2, (self2, that) => flatMap5(self2, () => that));
var composeK4 = /* @__PURE__ */ dual4(2, (afb, bfc) => (a3) => flatMap5(afb(a3), bfc));
var zipLeft4 = /* @__PURE__ */ dual4(2, (self2, that) => tap4(self2, () => that));
var tap4 = /* @__PURE__ */ dual4(2, (self2, f3) => flatMap5(self2, (a3) => map5(f3(a3), () => a3)));
var product7 = (self2, that) => isSome7(self2) && isSome7(that) ? some11([self2.value, that.value]) : none7();
var productMany7 = (self2, collection) => {
  if (isNone7(self2)) {
    return none7();
  }
  const out = [self2.value];
  for (const o3 of collection) {
    if (isNone7(o3)) {
      return none7();
    }
    out.push(o3.value);
  }
  return some11(out);
};
var all7 = (input) => {
  if (Symbol.iterator in input) {
    const out2 = [];
    for (const o3 of input) {
      if (isNone7(o3)) {
        return none7();
      }
      out2.push(o3.value);
    }
    return some11(out2);
  }
  const out = {};
  for (const key of Object.keys(input)) {
    const o3 = input[key];
    if (isNone7(o3)) {
      return none7();
    }
    out[key] = o3.value;
  }
  return some11(out);
};
var zipWith5 = /* @__PURE__ */ dual4(3, (self2, that, f3) => map5(product7(self2, that), ([a3, b3]) => f3(a3, b3)));
var ap4 = /* @__PURE__ */ dual4(2, (self2, that) => zipWith5(self2, that, (f3, a3) => f3(a3)));
var reduceCompact4 = /* @__PURE__ */ dual4(3, (self2, b3, f3) => {
  let out = b3;
  for (const oa of self2) {
    if (isSome7(oa)) {
      out = f3(out, oa.value);
    }
  }
  return out;
});
var toArray4 = (self2) => isNone7(self2) ? [] : [self2.value];
var partitionMap5 = /* @__PURE__ */ dual4(2, (self2, f3) => {
  if (isNone7(self2)) {
    return [none7(), none7()];
  }
  const e3 = f3(self2.value);
  return isLeft5(e3) ? [some11(e3.left), none7()] : [none7(), some11(e3.right)];
});
var filterMap5 = /* @__PURE__ */ dual4(2, (self2, f3) => isNone7(self2) ? none7() : f3(self2.value));
var filter5 = /* @__PURE__ */ dual4(2, (self2, predicate) => filterMap5(self2, (b3) => predicate(b3) ? some10(b3) : none6));
var getEquivalence6 = (isEquivalent) => make12((x3, y3) => x3 === y3 || (isNone7(x3) ? isNone7(y3) : isNone7(y3) ? false : isEquivalent(x3.value, y3.value)));
var getOrder5 = (O3) => make13((self2, that) => isSome7(self2) ? isSome7(that) ? O3(self2.value, that.value) : 1 : -1);
var lift24 = (f3) => dual4(2, (self2, that) => zipWith5(self2, that, f3));
var liftPredicate5 = (predicate) => (b3) => predicate(b3) ? some11(b3) : none7();
var containsWith5 = (isEquivalent) => dual4(2, (self2, a3) => isNone7(self2) ? false : isEquivalent(self2.value, a3));
var _equivalence6 = /* @__PURE__ */ equivalence4();
var contains5 = /* @__PURE__ */ containsWith5(_equivalence6);
var exists4 = /* @__PURE__ */ dual4(2, (self2, refinement) => isNone7(self2) ? false : refinement(self2.value));
var bindTo8 = /* @__PURE__ */ bindTo7(map5);
var let_8 = /* @__PURE__ */ let_7(map5);
var bind8 = /* @__PURE__ */ bind7(map5, flatMap5);
var Do5 = /* @__PURE__ */ some11({});
var adapter7 = /* @__PURE__ */ adapter6();
var gen4 = (f3) => {
  const iterator = f3(adapter7);
  let state = iterator.next();
  if (state.done) {
    return some11(state.value);
  } else {
    let current = state.value;
    if (isGenKind4(current)) {
      current = current.value;
    } else {
      current = yieldWrapGet4(current);
    }
    if (isNone7(current)) {
      return current;
    }
    while (!state.done) {
      state = iterator.next(current.value);
      if (!state.done) {
        current = state.value;
        if (isGenKind4(current)) {
          current = current.value;
        } else {
          current = yieldWrapGet4(current);
        }
        if (isNone7(current)) {
          return current;
        }
      }
    }
    return some11(state.value);
  }
};

// ../../node_modules/.pnpm/effect@3.2.8/node_modules/effect/dist/esm/MutableRef.js
var MutableRef_exports = {};
__export(MutableRef_exports, {
  compareAndSet: () => compareAndSet2,
  decrement: () => decrement2,
  decrementAndGet: () => decrementAndGet2,
  get: () => get3,
  getAndDecrement: () => getAndDecrement2,
  getAndIncrement: () => getAndIncrement2,
  getAndSet: () => getAndSet2,
  getAndUpdate: () => getAndUpdate2,
  increment: () => increment2,
  incrementAndGet: () => incrementAndGet2,
  make: () => make14,
  set: () => set3,
  setAndGet: () => setAndGet2,
  toggle: () => toggle2,
  update: () => update2,
  updateAndGet: () => updateAndGet2
});
var TypeId13 = /* @__PURE__ */ Symbol.for("effect/MutableRef");
var MutableRefProto2 = {
  [TypeId13]: TypeId13,
  toString() {
    return format4(this.toJSON());
  },
  toJSON() {
    return {
      _id: "MutableRef",
      current: toJSON4(this.current)
    };
  },
  [NodeInspectSymbol4]() {
    return this.toJSON();
  },
  pipe() {
    return pipeArguments4(this, arguments);
  }
};
var make14 = (value) => {
  const ref = Object.create(MutableRefProto2);
  ref.current = value;
  return ref;
};
var compareAndSet2 = /* @__PURE__ */ dual4(3, (self2, oldValue, newValue) => {
  if (equals4(oldValue, self2.current)) {
    self2.current = newValue;
    return true;
  }
  return false;
});
var decrement2 = (self2) => update2(self2, (n3) => n3 - 1);
var decrementAndGet2 = (self2) => updateAndGet2(self2, (n3) => n3 - 1);
var get3 = (self2) => self2.current;
var getAndDecrement2 = (self2) => getAndUpdate2(self2, (n3) => n3 - 1);
var getAndIncrement2 = (self2) => getAndUpdate2(self2, (n3) => n3 + 1);
var getAndSet2 = /* @__PURE__ */ dual4(2, (self2, value) => {
  const ret = self2.current;
  self2.current = value;
  return ret;
});
var getAndUpdate2 = /* @__PURE__ */ dual4(2, (self2, f3) => getAndSet2(self2, f3(get3(self2))));
var increment2 = (self2) => update2(self2, (n3) => n3 + 1);
var incrementAndGet2 = (self2) => updateAndGet2(self2, (n3) => n3 + 1);
var set3 = /* @__PURE__ */ dual4(2, (self2, value) => {
  self2.current = value;
  return self2;
});
var setAndGet2 = /* @__PURE__ */ dual4(2, (self2, value) => {
  self2.current = value;
  return self2.current;
});
var update2 = /* @__PURE__ */ dual4(2, (self2, f3) => set3(self2, f3(get3(self2))));
var updateAndGet2 = /* @__PURE__ */ dual4(2, (self2, f3) => setAndGet2(self2, f3(get3(self2))));
var toggle2 = (self2) => update2(self2, (_3) => !_3);

// ../../node_modules/.pnpm/effect@3.2.8/node_modules/effect/dist/esm/MutableList.js
var MutableList_exports = {};
__export(MutableList_exports, {
  append: () => append2,
  empty: () => empty11,
  forEach: () => forEach5,
  fromIterable: () => fromIterable7,
  head: () => head2,
  isEmpty: () => isEmpty3,
  length: () => length2,
  make: () => make15,
  pop: () => pop,
  prepend: () => prepend4,
  reset: () => reset,
  shift: () => shift,
  tail: () => tail2
});
var TypeId14 = /* @__PURE__ */ Symbol.for("effect/MutableList");
var MutableListProto = {
  [TypeId14]: TypeId14,
  [Symbol.iterator]() {
    let done = false;
    let head3 = this.head;
    return {
      next() {
        if (done) {
          return this.return();
        }
        if (head3 == null) {
          done = true;
          return this.return();
        }
        const value = head3.value;
        head3 = head3.next;
        return {
          done,
          value
        };
      },
      return(value) {
        if (!done) {
          done = true;
        }
        return {
          done: true,
          value
        };
      }
    };
  },
  toString() {
    return format4(this.toJSON());
  },
  toJSON() {
    return {
      _id: "MutableList",
      values: Array.from(this).map(toJSON4)
    };
  },
  [NodeInspectSymbol4]() {
    return this.toJSON();
  },
  pipe() {
    return pipeArguments4(this, arguments);
  }
};
var makeNode = (value) => ({
  value,
  removed: false,
  prev: void 0,
  next: void 0
});
var empty11 = () => {
  const list = Object.create(MutableListProto);
  list.head = void 0;
  list.tail = void 0;
  list._length = 0;
  return list;
};
var fromIterable7 = (iterable) => {
  const list = empty11();
  for (const element of iterable) {
    append2(list, element);
  }
  return list;
};
var make15 = (...elements) => fromIterable7(elements);
var isEmpty3 = (self2) => length2(self2) === 0;
var length2 = (self2) => self2._length;
var tail2 = (self2) => self2.tail === void 0 ? void 0 : self2.tail.value;
var head2 = (self2) => self2.head === void 0 ? void 0 : self2.head.value;
var forEach5 = /* @__PURE__ */ dual4(2, (self2, f3) => {
  let current = self2.head;
  while (current !== void 0) {
    f3(current.value);
    current = current.next;
  }
});
var reset = (self2) => {
  self2._length = 0;
  self2.head = void 0;
  self2.tail = void 0;
  return self2;
};
var append2 = /* @__PURE__ */ dual4(2, (self2, value) => {
  const node = makeNode(value);
  if (self2.head === void 0) {
    self2.head = node;
  }
  if (self2.tail === void 0) {
    self2.tail = node;
  } else {
    self2.tail.next = node;
    node.prev = self2.tail;
    self2.tail = node;
  }
  self2._length += 1;
  return self2;
});
var shift = (self2) => {
  const head3 = self2.head;
  if (head3 !== void 0) {
    remove2(self2, head3);
    return head3.value;
  }
  return void 0;
};
var pop = (self2) => {
  const tail3 = self2.tail;
  if (tail3 !== void 0) {
    remove2(self2, tail3);
    return tail3.value;
  }
  return void 0;
};
var prepend4 = /* @__PURE__ */ dual4(2, (self2, value) => {
  const node = makeNode(value);
  node.next = self2.head;
  if (self2.head !== void 0) {
    self2.head.prev = node;
  }
  self2.head = node;
  if (self2.tail === void 0) {
    self2.tail = node;
  }
  self2._length += 1;
  return self2;
});
var remove2 = (self2, node) => {
  if (node.removed) {
    return;
  }
  node.removed = true;
  if (node.prev !== void 0 && node.next !== void 0) {
    node.prev.next = node.next;
    node.next.prev = node.prev;
  } else if (node.prev !== void 0) {
    self2.tail = node.prev;
    node.prev.next = void 0;
  } else if (node.next !== void 0) {
    self2.head = node.next;
    node.next.prev = void 0;
  } else {
    self2.tail = void 0;
    self2.head = void 0;
  }
  if (self2._length > 0) {
    self2._length -= 1;
  }
};
var store2;
function getGlobalMessage(lang) {
  return store2?.get(lang);
}
var store3;
function getSchemaMessage(lang) {
  return store3?.get(lang);
}
var store4;
function getSpecificMessage(reference, lang) {
  return store4?.get(reference)?.get(lang);
}
function _stringify(input) {
  let type = typeof input;
  if (type === "object") {
    type = (input && Object.getPrototypeOf(input)?.constructor?.name) ?? "null";
  }
  return type === "string" ? `"${input}"` : type === "number" || type === "bigint" || type === "boolean" ? `${input}` : type;
}
function _addIssue(context, label, dataset, config2, other) {
  const input = dataset.value;
  const expected = context.expects;
  const received = _stringify(input);
  const issue = {
    kind: context.kind,
    type: context.type,
    input,
    expected,
    received,
    message: `Invalid ${label}: ${expected ? `Expected ${expected} but r` : "R"}eceived ${received}`,
    // @ts-expect-error
    requirement: context.requirement,
    path: other?.path,
    issues: other?.issues,
    lang: config2.lang,
    abortEarly: config2.abortEarly,
    abortPipeEarly: config2.abortPipeEarly,
    skipPipe: config2.skipPipe
  };
  const isSchema = context.kind === "schema";
  const message = (
    // @ts-expect-error
    context.message ?? getSpecificMessage(context.reference, issue.lang) ?? (isSchema ? getSchemaMessage(issue.lang) : null) ?? config2.message ?? getGlobalMessage(issue.lang)
  );
  if (message) {
    issue.message = typeof message === "function" ? message(issue) : message;
  }
  if (isSchema) {
    dataset.typed = false;
  }
  if (dataset.issues) {
    dataset.issues.push(issue);
  } else {
    dataset.issues = [issue];
  }
}
function getDefault(schema, dataset, config2) {
  return typeof schema.default === "function" ? (
    // @ts-expect-error
    schema.default(dataset, config2)
  ) : (
    // @ts-expect-error
    schema.default
  );
}
function array6(item, message) {
  return {
    kind: "schema",
    type: "array",
    reference: array6,
    expects: "Array",
    async: false,
    item,
    message,
    _run(dataset, config2) {
      const input = dataset.value;
      if (Array.isArray(input)) {
        dataset.typed = true;
        dataset.value = [];
        for (let key = 0; key < input.length; key++) {
          const value2 = input[key];
          const itemDataset = this.item._run({ typed: false, value: value2 }, config2);
          if (itemDataset.issues) {
            const pathItem = {
              type: "array",
              origin: "value",
              input,
              key,
              value: value2
            };
            for (const issue of itemDataset.issues) {
              if (issue.path) {
                issue.path.unshift(pathItem);
              } else {
                issue.path = [pathItem];
              }
              dataset.issues?.push(issue);
            }
            if (!dataset.issues) {
              dataset.issues = itemDataset.issues;
            }
            if (config2.abortEarly) {
              dataset.typed = false;
              break;
            }
          }
          if (!itemDataset.typed) {
            dataset.typed = false;
          }
          dataset.value.push(itemDataset.value);
        }
      } else {
        _addIssue(this, "type", dataset, config2);
      }
      return dataset;
    }
  };
}
function object(entries, message) {
  return {
    kind: "schema",
    type: "object",
    reference: object,
    expects: "Object",
    async: false,
    entries,
    message,
    _run(dataset, config2) {
      const input = dataset.value;
      if (input && typeof input === "object") {
        dataset.typed = true;
        dataset.value = {};
        for (const key in this.entries) {
          const value2 = input[key];
          const valueDataset = this.entries[key]._run(
            { typed: false, value: value2 },
            config2
          );
          if (valueDataset.issues) {
            const pathItem = {
              type: "object",
              origin: "value",
              input,
              key,
              value: value2
            };
            for (const issue of valueDataset.issues) {
              if (issue.path) {
                issue.path.unshift(pathItem);
              } else {
                issue.path = [pathItem];
              }
              dataset.issues?.push(issue);
            }
            if (!dataset.issues) {
              dataset.issues = valueDataset.issues;
            }
            if (config2.abortEarly) {
              dataset.typed = false;
              break;
            }
          }
          if (!valueDataset.typed) {
            dataset.typed = false;
          }
          if (valueDataset.value !== void 0 || key in input) {
            dataset.value[key] = valueDataset.value;
          }
        }
      } else {
        _addIssue(this, "type", dataset, config2);
      }
      return dataset;
    }
  };
}
function optional(wrapped, ...args) {
  const schema = {
    kind: "schema",
    type: "optional",
    reference: optional,
    expects: `${wrapped.expects} | undefined`,
    async: false,
    wrapped,
    _run(dataset, config2) {
      if (dataset.value === void 0) {
        if ("default" in this) {
          dataset.value = getDefault(
            this,
            dataset,
            config2
          );
        }
        if (dataset.value === void 0) {
          dataset.typed = true;
          return dataset;
        }
      }
      return this.wrapped._run(dataset, config2);
    }
  };
  if (0 in args) {
    schema.default = args[0];
  }
  return schema;
}
function string5(message) {
  return {
    kind: "schema",
    type: "string",
    reference: string5,
    expects: "string",
    async: false,
    message,
    _run(dataset, config2) {
      if (typeof dataset.value === "string") {
        dataset.typed = true;
      } else {
        _addIssue(this, "type", dataset, config2);
      }
      return dataset;
    }
  };
}
var ESLintReactSettingsSchema = object({
  additionalHooks: optional(object({
    use: optional(string5()),
    useCallback: optional(array6(string5())),
    useContext: optional(array6(string5())),
    useDebugValue: optional(array6(string5())),
    useDeferredValue: optional(array6(string5())),
    useEffect: optional(array6(string5())),
    useId: optional(array6(string5())),
    useImperativeHandle: optional(array6(string5())),
    useInsertionEffect: optional(array6(string5())),
    useLayoutEffect: optional(array6(string5())),
    useMemo: optional(array6(string5())),
    useOptimistic: optional(array6(string5())),
    useReducer: optional(array6(string5())),
    useRef: optional(array6(string5())),
    useState: optional(array6(string5())),
    useSyncExternalStore: optional(array6(string5())),
    useTransition: optional(array6(string5()))
  })),
  importSource: optional(string5()),
  jsxPragma: optional(string5()),
  jsxPragmaFrag: optional(string5()),
  version: optional(string5())
});
var ESLintSettingsSchema = object({
  reactOptions: optional(ESLintReactSettingsSchema)
});
var __defProp4 = Object.defineProperty;
var __export4 = (target, all33) => {
  for (var name in all33)
    __defProp4(target, name, { get: all33[name], enumerable: true });
};
var Function_exports5 = {};
__export4(Function_exports5, {
  SK: () => SK5,
  absurd: () => absurd5,
  apply: () => apply5,
  compose: () => compose8,
  constFalse: () => constFalse5,
  constNull: () => constNull5,
  constTrue: () => constTrue5,
  constUndefined: () => constUndefined5,
  constVoid: () => constVoid5,
  constant: () => constant5,
  dual: () => dual5,
  flip: () => flip5,
  flow: () => flow5,
  hole: () => hole5,
  identity: () => identity5,
  isFunction: () => isFunction9,
  pipe: () => pipe5,
  satisfies: () => satisfies5,
  tupled: () => tupled5,
  unsafeCoerce: () => unsafeCoerce5,
  untupled: () => untupled5
});
var isFunction9 = (input) => typeof input === "function";
var dual5 = function(arity, body) {
  if (typeof arity === "function") {
    return function() {
      if (arity(arguments)) {
        return body.apply(this, arguments);
      }
      return (self2) => body(self2, ...arguments);
    };
  }
  switch (arity) {
    case 0:
    case 1:
      throw new RangeError(`Invalid arity ${arity}`);
    case 2:
      return function(a22, b22) {
        if (arguments.length >= 2) {
          return body(a22, b22);
        }
        return function(self2) {
          return body(self2, a22);
        };
      };
    case 3:
      return function(a22, b22, c22) {
        if (arguments.length >= 3) {
          return body(a22, b22, c22);
        }
        return function(self2) {
          return body(self2, a22, b22);
        };
      };
    case 4:
      return function(a22, b22, c22, d22) {
        if (arguments.length >= 4) {
          return body(a22, b22, c22, d22);
        }
        return function(self2) {
          return body(self2, a22, b22, c22);
        };
      };
    case 5:
      return function(a22, b22, c22, d22, e22) {
        if (arguments.length >= 5) {
          return body(a22, b22, c22, d22, e22);
        }
        return function(self2) {
          return body(self2, a22, b22, c22, d22);
        };
      };
    default:
      return function() {
        if (arguments.length >= arity) {
          return body.apply(this, arguments);
        }
        const args = arguments;
        return function(self2) {
          return body(self2, ...args);
        };
      };
  }
};
var apply5 = (a22) => (self2) => self2(a22);
var identity5 = (a22) => a22;
var satisfies5 = () => (b22) => b22;
var unsafeCoerce5 = identity5;
var constant5 = (value) => () => value;
var constTrue5 = /* @__PURE__ */ constant5(true);
var constFalse5 = /* @__PURE__ */ constant5(false);
var constNull5 = /* @__PURE__ */ constant5(null);
var constUndefined5 = /* @__PURE__ */ constant5(void 0);
var constVoid5 = constUndefined5;
var flip5 = (f22) => (...b22) => (...a22) => f22(...a22)(...b22);
var compose8 = /* @__PURE__ */ dual5(2, (ab, bc) => (a22) => bc(ab(a22)));
var absurd5 = (_22) => {
  throw new Error("Called `absurd` function which should be uncallable");
};
var tupled5 = (f22) => (a22) => f22(...a22);
var untupled5 = (f22) => (...a22) => f22(a22);
function pipe5(a22, ab, bc, cd, de, ef, fg, gh, hi) {
  switch (arguments.length) {
    case 1:
      return a22;
    case 2:
      return ab(a22);
    case 3:
      return bc(ab(a22));
    case 4:
      return cd(bc(ab(a22)));
    case 5:
      return de(cd(bc(ab(a22))));
    case 6:
      return ef(de(cd(bc(ab(a22)))));
    case 7:
      return fg(ef(de(cd(bc(ab(a22))))));
    case 8:
      return gh(fg(ef(de(cd(bc(ab(a22)))))));
    case 9:
      return hi(gh(fg(ef(de(cd(bc(ab(a22))))))));
    default: {
      let ret = arguments[0];
      for (let i22 = 1; i22 < arguments.length; i22++) {
        ret = arguments[i22](ret);
      }
      return ret;
    }
  }
}
function flow5(ab, bc, cd, de, ef, fg, gh, hi, ij) {
  switch (arguments.length) {
    case 1:
      return ab;
    case 2:
      return function() {
        return bc(ab.apply(this, arguments));
      };
    case 3:
      return function() {
        return cd(bc(ab.apply(this, arguments)));
      };
    case 4:
      return function() {
        return de(cd(bc(ab.apply(this, arguments))));
      };
    case 5:
      return function() {
        return ef(de(cd(bc(ab.apply(this, arguments)))));
      };
    case 6:
      return function() {
        return fg(ef(de(cd(bc(ab.apply(this, arguments))))));
      };
    case 7:
      return function() {
        return gh(fg(ef(de(cd(bc(ab.apply(this, arguments)))))));
      };
    case 8:
      return function() {
        return hi(gh(fg(ef(de(cd(bc(ab.apply(this, arguments))))))));
      };
    case 9:
      return function() {
        return ij(hi(gh(fg(ef(de(cd(bc(ab.apply(this, arguments)))))))));
      };
  }
  return;
}
var hole5 = /* @__PURE__ */ unsafeCoerce5(absurd5);
var SK5 = (_22, b22) => b22;
var make16 = (isEquivalent) => (self2, that) => self2 === that || isEquivalent(self2, that);
var let_9 = (map32) => dual5(3, (self2, name, f22) => map32(self2, (a22) => Object.assign({}, a22, {
  [name]: f22(a22)
})));
var bindTo9 = (map32) => dual5(2, (self2, name) => map32(self2, (a22) => ({
  [name]: a22
})));
var bind9 = (map32, flatMap32) => dual5(3, (self2, name, f22) => flatMap32(self2, (a22) => map32(f22(a22), (b22) => Object.assign({}, a22, {
  [name]: b22
}))));
var moduleVersion5 = "3.2.8";
var getCurrentVersion5 = () => moduleVersion5;
var globalStoreId5 = /* @__PURE__ */ Symbol.for(`effect/GlobalValue/globalStoreId/${/* @__PURE__ */ getCurrentVersion5()}`);
if (!(globalStoreId5 in globalThis)) {
  globalThis[globalStoreId5] = /* @__PURE__ */ new Map();
}
var globalStore5 = globalThis[globalStoreId5];
var globalValue5 = (id, compute) => {
  if (!globalStore5.has(id)) {
    globalStore5.set(id, compute());
  }
  return globalStore5.get(id);
};
var isFunction23 = isFunction9;
var isRecordOrArray5 = (input) => typeof input === "object" && input !== null;
var isObject5 = (input) => isRecordOrArray5(input) || isFunction23(input);
var hasProperty5 = /* @__PURE__ */ dual5(2, (self2, property) => isObject5(self2) && property in self2);
var isNullable5 = (input) => input === null || input === void 0;
var getBugErrorMessage5 = (message) => `BUG: ${message} - please report an issue at https://github.com/Effect-TS/effect/issues`;
var GenKindTypeId5 = /* @__PURE__ */ Symbol.for("effect/Gen/GenKind");
var isGenKind5 = (u22) => isObject5(u22) && GenKindTypeId5 in u22;
var GenKindImpl5 = class {
  value;
  constructor(value) {
    this.value = value;
  }
  /**
   * @since 2.0.0
   */
  get _F() {
    return identity5;
  }
  /**
   * @since 2.0.0
   */
  get _R() {
    return (_22) => _22;
  }
  /**
   * @since 2.0.0
   */
  get _O() {
    return (_22) => _22;
  }
  /**
   * @since 2.0.0
   */
  get _E() {
    return (_22) => _22;
  }
  /**
   * @since 2.0.0
   */
  [GenKindTypeId5] = GenKindTypeId5;
  /**
   * @since 2.0.0
   */
  [Symbol.iterator]() {
    return new SingleShotGen6(this);
  }
};
var SingleShotGen6 = class _SingleShotGen33 {
  self;
  called = false;
  constructor(self2) {
    this.self = self2;
  }
  /**
   * @since 2.0.0
   */
  next(a22) {
    return this.called ? {
      value: a22,
      done: true
    } : (this.called = true, {
      value: this.self,
      done: false
    });
  }
  /**
   * @since 2.0.0
   */
  return(a22) {
    return {
      value: a22,
      done: true
    };
  }
  /**
   * @since 2.0.0
   */
  throw(e22) {
    throw e22;
  }
  /**
   * @since 2.0.0
   */
  [Symbol.iterator]() {
    return new _SingleShotGen33(this.self);
  }
};
var adapter8 = () => function() {
  let x22 = arguments[0];
  for (let i22 = 1; i22 < arguments.length; i22++) {
    x22 = arguments[i22](x22);
  }
  return new GenKindImpl5(x22);
};
var defaultIncHi5 = 335903614;
var defaultIncLo5 = 4150755663;
var MUL_HI5 = 1481765933 >>> 0;
var MUL_LO5 = 1284865837 >>> 0;
var BIT_535 = 9007199254740992;
var BIT_275 = 134217728;
var PCGRandom5 = class {
  _state;
  constructor(seedHi, seedLo, incHi, incLo) {
    if (isNullable5(seedLo) && isNullable5(seedHi)) {
      seedLo = Math.random() * 4294967295 >>> 0;
      seedHi = 0;
    } else if (isNullable5(seedLo)) {
      seedLo = seedHi;
      seedHi = 0;
    }
    if (isNullable5(incLo) && isNullable5(incHi)) {
      incLo = this._state ? this._state[3] : defaultIncLo5;
      incHi = this._state ? this._state[2] : defaultIncHi5;
    } else if (isNullable5(incLo)) {
      incLo = incHi;
      incHi = 0;
    }
    this._state = new Int32Array([0, 0, incHi >>> 0, ((incLo || 0) | 1) >>> 0]);
    this._next();
    add645(this._state, this._state[0], this._state[1], seedHi >>> 0, seedLo >>> 0);
    this._next();
    return this;
  }
  /**
   * Returns a copy of the internal state of this random number generator as a
   * JavaScript Array.
   *
   * @category getters
   * @since 2.0.0
   */
  getState() {
    return [this._state[0], this._state[1], this._state[2], this._state[3]];
  }
  /**
   * Restore state previously retrieved using `getState()`.
   *
   * @since 2.0.0
   */
  setState(state) {
    this._state[0] = state[0];
    this._state[1] = state[1];
    this._state[2] = state[2];
    this._state[3] = state[3] | 1;
  }
  /**
   * Get a uniformly distributed 32 bit integer between [0, max).
   *
   * @category getter
   * @since 2.0.0
   */
  integer(max3) {
    if (!max3) {
      return this._next();
    }
    max3 = max3 >>> 0;
    if ((max3 & max3 - 1) === 0) {
      return this._next() & max3 - 1;
    }
    let num = 0;
    const skew = (-max3 >>> 0) % max3 >>> 0;
    for (num = this._next(); num < skew; num = this._next()) {
    }
    return num % max3;
  }
  /**
   * Get a uniformly distributed IEEE-754 double between 0.0 and 1.0, with
   * 53 bits of precision (every bit of the mantissa is randomized).
   *
   * @category getters
   * @since 2.0.0
   */
  number() {
    const hi = (this._next() & 67108863) * 1;
    const lo = (this._next() & 134217727) * 1;
    return (hi * BIT_275 + lo) / BIT_535;
  }
  /** @internal */
  _next() {
    const oldHi = this._state[0] >>> 0;
    const oldLo = this._state[1] >>> 0;
    mul645(this._state, oldHi, oldLo, MUL_HI5, MUL_LO5);
    add645(this._state, this._state[0], this._state[1], this._state[2], this._state[3]);
    let xsHi = oldHi >>> 18;
    let xsLo = (oldLo >>> 18 | oldHi << 14) >>> 0;
    xsHi = (xsHi ^ oldHi) >>> 0;
    xsLo = (xsLo ^ oldLo) >>> 0;
    const xorshifted = (xsLo >>> 27 | xsHi << 5) >>> 0;
    const rot = oldHi >>> 27;
    const rot2 = (-rot >>> 0 & 31) >>> 0;
    return (xorshifted >>> rot | xorshifted << rot2) >>> 0;
  }
};
function mul645(out, aHi, aLo, bHi, bLo) {
  let c1 = (aLo >>> 16) * (bLo & 65535) >>> 0;
  let c0 = (aLo & 65535) * (bLo >>> 16) >>> 0;
  let lo = (aLo & 65535) * (bLo & 65535) >>> 0;
  let hi = (aLo >>> 16) * (bLo >>> 16) + ((c0 >>> 16) + (c1 >>> 16)) >>> 0;
  c0 = c0 << 16 >>> 0;
  lo = lo + c0 >>> 0;
  if (lo >>> 0 < c0 >>> 0) {
    hi = hi + 1 >>> 0;
  }
  c1 = c1 << 16 >>> 0;
  lo = lo + c1 >>> 0;
  if (lo >>> 0 < c1 >>> 0) {
    hi = hi + 1 >>> 0;
  }
  hi = hi + Math.imul(aLo, bHi) >>> 0;
  hi = hi + Math.imul(aHi, bLo) >>> 0;
  out[0] = hi;
  out[1] = lo;
}
function add645(out, aHi, aLo, bHi, bLo) {
  let hi = aHi + bHi >>> 0;
  const lo = aLo + bLo >>> 0;
  if (lo >>> 0 < aLo >>> 0) {
    hi = hi + 1 | 0;
  }
  out[0] = hi;
  out[1] = lo;
}
var YieldWrapTypeId5 = /* @__PURE__ */ Symbol.for("effect/Utils/YieldWrap");
var YieldWrap5 = class {
  /**
   * @since 3.0.6
   */
  #value;
  constructor(value) {
    this.#value = value;
  }
  /**
   * @since 3.0.6
   */
  [YieldWrapTypeId5]() {
    return this.#value;
  }
};
function yieldWrapGet5(self2) {
  if (typeof self2 === "object" && self2 !== null && YieldWrapTypeId5 in self2) {
    return self2[YieldWrapTypeId5]();
  }
  throw new Error(getBugErrorMessage5("yieldWrapGet"));
}
var structuralRegionState5 = /* @__PURE__ */ globalValue5("effect/Utils/isStructuralRegion", () => ({
  enabled: false,
  tester: void 0
}));
var randomHashCache5 = /* @__PURE__ */ globalValue5(/* @__PURE__ */ Symbol.for("effect/Hash/randomHashCache"), () => /* @__PURE__ */ new WeakMap());
var pcgr5 = /* @__PURE__ */ globalValue5(/* @__PURE__ */ Symbol.for("effect/Hash/pcgr"), () => new PCGRandom5());
var symbol8 = /* @__PURE__ */ Symbol.for("effect/Hash");
var hash5 = (self2) => {
  if (structuralRegionState5.enabled === true) {
    return 0;
  }
  switch (typeof self2) {
    case "number":
      return number6(self2);
    case "bigint":
      return string6(self2.toString(10));
    case "boolean":
      return string6(String(self2));
    case "symbol":
      return string6(String(self2));
    case "string":
      return string6(self2);
    case "undefined":
      return string6("undefined");
    case "function":
    case "object": {
      if (self2 === null) {
        return string6("null");
      } else if (self2 instanceof Date) {
        return hash5(self2.toISOString());
      } else if (isHash5(self2)) {
        return self2[symbol8]();
      } else {
        return random5(self2);
      }
    }
    default:
      throw new Error(`BUG: unhandled typeof ${typeof self2} - please report an issue at https://github.com/Effect-TS/effect/issues`);
  }
};
var random5 = (self2) => {
  if (!randomHashCache5.has(self2)) {
    randomHashCache5.set(self2, number6(pcgr5.integer(Number.MAX_SAFE_INTEGER)));
  }
  return randomHashCache5.get(self2);
};
var combine6 = (b22) => (self2) => self2 * 53 ^ b22;
var optimize5 = (n22) => n22 & 3221225471 | n22 >>> 1 & 1073741824;
var isHash5 = (u22) => hasProperty5(u22, symbol8);
var number6 = (n22) => {
  if (n22 !== n22 || n22 === Infinity) {
    return 0;
  }
  let h22 = n22 | 0;
  if (h22 !== n22) {
    h22 ^= n22 * 4294967295;
  }
  while (n22 > 4294967295) {
    h22 ^= n22 /= 4294967295;
  }
  return optimize5(n22);
};
var string6 = (str) => {
  let h22 = 5381, i22 = str.length;
  while (i22) {
    h22 = h22 * 33 ^ str.charCodeAt(--i22);
  }
  return optimize5(h22);
};
var cached5 = function() {
  if (arguments.length === 1) {
    const self3 = arguments[0];
    return function(hash42) {
      Object.defineProperty(self3, symbol8, {
        value() {
          return hash42;
        },
        enumerable: false
      });
      return hash42;
    };
  }
  const self2 = arguments[0];
  const hash32 = arguments[1];
  Object.defineProperty(self2, symbol8, {
    value() {
      return hash32;
    },
    enumerable: false
  });
  return hash32;
};
var symbol23 = /* @__PURE__ */ Symbol.for("effect/Equal");
function equals5() {
  if (arguments.length === 1) {
    return (self2) => compareBoth5(self2, arguments[0]);
  }
  return compareBoth5(arguments[0], arguments[1]);
}
function compareBoth5(self2, that) {
  if (self2 === that) {
    return true;
  }
  const selfType = typeof self2;
  if (selfType !== typeof that) {
    return false;
  }
  if (selfType === "object" || selfType === "function") {
    if (self2 !== null && that !== null) {
      if (isEqual5(self2) && isEqual5(that)) {
        if (hash5(self2) === hash5(that) && self2[symbol23](that)) {
          return true;
        } else {
          return structuralRegionState5.enabled && structuralRegionState5.tester ? structuralRegionState5.tester(self2, that) : false;
        }
      } else if (self2 instanceof Date && that instanceof Date) {
        return self2.toISOString() === that.toISOString();
      }
    }
    if (structuralRegionState5.enabled) {
      if (Array.isArray(self2) && Array.isArray(that)) {
        return self2.length === that.length && self2.every((v22, i22) => compareBoth5(v22, that[i22]));
      }
      if (Object.getPrototypeOf(self2) === Object.prototype && Object.getPrototypeOf(self2) === Object.prototype) {
        const keysSelf = Object.keys(self2);
        const keysThat = Object.keys(that);
        if (keysSelf.length === keysThat.length) {
          for (const key of keysSelf) {
            if (!(key in that && compareBoth5(self2[key], that[key]))) {
              return structuralRegionState5.tester ? structuralRegionState5.tester(self2, that) : false;
            }
          }
          return true;
        }
      }
      return structuralRegionState5.tester ? structuralRegionState5.tester(self2, that) : false;
    }
  }
  return structuralRegionState5.enabled && structuralRegionState5.tester ? structuralRegionState5.tester(self2, that) : false;
}
var isEqual5 = (u22) => hasProperty5(u22, symbol23);
var equivalence5 = () => equals5;
var NodeInspectSymbol5 = /* @__PURE__ */ Symbol.for("nodejs.util.inspect.custom");
var toJSON5 = (x22) => {
  if (hasProperty5(x22, "toJSON") && isFunction23(x22["toJSON"]) && x22["toJSON"].length === 0) {
    return x22.toJSON();
  } else if (Array.isArray(x22)) {
    return x22.map(toJSON5);
  }
  return x22;
};
var format5 = (x22) => JSON.stringify(x22, null, 2);
var pipeArguments5 = (self2, args) => {
  switch (args.length) {
    case 1:
      return args[0](self2);
    case 2:
      return args[1](args[0](self2));
    case 3:
      return args[2](args[1](args[0](self2)));
    case 4:
      return args[3](args[2](args[1](args[0](self2))));
    case 5:
      return args[4](args[3](args[2](args[1](args[0](self2)))));
    case 6:
      return args[5](args[4](args[3](args[2](args[1](args[0](self2))))));
    case 7:
      return args[6](args[5](args[4](args[3](args[2](args[1](args[0](self2)))))));
    case 8:
      return args[7](args[6](args[5](args[4](args[3](args[2](args[1](args[0](self2))))))));
    case 9:
      return args[8](args[7](args[6](args[5](args[4](args[3](args[2](args[1](args[0](self2)))))))));
    default: {
      let ret = self2;
      for (let i22 = 0, len = args.length; i22 < len; i22++) {
        ret = args[i22](ret);
      }
      return ret;
    }
  }
};
var EffectTypeId6 = /* @__PURE__ */ Symbol.for("effect/Effect");
var StreamTypeId5 = /* @__PURE__ */ Symbol.for("effect/Stream");
var SinkTypeId5 = /* @__PURE__ */ Symbol.for("effect/Sink");
var ChannelTypeId5 = /* @__PURE__ */ Symbol.for("effect/Channel");
var effectVariance5 = {
  /* c8 ignore next */
  _R: (_22) => _22,
  /* c8 ignore next */
  _E: (_22) => _22,
  /* c8 ignore next */
  _A: (_22) => _22,
  _V: /* @__PURE__ */ getCurrentVersion5()
};
var sinkVariance5 = {
  /* c8 ignore next */
  _A: (_22) => _22,
  /* c8 ignore next */
  _In: (_22) => _22,
  /* c8 ignore next */
  _L: (_22) => _22,
  /* c8 ignore next */
  _E: (_22) => _22,
  /* c8 ignore next */
  _R: (_22) => _22
};
var channelVariance5 = {
  /* c8 ignore next */
  _Env: (_22) => _22,
  /* c8 ignore next */
  _InErr: (_22) => _22,
  /* c8 ignore next */
  _InElem: (_22) => _22,
  /* c8 ignore next */
  _InDone: (_22) => _22,
  /* c8 ignore next */
  _OutErr: (_22) => _22,
  /* c8 ignore next */
  _OutElem: (_22) => _22,
  /* c8 ignore next */
  _OutDone: (_22) => _22
};
var EffectPrototype5 = {
  [EffectTypeId6]: effectVariance5,
  [StreamTypeId5]: effectVariance5,
  [SinkTypeId5]: sinkVariance5,
  [ChannelTypeId5]: channelVariance5,
  [symbol23](that) {
    return this === that;
  },
  [symbol8]() {
    return cached5(this, random5(this));
  },
  [Symbol.iterator]() {
    return new SingleShotGen6(new YieldWrap5(this));
  },
  pipe() {
    return pipeArguments5(this, arguments);
  }
};
var TypeId15 = /* @__PURE__ */ Symbol.for("effect/Option");
var CommonProto8 = {
  ...EffectPrototype5,
  [TypeId15]: {
    _A: (_22) => _22
  },
  [NodeInspectSymbol5]() {
    return this.toJSON();
  },
  toString() {
    return format5(this.toJSON());
  }
};
var SomeProto5 = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(CommonProto8), {
  _tag: "Some",
  _op: "Some",
  [symbol23](that) {
    return isOption8(that) && isSome8(that) && equals5(this.value, that.value);
  },
  [symbol8]() {
    return cached5(this, combine6(hash5(this._tag))(hash5(this.value)));
  },
  toJSON() {
    return {
      _id: "Option",
      _tag: this._tag,
      value: toJSON5(this.value)
    };
  }
});
var NoneHash5 = /* @__PURE__ */ hash5("None");
var NoneProto5 = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(CommonProto8), {
  _tag: "None",
  _op: "None",
  [symbol23](that) {
    return isOption8(that) && isNone8(that);
  },
  [symbol8]() {
    return NoneHash5;
  },
  toJSON() {
    return {
      _id: "Option",
      _tag: this._tag
    };
  }
});
var isOption8 = (input) => hasProperty5(input, TypeId15);
var isNone8 = (fa) => fa._tag === "None";
var isSome8 = (fa) => fa._tag === "Some";
var none8 = /* @__PURE__ */ Object.create(NoneProto5);
var some12 = (value) => {
  const a22 = Object.create(SomeProto5);
  a22.value = value;
  return a22;
};
var TypeId23 = /* @__PURE__ */ Symbol.for("effect/Either");
var CommonProto23 = {
  ...EffectPrototype5,
  [TypeId23]: {
    _R: (_22) => _22
  },
  [NodeInspectSymbol5]() {
    return this.toJSON();
  },
  toString() {
    return format5(this.toJSON());
  }
};
var RightProto5 = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(CommonProto23), {
  _tag: "Right",
  _op: "Right",
  [symbol23](that) {
    return isEither5(that) && isRight6(that) && equals5(this.right, that.right);
  },
  [symbol8]() {
    return combine6(hash5(this._tag))(hash5(this.right));
  },
  toJSON() {
    return {
      _id: "Either",
      _tag: this._tag,
      right: toJSON5(this.right)
    };
  }
});
var LeftProto5 = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(CommonProto23), {
  _tag: "Left",
  _op: "Left",
  [symbol23](that) {
    return isEither5(that) && isLeft6(that) && equals5(this.left, that.left);
  },
  [symbol8]() {
    return combine6(hash5(this._tag))(hash5(this.left));
  },
  toJSON() {
    return {
      _id: "Either",
      _tag: this._tag,
      left: toJSON5(this.left)
    };
  }
});
var isEither5 = (input) => hasProperty5(input, TypeId23);
var isLeft6 = (ma) => ma._tag === "Left";
var isRight6 = (ma) => ma._tag === "Right";
var left6 = (left33) => {
  const a22 = Object.create(LeftProto5);
  a22.left = left33;
  return a22;
};
var right6 = (right33) => {
  const a22 = Object.create(RightProto5);
  a22.right = right33;
  return a22;
};
var getLeft8 = (self2) => isRight6(self2) ? none8 : some12(self2.left);
var getRight8 = (self2) => isLeft6(self2) ? none8 : some12(self2.right);
var Option_exports5 = {};
__export4(Option_exports5, {
  Do: () => Do6,
  TypeId: () => TypeId33,
  all: () => all8,
  andThen: () => andThen5,
  ap: () => ap5,
  as: () => as5,
  asVoid: () => asVoid5,
  bind: () => bind23,
  bindTo: () => bindTo23,
  composeK: () => composeK5,
  contains: () => contains6,
  containsWith: () => containsWith6,
  exists: () => exists5,
  filter: () => filter6,
  filterMap: () => filterMap6,
  firstSomeOf: () => firstSomeOf5,
  flatMap: () => flatMap6,
  flatMapNullable: () => flatMapNullable6,
  flatten: () => flatten6,
  fromIterable: () => fromIterable8,
  fromNullable: () => fromNullable6,
  gen: () => gen5,
  getEquivalence: () => getEquivalence7,
  getLeft: () => getLeft23,
  getOrElse: () => getOrElse5,
  getOrNull: () => getOrNull5,
  getOrThrow: () => getOrThrow5,
  getOrThrowWith: () => getOrThrowWith5,
  getOrUndefined: () => getOrUndefined5,
  getOrder: () => getOrder6,
  getRight: () => getRight23,
  isNone: () => isNone23,
  isOption: () => isOption23,
  isSome: () => isSome23,
  let: () => let_23,
  lift2: () => lift25,
  liftNullable: () => liftNullable6,
  liftPredicate: () => liftPredicate6,
  liftThrowable: () => liftThrowable5,
  map: () => map6,
  match: () => match7,
  none: () => none23,
  orElse: () => orElse5,
  orElseEither: () => orElseEither5,
  orElseSome: () => orElseSome5,
  partitionMap: () => partitionMap6,
  product: () => product8,
  productMany: () => productMany8,
  reduceCompact: () => reduceCompact5,
  some: () => some23,
  tap: () => tap5,
  toArray: () => toArray5,
  toRefinement: () => toRefinement5,
  void: () => void_5,
  zipLeft: () => zipLeft5,
  zipRight: () => zipRight5,
  zipWith: () => zipWith6
});
var make23 = (compare) => (self2, that) => self2 === that ? 0 : compare(self2, that);
var TypeId33 = /* @__PURE__ */ Symbol.for("effect/Option");
var none23 = () => none8;
var some23 = some12;
var isOption23 = isOption8;
var isNone23 = isNone8;
var isSome23 = isSome8;
var match7 = /* @__PURE__ */ dual5(2, (self2, {
  onNone,
  onSome
}) => isNone23(self2) ? onNone() : onSome(self2.value));
var toRefinement5 = (f22) => (a22) => isSome23(f22(a22));
var fromIterable8 = (collection) => {
  for (const a22 of collection) {
    return some23(a22);
  }
  return none23();
};
var getRight23 = getRight8;
var getLeft23 = getLeft8;
var getOrElse5 = /* @__PURE__ */ dual5(2, (self2, onNone) => isNone23(self2) ? onNone() : self2.value);
var orElse5 = /* @__PURE__ */ dual5(2, (self2, that) => isNone23(self2) ? that() : self2);
var orElseSome5 = /* @__PURE__ */ dual5(2, (self2, onNone) => isNone23(self2) ? some23(onNone()) : self2);
var orElseEither5 = /* @__PURE__ */ dual5(2, (self2, that) => isNone23(self2) ? map6(that(), right6) : map6(self2, left6));
var firstSomeOf5 = (collection) => {
  let out = none23();
  for (out of collection) {
    if (isSome23(out)) {
      return out;
    }
  }
  return out;
};
var fromNullable6 = (nullableValue) => nullableValue == null ? none23() : some23(nullableValue);
var liftNullable6 = (f22) => (...a22) => fromNullable6(f22(...a22));
var getOrNull5 = /* @__PURE__ */ getOrElse5(constNull5);
var getOrUndefined5 = /* @__PURE__ */ getOrElse5(constUndefined5);
var liftThrowable5 = (f22) => (...a22) => {
  try {
    return some23(f22(...a22));
  } catch (e22) {
    return none23();
  }
};
var getOrThrowWith5 = /* @__PURE__ */ dual5(2, (self2, onNone) => {
  if (isSome23(self2)) {
    return self2.value;
  }
  throw onNone();
});
var getOrThrow5 = /* @__PURE__ */ getOrThrowWith5(() => new Error("getOrThrow called on a None"));
var map6 = /* @__PURE__ */ dual5(2, (self2, f22) => isNone23(self2) ? none23() : some23(f22(self2.value)));
var as5 = /* @__PURE__ */ dual5(2, (self2, b22) => map6(self2, () => b22));
var asVoid5 = /* @__PURE__ */ as5(void 0);
var void_5 = /* @__PURE__ */ some23(void 0);
var flatMap6 = /* @__PURE__ */ dual5(2, (self2, f22) => isNone23(self2) ? none23() : f22(self2.value));
var andThen5 = /* @__PURE__ */ dual5(2, (self2, f22) => flatMap6(self2, (a22) => {
  const b22 = isFunction9(f22) ? f22(a22) : f22;
  return isOption23(b22) ? b22 : some23(b22);
}));
var flatMapNullable6 = /* @__PURE__ */ dual5(2, (self2, f22) => isNone23(self2) ? none23() : fromNullable6(f22(self2.value)));
var flatten6 = /* @__PURE__ */ flatMap6(identity5);
var zipRight5 = /* @__PURE__ */ dual5(2, (self2, that) => flatMap6(self2, () => that));
var composeK5 = /* @__PURE__ */ dual5(2, (afb, bfc) => (a22) => flatMap6(afb(a22), bfc));
var zipLeft5 = /* @__PURE__ */ dual5(2, (self2, that) => tap5(self2, () => that));
var tap5 = /* @__PURE__ */ dual5(2, (self2, f22) => flatMap6(self2, (a22) => map6(f22(a22), () => a22)));
var product8 = (self2, that) => isSome23(self2) && isSome23(that) ? some23([self2.value, that.value]) : none23();
var productMany8 = (self2, collection) => {
  if (isNone23(self2)) {
    return none23();
  }
  const out = [self2.value];
  for (const o22 of collection) {
    if (isNone23(o22)) {
      return none23();
    }
    out.push(o22.value);
  }
  return some23(out);
};
var all8 = (input) => {
  if (Symbol.iterator in input) {
    const out2 = [];
    for (const o22 of input) {
      if (isNone23(o22)) {
        return none23();
      }
      out2.push(o22.value);
    }
    return some23(out2);
  }
  const out = {};
  for (const key of Object.keys(input)) {
    const o22 = input[key];
    if (isNone23(o22)) {
      return none23();
    }
    out[key] = o22.value;
  }
  return some23(out);
};
var zipWith6 = /* @__PURE__ */ dual5(3, (self2, that, f22) => map6(product8(self2, that), ([a22, b22]) => f22(a22, b22)));
var ap5 = /* @__PURE__ */ dual5(2, (self2, that) => zipWith6(self2, that, (f22, a22) => f22(a22)));
var reduceCompact5 = /* @__PURE__ */ dual5(3, (self2, b22, f22) => {
  let out = b22;
  for (const oa of self2) {
    if (isSome23(oa)) {
      out = f22(out, oa.value);
    }
  }
  return out;
});
var toArray5 = (self2) => isNone23(self2) ? [] : [self2.value];
var partitionMap6 = /* @__PURE__ */ dual5(2, (self2, f22) => {
  if (isNone23(self2)) {
    return [none23(), none23()];
  }
  const e22 = f22(self2.value);
  return isLeft6(e22) ? [some23(e22.left), none23()] : [none23(), some23(e22.right)];
});
var filterMap6 = /* @__PURE__ */ dual5(2, (self2, f22) => isNone23(self2) ? none23() : f22(self2.value));
var filter6 = /* @__PURE__ */ dual5(2, (self2, predicate) => filterMap6(self2, (b22) => predicate(b22) ? some12(b22) : none8));
var getEquivalence7 = (isEquivalent) => make16((x22, y22) => x22 === y22 || (isNone23(x22) ? isNone23(y22) : isNone23(y22) ? false : isEquivalent(x22.value, y22.value)));
var getOrder6 = (O22) => make23((self2, that) => isSome23(self2) ? isSome23(that) ? O22(self2.value, that.value) : 1 : -1);
var lift25 = (f22) => dual5(2, (self2, that) => zipWith6(self2, that, f22));
var liftPredicate6 = (predicate) => (b22) => predicate(b22) ? some23(b22) : none23();
var containsWith6 = (isEquivalent) => dual5(2, (self2, a22) => isNone23(self2) ? false : isEquivalent(self2.value, a22));
var _equivalence7 = /* @__PURE__ */ equivalence5();
var contains6 = /* @__PURE__ */ containsWith6(_equivalence7);
var exists5 = /* @__PURE__ */ dual5(2, (self2, refinement) => isNone23(self2) ? false : refinement(self2.value));
var bindTo23 = /* @__PURE__ */ bindTo9(map6);
var let_23 = /* @__PURE__ */ let_9(map6);
var bind23 = /* @__PURE__ */ bind9(map6, flatMap6);
var Do6 = /* @__PURE__ */ some23({});
var adapter23 = /* @__PURE__ */ adapter8();
var gen5 = (f22) => {
  const iterator = f22(adapter23);
  let state = iterator.next();
  if (state.done) {
    return some23(state.value);
  } else {
    let current = state.value;
    if (isGenKind5(current)) {
      current = current.value;
    } else {
      current = yieldWrapGet5(current);
    }
    if (isNone23(current)) {
      return current;
    }
    while (!state.done) {
      state = iterator.next(current.value);
      if (!state.done) {
        current = state.value;
        if (isGenKind5(current)) {
          current = current.value;
        } else {
          current = yieldWrapGet5(current);
        }
        if (isNone23(current)) {
          return current;
        }
      }
    }
    return some23(state.value);
  }
};
var MutableRef_exports3 = {};
__export4(MutableRef_exports3, {
  compareAndSet: () => compareAndSet3,
  decrement: () => decrement3,
  decrementAndGet: () => decrementAndGet3,
  get: () => get4,
  getAndDecrement: () => getAndDecrement3,
  getAndIncrement: () => getAndIncrement3,
  getAndSet: () => getAndSet3,
  getAndUpdate: () => getAndUpdate3,
  increment: () => increment3,
  incrementAndGet: () => incrementAndGet3,
  make: () => make33,
  set: () => set4,
  setAndGet: () => setAndGet3,
  toggle: () => toggle3,
  update: () => update3,
  updateAndGet: () => updateAndGet3
});
var TypeId43 = /* @__PURE__ */ Symbol.for("effect/MutableRef");
var MutableRefProto3 = {
  [TypeId43]: TypeId43,
  toString() {
    return format5(this.toJSON());
  },
  toJSON() {
    return {
      _id: "MutableRef",
      current: toJSON5(this.current)
    };
  },
  [NodeInspectSymbol5]() {
    return this.toJSON();
  },
  pipe() {
    return pipeArguments5(this, arguments);
  }
};
var make33 = (value) => {
  const ref = Object.create(MutableRefProto3);
  ref.current = value;
  return ref;
};
var compareAndSet3 = /* @__PURE__ */ dual5(3, (self2, oldValue, newValue) => {
  if (equals5(oldValue, self2.current)) {
    self2.current = newValue;
    return true;
  }
  return false;
});
var decrement3 = (self2) => update3(self2, (n22) => n22 - 1);
var decrementAndGet3 = (self2) => updateAndGet3(self2, (n22) => n22 - 1);
var get4 = (self2) => self2.current;
var getAndDecrement3 = (self2) => getAndUpdate3(self2, (n22) => n22 - 1);
var getAndIncrement3 = (self2) => getAndUpdate3(self2, (n22) => n22 + 1);
var getAndSet3 = /* @__PURE__ */ dual5(2, (self2, value) => {
  const ret = self2.current;
  self2.current = value;
  return ret;
});
var getAndUpdate3 = /* @__PURE__ */ dual5(2, (self2, f22) => getAndSet3(self2, f22(get4(self2))));
var increment3 = (self2) => update3(self2, (n22) => n22 + 1);
var incrementAndGet3 = (self2) => updateAndGet3(self2, (n22) => n22 + 1);
var set4 = /* @__PURE__ */ dual5(2, (self2, value) => {
  self2.current = value;
  return self2;
});
var setAndGet3 = /* @__PURE__ */ dual5(2, (self2, value) => {
  self2.current = value;
  return self2.current;
});
var update3 = /* @__PURE__ */ dual5(2, (self2, f22) => set4(self2, f22(get4(self2))));
var updateAndGet3 = /* @__PURE__ */ dual5(2, (self2, f22) => setAndGet3(self2, f22(get4(self2))));
var toggle3 = (self2) => update3(self2, (_22) => !_22);
function getVariables2(initialScope) {
  const scopeRef = MutableRef_exports3.make(initialScope);
  const variablesRef = MutableRef_exports3.make(MutableRef_exports3.get(scopeRef).variables);
  while (MutableRef_exports3.get(scopeRef).type !== scopeManager.ScopeType.global) {
    MutableRef_exports3.set(scopeRef, MutableRef_exports3.get(scopeRef).upper);
    MutableRef_exports3.update(variablesRef, (variables) => variables.concat(MutableRef_exports3.get(scopeRef).variables));
  }
  return MutableRef_exports3.get(variablesRef).reverse();
}
var findVariable3 = Function_exports5.dual(2, (name, initialScope) => {
  return Option_exports5.fromNullable(getVariables2(initialScope).find((variable) => variable.name === name));
});
var t2 = Symbol.for("@ts-pattern/matcher");
var e2 = Symbol.for("@ts-pattern/isVariadic");
var n2 = "@ts-pattern/anonymous-select-key";
var r2 = (t22) => Boolean(t22 && "object" == typeof t22);
var i2 = (e22) => e22 && !!e22[t2];
var o2 = (n22, s22, c22) => {
  if (i2(n22)) {
    const e22 = n22[t2](), { matched: r22, selections: i22 } = e22.match(s22);
    return r22 && i22 && Object.keys(i22).forEach((t22) => c22(t22, i22[t22])), r22;
  }
  if (r2(n22)) {
    if (!r2(s22)) return false;
    if (Array.isArray(n22)) {
      if (!Array.isArray(s22)) return false;
      let t22 = [], r22 = [], a22 = [];
      for (const o22 of n22.keys()) {
        const s3 = n22[o22];
        i2(s3) && s3[e2] ? a22.push(s3) : a22.length ? r22.push(s3) : t22.push(s3);
      }
      if (a22.length) {
        if (a22.length > 1) throw new Error("Pattern error: Using `...P.array(...)` several times in a single pattern is not allowed.");
        if (s22.length < t22.length + r22.length) return false;
        const e22 = s22.slice(0, t22.length), n3 = 0 === r22.length ? [] : s22.slice(-r22.length), i22 = s22.slice(t22.length, 0 === r22.length ? Infinity : -r22.length);
        return t22.every((t3, n4) => o2(t3, e22[n4], c22)) && r22.every((t3, e3) => o2(t3, n3[e3], c22)) && (0 === a22.length || o2(a22[0], i22, c22));
      }
      return n22.length === s22.length && n22.every((t3, e22) => o2(t3, s22[e22], c22));
    }
    return Object.keys(n22).every((e22) => {
      const r22 = n22[e22];
      return (e22 in s22 || i2(a22 = r22) && "optional" === a22[t2]().matcherType) && o2(r22, s22[e22], c22);
      var a22;
    });
  }
  return Object.is(s22, n22);
};
var s2 = (e22) => {
  var n22, o22, a22;
  return r2(e22) ? i2(e22) ? null != (n22 = null == (o22 = (a22 = e22[t2]()).getSelectionKeys) ? void 0 : o22.call(a22)) ? n22 : [] : Array.isArray(e22) ? c2(e22, s2) : c2(Object.values(e22), s2) : [];
};
var c2 = (t22, e22) => t22.reduce((t3, n22) => t3.concat(e22(n22)), []);
function a2(...t22) {
  if (1 === t22.length) {
    const [e22] = t22;
    return (t3) => o2(e22, t3, () => {
    });
  }
  if (2 === t22.length) {
    const [e22, n22] = t22;
    return o2(e22, n22, () => {
    });
  }
  throw new Error(`isMatching wasn't given the right number of arguments: expected 1 or 2, received ${t22.length}.`);
}
function u2(t22) {
  return Object.assign(t22, { optional: () => l2(t22), and: (e22) => m2(t22, e22), or: (e22) => d2(t22, e22), select: (e22) => void 0 === e22 ? p2(t22) : p2(e22, t22) });
}
function h2(t22) {
  return Object.assign(((t3) => Object.assign(t3, { [Symbol.iterator]() {
    let n22 = 0;
    const r22 = [{ value: Object.assign(t3, { [e2]: true }), done: false }, { done: true, value: void 0 }];
    return { next: () => {
      var t4;
      return null != (t4 = r22[n22++]) ? t4 : r22.at(-1);
    } };
  } }))(t22), { optional: () => h2(l2(t22)), select: (e22) => h2(void 0 === e22 ? p2(t22) : p2(e22, t22)) });
}
function l2(e22) {
  return u2({ [t2]: () => ({ match: (t22) => {
    let n22 = {};
    const r22 = (t3, e3) => {
      n22[t3] = e3;
    };
    return void 0 === t22 ? (s2(e22).forEach((t3) => r22(t3, void 0)), { matched: true, selections: n22 }) : { matched: o2(e22, t22, r22), selections: n22 };
  }, getSelectionKeys: () => s2(e22), matcherType: "optional" }) });
}
var f2 = (t22, e22) => {
  for (const n22 of t22) if (!e22(n22)) return false;
  return true;
};
var g2 = (t22, e22) => {
  for (const [n22, r22] of t22.entries()) if (!e22(r22, n22)) return false;
  return true;
};
function m2(...e22) {
  return u2({ [t2]: () => ({ match: (t22) => {
    let n22 = {};
    const r22 = (t3, e3) => {
      n22[t3] = e3;
    };
    return { matched: e22.every((e3) => o2(e3, t22, r22)), selections: n22 };
  }, getSelectionKeys: () => c2(e22, s2), matcherType: "and" }) });
}
function d2(...e22) {
  return u2({ [t2]: () => ({ match: (t22) => {
    let n22 = {};
    const r22 = (t3, e3) => {
      n22[t3] = e3;
    };
    return c2(e22, s2).forEach((t3) => r22(t3, void 0)), { matched: e22.some((e3) => o2(e3, t22, r22)), selections: n22 };
  }, getSelectionKeys: () => c2(e22, s2), matcherType: "or" }) });
}
function y2(e22) {
  return { [t2]: () => ({ match: (t22) => ({ matched: Boolean(e22(t22)) }) }) };
}
function p2(...e22) {
  const r22 = "string" == typeof e22[0] ? e22[0] : void 0, i22 = 2 === e22.length ? e22[1] : "string" == typeof e22[0] ? void 0 : e22[0];
  return u2({ [t2]: () => ({ match: (t22) => {
    let e3 = { [null != r22 ? r22 : n2]: t22 };
    return { matched: void 0 === i22 || o2(i22, t22, (t3, n22) => {
      e3[t3] = n22;
    }), selections: e3 };
  }, getSelectionKeys: () => [null != r22 ? r22 : n2].concat(void 0 === i22 ? [] : s2(i22)) }) });
}
function v2(t22) {
  return "number" == typeof t22;
}
function b2(t22) {
  return "string" == typeof t22;
}
function w2(t22) {
  return "bigint" == typeof t22;
}
var S2 = u2(y2(function(t22) {
  return true;
}));
var O2 = S2;
var j2 = (t22) => Object.assign(u2(t22), { startsWith: (e22) => {
  return j2(m2(t22, (n22 = e22, y2((t3) => b2(t3) && t3.startsWith(n22)))));
  var n22;
}, endsWith: (e22) => {
  return j2(m2(t22, (n22 = e22, y2((t3) => b2(t3) && t3.endsWith(n22)))));
  var n22;
}, minLength: (e22) => j2(m2(t22, ((t3) => y2((e3) => b2(e3) && e3.length >= t3))(e22))), maxLength: (e22) => j2(m2(t22, ((t3) => y2((e3) => b2(e3) && e3.length <= t3))(e22))), includes: (e22) => {
  return j2(m2(t22, (n22 = e22, y2((t3) => b2(t3) && t3.includes(n22)))));
  var n22;
}, regex: (e22) => {
  return j2(m2(t22, (n22 = e22, y2((t3) => b2(t3) && Boolean(t3.match(n22))))));
  var n22;
} });
var E2 = j2(y2(b2));
var K2 = (t22) => Object.assign(u2(t22), { between: (e22, n22) => K2(m2(t22, ((t3, e3) => y2((n3) => v2(n3) && t3 <= n3 && e3 >= n3))(e22, n22))), lt: (e22) => K2(m2(t22, ((t3) => y2((e3) => v2(e3) && e3 < t3))(e22))), gt: (e22) => K2(m2(t22, ((t3) => y2((e3) => v2(e3) && e3 > t3))(e22))), lte: (e22) => K2(m2(t22, ((t3) => y2((e3) => v2(e3) && e3 <= t3))(e22))), gte: (e22) => K2(m2(t22, ((t3) => y2((e3) => v2(e3) && e3 >= t3))(e22))), int: () => K2(m2(t22, y2((t3) => v2(t3) && Number.isInteger(t3)))), finite: () => K2(m2(t22, y2((t3) => v2(t3) && Number.isFinite(t3)))), positive: () => K2(m2(t22, y2((t3) => v2(t3) && t3 > 0))), negative: () => K2(m2(t22, y2((t3) => v2(t3) && t3 < 0))) });
var x2 = K2(y2(v2));
var A2 = (t22) => Object.assign(u2(t22), { between: (e22, n22) => A2(m2(t22, ((t3, e3) => y2((n3) => w2(n3) && t3 <= n3 && e3 >= n3))(e22, n22))), lt: (e22) => A2(m2(t22, ((t3) => y2((e3) => w2(e3) && e3 < t3))(e22))), gt: (e22) => A2(m2(t22, ((t3) => y2((e3) => w2(e3) && e3 > t3))(e22))), lte: (e22) => A2(m2(t22, ((t3) => y2((e3) => w2(e3) && e3 <= t3))(e22))), gte: (e22) => A2(m2(t22, ((t3) => y2((e3) => w2(e3) && e3 >= t3))(e22))), positive: () => A2(m2(t22, y2((t3) => w2(t3) && t3 > 0))), negative: () => A2(m2(t22, y2((t3) => w2(t3) && t3 < 0))) });
var P3 = A2(y2(w2));
var T2 = u2(y2(function(t22) {
  return "boolean" == typeof t22;
}));
var k2 = u2(y2(function(t22) {
  return "symbol" == typeof t22;
}));
var B2 = u2(y2(function(t22) {
  return null == t22;
}));
var _2 = u2(y2(function(t22) {
  return null != t22;
}));
var N2 = { __proto__: null, matcher: t2, optional: l2, array: function(...e22) {
  return h2({ [t2]: () => ({ match: (t22) => {
    if (!Array.isArray(t22)) return { matched: false };
    if (0 === e22.length) return { matched: true };
    const n22 = e22[0];
    let r22 = {};
    if (0 === t22.length) return s2(n22).forEach((t3) => {
      r22[t3] = [];
    }), { matched: true, selections: r22 };
    const i22 = (t3, e3) => {
      r22[t3] = (r22[t3] || []).concat([e3]);
    };
    return { matched: t22.every((t3) => o2(n22, t3, i22)), selections: r22 };
  }, getSelectionKeys: () => 0 === e22.length ? [] : s2(e22[0]) }) });
}, set: function(...e22) {
  return u2({ [t2]: () => ({ match: (t22) => {
    if (!(t22 instanceof Set)) return { matched: false };
    let n22 = {};
    if (0 === t22.size) return { matched: true, selections: n22 };
    if (0 === e22.length) return { matched: true };
    const r22 = (t3, e3) => {
      n22[t3] = (n22[t3] || []).concat([e3]);
    }, i22 = e22[0];
    return { matched: f2(t22, (t3) => o2(i22, t3, r22)), selections: n22 };
  }, getSelectionKeys: () => 0 === e22.length ? [] : s2(e22[0]) }) });
}, map: function(...e22) {
  return u2({ [t2]: () => ({ match: (t22) => {
    if (!(t22 instanceof Map)) return { matched: false };
    let n22 = {};
    if (0 === t22.size) return { matched: true, selections: n22 };
    const r22 = (t3, e3) => {
      n22[t3] = (n22[t3] || []).concat([e3]);
    };
    if (0 === e22.length) return { matched: true };
    var i22;
    if (1 === e22.length) throw new Error(`\`P.map\` wasn't given enough arguments. Expected (key, value), received ${null == (i22 = e22[0]) ? void 0 : i22.toString()}`);
    const [s22, c22] = e22;
    return { matched: g2(t22, (t3, e3) => {
      const n3 = o2(s22, e3, r22), i3 = o2(c22, t3, r22);
      return n3 && i3;
    }), selections: n22 };
  }, getSelectionKeys: () => 0 === e22.length ? [] : [...s2(e22[0]), ...s2(e22[1])] }) });
}, intersection: m2, union: d2, not: function(e22) {
  return u2({ [t2]: () => ({ match: (t22) => ({ matched: !o2(e22, t22, () => {
  }) }), getSelectionKeys: () => [], matcherType: "not" }) });
}, when: y2, select: p2, any: S2, _: O2, string: E2, number: x2, bigint: P3, boolean: T2, symbol: k2, nullish: B2, nonNullable: _2, instanceOf: function(t22) {
  return u2(y2(/* @__PURE__ */ function(t3) {
    return (e22) => e22 instanceof t3;
  }(t22)));
}, shape: function(t22) {
  return u2(y2(a2(t22)));
} };
var KEYS3 = {
  ArrayExpression: [
    "elements"
  ],
  ArrayPattern: [
    "elements"
  ],
  ArrowFunctionExpression: [
    "params",
    "body"
  ],
  AssignmentExpression: [
    "left",
    "right"
  ],
  AssignmentPattern: [
    "left",
    "right"
  ],
  AwaitExpression: [
    "argument"
  ],
  BinaryExpression: [
    "left",
    "right"
  ],
  BlockStatement: [
    "body"
  ],
  BreakStatement: [
    "label"
  ],
  CallExpression: [
    "callee",
    "arguments"
  ],
  CatchClause: [
    "param",
    "body"
  ],
  ChainExpression: [
    "expression"
  ],
  ClassBody: [
    "body"
  ],
  ClassDeclaration: [
    "id",
    "superClass",
    "body"
  ],
  ClassExpression: [
    "id",
    "superClass",
    "body"
  ],
  ConditionalExpression: [
    "test",
    "consequent",
    "alternate"
  ],
  ContinueStatement: [
    "label"
  ],
  DebuggerStatement: [],
  DoWhileStatement: [
    "body",
    "test"
  ],
  EmptyStatement: [],
  ExperimentalRestProperty: [
    "argument"
  ],
  ExperimentalSpreadProperty: [
    "argument"
  ],
  ExportAllDeclaration: [
    "exported",
    "source"
  ],
  ExportDefaultDeclaration: [
    "declaration"
  ],
  ExportNamedDeclaration: [
    "declaration",
    "specifiers",
    "source"
  ],
  ExportSpecifier: [
    "exported",
    "local"
  ],
  ExpressionStatement: [
    "expression"
  ],
  ForInStatement: [
    "left",
    "right",
    "body"
  ],
  ForOfStatement: [
    "left",
    "right",
    "body"
  ],
  ForStatement: [
    "init",
    "test",
    "update",
    "body"
  ],
  FunctionDeclaration: [
    "id",
    "params",
    "body"
  ],
  FunctionExpression: [
    "id",
    "params",
    "body"
  ],
  Identifier: [],
  IfStatement: [
    "test",
    "consequent",
    "alternate"
  ],
  ImportDeclaration: [
    "specifiers",
    "source"
  ],
  ImportDefaultSpecifier: [
    "local"
  ],
  ImportExpression: [
    "source"
  ],
  ImportNamespaceSpecifier: [
    "local"
  ],
  ImportSpecifier: [
    "imported",
    "local"
  ],
  JSXAttribute: [
    "name",
    "value"
  ],
  JSXClosingElement: [
    "name"
  ],
  JSXClosingFragment: [],
  JSXElement: [
    "openingElement",
    "children",
    "closingElement"
  ],
  JSXEmptyExpression: [],
  JSXExpressionContainer: [
    "expression"
  ],
  JSXFragment: [
    "openingFragment",
    "children",
    "closingFragment"
  ],
  JSXIdentifier: [],
  JSXMemberExpression: [
    "object",
    "property"
  ],
  JSXNamespacedName: [
    "namespace",
    "name"
  ],
  JSXOpeningElement: [
    "name",
    "attributes"
  ],
  JSXOpeningFragment: [],
  JSXSpreadAttribute: [
    "argument"
  ],
  JSXSpreadChild: [
    "expression"
  ],
  JSXText: [],
  LabeledStatement: [
    "label",
    "body"
  ],
  Literal: [],
  LogicalExpression: [
    "left",
    "right"
  ],
  MemberExpression: [
    "object",
    "property"
  ],
  MetaProperty: [
    "meta",
    "property"
  ],
  MethodDefinition: [
    "key",
    "value"
  ],
  NewExpression: [
    "callee",
    "arguments"
  ],
  ObjectExpression: [
    "properties"
  ],
  ObjectPattern: [
    "properties"
  ],
  PrivateIdentifier: [],
  Program: [
    "body"
  ],
  Property: [
    "key",
    "value"
  ],
  PropertyDefinition: [
    "key",
    "value"
  ],
  RestElement: [
    "argument"
  ],
  ReturnStatement: [
    "argument"
  ],
  SequenceExpression: [
    "expressions"
  ],
  SpreadElement: [
    "argument"
  ],
  StaticBlock: [
    "body"
  ],
  Super: [],
  SwitchCase: [
    "test",
    "consequent"
  ],
  SwitchStatement: [
    "discriminant",
    "cases"
  ],
  TaggedTemplateExpression: [
    "tag",
    "quasi"
  ],
  TemplateElement: [],
  TemplateLiteral: [
    "quasis",
    "expressions"
  ],
  ThisExpression: [],
  ThrowStatement: [
    "argument"
  ],
  TryStatement: [
    "block",
    "handler",
    "finalizer"
  ],
  UnaryExpression: [
    "argument"
  ],
  UpdateExpression: [
    "argument"
  ],
  VariableDeclaration: [
    "declarations"
  ],
  VariableDeclarator: [
    "id",
    "init"
  ],
  WhileStatement: [
    "test",
    "body"
  ],
  WithStatement: [
    "object",
    "body"
  ],
  YieldExpression: [
    "argument"
  ]
};
var NODE_TYPES3 = Object.keys(KEYS3);
for (const type of NODE_TYPES3) {
  Object.freeze(KEYS3[type]);
}
Object.freeze(KEYS3);
var visitor_keys_default3 = KEYS3;
var KEY_BLACKLIST3 = /* @__PURE__ */ new Set([
  "parent",
  "leadingComments",
  "trailingComments"
]);
function filterKey3(key) {
  return !KEY_BLACKLIST3.has(key) && key[0] !== "_";
}
function getKeys3(node) {
  return Object.keys(node).filter(filterKey3);
}
function getInnermostScope3(initialScope, node) {
  const location = node.range[0];
  let scope = initialScope;
  let found = false;
  do {
    found = false;
    for (const childScope of scope.childScopes) {
      const range2 = childScope.block.range;
      if (range2[0] <= location && location < range2[1]) {
        scope = childScope;
        found = true;
        break;
      }
    }
  } while (found);
  return scope;
}
function findVariable23(initialScope, nameOrNode) {
  let name = "";
  let scope = initialScope;
  if (typeof nameOrNode === "string") {
    name = nameOrNode;
  } else {
    name = nameOrNode.name;
    scope = getInnermostScope3(scope, nameOrNode);
  }
  while (scope != null) {
    const variable = scope.set.get(name);
    if (variable != null) {
      return variable;
    }
    scope = scope.upper;
  }
  return null;
}
function negate03(token) {
  return !this(token);
}
function negate3(f22) {
  return negate03.bind(f22);
}
function isPunctuatorTokenWithValue3(token, value) {
  return token.type === "Punctuator" && token.value === value;
}
function isArrowToken3(token) {
  return isPunctuatorTokenWithValue3(token, "=>");
}
function isCommaToken3(token) {
  return isPunctuatorTokenWithValue3(token, ",");
}
function isSemicolonToken3(token) {
  return isPunctuatorTokenWithValue3(token, ";");
}
function isColonToken3(token) {
  return isPunctuatorTokenWithValue3(token, ":");
}
function isOpeningParenToken3(token) {
  return isPunctuatorTokenWithValue3(token, "(");
}
function isClosingParenToken3(token) {
  return isPunctuatorTokenWithValue3(token, ")");
}
function isOpeningBracketToken3(token) {
  return isPunctuatorTokenWithValue3(token, "[");
}
function isClosingBracketToken3(token) {
  return isPunctuatorTokenWithValue3(token, "]");
}
function isOpeningBraceToken3(token) {
  return isPunctuatorTokenWithValue3(token, "{");
}
function isClosingBraceToken3(token) {
  return isPunctuatorTokenWithValue3(token, "}");
}
function isCommentToken3(token) {
  return ["Block", "Line", "Shebang"].includes(token.type);
}
negate3(isArrowToken3);
negate3(isCommaToken3);
negate3(isSemicolonToken3);
negate3(isColonToken3);
negate3(isOpeningParenToken3);
negate3(isClosingParenToken3);
negate3(isOpeningBracketToken3);
negate3(isClosingBracketToken3);
negate3(isOpeningBraceToken3);
negate3(isClosingBraceToken3);
negate3(isCommentToken3);
function getOpeningParenOfParams3(node, sourceCode) {
  return node.id ? sourceCode.getTokenAfter(node.id, isOpeningParenToken3) : sourceCode.getFirstToken(node, isOpeningParenToken3);
}
function getFunctionHeadLocation3(node, sourceCode) {
  const parent = node.parent;
  let start = null;
  let end = null;
  if (node.type === "ArrowFunctionExpression") {
    const arrowToken = sourceCode.getTokenBefore(node.body, isArrowToken3);
    start = arrowToken.loc.start;
    end = arrowToken.loc.end;
  } else if (parent.type === "Property" || parent.type === "MethodDefinition" || parent.type === "PropertyDefinition") {
    start = parent.loc.start;
    end = getOpeningParenOfParams3(node, sourceCode).loc.start;
  } else {
    start = node.loc.start;
    end = getOpeningParenOfParams3(node, sourceCode).loc.start;
  }
  return {
    start: { ...start },
    end: { ...end }
  };
}
var globalObject3 = typeof globalThis !== "undefined" ? globalThis : typeof self !== "undefined" ? self : typeof window !== "undefined" ? window : typeof global !== "undefined" ? global : {};
var builtinNames3 = Object.freeze(
  /* @__PURE__ */ new Set([
    "Array",
    "ArrayBuffer",
    "BigInt",
    "BigInt64Array",
    "BigUint64Array",
    "Boolean",
    "DataView",
    "Date",
    "decodeURI",
    "decodeURIComponent",
    "encodeURI",
    "encodeURIComponent",
    "escape",
    "Float32Array",
    "Float64Array",
    "Function",
    "Infinity",
    "Int16Array",
    "Int32Array",
    "Int8Array",
    "isFinite",
    "isNaN",
    "isPrototypeOf",
    "JSON",
    "Map",
    "Math",
    "NaN",
    "Number",
    "Object",
    "parseFloat",
    "parseInt",
    "Promise",
    "Proxy",
    "Reflect",
    "RegExp",
    "Set",
    "String",
    "Symbol",
    "Uint16Array",
    "Uint32Array",
    "Uint8Array",
    "Uint8ClampedArray",
    "undefined",
    "unescape",
    "WeakMap",
    "WeakSet"
  ])
);
var callAllowed3 = new Set(
  [
    Array.isArray,
    Array.of,
    Array.prototype.at,
    Array.prototype.concat,
    Array.prototype.entries,
    Array.prototype.every,
    Array.prototype.filter,
    Array.prototype.find,
    Array.prototype.findIndex,
    Array.prototype.flat,
    Array.prototype.includes,
    Array.prototype.indexOf,
    Array.prototype.join,
    Array.prototype.keys,
    Array.prototype.lastIndexOf,
    Array.prototype.slice,
    Array.prototype.some,
    Array.prototype.toString,
    Array.prototype.values,
    typeof BigInt === "function" ? BigInt : void 0,
    Boolean,
    Date,
    Date.parse,
    decodeURI,
    decodeURIComponent,
    encodeURI,
    encodeURIComponent,
    escape,
    isFinite,
    isNaN,
    isPrototypeOf,
    Map,
    Map.prototype.entries,
    Map.prototype.get,
    Map.prototype.has,
    Map.prototype.keys,
    Map.prototype.values,
    ...Object.getOwnPropertyNames(Math).filter((k22) => k22 !== "random").map((k22) => Math[k22]).filter((f22) => typeof f22 === "function"),
    Number,
    Number.isFinite,
    Number.isNaN,
    Number.parseFloat,
    Number.parseInt,
    Number.prototype.toExponential,
    Number.prototype.toFixed,
    Number.prototype.toPrecision,
    Number.prototype.toString,
    Object,
    Object.entries,
    Object.is,
    Object.isExtensible,
    Object.isFrozen,
    Object.isSealed,
    Object.keys,
    Object.values,
    parseFloat,
    parseInt,
    RegExp,
    Set,
    Set.prototype.entries,
    Set.prototype.has,
    Set.prototype.keys,
    Set.prototype.values,
    String,
    String.fromCharCode,
    String.fromCodePoint,
    String.raw,
    String.prototype.at,
    String.prototype.charAt,
    String.prototype.charCodeAt,
    String.prototype.codePointAt,
    String.prototype.concat,
    String.prototype.endsWith,
    String.prototype.includes,
    String.prototype.indexOf,
    String.prototype.lastIndexOf,
    String.prototype.normalize,
    String.prototype.padEnd,
    String.prototype.padStart,
    String.prototype.slice,
    String.prototype.startsWith,
    String.prototype.substr,
    String.prototype.substring,
    String.prototype.toLowerCase,
    String.prototype.toString,
    String.prototype.toUpperCase,
    String.prototype.trim,
    String.prototype.trimEnd,
    String.prototype.trimLeft,
    String.prototype.trimRight,
    String.prototype.trimStart,
    Symbol.for,
    Symbol.keyFor,
    unescape
  ].filter((f22) => typeof f22 === "function")
);
var callPassThrough3 = /* @__PURE__ */ new Set([
  Object.freeze,
  Object.preventExtensions,
  Object.seal
]);
var getterAllowed3 = [
  [Map, /* @__PURE__ */ new Set(["size"])],
  [
    RegExp,
    /* @__PURE__ */ new Set([
      "dotAll",
      "flags",
      "global",
      "hasIndices",
      "ignoreCase",
      "multiline",
      "source",
      "sticky",
      "unicode"
    ])
  ],
  [Set, /* @__PURE__ */ new Set(["size"])]
];
function getPropertyDescriptor3(object2, name) {
  let x22 = object2;
  while ((typeof x22 === "object" || typeof x22 === "function") && x22 !== null) {
    const d22 = Object.getOwnPropertyDescriptor(x22, name);
    if (d22) {
      return d22;
    }
    x22 = Object.getPrototypeOf(x22);
  }
  return null;
}
function isGetter3(object2, name) {
  const d22 = getPropertyDescriptor3(object2, name);
  return d22 != null && d22.get != null;
}
function getElementValues3(nodeList, initialScope) {
  const valueList = [];
  for (let i22 = 0; i22 < nodeList.length; ++i22) {
    const elementNode = nodeList[i22];
    if (elementNode == null) {
      valueList.length = i22 + 1;
    } else if (elementNode.type === "SpreadElement") {
      const argument = getStaticValueR3(elementNode.argument, initialScope);
      if (argument == null) {
        return null;
      }
      valueList.push(...argument.value);
    } else {
      const element = getStaticValueR3(elementNode, initialScope);
      if (element == null) {
        return null;
      }
      valueList.push(element.value);
    }
  }
  return valueList;
}
function isEffectivelyConst3(variable) {
  const refs = variable.references;
  const inits = refs.filter((r22) => r22.init).length;
  const reads = refs.filter((r22) => r22.isReadOnly()).length;
  if (inits === 1 && reads + inits === refs.length) {
    return true;
  }
  return false;
}
var operations3 = Object.freeze({
  ArrayExpression(node, initialScope) {
    const elements = getElementValues3(node.elements, initialScope);
    return elements != null ? { value: elements } : null;
  },
  AssignmentExpression(node, initialScope) {
    if (node.operator === "=") {
      return getStaticValueR3(node.right, initialScope);
    }
    return null;
  },
  //eslint-disable-next-line complexity
  BinaryExpression(node, initialScope) {
    if (node.operator === "in" || node.operator === "instanceof") {
      return null;
    }
    const left33 = getStaticValueR3(node.left, initialScope);
    const right33 = getStaticValueR3(node.right, initialScope);
    if (left33 != null && right33 != null) {
      switch (node.operator) {
        case "==":
          return { value: left33.value == right33.value };
        case "!=":
          return { value: left33.value != right33.value };
        case "===":
          return { value: left33.value === right33.value };
        case "!==":
          return { value: left33.value !== right33.value };
        case "<":
          return { value: left33.value < right33.value };
        case "<=":
          return { value: left33.value <= right33.value };
        case ">":
          return { value: left33.value > right33.value };
        case ">=":
          return { value: left33.value >= right33.value };
        case "<<":
          return { value: left33.value << right33.value };
        case ">>":
          return { value: left33.value >> right33.value };
        case ">>>":
          return { value: left33.value >>> right33.value };
        case "+":
          return { value: left33.value + right33.value };
        case "-":
          return { value: left33.value - right33.value };
        case "*":
          return { value: left33.value * right33.value };
        case "/":
          return { value: left33.value / right33.value };
        case "%":
          return { value: left33.value % right33.value };
        case "**":
          return { value: left33.value ** right33.value };
        case "|":
          return { value: left33.value | right33.value };
        case "^":
          return { value: left33.value ^ right33.value };
        case "&":
          return { value: left33.value & right33.value };
      }
    }
    return null;
  },
  CallExpression(node, initialScope) {
    const calleeNode = node.callee;
    const args = getElementValues3(node.arguments, initialScope);
    if (args != null) {
      if (calleeNode.type === "MemberExpression") {
        if (calleeNode.property.type === "PrivateIdentifier") {
          return null;
        }
        const object2 = getStaticValueR3(calleeNode.object, initialScope);
        if (object2 != null) {
          if (object2.value == null && (object2.optional || node.optional)) {
            return { value: void 0, optional: true };
          }
          const property = getStaticPropertyNameValue3(
            calleeNode,
            initialScope
          );
          if (property != null) {
            const receiver = object2.value;
            const methodName = property.value;
            if (callAllowed3.has(receiver[methodName])) {
              return { value: receiver[methodName](...args) };
            }
            if (callPassThrough3.has(receiver[methodName])) {
              return { value: args[0] };
            }
          }
        }
      } else {
        const callee = getStaticValueR3(calleeNode, initialScope);
        if (callee != null) {
          if (callee.value == null && node.optional) {
            return { value: void 0, optional: true };
          }
          const func = callee.value;
          if (callAllowed3.has(func)) {
            return { value: func(...args) };
          }
          if (callPassThrough3.has(func)) {
            return { value: args[0] };
          }
        }
      }
    }
    return null;
  },
  ConditionalExpression(node, initialScope) {
    const test = getStaticValueR3(node.test, initialScope);
    if (test != null) {
      return test.value ? getStaticValueR3(node.consequent, initialScope) : getStaticValueR3(node.alternate, initialScope);
    }
    return null;
  },
  ExpressionStatement(node, initialScope) {
    return getStaticValueR3(node.expression, initialScope);
  },
  Identifier(node, initialScope) {
    if (initialScope != null) {
      const variable = findVariable23(initialScope, node);
      if (variable != null && variable.defs.length === 0 && builtinNames3.has(variable.name) && variable.name in globalObject3) {
        return { value: globalObject3[variable.name] };
      }
      if (variable != null && variable.defs.length === 1) {
        const def = variable.defs[0];
        if (def.parent && def.type === "Variable" && (def.parent.kind === "const" || isEffectivelyConst3(variable)) && // TODO(mysticatea): don't support destructuring here.
        def.node.id.type === "Identifier") {
          return getStaticValueR3(def.node.init, initialScope);
        }
      }
    }
    return null;
  },
  Literal(node) {
    if ((node.regex != null || node.bigint != null) && node.value == null) {
      return null;
    }
    return { value: node.value };
  },
  LogicalExpression(node, initialScope) {
    const left33 = getStaticValueR3(node.left, initialScope);
    if (left33 != null) {
      if (node.operator === "||" && Boolean(left33.value) === true || node.operator === "&&" && Boolean(left33.value) === false || node.operator === "??" && left33.value != null) {
        return left33;
      }
      const right33 = getStaticValueR3(node.right, initialScope);
      if (right33 != null) {
        return right33;
      }
    }
    return null;
  },
  MemberExpression(node, initialScope) {
    if (node.property.type === "PrivateIdentifier") {
      return null;
    }
    const object2 = getStaticValueR3(node.object, initialScope);
    if (object2 != null) {
      if (object2.value == null && (object2.optional || node.optional)) {
        return { value: void 0, optional: true };
      }
      const property = getStaticPropertyNameValue3(node, initialScope);
      if (property != null) {
        if (!isGetter3(object2.value, property.value)) {
          return { value: object2.value[property.value] };
        }
        for (const [classFn, allowed] of getterAllowed3) {
          if (object2.value instanceof classFn && allowed.has(property.value)) {
            return { value: object2.value[property.value] };
          }
        }
      }
    }
    return null;
  },
  ChainExpression(node, initialScope) {
    const expression = getStaticValueR3(node.expression, initialScope);
    if (expression != null) {
      return { value: expression.value };
    }
    return null;
  },
  NewExpression(node, initialScope) {
    const callee = getStaticValueR3(node.callee, initialScope);
    const args = getElementValues3(node.arguments, initialScope);
    if (callee != null && args != null) {
      const Func = callee.value;
      if (callAllowed3.has(Func)) {
        return { value: new Func(...args) };
      }
    }
    return null;
  },
  ObjectExpression(node, initialScope) {
    const object2 = {};
    for (const propertyNode of node.properties) {
      if (propertyNode.type === "Property") {
        if (propertyNode.kind !== "init") {
          return null;
        }
        const key = getStaticPropertyNameValue3(
          propertyNode,
          initialScope
        );
        const value = getStaticValueR3(propertyNode.value, initialScope);
        if (key == null || value == null) {
          return null;
        }
        object2[key.value] = value.value;
      } else if (propertyNode.type === "SpreadElement" || propertyNode.type === "ExperimentalSpreadProperty") {
        const argument = getStaticValueR3(
          propertyNode.argument,
          initialScope
        );
        if (argument == null) {
          return null;
        }
        Object.assign(object2, argument.value);
      } else {
        return null;
      }
    }
    return { value: object2 };
  },
  SequenceExpression(node, initialScope) {
    const last2 = node.expressions[node.expressions.length - 1];
    return getStaticValueR3(last2, initialScope);
  },
  TaggedTemplateExpression(node, initialScope) {
    const tag = getStaticValueR3(node.tag, initialScope);
    const expressions = getElementValues3(
      node.quasi.expressions,
      initialScope
    );
    if (tag != null && expressions != null) {
      const func = tag.value;
      const strings = node.quasi.quasis.map((q) => q.value.cooked);
      strings.raw = node.quasi.quasis.map((q) => q.value.raw);
      if (func === String.raw) {
        return { value: func(strings, ...expressions) };
      }
    }
    return null;
  },
  TemplateLiteral(node, initialScope) {
    const expressions = getElementValues3(node.expressions, initialScope);
    if (expressions != null) {
      let value = node.quasis[0].value.cooked;
      for (let i22 = 0; i22 < expressions.length; ++i22) {
        value += expressions[i22];
        value += node.quasis[i22 + 1].value.cooked;
      }
      return { value };
    }
    return null;
  },
  UnaryExpression(node, initialScope) {
    if (node.operator === "delete") {
      return null;
    }
    if (node.operator === "void") {
      return { value: void 0 };
    }
    const arg = getStaticValueR3(node.argument, initialScope);
    if (arg != null) {
      switch (node.operator) {
        case "-":
          return { value: -arg.value };
        case "+":
          return { value: +arg.value };
        case "!":
          return { value: !arg.value };
        case "~":
          return { value: ~arg.value };
        case "typeof":
          return { value: typeof arg.value };
      }
    }
    return null;
  }
});
function getStaticValueR3(node, initialScope) {
  if (node != null && Object.hasOwnProperty.call(operations3, node.type)) {
    return operations3[node.type](node, initialScope);
  }
  return null;
}
function getStaticPropertyNameValue3(node, initialScope) {
  const nameNode = node.type === "Property" ? node.key : node.property;
  if (node.computed) {
    return getStaticValueR3(nameNode, initialScope);
  }
  if (nameNode.type === "Identifier") {
    return { value: nameNode.name };
  }
  if (nameNode.type === "Literal") {
    if (nameNode.bigint) {
      return { value: nameNode.bigint };
    }
    return { value: String(nameNode.value) };
  }
  return null;
}
function getStaticValue4(node, initialScope = null) {
  try {
    return getStaticValueR3(node, initialScope);
  } catch (_error) {
    return null;
  }
}
function getStringIfConstant3(node, initialScope = null) {
  if (node && node.type === "Literal" && node.value === null) {
    if (node.regex) {
      return `/${node.regex.pattern}/${node.regex.flags}`;
    }
    if (node.bigint) {
      return node.bigint;
    }
  }
  const evaluated = getStaticValue4(node, initialScope);
  return evaluated && String(evaluated.value);
}
function getPropertyName3(node, initialScope) {
  switch (node.type) {
    case "MemberExpression":
      if (node.computed) {
        return getStringIfConstant3(node.property, initialScope);
      }
      if (node.property.type === "PrivateIdentifier") {
        return null;
      }
      return node.property.name;
    case "Property":
    case "MethodDefinition":
    case "PropertyDefinition":
      if (node.computed) {
        return getStringIfConstant3(node.key, initialScope);
      }
      if (node.key.type === "Literal") {
        return String(node.key.value);
      }
      if (node.key.type === "PrivateIdentifier") {
        return null;
      }
      return node.key.name;
  }
  return null;
}
function getFunctionNameWithKind3(node, sourceCode) {
  const parent = node.parent;
  const tokens = [];
  const isObjectMethod = parent.type === "Property" && parent.value === node;
  const isClassMethod = parent.type === "MethodDefinition" && parent.value === node;
  const isClassFieldMethod = parent.type === "PropertyDefinition" && parent.value === node;
  if (isClassMethod || isClassFieldMethod) {
    if (parent.static) {
      tokens.push("static");
    }
    if (parent.key.type === "PrivateIdentifier") {
      tokens.push("private");
    }
  }
  if (node.async) {
    tokens.push("async");
  }
  if (node.generator) {
    tokens.push("generator");
  }
  if (isObjectMethod || isClassMethod) {
    if (parent.kind === "constructor") {
      return "constructor";
    }
    if (parent.kind === "get") {
      tokens.push("getter");
    } else if (parent.kind === "set") {
      tokens.push("setter");
    } else {
      tokens.push("method");
    }
  } else if (isClassFieldMethod) {
    tokens.push("method");
  } else {
    if (node.type === "ArrowFunctionExpression") {
      tokens.push("arrow");
    }
    tokens.push("function");
  }
  if (isObjectMethod || isClassMethod || isClassFieldMethod) {
    if (parent.key.type === "PrivateIdentifier") {
      tokens.push(`#${parent.key.name}`);
    } else {
      const name = getPropertyName3(parent);
      if (name) {
        tokens.push(`'${name}'`);
      } else if (sourceCode) {
        const keyText = sourceCode.getText(parent.key);
        if (!keyText.includes("\n")) {
          tokens.push(`[${keyText}]`);
        }
      }
    }
  } else if (node.id) {
    tokens.push(`'${node.id.name}'`);
  } else if (parent.type === "VariableDeclarator" && parent.id && parent.id.type === "Identifier") {
    tokens.push(`'${parent.id.name}'`);
  } else if ((parent.type === "AssignmentExpression" || parent.type === "AssignmentPattern") && parent.left && parent.left.type === "Identifier") {
    tokens.push(`'${parent.left.name}'`);
  } else if (parent.type === "ExportDefaultDeclaration" && parent.declaration === node) {
    tokens.push("'default'");
  }
  return tokens.join(" ");
}
var typeConversionBinaryOps3 = Object.freeze(
  /* @__PURE__ */ new Set([
    "==",
    "!=",
    "<",
    "<=",
    ">",
    ">=",
    "<<",
    ">>",
    ">>>",
    "+",
    "-",
    "*",
    "/",
    "%",
    "|",
    "^",
    "&",
    "in"
  ])
);
var typeConversionUnaryOps3 = Object.freeze(/* @__PURE__ */ new Set(["-", "+", "!", "~"]));
function isNode3(x22) {
  return x22 !== null && typeof x22 === "object" && typeof x22.type === "string";
}
var visitor3 = Object.freeze(
  Object.assign(/* @__PURE__ */ Object.create(null), {
    $visit(node, options, visitorKeys) {
      const { type } = node;
      if (typeof this[type] === "function") {
        return this[type](node, options, visitorKeys);
      }
      return this.$visitChildren(node, options, visitorKeys);
    },
    $visitChildren(node, options, visitorKeys) {
      const { type } = node;
      for (const key of visitorKeys[type] || getKeys3(node)) {
        const value = node[key];
        if (Array.isArray(value)) {
          for (const element of value) {
            if (isNode3(element) && this.$visit(element, options, visitorKeys)) {
              return true;
            }
          }
        } else if (isNode3(value) && this.$visit(value, options, visitorKeys)) {
          return true;
        }
      }
      return false;
    },
    ArrowFunctionExpression() {
      return false;
    },
    AssignmentExpression() {
      return true;
    },
    AwaitExpression() {
      return true;
    },
    BinaryExpression(node, options, visitorKeys) {
      if (options.considerImplicitTypeConversion && typeConversionBinaryOps3.has(node.operator) && (node.left.type !== "Literal" || node.right.type !== "Literal")) {
        return true;
      }
      return this.$visitChildren(node, options, visitorKeys);
    },
    CallExpression() {
      return true;
    },
    FunctionExpression() {
      return false;
    },
    ImportExpression() {
      return true;
    },
    MemberExpression(node, options, visitorKeys) {
      if (options.considerGetters) {
        return true;
      }
      if (options.considerImplicitTypeConversion && node.computed && node.property.type !== "Literal") {
        return true;
      }
      return this.$visitChildren(node, options, visitorKeys);
    },
    MethodDefinition(node, options, visitorKeys) {
      if (options.considerImplicitTypeConversion && node.computed && node.key.type !== "Literal") {
        return true;
      }
      return this.$visitChildren(node, options, visitorKeys);
    },
    NewExpression() {
      return true;
    },
    Property(node, options, visitorKeys) {
      if (options.considerImplicitTypeConversion && node.computed && node.key.type !== "Literal") {
        return true;
      }
      return this.$visitChildren(node, options, visitorKeys);
    },
    PropertyDefinition(node, options, visitorKeys) {
      if (options.considerImplicitTypeConversion && node.computed && node.key.type !== "Literal") {
        return true;
      }
      return this.$visitChildren(node, options, visitorKeys);
    },
    UnaryExpression(node, options, visitorKeys) {
      if (node.operator === "delete") {
        return true;
      }
      if (options.considerImplicitTypeConversion && typeConversionUnaryOps3.has(node.operator) && node.argument.type !== "Literal") {
        return true;
      }
      return this.$visitChildren(node, options, visitorKeys);
    },
    UpdateExpression() {
      return true;
    },
    YieldExpression() {
      return true;
    }
  })
);
function hasSideEffect3(node, sourceCode, { considerGetters = false, considerImplicitTypeConversion = false } = {}) {
  return visitor3.$visit(
    node,
    { considerGetters, considerImplicitTypeConversion },
    sourceCode.visitorKeys || visitor_keys_default3
  );
}
function getParentSyntaxParen3(node, sourceCode) {
  const parent = node.parent;
  switch (parent.type) {
    case "CallExpression":
    case "NewExpression":
      if (parent.arguments.length === 1 && parent.arguments[0] === node) {
        return sourceCode.getTokenAfter(
          parent.callee,
          isOpeningParenToken3
        );
      }
      return null;
    case "DoWhileStatement":
      if (parent.test === node) {
        return sourceCode.getTokenAfter(
          parent.body,
          isOpeningParenToken3
        );
      }
      return null;
    case "IfStatement":
    case "WhileStatement":
      if (parent.test === node) {
        return sourceCode.getFirstToken(parent, 1);
      }
      return null;
    case "ImportExpression":
      if (parent.source === node) {
        return sourceCode.getFirstToken(parent, 1);
      }
      return null;
    case "SwitchStatement":
      if (parent.discriminant === node) {
        return sourceCode.getFirstToken(parent, 1);
      }
      return null;
    case "WithStatement":
      if (parent.object === node) {
        return sourceCode.getFirstToken(parent, 1);
      }
      return null;
    default:
      return null;
  }
}
function isParenthesized3(timesOrNode, nodeOrSourceCode, optionalSourceCode) {
  let times, node, sourceCode, maybeLeftParen, maybeRightParen;
  if (typeof timesOrNode === "number") {
    times = timesOrNode | 0;
    node = nodeOrSourceCode;
    sourceCode = optionalSourceCode;
    if (!(times >= 1)) {
      throw new TypeError("'times' should be a positive integer.");
    }
  } else {
    times = 1;
    node = timesOrNode;
    sourceCode = nodeOrSourceCode;
  }
  if (node == null || // `Program` can't be parenthesized
  node.parent == null || // `CatchClause.param` can't be parenthesized, example `try {} catch (error) {}`
  node.parent.type === "CatchClause" && node.parent.param === node) {
    return false;
  }
  maybeLeftParen = maybeRightParen = node;
  do {
    maybeLeftParen = sourceCode.getTokenBefore(maybeLeftParen);
    maybeRightParen = sourceCode.getTokenAfter(maybeRightParen);
  } while (maybeLeftParen != null && maybeRightParen != null && isOpeningParenToken3(maybeLeftParen) && isClosingParenToken3(maybeRightParen) && // Avoid false positive such as `if (a) {}`
  maybeLeftParen !== getParentSyntaxParen3(node, sourceCode) && --times > 0);
  return times === 0;
}
Function.call.bind(Object.hasOwnProperty);
var __defProp23 = Object.defineProperty;
var __export23 = (target, all33) => {
  for (var name in all33)
    __defProp23(target, name, { get: all33[name], enumerable: true });
};
var NodeType3 = types.AST_NODE_TYPES;
var is3 = utils.ASTUtils.isNodeOfType;
var isOneOf3 = utils.ASTUtils.isNodeOfTypes;
isOneOf3([
  NodeType3.ArrowFunctionExpression,
  NodeType3.FunctionDeclaration,
  NodeType3.FunctionExpression
]);
isOneOf3([
  NodeType3.ArrowFunctionExpression,
  NodeType3.FunctionDeclaration,
  NodeType3.FunctionExpression,
  NodeType3.TSCallSignatureDeclaration,
  NodeType3.TSConstructSignatureDeclaration,
  NodeType3.TSDeclareFunction,
  NodeType3.TSEmptyBodyFunctionExpression,
  NodeType3.TSFunctionType,
  NodeType3.TSMethodSignature
]);
isOneOf3([NodeType3.ClassDeclaration, NodeType3.ClassExpression]);
isOneOf3([
  NodeType3.DoWhileStatement,
  NodeType3.ForInStatement,
  NodeType3.ForOfStatement,
  NodeType3.ForStatement,
  NodeType3.WhileStatement
]);
isOneOf3([NodeType3.TSArrayType, NodeType3.TSTupleType]);
isOneOf3([
  NodeType3.PropertyDefinition,
  NodeType3.TSIndexSignature,
  NodeType3.TSParameterProperty,
  NodeType3.TSPropertySignature
]);
is3(NodeType3.JSXElement);
is3(NodeType3.JSXFragment);
isOneOf3([
  NodeType3.JSXAttribute,
  NodeType3.JSXSpreadChild,
  NodeType3.JSXClosingElement,
  NodeType3.JSXClosingFragment,
  NodeType3.JSXElement,
  NodeType3.JSXEmptyExpression,
  NodeType3.JSXExpressionContainer,
  NodeType3.JSXFragment,
  NodeType3.JSXIdentifier,
  NodeType3.JSXMemberExpression,
  NodeType3.JSXNamespacedName,
  NodeType3.JSXOpeningElement,
  NodeType3.JSXOpeningFragment,
  NodeType3.JSXSpreadAttribute,
  NodeType3.JSXSpreadChild,
  NodeType3.JSXText
]);
isOneOf3([
  NodeType3.JSXIdentifier,
  NodeType3.JSXMemberExpression,
  NodeType3.JSXNamespacedName
]);
isOneOf3([
  NodeType3.ArrayPattern,
  NodeType3.AssignmentPattern,
  NodeType3.ObjectPattern,
  NodeType3.RestElement
]);
isOneOf3([
  NodeType3.TSInterfaceDeclaration,
  NodeType3.TSTypeAliasDeclaration
]);
isOneOf3([
  NodeType3.ArrayExpression,
  NodeType3.ArrayPattern,
  NodeType3.ArrowFunctionExpression,
  NodeType3.CallExpression,
  NodeType3.ClassExpression,
  NodeType3.FunctionExpression,
  NodeType3.Identifier,
  NodeType3.JSXElement,
  NodeType3.JSXFragment,
  NodeType3.Literal,
  NodeType3.TemplateLiteral,
  NodeType3.MemberExpression,
  NodeType3.MetaProperty,
  NodeType3.ObjectExpression,
  NodeType3.ObjectPattern,
  NodeType3.SequenceExpression,
  NodeType3.Super,
  NodeType3.TaggedTemplateExpression,
  NodeType3.ThisExpression
]);
isOneOf3([
  NodeType3.ArrayExpression,
  NodeType3.ArrayPattern,
  NodeType3.ArrowFunctionExpression,
  NodeType3.CallExpression,
  NodeType3.ClassExpression,
  NodeType3.FunctionExpression,
  NodeType3.Identifier,
  NodeType3.JSXElement,
  NodeType3.JSXFragment,
  NodeType3.Literal,
  NodeType3.TemplateLiteral,
  NodeType3.MemberExpression,
  NodeType3.MetaProperty,
  NodeType3.ObjectExpression,
  NodeType3.ObjectPattern,
  NodeType3.SequenceExpression,
  NodeType3.Super,
  NodeType3.TaggedTemplateExpression,
  NodeType3.ThisExpression,
  NodeType3.TSAsExpression,
  NodeType3.TSNonNullExpression,
  NodeType3.TSTypeAssertion
]);
var Function_exports23 = {};
__export23(Function_exports23, {
  SK: () => SK23,
  absurd: () => absurd23,
  apply: () => apply23,
  compose: () => compose23,
  constFalse: () => constFalse23,
  constNull: () => constNull23,
  constTrue: () => constTrue23,
  constUndefined: () => constUndefined23,
  constVoid: () => constVoid23,
  constant: () => constant23,
  dual: () => dual23,
  flip: () => flip23,
  flow: () => flow23,
  hole: () => hole23,
  identity: () => identity23,
  isFunction: () => isFunction223,
  pipe: () => pipe23,
  satisfies: () => satisfies23,
  tupled: () => tupled23,
  unsafeCoerce: () => unsafeCoerce23,
  untupled: () => untupled23
});
var isFunction223 = (input) => typeof input === "function";
var dual23 = function(arity, body) {
  if (typeof arity === "function") {
    return function() {
      if (arity(arguments)) {
        return body.apply(this, arguments);
      }
      return (self2) => body(self2, ...arguments);
    };
  }
  switch (arity) {
    case 0:
    case 1:
      throw new RangeError(`Invalid arity ${arity}`);
    case 2:
      return function(a22, b22) {
        if (arguments.length >= 2) {
          return body(a22, b22);
        }
        return function(self2) {
          return body(self2, a22);
        };
      };
    case 3:
      return function(a22, b22, c22) {
        if (arguments.length >= 3) {
          return body(a22, b22, c22);
        }
        return function(self2) {
          return body(self2, a22, b22);
        };
      };
    case 4:
      return function(a22, b22, c22, d22) {
        if (arguments.length >= 4) {
          return body(a22, b22, c22, d22);
        }
        return function(self2) {
          return body(self2, a22, b22, c22);
        };
      };
    case 5:
      return function(a22, b22, c22, d22, e22) {
        if (arguments.length >= 5) {
          return body(a22, b22, c22, d22, e22);
        }
        return function(self2) {
          return body(self2, a22, b22, c22, d22);
        };
      };
    default:
      return function() {
        if (arguments.length >= arity) {
          return body.apply(this, arguments);
        }
        const args = arguments;
        return function(self2) {
          return body(self2, ...args);
        };
      };
  }
};
var apply23 = (a22) => (self2) => self2(a22);
var identity23 = (a22) => a22;
var satisfies23 = () => (b22) => b22;
var unsafeCoerce23 = identity23;
var constant23 = (value) => () => value;
var constTrue23 = /* @__PURE__ */ constant23(true);
var constFalse23 = /* @__PURE__ */ constant23(false);
var constNull23 = /* @__PURE__ */ constant23(null);
var constUndefined23 = /* @__PURE__ */ constant23(void 0);
var constVoid23 = constUndefined23;
var flip23 = (f22) => (...b22) => (...a22) => f22(...a22)(...b22);
var compose23 = /* @__PURE__ */ dual23(2, (ab, bc) => (a22) => bc(ab(a22)));
var absurd23 = (_22) => {
  throw new Error("Called `absurd` function which should be uncallable");
};
var tupled23 = (f22) => (a22) => f22(...a22);
var untupled23 = (f22) => (...a22) => f22(a22);
function pipe23(a22, ab, bc, cd, de, ef, fg, gh, hi) {
  switch (arguments.length) {
    case 1:
      return a22;
    case 2:
      return ab(a22);
    case 3:
      return bc(ab(a22));
    case 4:
      return cd(bc(ab(a22)));
    case 5:
      return de(cd(bc(ab(a22))));
    case 6:
      return ef(de(cd(bc(ab(a22)))));
    case 7:
      return fg(ef(de(cd(bc(ab(a22))))));
    case 8:
      return gh(fg(ef(de(cd(bc(ab(a22)))))));
    case 9:
      return hi(gh(fg(ef(de(cd(bc(ab(a22))))))));
    default: {
      let ret = arguments[0];
      for (let i22 = 1; i22 < arguments.length; i22++) {
        ret = arguments[i22](ret);
      }
      return ret;
    }
  }
}
function flow23(ab, bc, cd, de, ef, fg, gh, hi, ij) {
  switch (arguments.length) {
    case 1:
      return ab;
    case 2:
      return function() {
        return bc(ab.apply(this, arguments));
      };
    case 3:
      return function() {
        return cd(bc(ab.apply(this, arguments)));
      };
    case 4:
      return function() {
        return de(cd(bc(ab.apply(this, arguments))));
      };
    case 5:
      return function() {
        return ef(de(cd(bc(ab.apply(this, arguments)))));
      };
    case 6:
      return function() {
        return fg(ef(de(cd(bc(ab.apply(this, arguments))))));
      };
    case 7:
      return function() {
        return gh(fg(ef(de(cd(bc(ab.apply(this, arguments)))))));
      };
    case 8:
      return function() {
        return hi(gh(fg(ef(de(cd(bc(ab.apply(this, arguments))))))));
      };
    case 9:
      return function() {
        return ij(hi(gh(fg(ef(de(cd(bc(ab.apply(this, arguments)))))))));
      };
  }
  return;
}
var hole23 = /* @__PURE__ */ unsafeCoerce23(absurd23);
var SK23 = (_22, b22) => b22;
var make43 = (isEquivalent) => (self2, that) => self2 === that || isEquivalent(self2, that);
var let_33 = (map62) => dual23(3, (self2, name, f22) => map62(self2, (a22) => Object.assign({}, a22, {
  [name]: f22(a22)
})));
var bindTo33 = (map62) => dual23(2, (self2, name) => map62(self2, (a22) => ({
  [name]: a22
})));
var bind33 = (map62, flatMap42) => dual23(3, (self2, name, f22) => flatMap42(self2, (a22) => map62(f22(a22), (b22) => Object.assign({}, a22, {
  [name]: b22
}))));
var moduleVersion23 = "3.2.8";
var getCurrentVersion23 = () => moduleVersion23;
var globalStoreId23 = /* @__PURE__ */ Symbol.for(`effect/GlobalValue/globalStoreId/${/* @__PURE__ */ getCurrentVersion23()}`);
if (!(globalStoreId23 in globalThis)) {
  globalThis[globalStoreId23] = /* @__PURE__ */ new Map();
}
var globalStore23 = globalThis[globalStoreId23];
var globalValue23 = (id, compute) => {
  if (!globalStore23.has(id)) {
    globalStore23.set(id, compute());
  }
  return globalStore23.get(id);
};
var Predicate_exports23 = {};
__export23(Predicate_exports23, {
  all: () => all23,
  and: () => and5,
  compose: () => compose223,
  eqv: () => eqv5,
  every: () => every6,
  hasProperty: () => hasProperty23,
  implies: () => implies5,
  isBigInt: () => isBigInt5,
  isBoolean: () => isBoolean5,
  isDate: () => isDate5,
  isError: () => isError5,
  isFunction: () => isFunction323,
  isIterable: () => isIterable5,
  isMap: () => isMap5,
  isNever: () => isNever5,
  isNotNull: () => isNotNull5,
  isNotNullable: () => isNotNullable5,
  isNotUndefined: () => isNotUndefined5,
  isNull: () => isNull5,
  isNullable: () => isNullable23,
  isNumber: () => isNumber5,
  isObject: () => isObject23,
  isPromise: () => isPromise5,
  isPromiseLike: () => isPromiseLike5,
  isReadonlyRecord: () => isReadonlyRecord5,
  isRecord: () => isRecord5,
  isSet: () => isSet5,
  isString: () => isString5,
  isSymbol: () => isSymbol5,
  isTagged: () => isTagged5,
  isTruthy: () => isTruthy5,
  isUint8Array: () => isUint8Array5,
  isUndefined: () => isUndefined5,
  isUnknown: () => isUnknown5,
  mapInput: () => mapInput6,
  nand: () => nand5,
  nor: () => nor5,
  not: () => not5,
  or: () => or5,
  product: () => product23,
  productMany: () => productMany23,
  some: () => some33,
  struct: () => struct7,
  tuple: () => tuple6,
  xor: () => xor5
});
var mapInput6 = /* @__PURE__ */ dual23(2, (self2, f22) => (b22) => self2(f22(b22)));
var isTruthy5 = (input) => !!input;
var isSet5 = (input) => input instanceof Set;
var isMap5 = (input) => input instanceof Map;
var isString5 = (input) => typeof input === "string";
var isNumber5 = (input) => typeof input === "number";
var isBoolean5 = (input) => typeof input === "boolean";
var isBigInt5 = (input) => typeof input === "bigint";
var isSymbol5 = (input) => typeof input === "symbol";
var isFunction323 = isFunction223;
var isUndefined5 = (input) => input === void 0;
var isNotUndefined5 = (input) => input !== void 0;
var isNull5 = (input) => input === null;
var isNotNull5 = (input) => input !== null;
var isNever5 = (_22) => false;
var isUnknown5 = (_22) => true;
var isRecordOrArray23 = (input) => typeof input === "object" && input !== null;
var isObject23 = (input) => isRecordOrArray23(input) || isFunction323(input);
var hasProperty23 = /* @__PURE__ */ dual23(2, (self2, property) => isObject23(self2) && property in self2);
var isTagged5 = /* @__PURE__ */ dual23(2, (self2, tag) => hasProperty23(self2, "_tag") && self2["_tag"] === tag);
var isNullable23 = (input) => input === null || input === void 0;
var isNotNullable5 = (input) => input !== null && input !== void 0;
var isError5 = (input) => input instanceof Error;
var isUint8Array5 = (input) => input instanceof Uint8Array;
var isDate5 = (input) => input instanceof Date;
var isIterable5 = (input) => hasProperty23(input, Symbol.iterator);
var isRecord5 = (input) => isRecordOrArray23(input) && !Array.isArray(input);
var isReadonlyRecord5 = isRecord5;
var isPromise5 = (input) => hasProperty23(input, "then") && "catch" in input && isFunction323(input.then) && isFunction323(input.catch);
var isPromiseLike5 = (input) => hasProperty23(input, "then") && isFunction323(input.then);
var compose223 = /* @__PURE__ */ dual23(2, (ab, bc) => (a22) => ab(a22) && bc(a22));
var product23 = (self2, that) => ([a22, b22]) => self2(a22) && that(b22);
var all23 = (collection) => {
  return (as223) => {
    let collectionIndex = 0;
    for (const p22 of collection) {
      if (collectionIndex >= as223.length) {
        break;
      }
      if (p22(as223[collectionIndex]) === false) {
        return false;
      }
      collectionIndex++;
    }
    return true;
  };
};
var productMany23 = (self2, collection) => {
  const rest = all23(collection);
  return ([head22, ...tail3]) => self2(head22) === false ? false : rest(tail3);
};
var tuple6 = (...elements) => all23(elements);
var struct7 = (fields) => {
  const keys23 = Object.keys(fields);
  return (a22) => {
    for (const key of keys23) {
      if (!fields[key](a22[key])) {
        return false;
      }
    }
    return true;
  };
};
var not5 = (self2) => (a22) => !self2(a22);
var or5 = /* @__PURE__ */ dual23(2, (self2, that) => (a22) => self2(a22) || that(a22));
var and5 = /* @__PURE__ */ dual23(2, (self2, that) => (a22) => self2(a22) && that(a22));
var xor5 = /* @__PURE__ */ dual23(2, (self2, that) => (a22) => self2(a22) !== that(a22));
var eqv5 = /* @__PURE__ */ dual23(2, (self2, that) => (a22) => self2(a22) === that(a22));
var implies5 = /* @__PURE__ */ dual23(2, (self2, that) => (a22) => self2(a22) ? that(a22) : true);
var nor5 = /* @__PURE__ */ dual23(2, (self2, that) => (a22) => !(self2(a22) || that(a22)));
var nand5 = /* @__PURE__ */ dual23(2, (self2, that) => (a22) => !(self2(a22) && that(a22)));
var every6 = (collection) => (a22) => {
  for (const p22 of collection) {
    if (!p22(a22)) {
      return false;
    }
  }
  return true;
};
var some33 = (collection) => (a22) => {
  for (const p22 of collection) {
    if (p22(a22)) {
      return true;
    }
  }
  return false;
};
var getBugErrorMessage23 = (message) => `BUG: ${message} - please report an issue at https://github.com/Effect-TS/effect/issues`;
var GenKindTypeId23 = /* @__PURE__ */ Symbol.for("effect/Gen/GenKind");
var isGenKind23 = (u22) => isObject23(u22) && GenKindTypeId23 in u22;
var GenKindImpl23 = class {
  value;
  constructor(value) {
    this.value = value;
  }
  /**
   * @since 2.0.0
   */
  get _F() {
    return identity23;
  }
  /**
   * @since 2.0.0
   */
  get _R() {
    return (_22) => _22;
  }
  /**
   * @since 2.0.0
   */
  get _O() {
    return (_22) => _22;
  }
  /**
   * @since 2.0.0
   */
  get _E() {
    return (_22) => _22;
  }
  /**
   * @since 2.0.0
   */
  [GenKindTypeId23] = GenKindTypeId23;
  /**
   * @since 2.0.0
   */
  [Symbol.iterator]() {
    return new SingleShotGen23(this);
  }
};
var SingleShotGen23 = class _SingleShotGen6 {
  self;
  called = false;
  constructor(self2) {
    this.self = self2;
  }
  /**
   * @since 2.0.0
   */
  next(a22) {
    return this.called ? {
      value: a22,
      done: true
    } : (this.called = true, {
      value: this.self,
      done: false
    });
  }
  /**
   * @since 2.0.0
   */
  return(a22) {
    return {
      value: a22,
      done: true
    };
  }
  /**
   * @since 2.0.0
   */
  throw(e22) {
    throw e22;
  }
  /**
   * @since 2.0.0
   */
  [Symbol.iterator]() {
    return new _SingleShotGen6(this.self);
  }
};
var adapter33 = () => function() {
  let x22 = arguments[0];
  for (let i22 = 1; i22 < arguments.length; i22++) {
    x22 = arguments[i22](x22);
  }
  return new GenKindImpl23(x22);
};
var defaultIncHi23 = 335903614;
var defaultIncLo23 = 4150755663;
var MUL_HI23 = 1481765933 >>> 0;
var MUL_LO23 = 1284865837 >>> 0;
var BIT_5323 = 9007199254740992;
var BIT_2723 = 134217728;
var PCGRandom23 = class {
  _state;
  constructor(seedHi, seedLo, incHi, incLo) {
    if (isNullable23(seedLo) && isNullable23(seedHi)) {
      seedLo = Math.random() * 4294967295 >>> 0;
      seedHi = 0;
    } else if (isNullable23(seedLo)) {
      seedLo = seedHi;
      seedHi = 0;
    }
    if (isNullable23(incLo) && isNullable23(incHi)) {
      incLo = this._state ? this._state[3] : defaultIncLo23;
      incHi = this._state ? this._state[2] : defaultIncHi23;
    } else if (isNullable23(incLo)) {
      incLo = incHi;
      incHi = 0;
    }
    this._state = new Int32Array([0, 0, incHi >>> 0, ((incLo || 0) | 1) >>> 0]);
    this._next();
    add6423(this._state, this._state[0], this._state[1], seedHi >>> 0, seedLo >>> 0);
    this._next();
    return this;
  }
  /**
   * Returns a copy of the internal state of this random number generator as a
   * JavaScript Array.
   *
   * @category getters
   * @since 2.0.0
   */
  getState() {
    return [this._state[0], this._state[1], this._state[2], this._state[3]];
  }
  /**
   * Restore state previously retrieved using `getState()`.
   *
   * @since 2.0.0
   */
  setState(state) {
    this._state[0] = state[0];
    this._state[1] = state[1];
    this._state[2] = state[2];
    this._state[3] = state[3] | 1;
  }
  /**
   * Get a uniformly distributed 32 bit integer between [0, max).
   *
   * @category getter
   * @since 2.0.0
   */
  integer(max3) {
    if (!max3) {
      return this._next();
    }
    max3 = max3 >>> 0;
    if ((max3 & max3 - 1) === 0) {
      return this._next() & max3 - 1;
    }
    let num = 0;
    const skew = (-max3 >>> 0) % max3 >>> 0;
    for (num = this._next(); num < skew; num = this._next()) {
    }
    return num % max3;
  }
  /**
   * Get a uniformly distributed IEEE-754 double between 0.0 and 1.0, with
   * 53 bits of precision (every bit of the mantissa is randomized).
   *
   * @category getters
   * @since 2.0.0
   */
  number() {
    const hi = (this._next() & 67108863) * 1;
    const lo = (this._next() & 134217727) * 1;
    return (hi * BIT_2723 + lo) / BIT_5323;
  }
  /** @internal */
  _next() {
    const oldHi = this._state[0] >>> 0;
    const oldLo = this._state[1] >>> 0;
    mul6423(this._state, oldHi, oldLo, MUL_HI23, MUL_LO23);
    add6423(this._state, this._state[0], this._state[1], this._state[2], this._state[3]);
    let xsHi = oldHi >>> 18;
    let xsLo = (oldLo >>> 18 | oldHi << 14) >>> 0;
    xsHi = (xsHi ^ oldHi) >>> 0;
    xsLo = (xsLo ^ oldLo) >>> 0;
    const xorshifted = (xsLo >>> 27 | xsHi << 5) >>> 0;
    const rot = oldHi >>> 27;
    const rot2 = (-rot >>> 0 & 31) >>> 0;
    return (xorshifted >>> rot | xorshifted << rot2) >>> 0;
  }
};
function mul6423(out, aHi, aLo, bHi, bLo) {
  let c1 = (aLo >>> 16) * (bLo & 65535) >>> 0;
  let c0 = (aLo & 65535) * (bLo >>> 16) >>> 0;
  let lo = (aLo & 65535) * (bLo & 65535) >>> 0;
  let hi = (aLo >>> 16) * (bLo >>> 16) + ((c0 >>> 16) + (c1 >>> 16)) >>> 0;
  c0 = c0 << 16 >>> 0;
  lo = lo + c0 >>> 0;
  if (lo >>> 0 < c0 >>> 0) {
    hi = hi + 1 >>> 0;
  }
  c1 = c1 << 16 >>> 0;
  lo = lo + c1 >>> 0;
  if (lo >>> 0 < c1 >>> 0) {
    hi = hi + 1 >>> 0;
  }
  hi = hi + Math.imul(aLo, bHi) >>> 0;
  hi = hi + Math.imul(aHi, bLo) >>> 0;
  out[0] = hi;
  out[1] = lo;
}
function add6423(out, aHi, aLo, bHi, bLo) {
  let hi = aHi + bHi >>> 0;
  const lo = aLo + bLo >>> 0;
  if (lo >>> 0 < aLo >>> 0) {
    hi = hi + 1 | 0;
  }
  out[0] = hi;
  out[1] = lo;
}
var YieldWrapTypeId23 = /* @__PURE__ */ Symbol.for("effect/Utils/YieldWrap");
var YieldWrap23 = class {
  /**
   * @since 3.0.6
   */
  #value;
  constructor(value) {
    this.#value = value;
  }
  /**
   * @since 3.0.6
   */
  [YieldWrapTypeId23]() {
    return this.#value;
  }
};
function yieldWrapGet23(self2) {
  if (typeof self2 === "object" && self2 !== null && YieldWrapTypeId23 in self2) {
    return self2[YieldWrapTypeId23]();
  }
  throw new Error(getBugErrorMessage23("yieldWrapGet"));
}
var structuralRegionState23 = /* @__PURE__ */ globalValue23("effect/Utils/isStructuralRegion", () => ({
  enabled: false,
  tester: void 0
}));
var randomHashCache23 = /* @__PURE__ */ globalValue23(/* @__PURE__ */ Symbol.for("effect/Hash/randomHashCache"), () => /* @__PURE__ */ new WeakMap());
var pcgr23 = /* @__PURE__ */ globalValue23(/* @__PURE__ */ Symbol.for("effect/Hash/pcgr"), () => new PCGRandom23());
var symbol33 = /* @__PURE__ */ Symbol.for("effect/Hash");
var hash23 = (self2) => {
  if (structuralRegionState23.enabled === true) {
    return 0;
  }
  switch (typeof self2) {
    case "number":
      return number23(self2);
    case "bigint":
      return string23(self2.toString(10));
    case "boolean":
      return string23(String(self2));
    case "symbol":
      return string23(String(self2));
    case "string":
      return string23(self2);
    case "undefined":
      return string23("undefined");
    case "function":
    case "object": {
      if (self2 === null) {
        return string23("null");
      } else if (self2 instanceof Date) {
        return hash23(self2.toISOString());
      } else if (isHash23(self2)) {
        return self2[symbol33]();
      } else {
        return random23(self2);
      }
    }
    default:
      throw new Error(`BUG: unhandled typeof ${typeof self2} - please report an issue at https://github.com/Effect-TS/effect/issues`);
  }
};
var random23 = (self2) => {
  if (!randomHashCache23.has(self2)) {
    randomHashCache23.set(self2, number23(pcgr23.integer(Number.MAX_SAFE_INTEGER)));
  }
  return randomHashCache23.get(self2);
};
var combine23 = (b22) => (self2) => self2 * 53 ^ b22;
var optimize23 = (n22) => n22 & 3221225471 | n22 >>> 1 & 1073741824;
var isHash23 = (u22) => hasProperty23(u22, symbol33);
var number23 = (n22) => {
  if (n22 !== n22 || n22 === Infinity) {
    return 0;
  }
  let h22 = n22 | 0;
  if (h22 !== n22) {
    h22 ^= n22 * 4294967295;
  }
  while (n22 > 4294967295) {
    h22 ^= n22 /= 4294967295;
  }
  return optimize23(n22);
};
var string23 = (str) => {
  let h22 = 5381, i22 = str.length;
  while (i22) {
    h22 = h22 * 33 ^ str.charCodeAt(--i22);
  }
  return optimize23(h22);
};
var structureKeys23 = (o22, keys23) => {
  let h22 = 12289;
  for (let i22 = 0; i22 < keys23.length; i22++) {
    h22 ^= pipe23(string23(keys23[i22]), combine23(hash23(o22[keys23[i22]])));
  }
  return optimize23(h22);
};
var structure23 = (o22) => structureKeys23(o22, Object.keys(o22));
var array7 = (arr) => {
  let h22 = 6151;
  for (let i22 = 0; i22 < arr.length; i22++) {
    h22 = pipe23(h22, combine23(hash23(arr[i22])));
  }
  return optimize23(h22);
};
var cached23 = function() {
  if (arguments.length === 1) {
    const self22 = arguments[0];
    return function(hash32) {
      Object.defineProperty(self22, symbol33, {
        value() {
          return hash32;
        },
        enumerable: false
      });
      return hash32;
    };
  }
  const self2 = arguments[0];
  const hash223 = arguments[1];
  Object.defineProperty(self2, symbol33, {
    value() {
      return hash223;
    },
    enumerable: false
  });
  return hash223;
};
var symbol223 = /* @__PURE__ */ Symbol.for("effect/Equal");
function equals23() {
  if (arguments.length === 1) {
    return (self2) => compareBoth23(self2, arguments[0]);
  }
  return compareBoth23(arguments[0], arguments[1]);
}
function compareBoth23(self2, that) {
  if (self2 === that) {
    return true;
  }
  const selfType = typeof self2;
  if (selfType !== typeof that) {
    return false;
  }
  if (selfType === "object" || selfType === "function") {
    if (self2 !== null && that !== null) {
      if (isEqual23(self2) && isEqual23(that)) {
        if (hash23(self2) === hash23(that) && self2[symbol223](that)) {
          return true;
        } else {
          return structuralRegionState23.enabled && structuralRegionState23.tester ? structuralRegionState23.tester(self2, that) : false;
        }
      } else if (self2 instanceof Date && that instanceof Date) {
        return self2.toISOString() === that.toISOString();
      }
    }
    if (structuralRegionState23.enabled) {
      if (Array.isArray(self2) && Array.isArray(that)) {
        return self2.length === that.length && self2.every((v22, i22) => compareBoth23(v22, that[i22]));
      }
      if (Object.getPrototypeOf(self2) === Object.prototype && Object.getPrototypeOf(self2) === Object.prototype) {
        const keysSelf = Object.keys(self2);
        const keysThat = Object.keys(that);
        if (keysSelf.length === keysThat.length) {
          for (const key of keysSelf) {
            if (!(key in that && compareBoth23(self2[key], that[key]))) {
              return structuralRegionState23.tester ? structuralRegionState23.tester(self2, that) : false;
            }
          }
          return true;
        }
      }
      return structuralRegionState23.tester ? structuralRegionState23.tester(self2, that) : false;
    }
  }
  return structuralRegionState23.enabled && structuralRegionState23.tester ? structuralRegionState23.tester(self2, that) : false;
}
var isEqual23 = (u22) => hasProperty23(u22, symbol223);
var equivalence23 = () => equals23;
var NodeInspectSymbol23 = /* @__PURE__ */ Symbol.for("nodejs.util.inspect.custom");
var toJSON23 = (x22) => {
  if (hasProperty23(x22, "toJSON") && isFunction323(x22["toJSON"]) && x22["toJSON"].length === 0) {
    return x22.toJSON();
  } else if (Array.isArray(x22)) {
    return x22.map(toJSON23);
  }
  return x22;
};
var format23 = (x22) => JSON.stringify(x22, null, 2);
var pipeArguments23 = (self2, args) => {
  switch (args.length) {
    case 1:
      return args[0](self2);
    case 2:
      return args[1](args[0](self2));
    case 3:
      return args[2](args[1](args[0](self2)));
    case 4:
      return args[3](args[2](args[1](args[0](self2))));
    case 5:
      return args[4](args[3](args[2](args[1](args[0](self2)))));
    case 6:
      return args[5](args[4](args[3](args[2](args[1](args[0](self2))))));
    case 7:
      return args[6](args[5](args[4](args[3](args[2](args[1](args[0](self2)))))));
    case 8:
      return args[7](args[6](args[5](args[4](args[3](args[2](args[1](args[0](self2))))))));
    case 9:
      return args[8](args[7](args[6](args[5](args[4](args[3](args[2](args[1](args[0](self2)))))))));
    default: {
      let ret = self2;
      for (let i22 = 0, len = args.length; i22 < len; i22++) {
        ret = args[i22](ret);
      }
      return ret;
    }
  }
};
var OP_COMMIT23 = "Commit";
var OP_FAILURE3 = "Failure";
var OP_WITH_RUNTIME3 = "WithRuntime";
var EffectTypeId23 = /* @__PURE__ */ Symbol.for("effect/Effect");
var StreamTypeId23 = /* @__PURE__ */ Symbol.for("effect/Stream");
var SinkTypeId23 = /* @__PURE__ */ Symbol.for("effect/Sink");
var ChannelTypeId23 = /* @__PURE__ */ Symbol.for("effect/Channel");
var effectVariance23 = {
  /* c8 ignore next */
  _R: (_22) => _22,
  /* c8 ignore next */
  _E: (_22) => _22,
  /* c8 ignore next */
  _A: (_22) => _22,
  _V: /* @__PURE__ */ getCurrentVersion23()
};
var sinkVariance23 = {
  /* c8 ignore next */
  _A: (_22) => _22,
  /* c8 ignore next */
  _In: (_22) => _22,
  /* c8 ignore next */
  _L: (_22) => _22,
  /* c8 ignore next */
  _E: (_22) => _22,
  /* c8 ignore next */
  _R: (_22) => _22
};
var channelVariance23 = {
  /* c8 ignore next */
  _Env: (_22) => _22,
  /* c8 ignore next */
  _InErr: (_22) => _22,
  /* c8 ignore next */
  _InElem: (_22) => _22,
  /* c8 ignore next */
  _InDone: (_22) => _22,
  /* c8 ignore next */
  _OutErr: (_22) => _22,
  /* c8 ignore next */
  _OutElem: (_22) => _22,
  /* c8 ignore next */
  _OutDone: (_22) => _22
};
var EffectPrototype23 = {
  [EffectTypeId23]: effectVariance23,
  [StreamTypeId23]: effectVariance23,
  [SinkTypeId23]: sinkVariance23,
  [ChannelTypeId23]: channelVariance23,
  [symbol223](that) {
    return this === that;
  },
  [symbol33]() {
    return cached23(this, random23(this));
  },
  [Symbol.iterator]() {
    return new SingleShotGen23(new YieldWrap23(this));
  },
  pipe() {
    return pipeArguments23(this, arguments);
  }
};
var StructuralPrototype23 = {
  [symbol33]() {
    return cached23(this, structure23(this));
  },
  [symbol223](that) {
    const selfKeys = Object.keys(this);
    const thatKeys = Object.keys(that);
    if (selfKeys.length !== thatKeys.length) {
      return false;
    }
    for (const key of selfKeys) {
      if (!(key in that && equals23(this[key], that[key]))) {
        return false;
      }
    }
    return true;
  }
};
var CommitPrototype23 = {
  ...EffectPrototype23,
  _op: OP_COMMIT23
};
var StructuralCommitPrototype23 = {
  ...CommitPrototype23,
  ...StructuralPrototype23
};
var TypeId53 = /* @__PURE__ */ Symbol.for("effect/Option");
var CommonProto33 = {
  ...EffectPrototype23,
  [TypeId53]: {
    _A: (_22) => _22
  },
  [NodeInspectSymbol23]() {
    return this.toJSON();
  },
  toString() {
    return format23(this.toJSON());
  }
};
var SomeProto23 = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(CommonProto33), {
  _tag: "Some",
  _op: "Some",
  [symbol223](that) {
    return isOption33(that) && isSome33(that) && equals23(this.value, that.value);
  },
  [symbol33]() {
    return cached23(this, combine23(hash23(this._tag))(hash23(this.value)));
  },
  toJSON() {
    return {
      _id: "Option",
      _tag: this._tag,
      value: toJSON23(this.value)
    };
  }
});
var NoneHash23 = /* @__PURE__ */ hash23("None");
var NoneProto23 = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(CommonProto33), {
  _tag: "None",
  _op: "None",
  [symbol223](that) {
    return isOption33(that) && isNone33(that);
  },
  [symbol33]() {
    return NoneHash23;
  },
  toJSON() {
    return {
      _id: "Option",
      _tag: this._tag
    };
  }
});
var isOption33 = (input) => hasProperty23(input, TypeId53);
var isNone33 = (fa) => fa._tag === "None";
var isSome33 = (fa) => fa._tag === "Some";
var none33 = /* @__PURE__ */ Object.create(NoneProto23);
var some223 = (value) => {
  const a22 = Object.create(SomeProto23);
  a22.value = value;
  return a22;
};
var TypeId223 = /* @__PURE__ */ Symbol.for("effect/Either");
var CommonProto223 = {
  ...EffectPrototype23,
  [TypeId223]: {
    _R: (_22) => _22
  },
  [NodeInspectSymbol23]() {
    return this.toJSON();
  },
  toString() {
    return format23(this.toJSON());
  }
};
var RightProto23 = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(CommonProto223), {
  _tag: "Right",
  _op: "Right",
  [symbol223](that) {
    return isEither23(that) && isRight23(that) && equals23(this.right, that.right);
  },
  [symbol33]() {
    return combine23(hash23(this._tag))(hash23(this.right));
  },
  toJSON() {
    return {
      _id: "Either",
      _tag: this._tag,
      right: toJSON23(this.right)
    };
  }
});
var LeftProto23 = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(CommonProto223), {
  _tag: "Left",
  _op: "Left",
  [symbol223](that) {
    return isEither23(that) && isLeft23(that) && equals23(this.left, that.left);
  },
  [symbol33]() {
    return combine23(hash23(this._tag))(hash23(this.left));
  },
  toJSON() {
    return {
      _id: "Either",
      _tag: this._tag,
      left: toJSON23(this.left)
    };
  }
});
var isEither23 = (input) => hasProperty23(input, TypeId223);
var isLeft23 = (ma) => ma._tag === "Left";
var isRight23 = (ma) => ma._tag === "Right";
var left23 = (left33) => {
  const a22 = Object.create(LeftProto23);
  a22.left = left33;
  return a22;
};
var right23 = (right33) => {
  const a22 = Object.create(RightProto23);
  a22.right = right33;
  return a22;
};
var getLeft33 = (self2) => isRight23(self2) ? none33 : some223(self2.left);
var getRight33 = (self2) => isLeft23(self2) ? none33 : some223(self2.right);
var right223 = right23;
var left223 = left23;
var Option_exports23 = {};
__export23(Option_exports23, {
  Do: () => Do23,
  TypeId: () => TypeId323,
  all: () => all223,
  andThen: () => andThen23,
  ap: () => ap23,
  as: () => as23,
  asVoid: () => asVoid23,
  bind: () => bind223,
  bindTo: () => bindTo223,
  composeK: () => composeK23,
  contains: () => contains23,
  containsWith: () => containsWith23,
  exists: () => exists23,
  filter: () => filter23,
  filterMap: () => filterMap23,
  firstSomeOf: () => firstSomeOf23,
  flatMap: () => flatMap23,
  flatMapNullable: () => flatMapNullable23,
  flatten: () => flatten23,
  fromIterable: () => fromIterable23,
  fromNullable: () => fromNullable23,
  gen: () => gen23,
  getEquivalence: () => getEquivalence23,
  getLeft: () => getLeft223,
  getOrElse: () => getOrElse23,
  getOrNull: () => getOrNull23,
  getOrThrow: () => getOrThrow23,
  getOrThrowWith: () => getOrThrowWith23,
  getOrUndefined: () => getOrUndefined23,
  getOrder: () => getOrder23,
  getRight: () => getRight223,
  isNone: () => isNone223,
  isOption: () => isOption223,
  isSome: () => isSome223,
  let: () => let_223,
  lift2: () => lift223,
  liftNullable: () => liftNullable23,
  liftPredicate: () => liftPredicate23,
  liftThrowable: () => liftThrowable23,
  map: () => map23,
  match: () => match23,
  none: () => none223,
  orElse: () => orElse23,
  orElseEither: () => orElseEither23,
  orElseSome: () => orElseSome23,
  partitionMap: () => partitionMap23,
  product: () => product223,
  productMany: () => productMany223,
  reduceCompact: () => reduceCompact23,
  some: () => some323,
  tap: () => tap23,
  toArray: () => toArray23,
  toRefinement: () => toRefinement23,
  void: () => void_23,
  zipLeft: () => zipLeft23,
  zipRight: () => zipRight23,
  zipWith: () => zipWith23
});
var make223 = (compare) => (self2, that) => self2 === that ? 0 : compare(self2, that);
var TypeId323 = /* @__PURE__ */ Symbol.for("effect/Option");
var none223 = () => none33;
var some323 = some223;
var isOption223 = isOption33;
var isNone223 = isNone33;
var isSome223 = isSome33;
var match23 = /* @__PURE__ */ dual23(2, (self2, {
  onNone,
  onSome
}) => isNone223(self2) ? onNone() : onSome(self2.value));
var toRefinement23 = (f22) => (a22) => isSome223(f22(a22));
var fromIterable23 = (collection) => {
  for (const a22 of collection) {
    return some323(a22);
  }
  return none223();
};
var getRight223 = getRight33;
var getLeft223 = getLeft33;
var getOrElse23 = /* @__PURE__ */ dual23(2, (self2, onNone) => isNone223(self2) ? onNone() : self2.value);
var orElse23 = /* @__PURE__ */ dual23(2, (self2, that) => isNone223(self2) ? that() : self2);
var orElseSome23 = /* @__PURE__ */ dual23(2, (self2, onNone) => isNone223(self2) ? some323(onNone()) : self2);
var orElseEither23 = /* @__PURE__ */ dual23(2, (self2, that) => isNone223(self2) ? map23(that(), right23) : map23(self2, left23));
var firstSomeOf23 = (collection) => {
  let out = none223();
  for (out of collection) {
    if (isSome223(out)) {
      return out;
    }
  }
  return out;
};
var fromNullable23 = (nullableValue) => nullableValue == null ? none223() : some323(nullableValue);
var liftNullable23 = (f22) => (...a22) => fromNullable23(f22(...a22));
var getOrNull23 = /* @__PURE__ */ getOrElse23(constNull23);
var getOrUndefined23 = /* @__PURE__ */ getOrElse23(constUndefined23);
var liftThrowable23 = (f22) => (...a22) => {
  try {
    return some323(f22(...a22));
  } catch (e22) {
    return none223();
  }
};
var getOrThrowWith23 = /* @__PURE__ */ dual23(2, (self2, onNone) => {
  if (isSome223(self2)) {
    return self2.value;
  }
  throw onNone();
});
var getOrThrow23 = /* @__PURE__ */ getOrThrowWith23(() => new Error("getOrThrow called on a None"));
var map23 = /* @__PURE__ */ dual23(2, (self2, f22) => isNone223(self2) ? none223() : some323(f22(self2.value)));
var as23 = /* @__PURE__ */ dual23(2, (self2, b22) => map23(self2, () => b22));
var asVoid23 = /* @__PURE__ */ as23(void 0);
var void_23 = /* @__PURE__ */ some323(void 0);
var flatMap23 = /* @__PURE__ */ dual23(2, (self2, f22) => isNone223(self2) ? none223() : f22(self2.value));
var andThen23 = /* @__PURE__ */ dual23(2, (self2, f22) => flatMap23(self2, (a22) => {
  const b22 = isFunction223(f22) ? f22(a22) : f22;
  return isOption223(b22) ? b22 : some323(b22);
}));
var flatMapNullable23 = /* @__PURE__ */ dual23(2, (self2, f22) => isNone223(self2) ? none223() : fromNullable23(f22(self2.value)));
var flatten23 = /* @__PURE__ */ flatMap23(identity23);
var zipRight23 = /* @__PURE__ */ dual23(2, (self2, that) => flatMap23(self2, () => that));
var composeK23 = /* @__PURE__ */ dual23(2, (afb, bfc) => (a22) => flatMap23(afb(a22), bfc));
var zipLeft23 = /* @__PURE__ */ dual23(2, (self2, that) => tap23(self2, () => that));
var tap23 = /* @__PURE__ */ dual23(2, (self2, f22) => flatMap23(self2, (a22) => map23(f22(a22), () => a22)));
var product223 = (self2, that) => isSome223(self2) && isSome223(that) ? some323([self2.value, that.value]) : none223();
var productMany223 = (self2, collection) => {
  if (isNone223(self2)) {
    return none223();
  }
  const out = [self2.value];
  for (const o22 of collection) {
    if (isNone223(o22)) {
      return none223();
    }
    out.push(o22.value);
  }
  return some323(out);
};
var all223 = (input) => {
  if (Symbol.iterator in input) {
    const out2 = [];
    for (const o22 of input) {
      if (isNone223(o22)) {
        return none223();
      }
      out2.push(o22.value);
    }
    return some323(out2);
  }
  const out = {};
  for (const key of Object.keys(input)) {
    const o22 = input[key];
    if (isNone223(o22)) {
      return none223();
    }
    out[key] = o22.value;
  }
  return some323(out);
};
var zipWith23 = /* @__PURE__ */ dual23(3, (self2, that, f22) => map23(product223(self2, that), ([a22, b22]) => f22(a22, b22)));
var ap23 = /* @__PURE__ */ dual23(2, (self2, that) => zipWith23(self2, that, (f22, a22) => f22(a22)));
var reduceCompact23 = /* @__PURE__ */ dual23(3, (self2, b22, f22) => {
  let out = b22;
  for (const oa of self2) {
    if (isSome223(oa)) {
      out = f22(out, oa.value);
    }
  }
  return out;
});
var toArray23 = (self2) => isNone223(self2) ? [] : [self2.value];
var partitionMap23 = /* @__PURE__ */ dual23(2, (self2, f22) => {
  if (isNone223(self2)) {
    return [none223(), none223()];
  }
  const e22 = f22(self2.value);
  return isLeft23(e22) ? [some323(e22.left), none223()] : [none223(), some323(e22.right)];
});
var filterMap23 = /* @__PURE__ */ dual23(2, (self2, f22) => isNone223(self2) ? none223() : f22(self2.value));
var filter23 = /* @__PURE__ */ dual23(2, (self2, predicate) => filterMap23(self2, (b22) => predicate(b22) ? some223(b22) : none33));
var getEquivalence23 = (isEquivalent) => make43((x22, y22) => x22 === y22 || (isNone223(x22) ? isNone223(y22) : isNone223(y22) ? false : isEquivalent(x22.value, y22.value)));
var getOrder23 = (O22) => make223((self2, that) => isSome223(self2) ? isSome223(that) ? O22(self2.value, that.value) : 1 : -1);
var lift223 = (f22) => dual23(2, (self2, that) => zipWith23(self2, that, f22));
var liftPredicate23 = (predicate) => (b22) => predicate(b22) ? some323(b22) : none223();
var containsWith23 = (isEquivalent) => dual23(2, (self2, a22) => isNone223(self2) ? false : isEquivalent(self2.value, a22));
var _equivalence23 = /* @__PURE__ */ equivalence23();
var contains23 = /* @__PURE__ */ containsWith23(_equivalence23);
var exists23 = /* @__PURE__ */ dual23(2, (self2, refinement) => isNone223(self2) ? false : refinement(self2.value));
var bindTo223 = /* @__PURE__ */ bindTo33(map23);
var let_223 = /* @__PURE__ */ let_33(map23);
var bind223 = /* @__PURE__ */ bind33(map23, flatMap23);
var Do23 = /* @__PURE__ */ some323({});
var adapter223 = /* @__PURE__ */ adapter33();
var gen23 = (f22) => {
  const iterator = f22(adapter223);
  let state = iterator.next();
  if (state.done) {
    return some323(state.value);
  } else {
    let current = state.value;
    if (isGenKind23(current)) {
      current = current.value;
    } else {
      current = yieldWrapGet23(current);
    }
    if (isNone223(current)) {
      return current;
    }
    while (!state.done) {
      state = iterator.next(current.value);
      if (!state.done) {
        current = state.value;
        if (isGenKind23(current)) {
          current = current.value;
        } else {
          current = yieldWrapGet23(current);
        }
        if (isNone223(current)) {
          return current;
        }
      }
    }
    return some323(state.value);
  }
};
var fromIterable223 = (collection) => Array.isArray(collection) ? collection : Array.from(collection);
var reverse5 = (self2) => Array.from(self2).reverse();
var reduce6 = /* @__PURE__ */ dual23(3, (self2, b22, f22) => fromIterable223(self2).reduce((b222, a22, i22) => f22(b222, a22, i22), b22));
var TagTypeId3 = /* @__PURE__ */ Symbol.for("effect/Context/Tag");
var STMSymbolKey3 = "effect/STM";
var STMTypeId3 = /* @__PURE__ */ Symbol.for(STMSymbolKey3);
var TagProto3 = {
  ...EffectPrototype23,
  _tag: "Tag",
  _op: "Tag",
  [STMTypeId3]: effectVariance23,
  [TagTypeId3]: {
    _Service: (_22) => _22,
    _Identifier: (_22) => _22
  },
  toString() {
    return format23(this.toJSON());
  },
  toJSON() {
    return {
      _id: "Tag",
      key: this.key,
      stack: this.stack
    };
  },
  [NodeInspectSymbol23]() {
    return this.toJSON();
  },
  of(self2) {
    return self2;
  },
  context(self2) {
    return make323(this, self2);
  }
};
var makeGenericTag3 = (key) => {
  const limit = Error.stackTraceLimit;
  Error.stackTraceLimit = 2;
  const creationError = new Error();
  Error.stackTraceLimit = limit;
  const tag = Object.create(TagProto3);
  Object.defineProperty(tag, "stack", {
    get() {
      return creationError.stack;
    }
  });
  tag.key = key;
  return tag;
};
var TypeId423 = /* @__PURE__ */ Symbol.for("effect/Context");
var ContextProto3 = {
  [TypeId423]: {
    _Services: (_22) => _22
  },
  [symbol223](that) {
    if (isContext3(that)) {
      if (this.unsafeMap.size === that.unsafeMap.size) {
        for (const k22 of this.unsafeMap.keys()) {
          if (!that.unsafeMap.has(k22) || !equals23(this.unsafeMap.get(k22), that.unsafeMap.get(k22))) {
            return false;
          }
        }
        return true;
      }
    }
    return false;
  },
  [symbol33]() {
    return cached23(this, number23(this.unsafeMap.size));
  },
  pipe() {
    return pipeArguments23(this, arguments);
  },
  toString() {
    return format23(this.toJSON());
  },
  toJSON() {
    return {
      _id: "Context",
      services: Array.from(this.unsafeMap).map(toJSON23)
    };
  },
  [NodeInspectSymbol23]() {
    return this.toJSON();
  }
};
var makeContext3 = (unsafeMap) => {
  const context = Object.create(ContextProto3);
  context.unsafeMap = unsafeMap;
  return context;
};
var isContext3 = (u22) => hasProperty23(u22, TypeId423);
var _empty7 = /* @__PURE__ */ makeContext3(/* @__PURE__ */ new Map());
var empty12 = () => _empty7;
var make323 = (tag, service) => makeContext3(/* @__PURE__ */ new Map([[tag.key, service]]));
var GenericTag3 = makeGenericTag3;
var empty23 = empty12;
var TypeId523 = /* @__PURE__ */ Symbol.for("effect/Chunk");
function copy4(src, srcPos, dest, destPos, len) {
  for (let i22 = srcPos; i22 < Math.min(src.length, srcPos + len); i22++) {
    dest[destPos + i22 - srcPos] = src[i22];
  }
  return dest;
}
var emptyArray3 = [];
var getEquivalence223 = (isEquivalent) => make43((self2, that) => self2.length === that.length && toReadonlyArray3(self2).every((value, i22) => isEquivalent(value, unsafeGet23(that, i22))));
var _equivalence223 = /* @__PURE__ */ getEquivalence223(equals23);
var ChunkProto3 = {
  [TypeId523]: {
    _A: (_22) => _22
  },
  toString() {
    return format23(this.toJSON());
  },
  toJSON() {
    return {
      _id: "Chunk",
      values: toReadonlyArray3(this).map(toJSON23)
    };
  },
  [NodeInspectSymbol23]() {
    return this.toJSON();
  },
  [symbol223](that) {
    return isChunk3(that) && _equivalence223(this, that);
  },
  [symbol33]() {
    return cached23(this, array7(toReadonlyArray3(this)));
  },
  [Symbol.iterator]() {
    switch (this.backing._tag) {
      case "IArray": {
        return this.backing.array[Symbol.iterator]();
      }
      case "IEmpty": {
        return emptyArray3[Symbol.iterator]();
      }
      default: {
        return toReadonlyArray3(this)[Symbol.iterator]();
      }
    }
  },
  pipe() {
    return pipeArguments23(this, arguments);
  }
};
var makeChunk3 = (backing) => {
  const chunk = Object.create(ChunkProto3);
  chunk.backing = backing;
  switch (backing._tag) {
    case "IEmpty": {
      chunk.length = 0;
      chunk.depth = 0;
      chunk.left = chunk;
      chunk.right = chunk;
      break;
    }
    case "IConcat": {
      chunk.length = backing.left.length + backing.right.length;
      chunk.depth = 1 + Math.max(backing.left.depth, backing.right.depth);
      chunk.left = backing.left;
      chunk.right = backing.right;
      break;
    }
    case "IArray": {
      chunk.length = backing.array.length;
      chunk.depth = 0;
      chunk.left = _empty23;
      chunk.right = _empty23;
      break;
    }
    case "ISingleton": {
      chunk.length = 1;
      chunk.depth = 0;
      chunk.left = _empty23;
      chunk.right = _empty23;
      break;
    }
    case "ISlice": {
      chunk.length = backing.length;
      chunk.depth = backing.chunk.depth + 1;
      chunk.left = _empty23;
      chunk.right = _empty23;
      break;
    }
  }
  return chunk;
};
var isChunk3 = (u22) => hasProperty23(u22, TypeId523);
var _empty23 = /* @__PURE__ */ makeChunk3({
  _tag: "IEmpty"
});
var empty33 = () => _empty23;
var make423 = (...as223) => as223.length === 1 ? of4(as223[0]) : unsafeFromNonEmptyArray3(as223);
var of4 = (a22) => makeChunk3({
  _tag: "ISingleton",
  a: a22
});
var copyToArray3 = (self2, array33, initial) => {
  switch (self2.backing._tag) {
    case "IArray": {
      copy4(self2.backing.array, 0, array33, initial, self2.length);
      break;
    }
    case "IConcat": {
      copyToArray3(self2.left, array33, initial);
      copyToArray3(self2.right, array33, initial + self2.left.length);
      break;
    }
    case "ISingleton": {
      array33[initial] = self2.backing.a;
      break;
    }
    case "ISlice": {
      let i22 = 0;
      let j22 = initial;
      while (i22 < self2.length) {
        array33[j22] = unsafeGet23(self2, i22);
        i22 += 1;
        j22 += 1;
      }
      break;
    }
  }
};
var toReadonlyArray3 = (self2) => {
  switch (self2.backing._tag) {
    case "IEmpty": {
      return emptyArray3;
    }
    case "IArray": {
      return self2.backing.array;
    }
    default: {
      const arr = new Array(self2.length);
      copyToArray3(self2, arr, 0);
      self2.backing = {
        _tag: "IArray",
        array: arr
      };
      self2.left = _empty23;
      self2.right = _empty23;
      self2.depth = 0;
      return arr;
    }
  }
};
var reverse23 = (self2) => {
  switch (self2.backing._tag) {
    case "IEmpty":
    case "ISingleton":
      return self2;
    case "IArray": {
      return makeChunk3({
        _tag: "IArray",
        array: reverse5(self2.backing.array)
      });
    }
    case "IConcat": {
      return makeChunk3({
        _tag: "IConcat",
        left: reverse23(self2.backing.right),
        right: reverse23(self2.backing.left)
      });
    }
    case "ISlice":
      return unsafeFromArray3(reverse5(toReadonlyArray3(self2)));
  }
};
var unsafeFromArray3 = (self2) => makeChunk3({
  _tag: "IArray",
  array: self2
});
var unsafeFromNonEmptyArray3 = (self2) => unsafeFromArray3(self2);
var unsafeGet23 = /* @__PURE__ */ dual23(2, (self2, index) => {
  switch (self2.backing._tag) {
    case "IEmpty": {
      throw new Error(`Index out of bounds`);
    }
    case "ISingleton": {
      if (index !== 0) {
        throw new Error(`Index out of bounds`);
      }
      return self2.backing.a;
    }
    case "IArray": {
      if (index >= self2.length || index < 0) {
        throw new Error(`Index out of bounds`);
      }
      return self2.backing.array[index];
    }
    case "IConcat": {
      return index < self2.left.length ? unsafeGet23(self2.left, index) : unsafeGet23(self2.right, index - self2.left.length);
    }
    case "ISlice": {
      return unsafeGet23(self2.backing.chunk, index + self2.backing.offset);
    }
  }
});
var prepend5 = /* @__PURE__ */ dual23(2, (self2, elem) => appendAll4(of4(elem), self2));
var drop4 = /* @__PURE__ */ dual23(2, (self2, n22) => {
  if (n22 <= 0) {
    return self2;
  } else if (n22 >= self2.length) {
    return _empty23;
  } else {
    switch (self2.backing._tag) {
      case "ISlice": {
        return makeChunk3({
          _tag: "ISlice",
          chunk: self2.backing.chunk,
          offset: self2.backing.offset + n22,
          length: self2.backing.length - n22
        });
      }
      case "IConcat": {
        if (n22 > self2.left.length) {
          return drop4(self2.right, n22 - self2.left.length);
        }
        return makeChunk3({
          _tag: "IConcat",
          left: drop4(self2.left, n22),
          right: self2.right
        });
      }
      default: {
        return makeChunk3({
          _tag: "ISlice",
          chunk: self2,
          offset: n22,
          length: self2.length - n22
        });
      }
    }
  }
});
var appendAll4 = /* @__PURE__ */ dual23(2, (self2, that) => {
  if (self2.backing._tag === "IEmpty") {
    return that;
  }
  if (that.backing._tag === "IEmpty") {
    return self2;
  }
  const diff23 = that.depth - self2.depth;
  if (Math.abs(diff23) <= 1) {
    return makeChunk3({
      _tag: "IConcat",
      left: self2,
      right: that
    });
  } else if (diff23 < -1) {
    if (self2.left.depth >= self2.right.depth) {
      const nr = appendAll4(self2.right, that);
      return makeChunk3({
        _tag: "IConcat",
        left: self2.left,
        right: nr
      });
    } else {
      const nrr = appendAll4(self2.right.right, that);
      if (nrr.depth === self2.depth - 3) {
        const nr = makeChunk3({
          _tag: "IConcat",
          left: self2.right.left,
          right: nrr
        });
        return makeChunk3({
          _tag: "IConcat",
          left: self2.left,
          right: nr
        });
      } else {
        const nl = makeChunk3({
          _tag: "IConcat",
          left: self2.left,
          right: self2.right.left
        });
        return makeChunk3({
          _tag: "IConcat",
          left: nl,
          right: nrr
        });
      }
    }
  } else {
    if (that.right.depth >= that.left.depth) {
      const nl = appendAll4(self2, that.left);
      return makeChunk3({
        _tag: "IConcat",
        left: nl,
        right: that.right
      });
    } else {
      const nll = appendAll4(self2, that.left.left);
      if (nll.depth === that.depth - 3) {
        const nl = makeChunk3({
          _tag: "IConcat",
          left: nll,
          right: that.left.right
        });
        return makeChunk3({
          _tag: "IConcat",
          left: nl,
          right: that.right
        });
      } else {
        const nr = makeChunk3({
          _tag: "IConcat",
          left: that.left.right,
          right: that.right
        });
        return makeChunk3({
          _tag: "IConcat",
          left: nll,
          right: nr
        });
      }
    }
  }
});
var isEmpty4 = (self2) => self2.length === 0;
var isNonEmpty3 = (self2) => self2.length > 0;
var unsafeHead3 = (self2) => unsafeGet23(self2, 0);
var headNonEmpty4 = unsafeHead3;
var tailNonEmpty4 = (self2) => drop4(self2, 1);
var SIZE3 = 5;
var BUCKET_SIZE3 = /* @__PURE__ */ Math.pow(2, SIZE3);
var MASK3 = BUCKET_SIZE3 - 1;
var MAX_INDEX_NODE3 = BUCKET_SIZE3 / 2;
var MIN_ARRAY_NODE3 = BUCKET_SIZE3 / 4;
function popcount3(x22) {
  x22 -= x22 >> 1 & 1431655765;
  x22 = (x22 & 858993459) + (x22 >> 2 & 858993459);
  x22 = x22 + (x22 >> 4) & 252645135;
  x22 += x22 >> 8;
  x22 += x22 >> 16;
  return x22 & 127;
}
function hashFragment3(shift2, h22) {
  return h22 >>> shift2 & MASK3;
}
function toBitmap3(x22) {
  return 1 << x22;
}
function fromBitmap3(bitmap, bit) {
  return popcount3(bitmap & bit - 1);
}
var make53 = (value, previous) => ({
  value,
  previous
});
function arrayUpdate3(mutate23, at, v22, arr) {
  let out = arr;
  if (!mutate23) {
    const len = arr.length;
    out = new Array(len);
    for (let i22 = 0; i22 < len; ++i22) out[i22] = arr[i22];
  }
  out[at] = v22;
  return out;
}
function arraySpliceOut3(mutate23, at, arr) {
  const newLen = arr.length - 1;
  let i22 = 0;
  let g22 = 0;
  let out = arr;
  if (mutate23) {
    i22 = g22 = at;
  } else {
    out = new Array(newLen);
    while (i22 < at) out[g22++] = arr[i22++];
  }
  ++i22;
  while (i22 <= newLen) out[g22++] = arr[i22++];
  if (mutate23) {
    out.length = newLen;
  }
  return out;
}
function arraySpliceIn3(mutate23, at, v22, arr) {
  const len = arr.length;
  if (mutate23) {
    let i222 = len;
    while (i222 >= at) arr[i222--] = arr[i222];
    arr[at] = v22;
    return arr;
  }
  let i22 = 0, g22 = 0;
  const out = new Array(len + 1);
  while (i22 < at) out[g22++] = arr[i22++];
  out[at] = v22;
  while (i22 < len) out[++g22] = arr[i22++];
  return out;
}
var EmptyNode3 = class _EmptyNode3 {
  _tag = "EmptyNode";
  modify(edit, _shift, f22, hash223, key, size43) {
    const v22 = f22(none223());
    if (isNone223(v22)) return new _EmptyNode3();
    ++size43.value;
    return new LeafNode3(edit, hash223, key, v22);
  }
};
function isEmptyNode3(a22) {
  return isTagged5(a22, "EmptyNode");
}
function isLeafNode3(node) {
  return isEmptyNode3(node) || node._tag === "LeafNode" || node._tag === "CollisionNode";
}
function canEditNode3(node, edit) {
  return isEmptyNode3(node) ? false : edit === node.edit;
}
var LeafNode3 = class _LeafNode3 {
  edit;
  hash;
  key;
  value;
  _tag = "LeafNode";
  constructor(edit, hash223, key, value) {
    this.edit = edit;
    this.hash = hash223;
    this.key = key;
    this.value = value;
  }
  modify(edit, shift2, f22, hash223, key, size43) {
    if (equals23(key, this.key)) {
      const v222 = f22(this.value);
      if (v222 === this.value) return this;
      else if (isNone223(v222)) {
        --size43.value;
        return new EmptyNode3();
      }
      if (canEditNode3(this, edit)) {
        this.value = v222;
        return this;
      }
      return new _LeafNode3(edit, hash223, key, v222);
    }
    const v22 = f22(none223());
    if (isNone223(v22)) return this;
    ++size43.value;
    return mergeLeaves3(edit, shift2, this.hash, this, hash223, new _LeafNode3(edit, hash223, key, v22));
  }
};
var CollisionNode3 = class _CollisionNode3 {
  edit;
  hash;
  children;
  _tag = "CollisionNode";
  constructor(edit, hash223, children) {
    this.edit = edit;
    this.hash = hash223;
    this.children = children;
  }
  modify(edit, shift2, f22, hash223, key, size43) {
    if (hash223 === this.hash) {
      const canEdit = canEditNode3(this, edit);
      const list = this.updateCollisionList(canEdit, edit, this.hash, this.children, f22, key, size43);
      if (list === this.children) return this;
      return list.length > 1 ? new _CollisionNode3(edit, this.hash, list) : list[0];
    }
    const v22 = f22(none223());
    if (isNone223(v22)) return this;
    ++size43.value;
    return mergeLeaves3(edit, shift2, this.hash, this, hash223, new LeafNode3(edit, hash223, key, v22));
  }
  updateCollisionList(mutate23, edit, hash223, list, f22, key, size43) {
    const len = list.length;
    for (let i22 = 0; i22 < len; ++i22) {
      const child = list[i22];
      if ("key" in child && equals23(key, child.key)) {
        const value = child.value;
        const newValue2 = f22(value);
        if (newValue2 === value) return list;
        if (isNone223(newValue2)) {
          --size43.value;
          return arraySpliceOut3(mutate23, i22, list);
        }
        return arrayUpdate3(mutate23, i22, new LeafNode3(edit, hash223, key, newValue2), list);
      }
    }
    const newValue = f22(none223());
    if (isNone223(newValue)) return list;
    ++size43.value;
    return arrayUpdate3(mutate23, len, new LeafNode3(edit, hash223, key, newValue), list);
  }
};
var IndexedNode3 = class _IndexedNode3 {
  edit;
  mask;
  children;
  _tag = "IndexedNode";
  constructor(edit, mask, children) {
    this.edit = edit;
    this.mask = mask;
    this.children = children;
  }
  modify(edit, shift2, f22, hash223, key, size43) {
    const mask = this.mask;
    const children = this.children;
    const frag = hashFragment3(shift2, hash223);
    const bit = toBitmap3(frag);
    const indx = fromBitmap3(mask, bit);
    const exists223 = mask & bit;
    const canEdit = canEditNode3(this, edit);
    if (!exists223) {
      const _newChild = new EmptyNode3().modify(edit, shift2 + SIZE3, f22, hash223, key, size43);
      if (!_newChild) return this;
      return children.length >= MAX_INDEX_NODE3 ? expand3(edit, frag, _newChild, mask, children) : new _IndexedNode3(edit, mask | bit, arraySpliceIn3(canEdit, indx, _newChild, children));
    }
    const current = children[indx];
    const child = current.modify(edit, shift2 + SIZE3, f22, hash223, key, size43);
    if (current === child) return this;
    let bitmap = mask;
    let newChildren;
    if (isEmptyNode3(child)) {
      bitmap &= ~bit;
      if (!bitmap) return new EmptyNode3();
      if (children.length <= 2 && isLeafNode3(children[indx ^ 1])) {
        return children[indx ^ 1];
      }
      newChildren = arraySpliceOut3(canEdit, indx, children);
    } else {
      newChildren = arrayUpdate3(canEdit, indx, child, children);
    }
    if (canEdit) {
      this.mask = bitmap;
      this.children = newChildren;
      return this;
    }
    return new _IndexedNode3(edit, bitmap, newChildren);
  }
};
var ArrayNode3 = class _ArrayNode3 {
  edit;
  size;
  children;
  _tag = "ArrayNode";
  constructor(edit, size43, children) {
    this.edit = edit;
    this.size = size43;
    this.children = children;
  }
  modify(edit, shift2, f22, hash223, key, size43) {
    let count = this.size;
    const children = this.children;
    const frag = hashFragment3(shift2, hash223);
    const child = children[frag];
    const newChild = (child || new EmptyNode3()).modify(edit, shift2 + SIZE3, f22, hash223, key, size43);
    if (child === newChild) return this;
    const canEdit = canEditNode3(this, edit);
    let newChildren;
    if (isEmptyNode3(child) && !isEmptyNode3(newChild)) {
      ++count;
      newChildren = arrayUpdate3(canEdit, frag, newChild, children);
    } else if (!isEmptyNode3(child) && isEmptyNode3(newChild)) {
      --count;
      if (count <= MIN_ARRAY_NODE3) {
        return pack3(edit, count, frag, children);
      }
      newChildren = arrayUpdate3(canEdit, frag, new EmptyNode3(), children);
    } else {
      newChildren = arrayUpdate3(canEdit, frag, newChild, children);
    }
    if (canEdit) {
      this.size = count;
      this.children = newChildren;
      return this;
    }
    return new _ArrayNode3(edit, count, newChildren);
  }
};
function pack3(edit, count, removed, elements) {
  const children = new Array(count - 1);
  let g22 = 0;
  let bitmap = 0;
  for (let i22 = 0, len = elements.length; i22 < len; ++i22) {
    if (i22 !== removed) {
      const elem = elements[i22];
      if (elem && !isEmptyNode3(elem)) {
        children[g22++] = elem;
        bitmap |= 1 << i22;
      }
    }
  }
  return new IndexedNode3(edit, bitmap, children);
}
function expand3(edit, frag, child, bitmap, subNodes) {
  const arr = [];
  let bit = bitmap;
  let count = 0;
  for (let i22 = 0; bit; ++i22) {
    if (bit & 1) arr[i22] = subNodes[count++];
    bit >>>= 1;
  }
  arr[frag] = child;
  return new ArrayNode3(edit, count + 1, arr);
}
function mergeLeavesInner3(edit, shift2, h1, n1, h22, n22) {
  if (h1 === h22) return new CollisionNode3(edit, h1, [n22, n1]);
  const subH1 = hashFragment3(shift2, h1);
  const subH2 = hashFragment3(shift2, h22);
  if (subH1 === subH2) {
    return (child) => new IndexedNode3(edit, toBitmap3(subH1) | toBitmap3(subH2), [child]);
  } else {
    const children = subH1 < subH2 ? [n1, n22] : [n22, n1];
    return new IndexedNode3(edit, toBitmap3(subH1) | toBitmap3(subH2), children);
  }
}
function mergeLeaves3(edit, shift2, h1, n1, h22, n22) {
  let stack = void 0;
  let currentShift = shift2;
  while (true) {
    const res = mergeLeavesInner3(edit, currentShift, h1, n1, h22, n22);
    if (typeof res === "function") {
      stack = make53(res, stack);
      currentShift = currentShift + SIZE3;
    } else {
      let final = res;
      while (stack != null) {
        final = stack.value(final);
        stack = stack.previous;
      }
      return final;
    }
  }
}
var HashMapSymbolKey3 = "effect/HashMap";
var HashMapTypeId3 = /* @__PURE__ */ Symbol.for(HashMapSymbolKey3);
var HashMapProto3 = {
  [HashMapTypeId3]: HashMapTypeId3,
  [Symbol.iterator]() {
    return new HashMapIterator3(this, (k22, v22) => [k22, v22]);
  },
  [symbol33]() {
    let hash223 = hash23(HashMapSymbolKey3);
    for (const item of this) {
      hash223 ^= pipe23(hash23(item[0]), combine23(hash23(item[1])));
    }
    return cached23(this, hash223);
  },
  [symbol223](that) {
    if (isHashMap3(that)) {
      if (that._size !== this._size) {
        return false;
      }
      for (const item of this) {
        const elem = pipe23(that, getHash3(item[0], hash23(item[0])));
        if (isNone223(elem)) {
          return false;
        } else {
          if (!equals23(item[1], elem.value)) {
            return false;
          }
        }
      }
      return true;
    }
    return false;
  },
  toString() {
    return format23(this.toJSON());
  },
  toJSON() {
    return {
      _id: "HashMap",
      values: Array.from(this).map(toJSON23)
    };
  },
  [NodeInspectSymbol23]() {
    return this.toJSON();
  },
  pipe() {
    return pipeArguments23(this, arguments);
  }
};
var makeImpl4 = (editable, edit, root, size43) => {
  const map62 = Object.create(HashMapProto3);
  map62._editable = editable;
  map62._edit = edit;
  map62._root = root;
  map62._size = size43;
  return map62;
};
var HashMapIterator3 = class _HashMapIterator3 {
  map;
  f;
  v;
  constructor(map62, f22) {
    this.map = map62;
    this.f = f22;
    this.v = visitLazy3(this.map._root, this.f, void 0);
  }
  next() {
    if (isNone223(this.v)) {
      return {
        done: true,
        value: void 0
      };
    }
    const v0 = this.v.value;
    this.v = applyCont3(v0.cont);
    return {
      done: false,
      value: v0.value
    };
  }
  [Symbol.iterator]() {
    return new _HashMapIterator3(this.map, this.f);
  }
};
var applyCont3 = (cont) => cont ? visitLazyChildren3(cont[0], cont[1], cont[2], cont[3], cont[4]) : none223();
var visitLazy3 = (node, f22, cont = void 0) => {
  switch (node._tag) {
    case "LeafNode": {
      if (isSome223(node.value)) {
        return some323({
          value: f22(node.key, node.value.value),
          cont
        });
      }
      return applyCont3(cont);
    }
    case "CollisionNode":
    case "ArrayNode":
    case "IndexedNode": {
      const children = node.children;
      return visitLazyChildren3(children.length, children, 0, f22, cont);
    }
    default: {
      return applyCont3(cont);
    }
  }
};
var visitLazyChildren3 = (len, children, i22, f22, cont) => {
  while (i22 < len) {
    const child = children[i22++];
    if (child && !isEmptyNode3(child)) {
      return visitLazy3(child, f22, [len, children, i22, f22, cont]);
    }
  }
  return applyCont3(cont);
};
var _empty33 = /* @__PURE__ */ makeImpl4(false, 0, /* @__PURE__ */ new EmptyNode3(), 0);
var empty43 = () => _empty33;
var isHashMap3 = (u22) => hasProperty23(u22, HashMapTypeId3);
var getHash3 = /* @__PURE__ */ dual23(3, (self2, key, hash223) => {
  let node = self2._root;
  let shift2 = 0;
  while (true) {
    switch (node._tag) {
      case "LeafNode": {
        return equals23(key, node.key) ? node.value : none223();
      }
      case "CollisionNode": {
        if (hash223 === node.hash) {
          const children = node.children;
          for (let i22 = 0, len = children.length; i22 < len; ++i22) {
            const child = children[i22];
            if ("key" in child && equals23(key, child.key)) {
              return child.value;
            }
          }
        }
        return none223();
      }
      case "IndexedNode": {
        const frag = hashFragment3(shift2, hash223);
        const bit = toBitmap3(frag);
        if (node.mask & bit) {
          node = node.children[fromBitmap3(node.mask, bit)];
          shift2 += SIZE3;
          break;
        }
        return none223();
      }
      case "ArrayNode": {
        node = node.children[hashFragment3(shift2, hash223)];
        if (node) {
          shift2 += SIZE3;
          break;
        }
        return none223();
      }
      default:
        return none223();
    }
  }
});
var set23 = /* @__PURE__ */ dual23(3, (self2, key, value) => modifyAt3(self2, key, () => some323(value)));
var setTree3 = /* @__PURE__ */ dual23(3, (self2, newRoot, newSize) => {
  if (self2._editable) {
    self2._root = newRoot;
    self2._size = newSize;
    return self2;
  }
  return newRoot === self2._root ? self2 : makeImpl4(self2._editable, self2._edit, newRoot, newSize);
});
var keys4 = (self2) => new HashMapIterator3(self2, (key) => key);
var size5 = (self2) => self2._size;
var beginMutation4 = (self2) => makeImpl4(true, self2._edit + 1, self2._root, self2._size);
var modifyAt3 = /* @__PURE__ */ dual23(3, (self2, key, f22) => modifyHash3(self2, key, hash23(key), f22));
var modifyHash3 = /* @__PURE__ */ dual23(4, (self2, key, hash223, f22) => {
  const size43 = {
    value: self2._size
  };
  const newRoot = self2._root.modify(self2._editable ? self2._edit : NaN, 0, f22, hash223, key, size43);
  return pipe23(self2, setTree3(newRoot, size43.value));
});
var forEach6 = /* @__PURE__ */ dual23(2, (self2, f22) => reduce23(self2, void 0, (_22, value, key) => f22(value, key)));
var reduce23 = /* @__PURE__ */ dual23(3, (self2, zero, f22) => {
  const root = self2._root;
  if (root._tag === "LeafNode") {
    return isSome223(root.value) ? f22(zero, root.value.value, root.key) : zero;
  }
  if (root._tag === "EmptyNode") {
    return zero;
  }
  const toVisit = [root.children];
  let children;
  while (children = toVisit.pop()) {
    for (let i22 = 0, len = children.length; i22 < len; ) {
      const child = children[i22++];
      if (child && !isEmptyNode3(child)) {
        if (child._tag === "LeafNode") {
          if (isSome223(child.value)) {
            zero = f22(zero, child.value.value, child.key);
          }
        } else {
          toVisit.push(child.children);
        }
      }
    }
  }
  return zero;
});
var HashSetSymbolKey3 = "effect/HashSet";
var HashSetTypeId3 = /* @__PURE__ */ Symbol.for(HashSetSymbolKey3);
var HashSetProto3 = {
  [HashSetTypeId3]: HashSetTypeId3,
  [Symbol.iterator]() {
    return keys4(this._keyMap);
  },
  [symbol33]() {
    return cached23(this, combine23(hash23(this._keyMap))(hash23(HashSetSymbolKey3)));
  },
  [symbol223](that) {
    if (isHashSet3(that)) {
      return size5(this._keyMap) === size5(that._keyMap) && equals23(this._keyMap, that._keyMap);
    }
    return false;
  },
  toString() {
    return format23(this.toJSON());
  },
  toJSON() {
    return {
      _id: "HashSet",
      values: Array.from(this).map(toJSON23)
    };
  },
  [NodeInspectSymbol23]() {
    return this.toJSON();
  },
  pipe() {
    return pipeArguments23(this, arguments);
  }
};
var makeImpl23 = (keyMap) => {
  const set223 = Object.create(HashSetProto3);
  set223._keyMap = keyMap;
  return set223;
};
var isHashSet3 = (u22) => hasProperty23(u22, HashSetTypeId3);
var _empty43 = /* @__PURE__ */ makeImpl23(/* @__PURE__ */ empty43());
var empty53 = () => _empty43;
var size23 = (self2) => size5(self2._keyMap);
var beginMutation23 = (self2) => makeImpl23(beginMutation4(self2._keyMap));
var endMutation3 = (self2) => {
  self2._keyMap._editable = false;
  return self2;
};
var mutate3 = /* @__PURE__ */ dual23(2, (self2, f22) => {
  const transient = beginMutation23(self2);
  f22(transient);
  return endMutation3(transient);
});
var add23 = /* @__PURE__ */ dual23(2, (self2, value) => self2._keyMap._editable ? (set23(value, true)(self2._keyMap), self2) : makeImpl23(set23(value, true)(self2._keyMap)));
var union23 = /* @__PURE__ */ dual23(2, (self2, that) => mutate3(empty53(), (set223) => {
  forEach23(self2, (value) => add23(set223, value));
  for (const value of that) {
    add23(set223, value);
  }
}));
var forEach23 = /* @__PURE__ */ dual23(2, (self2, f22) => forEach6(self2._keyMap, (_22, k22) => f22(k22)));
var empty63 = empty53;
var size33 = size23;
var add33 = add23;
var union33 = union23;
var ArrayProto3 = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(Array.prototype), {
  [symbol33]() {
    return cached23(this, array7(this));
  },
  [symbol223](that) {
    if (Array.isArray(that) && this.length === that.length) {
      return this.every((v22, i22) => equals23(v22, that[i22]));
    } else {
      return false;
    }
  }
});
var Structural4 = /* @__PURE__ */ function() {
  function Structural33(args) {
    if (args) {
      Object.assign(this, args);
    }
  }
  Structural33.prototype = StructuralPrototype23;
  return Structural33;
}();
var struct23 = (as223) => Object.assign(Object.create(StructuralPrototype23), as223);
var ContextPatchTypeId3 = /* @__PURE__ */ Symbol.for("effect/DifferContextPatch");
function variance4(a22) {
  return a22;
}
var PatchProto3 = {
  ...Structural4.prototype,
  [ContextPatchTypeId3]: {
    _Value: variance4,
    _Patch: variance4
  }
};
var EmptyProto3 = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(PatchProto3), {
  _tag: "Empty"
});
var _empty53 = /* @__PURE__ */ Object.create(EmptyProto3);
var empty73 = () => _empty53;
var AndThenProto3 = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(PatchProto3), {
  _tag: "AndThen"
});
var makeAndThen3 = (first, second) => {
  const o22 = Object.create(AndThenProto3);
  o22.first = first;
  o22.second = second;
  return o22;
};
var AddServiceProto3 = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(PatchProto3), {
  _tag: "AddService"
});
var makeAddService3 = (key, service) => {
  const o22 = Object.create(AddServiceProto3);
  o22.key = key;
  o22.service = service;
  return o22;
};
var RemoveServiceProto3 = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(PatchProto3), {
  _tag: "RemoveService"
});
var makeRemoveService3 = (key) => {
  const o22 = Object.create(RemoveServiceProto3);
  o22.key = key;
  return o22;
};
var UpdateServiceProto3 = /* @__PURE__ */ Object.assign(/* @__PURE__ */ Object.create(PatchProto3), {
  _tag: "UpdateService"
});
var makeUpdateService3 = (key, update22) => {
  const o22 = Object.create(UpdateServiceProto3);
  o22.key = key;
  o22.update = update22;
  return o22;
};
var diff3 = (oldValue, newValue) => {
  const missingServices = new Map(oldValue.unsafeMap);
  let patch23 = empty73();
  for (const [tag, newService] of newValue.unsafeMap.entries()) {
    if (missingServices.has(tag)) {
      const old = missingServices.get(tag);
      missingServices.delete(tag);
      if (!equals23(old, newService)) {
        patch23 = combine223(makeUpdateService3(tag, () => newService))(patch23);
      }
    } else {
      missingServices.delete(tag);
      patch23 = combine223(makeAddService3(tag, newService))(patch23);
    }
  }
  for (const [tag] of missingServices.entries()) {
    patch23 = combine223(makeRemoveService3(tag))(patch23);
  }
  return patch23;
};
var combine223 = /* @__PURE__ */ dual23(2, (self2, that) => makeAndThen3(self2, that));
var patch3 = /* @__PURE__ */ dual23(2, (self2, context) => {
  if (self2._tag === "Empty") {
    return context;
  }
  let wasServiceUpdated = false;
  let patches = of4(self2);
  const updatedContext = new Map(context.unsafeMap);
  while (isNonEmpty3(patches)) {
    const head22 = headNonEmpty4(patches);
    const tail3 = tailNonEmpty4(patches);
    switch (head22._tag) {
      case "Empty": {
        patches = tail3;
        break;
      }
      case "AddService": {
        updatedContext.set(head22.key, head22.service);
        patches = tail3;
        break;
      }
      case "AndThen": {
        patches = prepend5(prepend5(tail3, head22.second), head22.first);
        break;
      }
      case "RemoveService": {
        updatedContext.delete(head22.key);
        patches = tail3;
        break;
      }
      case "UpdateService": {
        updatedContext.set(head22.key, head22.update(updatedContext.get(head22.key)));
        wasServiceUpdated = true;
        patches = tail3;
        break;
      }
    }
  }
  if (!wasServiceUpdated) {
    return makeContext3(updatedContext);
  }
  const map62 = /* @__PURE__ */ new Map();
  for (const [tag] of context.unsafeMap) {
    if (updatedContext.has(tag)) {
      map62.set(tag, updatedContext.get(tag));
      updatedContext.delete(tag);
    }
  }
  for (const [tag, s22] of updatedContext) {
    map62.set(tag, s22);
  }
  return makeContext3(map62);
});
var DifferTypeId3 = /* @__PURE__ */ Symbol.for("effect/Differ");
var DifferProto3 = {
  [DifferTypeId3]: {
    _P: identity23,
    _V: identity23
  }
};
var make73 = (params) => {
  const differ = Object.create(DifferProto3);
  differ.empty = params.empty;
  differ.diff = params.diff;
  differ.combine = params.combine;
  differ.patch = params.patch;
  return differ;
};
var environment3 = () => make73({
  empty: empty73(),
  combine: (first, second) => combine223(second)(first),
  diff: (oldValue, newValue) => diff3(oldValue, newValue),
  patch: (patch23, oldValue) => patch3(oldValue)(patch23)
});
var OP_DIE3 = "Die";
var OP_EMPTY3 = "Empty";
var OP_FAIL3 = "Fail";
var OP_INTERRUPT3 = "Interrupt";
var OP_PARALLEL3 = "Parallel";
var OP_SEQUENTIAL3 = "Sequential";
var CauseSymbolKey3 = "effect/Cause";
var CauseTypeId3 = /* @__PURE__ */ Symbol.for(CauseSymbolKey3);
var variance23 = {
  /* c8 ignore next */
  _E: (_22) => _22
};
var proto3 = {
  [CauseTypeId3]: variance23,
  [symbol33]() {
    return pipe23(hash23(CauseSymbolKey3), combine23(hash23(flattenCause3(this))), cached23(this));
  },
  [symbol223](that) {
    return isCause3(that) && causeEquals3(this, that);
  },
  pipe() {
    return pipeArguments23(this, arguments);
  },
  toJSON() {
    switch (this._tag) {
      case "Empty":
        return {
          _id: "Cause",
          _tag: this._tag
        };
      case "Die":
        return {
          _id: "Cause",
          _tag: this._tag,
          defect: toJSON23(this.defect)
        };
      case "Interrupt":
        return {
          _id: "Cause",
          _tag: this._tag,
          fiberId: this.fiberId.toJSON()
        };
      case "Fail":
        return {
          _id: "Cause",
          _tag: this._tag,
          failure: toJSON23(this.error)
        };
      case "Sequential":
      case "Parallel":
        return {
          _id: "Cause",
          _tag: this._tag,
          left: toJSON23(this.left),
          right: toJSON23(this.right)
        };
    }
  },
  toString() {
    return pretty3(this);
  },
  [NodeInspectSymbol23]() {
    return this.toJSON();
  }
};
var fail4 = (error) => {
  const o22 = Object.create(proto3);
  o22._tag = OP_FAIL3;
  o22.error = error;
  return o22;
};
var parallel3 = (left33, right33) => {
  const o22 = Object.create(proto3);
  o22._tag = OP_PARALLEL3;
  o22.left = left33;
  o22.right = right33;
  return o22;
};
var sequential3 = (left33, right33) => {
  const o22 = Object.create(proto3);
  o22._tag = OP_SEQUENTIAL3;
  o22.left = left33;
  o22.right = right33;
  return o22;
};
var isCause3 = (u22) => hasProperty23(u22, CauseTypeId3);
var isInterruptedOnly3 = (self2) => reduceWithContext3(void 0, IsInterruptedOnlyCauseReducer3)(self2);
var causeEquals3 = (left33, right33) => {
  let leftStack = of4(left33);
  let rightStack = of4(right33);
  while (isNonEmpty3(leftStack) && isNonEmpty3(rightStack)) {
    const [leftParallel, leftSequential] = pipe23(headNonEmpty4(leftStack), reduce43([empty63(), empty33()], ([parallel23, sequential23], cause) => {
      const [par, seq] = evaluateCause3(cause);
      return some323([pipe23(parallel23, union33(par)), pipe23(sequential23, appendAll4(seq))]);
    }));
    const [rightParallel, rightSequential] = pipe23(headNonEmpty4(rightStack), reduce43([empty63(), empty33()], ([parallel23, sequential23], cause) => {
      const [par, seq] = evaluateCause3(cause);
      return some323([pipe23(parallel23, union33(par)), pipe23(sequential23, appendAll4(seq))]);
    }));
    if (!equals23(leftParallel, rightParallel)) {
      return false;
    }
    leftStack = leftSequential;
    rightStack = rightSequential;
  }
  return true;
};
var flattenCause3 = (cause) => {
  return flattenCauseLoop3(of4(cause), empty33());
};
var flattenCauseLoop3 = (causes, flattened) => {
  while (1) {
    const [parallel23, sequential23] = pipe23(causes, reduce6([empty63(), empty33()], ([parallel32, sequential32], cause) => {
      const [par, seq] = evaluateCause3(cause);
      return [pipe23(parallel32, union33(par)), pipe23(sequential32, appendAll4(seq))];
    }));
    const updated = size33(parallel23) > 0 ? pipe23(flattened, prepend5(parallel23)) : flattened;
    if (isEmpty4(sequential23)) {
      return reverse23(updated);
    }
    causes = sequential23;
    flattened = updated;
  }
  throw new Error(getBugErrorMessage23("Cause.flattenCauseLoop"));
};
var evaluateCause3 = (self2) => {
  let cause = self2;
  const stack = [];
  let _parallel = empty63();
  let _sequential = empty33();
  while (cause !== void 0) {
    switch (cause._tag) {
      case OP_EMPTY3: {
        if (stack.length === 0) {
          return [_parallel, _sequential];
        }
        cause = stack.pop();
        break;
      }
      case OP_FAIL3: {
        _parallel = add33(_parallel, make423(cause._tag, cause.error));
        if (stack.length === 0) {
          return [_parallel, _sequential];
        }
        cause = stack.pop();
        break;
      }
      case OP_DIE3: {
        _parallel = add33(_parallel, make423(cause._tag, cause.defect));
        if (stack.length === 0) {
          return [_parallel, _sequential];
        }
        cause = stack.pop();
        break;
      }
      case OP_INTERRUPT3: {
        _parallel = add33(_parallel, make423(cause._tag, cause.fiberId));
        if (stack.length === 0) {
          return [_parallel, _sequential];
        }
        cause = stack.pop();
        break;
      }
      case OP_SEQUENTIAL3: {
        switch (cause.left._tag) {
          case OP_EMPTY3: {
            cause = cause.right;
            break;
          }
          case OP_SEQUENTIAL3: {
            cause = sequential3(cause.left.left, sequential3(cause.left.right, cause.right));
            break;
          }
          case OP_PARALLEL3: {
            cause = parallel3(sequential3(cause.left.left, cause.right), sequential3(cause.left.right, cause.right));
            break;
          }
          default: {
            _sequential = prepend5(_sequential, cause.right);
            cause = cause.left;
            break;
          }
        }
        break;
      }
      case OP_PARALLEL3: {
        stack.push(cause.right);
        cause = cause.left;
        break;
      }
    }
  }
  throw new Error(getBugErrorMessage23("Cause.evaluateCauseLoop"));
};
var IsInterruptedOnlyCauseReducer3 = {
  emptyCase: constTrue23,
  failCase: constFalse23,
  dieCase: constFalse23,
  interruptCase: constTrue23,
  sequentialCase: (_22, left33, right33) => left33 && right33,
  parallelCase: (_22, left33, right33) => left33 && right33
};
var OP_SEQUENTIAL_CASE3 = "SequentialCase";
var OP_PARALLEL_CASE3 = "ParallelCase";
var reduce43 = /* @__PURE__ */ dual23(3, (self2, zero, pf) => {
  let accumulator = zero;
  let cause = self2;
  const causes = [];
  while (cause !== void 0) {
    const option = pf(accumulator, cause);
    accumulator = isSome223(option) ? option.value : accumulator;
    switch (cause._tag) {
      case OP_SEQUENTIAL3: {
        causes.push(cause.right);
        cause = cause.left;
        break;
      }
      case OP_PARALLEL3: {
        causes.push(cause.right);
        cause = cause.left;
        break;
      }
      default: {
        cause = void 0;
        break;
      }
    }
    if (cause === void 0 && causes.length > 0) {
      cause = causes.pop();
    }
  }
  return accumulator;
});
var reduceWithContext3 = /* @__PURE__ */ dual23(3, (self2, context, reducer) => {
  const input = [self2];
  const output = [];
  while (input.length > 0) {
    const cause = input.pop();
    switch (cause._tag) {
      case OP_EMPTY3: {
        output.push(right223(reducer.emptyCase(context)));
        break;
      }
      case OP_FAIL3: {
        output.push(right223(reducer.failCase(context, cause.error)));
        break;
      }
      case OP_DIE3: {
        output.push(right223(reducer.dieCase(context, cause.defect)));
        break;
      }
      case OP_INTERRUPT3: {
        output.push(right223(reducer.interruptCase(context, cause.fiberId)));
        break;
      }
      case OP_SEQUENTIAL3: {
        input.push(cause.right);
        input.push(cause.left);
        output.push(left223({
          _tag: OP_SEQUENTIAL_CASE3
        }));
        break;
      }
      case OP_PARALLEL3: {
        input.push(cause.right);
        input.push(cause.left);
        output.push(left223({
          _tag: OP_PARALLEL_CASE3
        }));
        break;
      }
    }
  }
  const accumulator = [];
  while (output.length > 0) {
    const either = output.pop();
    switch (either._tag) {
      case "Left": {
        switch (either.left._tag) {
          case OP_SEQUENTIAL_CASE3: {
            const left33 = accumulator.pop();
            const right33 = accumulator.pop();
            const value = reducer.sequentialCase(context, left33, right33);
            accumulator.push(value);
            break;
          }
          case OP_PARALLEL_CASE3: {
            const left33 = accumulator.pop();
            const right33 = accumulator.pop();
            const value = reducer.parallelCase(context, left33, right33);
            accumulator.push(value);
            break;
          }
        }
        break;
      }
      case "Right": {
        accumulator.push(either.right);
        break;
      }
    }
  }
  if (accumulator.length === 0) {
    throw new Error("BUG: Cause.reduceWithContext - please report an issue at https://github.com/Effect-TS/effect/issues");
  }
  return accumulator.pop();
});
var pretty3 = (cause) => {
  if (isInterruptedOnly3(cause)) {
    return "All fibers interrupted without errors.";
  }
  return prettyErrors3(cause).map((e22) => e22.stack).join("\n");
};
var PrettyError3 = class extends globalThis.Error {
  span = void 0;
  constructor(originalError) {
    const prevLimit = Error.stackTraceLimit;
    Error.stackTraceLimit = 0;
    super(prettyErrorMessage3(originalError));
    Error.stackTraceLimit = prevLimit;
    this.name = originalError instanceof Error ? originalError.name : "Error";
    if (typeof originalError === "object" && originalError !== null) {
      if (spanSymbol4 in originalError) {
        this.span = originalError[spanSymbol4];
      }
      Object.keys(originalError).forEach((key) => {
        if (!(key in this)) {
          this[key] = originalError[key];
        }
      });
    }
    this.stack = prettyErrorStack3(this.message, originalError instanceof Error && originalError.stack ? originalError.stack : "", this.span);
  }
  toJSON() {
    const out = {
      message: this.message,
      stack: this.stack
    };
    if (this.span) {
      out.span = this.span;
    }
    return out;
  }
};
var prettyErrorMessage3 = (u22) => {
  if (typeof u22 === "string") {
    return `Error: ${u22}`;
  }
  try {
    if (hasProperty23(u22, "toString") && isFunction323(u22["toString"]) && u22["toString"] !== Object.prototype.toString && u22["toString"] !== globalThis.Array.prototype.toString) {
      return u22["toString"]();
    }
  } catch {
  }
  return `Error: ${JSON.stringify(u22)}`;
};
var locationRegex3 = /\((.*)\)/;
var spanToTrace3 = /* @__PURE__ */ globalValue23("effect/Tracer/spanToTrace", () => /* @__PURE__ */ new WeakMap());
var prettyErrorStack3 = (message, stack, span2) => {
  const out = [message];
  const lines = stack.split("\n");
  for (let i22 = 1; i22 < lines.length; i22++) {
    if (lines[i22].includes("Generator.next")) {
      break;
    }
    if (lines[i22].includes("effect_internal_function")) {
      out.pop();
      break;
    }
    out.push(lines[i22].replace(/at .*effect_instruction_i.*\((.*)\)/, "at $1").replace(/EffectPrimitive\.\w+/, "<anonymous>"));
  }
  if (span2) {
    let current = span2;
    let i22 = 0;
    while (current && current._tag === "Span" && i22 < 10) {
      const stackFn = spanToTrace3.get(current);
      if (typeof stackFn === "function") {
        const stack2 = stackFn();
        const locationMatch = stack2.match(locationRegex3);
        const location = locationMatch ? locationMatch[1] : stack2.replace(/^at /, "");
        out.push(`    at ${current.name} (${location})`);
      } else {
        out.push(`    at ${current.name}`);
      }
      current = getOrUndefined23(current.parent);
      i22++;
    }
  }
  return out.join("\n");
};
var spanSymbol4 = /* @__PURE__ */ Symbol.for("effect/SpanAnnotation");
var prettyErrors3 = (cause) => reduceWithContext3(cause, void 0, {
  emptyCase: () => [],
  dieCase: (_22, unknownError) => {
    return [new PrettyError3(unknownError)];
  },
  failCase: (_22, error) => {
    return [new PrettyError3(error)];
  },
  interruptCase: () => [],
  parallelCase: (_22, l22, r22) => [...l22, ...r22],
  sequentialCase: (_22, l22, r22) => [...l22, ...r22]
});
var SingleShotGen223 = class _SingleShotGen23 {
  self;
  called = false;
  constructor(self2) {
    this.self = self2;
  }
  next(a22) {
    return this.called ? {
      value: a22,
      done: true
    } : (this.called = true, {
      value: this.self,
      done: false
    });
  }
  return(a22) {
    return {
      value: a22,
      done: true
    };
  }
  throw(e22) {
    throw e22;
  }
  [Symbol.iterator]() {
    return new _SingleShotGen23(this.self);
  }
};
var spanTag3 = /* @__PURE__ */ GenericTag3("effect/ParentSpan");
var EffectTypeId223 = /* @__PURE__ */ Symbol.for("effect/Effect");
var EffectPrimitive3 = class {
  _op;
  effect_instruction_i0 = void 0;
  effect_instruction_i1 = void 0;
  effect_instruction_i2 = void 0;
  trace = void 0;
  [EffectTypeId223] = effectVariance23;
  constructor(_op) {
    this._op = _op;
  }
  [symbol223](that) {
    return this === that;
  }
  [symbol33]() {
    return cached23(this, random23(this));
  }
  pipe() {
    return pipeArguments23(this, arguments);
  }
  toJSON() {
    return {
      _id: "Effect",
      _op: this._op,
      effect_instruction_i0: toJSON23(this.effect_instruction_i0),
      effect_instruction_i1: toJSON23(this.effect_instruction_i1),
      effect_instruction_i2: toJSON23(this.effect_instruction_i2)
    };
  }
  toString() {
    return format23(this.toJSON());
  }
  [NodeInspectSymbol23]() {
    return this.toJSON();
  }
  [Symbol.iterator]() {
    return new SingleShotGen223(new YieldWrap23(this));
  }
};
var EffectPrimitiveFailure3 = class {
  _op;
  effect_instruction_i0 = void 0;
  effect_instruction_i1 = void 0;
  effect_instruction_i2 = void 0;
  trace = void 0;
  [EffectTypeId223] = effectVariance23;
  constructor(_op) {
    this._op = _op;
    this._tag = _op;
  }
  [symbol223](that) {
    return exitIsExit3(that) && that._op === "Failure" && // @ts-expect-error
    equals23(this.effect_instruction_i0, that.effect_instruction_i0);
  }
  [symbol33]() {
    return pipe23(
      // @ts-expect-error
      string23(this._tag),
      // @ts-expect-error
      combine23(hash23(this.effect_instruction_i0)),
      cached23(this)
    );
  }
  get cause() {
    return this.effect_instruction_i0;
  }
  pipe() {
    return pipeArguments23(this, arguments);
  }
  toJSON() {
    return {
      _id: "Exit",
      _tag: this._op,
      cause: this.cause.toJSON()
    };
  }
  toString() {
    return format23(this.toJSON());
  }
  [NodeInspectSymbol23]() {
    return this.toJSON();
  }
  [Symbol.iterator]() {
    return new SingleShotGen223(new YieldWrap23(this));
  }
};
var isEffect3 = (u22) => hasProperty23(u22, EffectTypeId223);
var withFiberRuntime3 = (withRuntime) => {
  const effect = new EffectPrimitive3(OP_WITH_RUNTIME3);
  effect.effect_instruction_i0 = withRuntime;
  return effect;
};
var spanSymbol23 = /* @__PURE__ */ Symbol.for("effect/SpanAnnotation");
var originalSymbol3 = /* @__PURE__ */ Symbol.for("effect/OriginalAnnotation");
var capture3 = (obj, span2) => {
  if (isSome223(span2)) {
    return new Proxy(obj, {
      has(target, p22) {
        return p22 === spanSymbol23 || p22 === originalSymbol3 || p22 in target;
      },
      get(target, p22) {
        if (p22 === spanSymbol23) {
          return span2.value;
        }
        if (p22 === originalSymbol3) {
          return obj;
        }
        return target[p22];
      }
    });
  }
  return obj;
};
var fail23 = (error) => isObject23(error) && !(spanSymbol23 in error) ? withFiberRuntime3((fiber) => failCause3(fail4(capture3(error, currentSpanFromFiber3(fiber))))) : failCause3(fail4(error));
var failCause3 = (cause) => {
  const effect = new EffectPrimitiveFailure3(OP_FAILURE3);
  effect.effect_instruction_i0 = cause;
  return effect;
};
var FiberRefSymbolKey3 = "effect/FiberRef";
var FiberRefTypeId3 = /* @__PURE__ */ Symbol.for(FiberRefSymbolKey3);
var fiberRefVariance3 = {
  /* c8 ignore next */
  _A: (_22) => _22
};
var fiberRefUnsafeMakeContext3 = (initial) => {
  const differ = environment3();
  return fiberRefUnsafeMakePatch3(initial, {
    differ,
    fork: differ.empty
  });
};
var fiberRefUnsafeMakePatch3 = (initial, options) => ({
  [FiberRefTypeId3]: fiberRefVariance3,
  initial,
  diff: (oldValue, newValue) => options.differ.diff(oldValue, newValue),
  combine: (first, second) => options.differ.combine(first, second),
  patch: (patch23) => (oldValue) => options.differ.patch(patch23, oldValue),
  fork: options.fork,
  join: options.join ?? ((_22, n22) => n22),
  pipe() {
    return pipeArguments23(this, arguments);
  }
});
var currentContext3 = /* @__PURE__ */ globalValue23(/* @__PURE__ */ Symbol.for("effect/FiberRef/currentContext"), () => fiberRefUnsafeMakeContext3(empty23()));
var YieldableError3 = /* @__PURE__ */ function() {
  class YieldableError23 extends globalThis.Error {
    commit() {
      return fail23(this);
    }
    toString() {
      return this.message ? `${this.name}: ${this.message}` : this.name;
    }
    toJSON() {
      return {
        ...this
      };
    }
    [NodeInspectSymbol23]() {
      const stack = this.stack;
      if (stack) {
        return `${this.toString()}
${stack.split("\n").slice(1).join("\n")}`;
      }
      return this.toString();
    }
  }
  Object.assign(YieldableError23.prototype, StructuralCommitPrototype23);
  return YieldableError23;
}();
var exitIsExit3 = (u22) => isEffect3(u22) && "_tag" in u22 && (u22._tag === "Success" || u22._tag === "Failure");
var currentSpanFromFiber3 = (fiber) => {
  const span2 = fiber.getFiberRef(currentContext3).unsafeMap.get(spanTag3.key);
  return span2 !== void 0 && span2._tag === "Span" ? some323(span2) : none223();
};
var Data_exports23 = {};
__export23(Data_exports23, {
  Class: () => Class23,
  Error: () => Error23,
  Structural: () => Structural23,
  TaggedClass: () => TaggedClass3,
  TaggedError: () => TaggedError3,
  array: () => array23,
  case: () => _case3,
  struct: () => struct33,
  tagged: () => tagged3,
  taggedEnum: () => taggedEnum3,
  tuple: () => tuple23,
  unsafeArray: () => unsafeArray3,
  unsafeStruct: () => unsafeStruct3
});
var struct33 = struct23;
var unsafeStruct3 = (as223) => Object.setPrototypeOf(as223, StructuralPrototype23);
var tuple23 = (...as223) => unsafeArray3(as223);
var array23 = (as223) => unsafeArray3(as223.slice(0));
var unsafeArray3 = (as223) => Object.setPrototypeOf(as223, ArrayProto3);
var _case3 = () => (args) => args === void 0 ? Object.create(StructuralPrototype23) : struct33(args);
var tagged3 = (tag) => (args) => {
  const value = args === void 0 ? Object.create(StructuralPrototype23) : struct33(args);
  value._tag = tag;
  return value;
};
var Class23 = Structural4;
var TaggedClass3 = (tag) => {
  class Base extends Class23 {
    _tag = tag;
  }
  return Base;
};
var Structural23 = Structural4;
var taggedEnum3 = () => new Proxy({}, {
  get(_target, tag, _receiver) {
    if (tag === "$is") {
      return isTagged5;
    } else if (tag === "$match") {
      return taggedMatch3;
    }
    return tagged3(tag);
  }
});
function taggedMatch3() {
  if (arguments.length === 1) {
    const cases2 = arguments[0];
    return function(value2) {
      return cases2[value2._tag](value2);
    };
  }
  const value = arguments[0];
  const cases = arguments[1];
  return cases[value._tag](value);
}
var Error23 = /* @__PURE__ */ function() {
  return class Base extends YieldableError3 {
    constructor(args) {
      super();
      if (args) {
        Object.assign(this, args);
      }
    }
  };
}();
var TaggedError3 = (tag) => {
  class Base extends Error23 {
    _tag = tag;
  }
  Base.prototype.name = tag;
  return Base;
};
var traverseUp3 = Function_exports23.dual(2, (node, predicate) => {
  const { parent } = node;
  if (!parent || parent.type === NodeType3.Program) return Option_exports23.none();
  return predicate(parent) ? Option_exports23.some(parent) : traverseUp3(parent, predicate);
});
var traverseUpGuard3 = Function_exports23.dual(2, (node, predicate) => {
  const { parent } = node;
  if (!parent || parent.type === NodeType3.Program) return Option_exports23.none();
  return predicate(parent) ? Option_exports23.some(parent) : traverseUpGuard3(parent, predicate);
});
var ESLintCommunityESLintUtils3;
((ESLintCommunityESLintUtils23) => {
  ESLintCommunityESLintUtils23.getFunctionHeadLocation = getFunctionHeadLocation3;
  ESLintCommunityESLintUtils23.getFunctionNameWithKind = getFunctionNameWithKind3;
  ESLintCommunityESLintUtils23.getPropertyName = getPropertyName3;
  ESLintCommunityESLintUtils23.getStaticValue = getStaticValue4;
  ESLintCommunityESLintUtils23.getStringIfConstant = getStringIfConstant3;
  ESLintCommunityESLintUtils23.hasSideEffect = hasSideEffect3;
  ESLintCommunityESLintUtils23.isParenthesized = isParenthesized3;
})(ESLintCommunityESLintUtils3 || (ESLintCommunityESLintUtils3 = {}));
var Construction3 = Data_exports23.taggedEnum();
Construction3.None();
a2({
  type: N2.union([NodeType3.FunctionExpression, NodeType3.ArrowFunctionExpression]),
  parent: {
    type: NodeType3.Property,
    parent: {
      type: NodeType3.ObjectExpression
    }
  }
});
a2({
  type: N2.union([NodeType3.FunctionExpression, NodeType3.ArrowFunctionExpression]),
  parent: {
    type: NodeType3.MethodDefinition,
    parent: {
      type: NodeType3.ClassBody
    }
  }
});
a2({
  type: N2.union([NodeType3.FunctionExpression, NodeType3.ArrowFunctionExpression]),
  parent: {
    type: NodeType3.Property,
    parent: {
      type: NodeType3.ClassBody
    }
  }
});
function isInitializedFromReact(variableName, context, initialScope) {
  if (variableName.toLowerCase() === "react") return true;
  const maybeVariable = findVariable3(variableName, initialScope);
  const maybeLatestDef = Option_exports4.flatMapNullable(maybeVariable, (v3) => v3.defs.at(-1));
  if (Option_exports4.isNone(maybeLatestDef)) return false;
  const latestDef = maybeLatestDef.value;
  const { node, parent } = latestDef;
  const settings = valibot.parse(ESLintSettingsSchema, context.settings);
  const importSource = settings.reactOptions?.importSource ?? "react";
  if (node.type === NodeType.VariableDeclarator && node.init) {
    const { init: init2 } = node;
    if (init2.type === NodeType.MemberExpression && init2.object.type === NodeType.Identifier) {
      return isInitializedFromReact(init2.object.name, context, initialScope);
    }
    if (init2.type === NodeType.Identifier) {
      return isInitializedFromReact(init2.name, context, initialScope);
    }
    const maybeRequireExpression = tsPattern.match(init2).with({
      type: NodeType.CallExpression,
      callee: { type: NodeType.Identifier, name: "require" }
    }, (exp) => Option_exports4.some(exp)).with(
      {
        type: NodeType.MemberExpression,
        object: {
          type: NodeType.CallExpression,
          callee: { type: NodeType.Identifier, name: "require" }
        }
      },
      ({ object: object2 }) => Option_exports4.some(object2)
    ).otherwise(Option_exports4.none);
    if (Option_exports4.isNone(maybeRequireExpression)) return false;
    const requireExpression = maybeRequireExpression.value;
    const [firstArg] = requireExpression.arguments;
    if (firstArg?.type !== NodeType.Literal || !Predicate_exports3.isString(firstArg.value)) return false;
    return firstArg.value === importSource || firstArg.value.startsWith(`${importSource}/`);
  }
  return tsPattern.isMatching({ type: "ImportDeclaration", source: { value: importSource } }, parent);
}
function isFromReact(name) {
  return (node, context) => {
    const initialScope = context.sourceCode.getScope(node);
    if (node.type === NodeType.MemberExpression) {
      return node.object.type === NodeType.Identifier && node.property.type === NodeType.Identifier && node.property.name === name && isInitializedFromReact(node.object.name, context, initialScope);
    }
    if (node.name === name) return isInitializedFromReact(name, context, initialScope);
    return false;
  };
}
function isFromReactMember(memberName, name) {
  return (node, context) => {
    const initialScope = context.sourceCode.getScope(node);
    if (node.property.type !== NodeType.Identifier || node.property.name !== name) return false;
    if (node.object.type === NodeType.Identifier && node.object.name === memberName) {
      return isInitializedFromReact(node.object.name, context, initialScope);
    }
    if (node.object.type === NodeType.MemberExpression && node.object.object.type === NodeType.Identifier && isInitializedFromReact(node.object.object.name, context, initialScope) && node.object.property.type === NodeType.Identifier) {
      return node.object.property.name === memberName;
    }
    return false;
  };
}
function isCallFromReact(name) {
  return (node, context) => {
    if (!isOneOf([NodeType.Identifier, NodeType.MemberExpression])(node.callee)) return false;
    return isFromReact(name)(node.callee, context);
  };
}
function isCallFromReactMember(pragmaMemberName, name) {
  return (node, context) => {
    if (!is(NodeType.MemberExpression)(node.callee)) return false;
    return isFromReactMember(pragmaMemberName, name)(node.callee, context);
  };
}

// src/internal/is-react-api.ts
function isReactAPIWithName(name, member) {
  return member ? isFromReactMember(name, member) : isFromReact(name);
}
function isReactAPICallWithName(name, member) {
  return member ? isCallFromReactMember(name, member) : isCallFromReact(name);
}

// src/react-api.ts
var isChildrenCount = isReactAPIWithName("Children", "count");
var isChildrenForEach = isReactAPIWithName("Children", "forEach");
var isChildrenMap = isReactAPIWithName("Children", "map");
var isChildrenOnly = isReactAPIWithName("Children", "only");
var isChildrenToArray = isReactAPIWithName("Children", "toArray");
var isCloneElement = isReactAPIWithName("cloneElement");
var isCreateContext = isReactAPIWithName("createContext");
var isCreateElement = isReactAPIWithName("createElement");
var isCreateRef = isReactAPIWithName("createRef");
var isForwardRef = isReactAPIWithName("forwardRef");
var isMemo = isReactAPIWithName("memo");
var isChildrenCountCall = isReactAPICallWithName("Children", "count");
var isChildrenForEachCall = isReactAPICallWithName("Children", "forEach");
var isChildrenMapCall = isReactAPICallWithName("Children", "map");
var isChildrenOnlyCall = isReactAPICallWithName("Children", "only");
var isChildrenToArrayCall = isReactAPICallWithName("Children", "toArray");
var isCloneElementCall = isReactAPICallWithName("cloneElement");
var isCreateContextCall = isReactAPICallWithName("createContext");
var isCreateElementCall = isReactAPICallWithName("createElement");
var isCreateRefCall = isReactAPICallWithName("createRef");
var isForwardRefCall = isReactAPICallWithName("forwardRef");
var isMemoCall = isReactAPICallWithName("memo");

// src/element/hierarchy.ts
function isInsideCreateElementProps(node, context) {
  return Function_exports4.pipe(
    traverseUp(node, (n3) => is(NodeType.CallExpression)(n3) && isCreateElementCall(n3, context)),
    Option_exports4.filter(is(NodeType.CallExpression)),
    Option_exports4.flatMapNullable((c3) => c3.arguments.at(1)),
    Option_exports4.filter(is(NodeType.ObjectExpression)),
    Option_exports4.zipWith(traverseUp(node, is(NodeType.ObjectExpression)), (a3, b3) => a3 === b3),
    Option_exports4.getOrElse(Function_exports4.constFalse)
  );
}
function isChildrenOfCreateElement(node, context) {
  return Function_exports4.pipe(
    Option_exports4.fromNullable(node.parent),
    Option_exports4.filter(is(NodeType.CallExpression)),
    Option_exports4.filter((n3) => isCreateElementCall(n3, context)),
    Option_exports4.exists(
      (n3) => n3.arguments.slice(2).some((arg) => arg === node)
    )
  );
}
function hasChildren(node, predicate) {
  if (Predicate_exports3.isFunction(predicate)) return node.children.some(predicate);
  return node.children.length > 0;
}
function isChildOfJSXElement(node) {
  return node.parent?.type === NodeType.JSXElement && node.parent.children.some((child) => child === node);
}
function isFragmentElement(node, context) {
  const fragment = valibot.parse(ESLintSettingsSchema, context.settings).reactOptions?.jsxPragmaFrag ?? "Fragment";
  const { name } = node.openingElement;
  if (name.type === NodeType.JSXIdentifier && name.name === fragment) return true;
  const initialScope = context.sourceCode.getScope(node);
  return name.type === NodeType.JSXMemberExpression && name.object.type === NodeType.JSXIdentifier && isInitializedFromReact(name.object.name, context, initialScope) && name.property.name === fragment;
}

// src/hook/hook-name.ts
var RE_HOOK_NAME = /^use[A-Z\d]/u;
function isReactHookName(name) {
  return name === "use" || RE_HOOK_NAME.test(name);
}

// src/hook/is.ts
function isReactHook(node) {
  return Function_exports4.pipe(
    getFunctionIdentifier(node),
    Option_exports4.flatMapNullable((id) => id.name),
    Option_exports4.exists(isReactHookName)
  );
}
function isReactHookCall(node) {
  if (node.callee.type === NodeType.Identifier) return isReactHookName(node.callee.name);
  if (node.callee.type === NodeType.MemberExpression) {
    return node.callee.property.type === NodeType.Identifier && isReactHookName(node.callee.property.name);
  }
  return false;
}
function isReactHookCallWithName(name) {
  return (node, context) => {
    const initialScope = context.sourceCode.getScope(node);
    return tsPattern.match(node.callee).with({ type: NodeType.Identifier, name }, (n3) => isInitializedFromReact(n3.name, context, initialScope)).with({ type: NodeType.MemberExpression, object: { name: tsPattern.P.string }, property: { name } }, (n3) => {
      return isInitializedFromReact(n3.object.name, context, initialScope);
    }).otherwise(Function_exports4.constFalse);
  };
}
function isReactHookCallWithNameLoose(name) {
  return (node) => {
    return tsPattern.match(node.callee).with({ type: NodeType.Identifier, name }, Function_exports4.constTrue).with({ type: NodeType.MemberExpression, property: { name } }, Function_exports4.constTrue).otherwise(Function_exports4.constFalse);
  };
}
var isUseCallbackCall = isReactHookCallWithName("useCallback");
var isUseContextCall = isReactHookCallWithName("useContext");
var isUseDebugValueCall = isReactHookCallWithName("useDebugValue");
var isUseDeferredValueCall = isReactHookCallWithName("useDeferredValue");
var isUseEffectCall = isReactHookCallWithName("useEffect");
var isUseIdCall = isReactHookCallWithName("useId");
var isUseImperativeHandleCall = isReactHookCallWithName("useImperativeHandle");
var isUseInsertionEffectCall = isReactHookCallWithName("useInsertionEffect");
var isUseLayoutEffectCall = isReactHookCallWithName("useLayoutEffect");
var isUseMemoCall = isReactHookCallWithName("useMemo");
var isUseReducerCall = isReactHookCallWithName("useReducer");
var isUseRefCall = isReactHookCallWithName("useRef");
var isUseStateCall = isReactHookCallWithName("useState");
var isUseSyncExternalStoreCall = isReactHookCallWithName("useSyncExternalStore");
var isUseTransitionCall = isReactHookCallWithName("useTransition");

// src/hook/hierarchy.ts
function isInsideReactHook(node) {
  return Option_exports4.exists(traverseUpGuard(node, isFunction), isReactHook);
}
function isInsideReactHookCall(node) {
  return Option_exports4.isSome(traverseUp(node, (n3) => is(NodeType.CallExpression)(n3) && isReactHookCall(n3)));
}
var uid = new ShortUniqueId__default.default({ length: 10 });
function useHookCollector() {
  const hooks = /* @__PURE__ */ new Map();
  const functionStack = MutableList_exports.make();
  const getCurrentFunction = () => MutableList_exports.tail(functionStack);
  const onFunctionEnter = (node) => {
    MutableList_exports.append(functionStack, node);
    const currentFn = getCurrentFunction();
    if (!currentFn) return;
    const id = getFunctionIdentifier(currentFn);
    const name = Option_exports4.flatMapNullable(id, (id2) => id2.name);
    if (Option_exports4.isSome(id) && Option_exports4.isSome(name) && isReactHookName(name.value)) {
      const key = uid.rnd();
      hooks.set(key, {
        _: key,
        id,
        kind: "function",
        name,
        flag: 0n,
        hint: 0n,
        hookCalls: [],
        node: currentFn
      });
    }
  };
  const onFunctionExit = () => {
    MutableList_exports.pop(functionStack);
  };
  const ctx = {
    getAllHooks(_3) {
      return hooks;
    },
    getCurrentHooks() {
      return new Map(hooks);
    }
  };
  const listeners = {
    ":function": onFunctionEnter,
    ":function:exit": onFunctionExit,
    CallExpression(node) {
      const currentFn = getCurrentFunction();
      if (!currentFn) return;
      if (isReactHookCall(node)) {
        const hook = Array.from(hooks.values()).find((hook2) => hook2.node === currentFn);
        if (!hook) return;
        hooks.set(hook._, {
          ...hook,
          hookCalls: [
            ...hook.hookCalls,
            node
          ]
        });
      }
    }
  };
  return {
    ctx,
    listeners
  };
}

// src/component/component-collector-hint.ts
var ERComponentHint = {
  ...JSXValueHint,
  // 1n << 0n - 1n << 63n are reserved for JSXValueHint
  // Skip function component created by React.memo
  SkipMemo: 1n << 64n,
  // Skip function component created by React.forwardRef
  SkipForwardRef: 1n << 65n,
  // Skip function component defined in map function callback
  SkipMapCallback: 1n << 66n,
  // Skip function component defined on object method
  SkipObjectMethod: 1n << 67n,
  // Skip function component defined on class method
  SkipClassMethod: 1n << 68n,
  // Skip function component defined on class property
  SkipClassProperty: 1n << 69n
};
var DEFAULT_COMPONENT_HINT = 0n | ERComponentHint.SkipUndefinedLiteral | ERComponentHint.SkipBooleanLiteral | ERComponentHint.SkipStringLiteral | ERComponentHint.SkipNumberLiteral;

// src/component/component-flag.ts
var ERClassComponentFlag = {
  None: 0n,
  PureComponent: 1n << 0n
  // Reserved for future use
  // CreateElement: 1n << 1n,
};
var ERFunctionComponentFlag = {
  None: 0n,
  Memo: 1n << 0n,
  ForwardRef: 1n << 1n
  // Reserved for future use
  // CreateElement: 1n << 2n,
  // Reserved for future use
  // hasHooks: 1n << 3n,
  // Reserved for future use
  // Async: 1n << 4n,
};

// src/component/component-id.ts
function isComponentWrapperCall(node, context) {
  if (node.type !== NodeType.CallExpression) return false;
  return isMemoCall(node, context) || isForwardRefCall(node, context) || isReactHookCallWithNameLoose("useCallback")(node);
}
function getFunctionComponentIdentifier(node, context) {
  const functionId = getFunctionIdentifier(node);
  if (Option_exports4.isSome(functionId)) return functionId;
  const { parent } = node;
  if (parent.type === NodeType.CallExpression && isComponentWrapperCall(parent, context) && parent.parent.type === NodeType.VariableDeclarator && parent.parent.id.type === NodeType.Identifier && parent.parent.parent.type === NodeType.VariableDeclaration) {
    return Option_exports4.some(parent.parent.id);
  }
  if (parent.type === NodeType.CallExpression && isComponentWrapperCall(parent, context) && parent.parent.type === NodeType.CallExpression && isComponentWrapperCall(parent.parent, context) && parent.parent.parent.type === NodeType.VariableDeclarator && parent.parent.parent.id.type === NodeType.Identifier && parent.parent.parent.parent.type === NodeType.VariableDeclaration) {
    return Option_exports4.some(parent.parent.parent.id);
  }
  return Option_exports4.none();
}
function getComponentInitPath(node) {
  const { parent } = node;
  if (node.type === NodeType.FunctionDeclaration) return Option_exports4.some([node]);
  if (parent.type === NodeType.VariableDeclarator && parent.parent.type === NodeType.VariableDeclaration) {
    return Option_exports4.some([
      parent.parent,
      parent,
      node
    ]);
  }
  if (parent.type === NodeType.CallExpression && parent.parent.type === NodeType.VariableDeclarator && parent.parent.parent.type === NodeType.VariableDeclaration) {
    return Option_exports4.some([
      parent.parent.parent,
      parent.parent,
      parent,
      node
    ]);
  }
  if (parent.type === NodeType.CallExpression && parent.parent.type === NodeType.CallExpression && parent.parent.parent.type === NodeType.VariableDeclarator && parent.parent.parent.parent.type === NodeType.VariableDeclaration) {
    return Option_exports4.some([
      parent.parent.parent.parent,
      parent.parent.parent,
      parent.parent,
      parent,
      node
    ]);
  }
  if (parent.type === NodeType.Property && parent.parent.type === NodeType.ObjectExpression && parent.parent.parent.type === NodeType.VariableDeclarator && parent.parent.parent.parent.type === NodeType.VariableDeclaration) {
    return Option_exports4.some([
      parent.parent.parent.parent,
      parent.parent.parent,
      parent.parent,
      parent,
      node
    ]);
  }
  if (parent.type === NodeType.MethodDefinition && parent.parent.type === NodeType.ClassBody && parent.parent.parent.type === NodeType.ClassDeclaration) {
    return Option_exports4.some([
      parent.parent.parent,
      parent.parent,
      parent,
      node
    ]);
  }
  if (parent.type === NodeType.PropertyDefinition && parent.parent.type === NodeType.ClassBody && parent.parent.parent.type === NodeType.ClassDeclaration) {
    return Option_exports4.some([
      parent.parent.parent,
      parent.parent,
      parent,
      node
    ]);
  }
  return Option_exports4.none();
}
function hasCallInInitPath(callName) {
  return (initPath) => {
    return Function_exports4.pipe(
      initPath,
      Option_exports4.filter((p3) => p3.length > 0),
      Option_exports4.exists((nodes) => {
        return nodes.some(
          // callName.includes(".")
          //   ? n => {
          //     const [objectName, propertyName] = callName.split(".");
          //     return "callee" in n
          //       && n.callee.type === NodeType.MemberExpression
          //       && n.callee.object.type === NodeType.Identifier
          //       && n.callee.object.name === objectName
          //       && n.callee.property.type === NodeType.Identifier
          //       && n.callee.property.name === propertyName;
          //   }
          //   : n => {
          //     return "callee" in n
          //       && n.callee.type === NodeType.Identifier
          //       && n.callee.name === callName;
          //   },
          (n3) => {
            if (n3.type !== NodeType.CallExpression) return false;
            if (n3.callee.type === NodeType.Identifier) return n3.callee.name === callName;
            return tsPattern.isMatching({ callee: { property: { name: callName } } }, n3);
          }
        );
      })
    );
  };
}

// src/component/component-name.ts
var RE_COMPONENT_NAME = /^[A-Z]/u;
function getComponentNameFromIdentifier(node) {
  return Array.isArray(node) ? node.map((n3) => n3.name).join(".") : node.name;
}
function isComponentName(name) {
  return !!name && RE_COMPONENT_NAME.test(name);
}
function hasNoneOrValidComponentName(node, context) {
  return Option_exports4.match(
    getFunctionComponentIdentifier(node, context),
    {
      onNone: Function_exports4.constTrue,
      onSome: (id) => {
        const name = Array.isArray(id) ? id.at(-1)?.name : id.name;
        return !!name && isComponentName(name);
      }
    }
  );
}
var uid2 = new ShortUniqueId__default.default({ length: 10 });
function isClassComponent(node) {
  if (!("superClass" in node && node.superClass)) return false;
  const { superClass } = node;
  return tsPattern.match(superClass).with({ type: NodeType.Identifier, name: tsPattern.P.string }, ({ name }) => /^(Pure)?Component$/u.test(name)).with({
    type: NodeType.MemberExpression,
    property: { name: tsPattern.P.string }
  }, ({ property }) => /^(Pure)?Component$/u.test(property.name)).otherwise(() => false);
}
function isPureComponent(node) {
  if ("superClass" in node && node.superClass) {
    return tsPattern.match(node.superClass).with({ type: NodeType.Identifier, name: tsPattern.P.string }, ({ name }) => /^PureComponent$/u.test(name)).with({
      type: NodeType.MemberExpression,
      property: { name: tsPattern.P.string }
    }, ({ property }) => /^PureComponent$/u.test(property.name)).otherwise(() => false);
  }
  return false;
}
function useComponentCollectorLegacy() {
  const components = /* @__PURE__ */ new Map();
  const ctx = {
    getAllComponents(_3) {
      return components;
    },
    getCurrentComponents() {
      return new Map(components);
    }
  };
  const collect2 = (node) => {
    if (!isClassComponent(node)) return;
    const id = getClassIdentifier(node);
    const key = uid2.rnd();
    const flag = isPureComponent(node) ? ERClassComponentFlag.PureComponent : ERClassComponentFlag.None;
    components.set(
      key,
      {
        _: key,
        id,
        kind: "class",
        name: Option_exports4.flatMapNullable(id, (n3) => n3.name),
        // TODO: get displayName of class component
        displayName: Option_exports4.none(),
        flag,
        hint: 0n,
        // TODO: get methods of class component
        methods: [],
        node
      }
    );
  };
  const listeners = {
    ClassDeclaration: collect2,
    ClassExpression: collect2
  };
  return {
    ctx,
    listeners
  };
}

// src/component/component-render-method.ts
var isRenderMethodLike = tsPattern.isMatching({
  key: {
    type: NodeType.Identifier,
    name: "render"
  },
  type: tsPattern.P.union(NodeType.MethodDefinition, NodeType.PropertyDefinition),
  parent: {
    type: NodeType.ClassBody,
    parent: {
      type: NodeType.ClassDeclaration
    }
  }
});
function isFunctionOfRenderMethod(node) {
  if (!isRenderMethodLike(node.parent)) return false;
  return isClassComponent(node.parent.parent.parent);
}
function isInsideRenderMethod(node) {
  const predicate = (node2) => {
    return isRenderMethodLike(node2) && isClassComponent(node2.parent.parent);
  };
  return Option_exports4.isSome(traverseUp(node, predicate));
}

// src/component/component-collector.ts
var uid3 = new ShortUniqueId__default.default({ length: 10 });
var isMapCall = tsPattern.isMatching({
  callee: {
    type: NodeType.MemberExpression,
    property: {
      name: "map"
    }
  }
});
function hasValidHierarchy(node, context, hint) {
  if (isChildrenOfCreateElement(node, context) || isFunctionOfRenderMethod(node)) {
    return false;
  }
  if (hint & ERComponentHint.SkipMapCallback && isMapCall(node.parent)) {
    return false;
  }
  if (hint & ERComponentHint.SkipObjectMethod && isFunctionOfObjectMethod(node.parent)) {
    return false;
  }
  if (hint & ERComponentHint.SkipClassMethod && isFunctionOfClassMethod(node.parent)) {
    return false;
  }
  if (hint & ERComponentHint.SkipClassProperty && isFunctionOfClassProperty(node.parent)) {
    return false;
  }
  return !Function_exports4.pipe(
    traverseUp(
      node,
      isOneOf([
        NodeType.JSXExpressionContainer,
        NodeType.ArrowFunctionExpression,
        NodeType.FunctionExpression,
        NodeType.Property,
        NodeType.ClassBody
      ])
    ),
    Option_exports4.exists(is(NodeType.JSXExpressionContainer))
  );
}
function getComponentFlag(initPath) {
  const flagRef = MutableRef_exports.make(ERFunctionComponentFlag.None);
  if (hasCallInInitPath("memo")(initPath)) {
    MutableRef_exports.update(flagRef, (f3) => f3 | ERFunctionComponentFlag.Memo);
  }
  if (hasCallInInitPath("forwardRef")(initPath)) {
    MutableRef_exports.update(flagRef, (f3) => f3 | ERFunctionComponentFlag.ForwardRef);
  }
  return MutableRef_exports.get(flagRef);
}
function useComponentCollector(context, hint = DEFAULT_COMPONENT_HINT) {
  const components = /* @__PURE__ */ new Map();
  const functionStack = MutableList_exports.make();
  const getCurrentFunction = () => Option_exports4.fromNullable(MutableList_exports.tail(functionStack));
  const onFunctionEnter = (node) => MutableList_exports.append(functionStack, [node, false, []]);
  const onFunctionExit = () => MutableList_exports.pop(functionStack);
  const ctx = {
    getAllComponents(_3) {
      return components;
    },
    getCurrentComponents() {
      return new Map(components);
    },
    getCurrentFunction,
    getCurrentFunctionStack() {
      return [...functionStack];
    }
  };
  const listeners = {
    ":function": onFunctionEnter,
    ":function:exit": onFunctionExit,
    ReturnStatement(node) {
      const maybeCurrentFn = getCurrentFunction();
      if (Option_exports4.isNone(maybeCurrentFn)) return;
      const [currentFn, isKnown, hookCalls] = maybeCurrentFn.value;
      if (isKnown) return;
      const isComponent = hasNoneOrValidComponentName(currentFn, context) && isJSXValue(node.argument, context, hint) && hasValidHierarchy(currentFn, context, hint);
      if (!isComponent) return;
      MutableList_exports.pop(functionStack);
      MutableList_exports.append(functionStack, [currentFn, true, []]);
      const initPath = getComponentInitPath(currentFn);
      const id = getFunctionComponentIdentifier(currentFn, context);
      const name = Option_exports4.flatMapNullable(id, getComponentNameFromIdentifier);
      const key = uid3.rnd();
      components.set(key, {
        _: key,
        id,
        kind: "function",
        name,
        displayName: Option_exports4.none(),
        flag: getComponentFlag(initPath),
        hint,
        hookCalls,
        initPath,
        node: currentFn
      });
    },
    // eslint-disable-next-line perfectionist/sort-objects
    "ArrowFunctionExpression[body.type!='BlockStatement']"() {
      const maybeCurrentFn = getCurrentFunction();
      if (Option_exports4.isNone(maybeCurrentFn)) return;
      const [currentFn, _3, hookCalls] = maybeCurrentFn.value;
      const { body } = currentFn;
      const isComponent = Function_exports4.constTrue() && hasNoneOrValidComponentName(currentFn, context) && isJSXValue(body, context, hint) && hasValidHierarchy(currentFn, context, hint);
      if (!isComponent) return;
      const initPath = getComponentInitPath(currentFn);
      const id = getFunctionComponentIdentifier(currentFn, context);
      const name = Option_exports4.flatMapNullable(id, getComponentNameFromIdentifier);
      const key = uid3.rnd();
      components.set(key, {
        _: key,
        id,
        kind: "function",
        name,
        displayName: Option_exports4.none(),
        flag: getComponentFlag(initPath),
        hint,
        hookCalls,
        initPath,
        node: currentFn
      });
    },
    "CallExpression:exit"(node) {
      if (!isReactHookCall(node)) return;
      const maybeCurrentFn = getCurrentFunction();
      if (Option_exports4.isNone(maybeCurrentFn)) return;
      const [currentFn, IsComponent, hookCalls] = maybeCurrentFn.value;
      MutableList_exports.pop(functionStack);
      MutableList_exports.append(functionStack, [currentFn, IsComponent, [...hookCalls, node]]);
    },
    // eslint-disable-next-line perfectionist/sort-objects
    "AssignmentExpression[operator='='][left.type='MemberExpression'][left.property.name='displayName']"(node) {
      if (node.type !== NodeType.AssignmentExpression) return;
      const { left: left7, right: right7 } = node;
      if (left7.type !== NodeType.MemberExpression) return;
      const maybeComponentName = tsPattern.match(left7.object).with({ type: NodeType.Identifier }, (n3) => Option_exports4.some(n3.name)).otherwise(Option_exports4.none);
      if (Option_exports4.isNone(maybeComponentName)) return;
      const component = Array.from(components.values()).findLast(({ name }) => Option_exports4.exists(name, (n3) => n3 === maybeComponentName.value));
      if (!component) return;
      components.set(component._, {
        ...component,
        displayName: Option_exports4.some(right7)
      });
    }
  };
  return {
    ctx,
    listeners
  };
}
function getParentClassComponent(node, context) {
  const initialScope = context.sourceCode.getScope(node);
  const scopeRef = MutableRef_exports.make(Option_exports4.fromNullable(initialScope));
  while (Function_exports4.pipe(MutableRef_exports.get(scopeRef), Option_exports4.exists(({ type }) => type !== scopeManager.ScopeType.class))) {
    MutableRef_exports.update(scopeRef, Option_exports4.flatMapNullable((s3) => s3.upper));
  }
  return Function_exports4.pipe(
    MutableRef_exports.get(scopeRef),
    Option_exports4.flatMapNullable((s3) => s3.block),
    Option_exports4.filter(isClass),
    Option_exports4.filter((node2) => isClassComponent(node2))
  );
}
function unsafeIsDirectValueOfRenderProperty(node) {
  const matching = tsPattern.isMatching({
    key: {
      type: NodeType.Identifier,
      name: tsPattern.P.string.startsWith("render")
    },
    type: NodeType.Property
  });
  return matching(node) || matching(node.parent);
}
function unsafeIsDeclaredInRenderProp(node) {
  if (unsafeIsDirectValueOfRenderProperty(node)) {
    return true;
  }
  return Function_exports4.pipe(
    traverseUpGuard(node, is(NodeType.JSXExpressionContainer)),
    Option_exports4.flatMapNullable((c3) => c3.parent),
    Option_exports4.filter(is(NodeType.JSXAttribute)),
    Option_exports4.flatMapNullable((a3) => a3.name),
    Option_exports4.exists(tsPattern.isMatching({
      type: NodeType.JSXIdentifier,
      name: tsPattern.P.string.startsWith("render")
    }))
  );
}
function unsafeIsRenderFunction(node, context) {
  const { body, parent } = node;
  const maybeId = getFunctionIdentifier(node);
  if (Option_exports4.isSome(maybeId) && !maybeId.value.name.startsWith("render")) {
    return tsPattern.isMatching({
      type: NodeType.JSXExpressionContainer,
      parent: {
        type: NodeType.JSXAttribute,
        name: {
          type: NodeType.JSXIdentifier,
          name: tsPattern.P.string.startsWith("render")
        }
      }
    }, parent);
  }
  return isJSXValue(
    body,
    context,
    JSXValueHint.SkipNullLiteral | JSXValueHint.SkipUndefinedLiteral | JSXValueHint.StrictLogical | JSXValueHint.StrictConditional
  );
}
function unsafeIsRenderProp(node, context) {
  return tsPattern.isMatching({
    type: NodeType.JSXAttribute,
    name: {
      type: NodeType.JSXIdentifier,
      name: tsPattern.P.string.startsWith("render")
    },
    value: {
      type: NodeType.JSXExpressionContainer,
      expression: tsPattern.P.when(isFunction)
    }
  }, node) && unsafeIsRenderFunction(node.value.expression, context);
}

exports.DEFAULT_COMPONENT_HINT = DEFAULT_COMPONENT_HINT;
exports.ERClassComponentFlag = ERClassComponentFlag;
exports.ERComponentHint = ERComponentHint;
exports.ERFunctionComponentFlag = ERFunctionComponentFlag;
exports.RE_COMPONENT_NAME = RE_COMPONENT_NAME;
exports.RE_HOOK_NAME = RE_HOOK_NAME;
exports.getComponentInitPath = getComponentInitPath;
exports.getComponentNameFromIdentifier = getComponentNameFromIdentifier;
exports.getFunctionComponentIdentifier = getFunctionComponentIdentifier;
exports.getParentClassComponent = getParentClassComponent;
exports.hasCallInInitPath = hasCallInInitPath;
exports.hasChildren = hasChildren;
exports.hasNoneOrValidComponentName = hasNoneOrValidComponentName;
exports.isCallFromReact = isCallFromReact;
exports.isCallFromReactMember = isCallFromReactMember;
exports.isChildOfJSXElement = isChildOfJSXElement;
exports.isChildrenCount = isChildrenCount;
exports.isChildrenCountCall = isChildrenCountCall;
exports.isChildrenForEach = isChildrenForEach;
exports.isChildrenForEachCall = isChildrenForEachCall;
exports.isChildrenMap = isChildrenMap;
exports.isChildrenMapCall = isChildrenMapCall;
exports.isChildrenOfCreateElement = isChildrenOfCreateElement;
exports.isChildrenOnly = isChildrenOnly;
exports.isChildrenOnlyCall = isChildrenOnlyCall;
exports.isChildrenToArray = isChildrenToArray;
exports.isChildrenToArrayCall = isChildrenToArrayCall;
exports.isClassComponent = isClassComponent;
exports.isCloneElement = isCloneElement;
exports.isCloneElementCall = isCloneElementCall;
exports.isComponentName = isComponentName;
exports.isCreateContext = isCreateContext;
exports.isCreateContextCall = isCreateContextCall;
exports.isCreateElement = isCreateElement;
exports.isCreateElementCall = isCreateElementCall;
exports.isCreateRef = isCreateRef;
exports.isCreateRefCall = isCreateRefCall;
exports.isForwardRef = isForwardRef;
exports.isForwardRefCall = isForwardRefCall;
exports.isFragmentElement = isFragmentElement;
exports.isFromReact = isFromReact;
exports.isFromReactMember = isFromReactMember;
exports.isFunctionOfRenderMethod = isFunctionOfRenderMethod;
exports.isInitializedFromReact = isInitializedFromReact;
exports.isInsideCreateElementProps = isInsideCreateElementProps;
exports.isInsideReactHook = isInsideReactHook;
exports.isInsideReactHookCall = isInsideReactHookCall;
exports.isInsideRenderMethod = isInsideRenderMethod;
exports.isMemo = isMemo;
exports.isMemoCall = isMemoCall;
exports.isPureComponent = isPureComponent;
exports.isReactAPICallWithName = isReactAPICallWithName;
exports.isReactAPIWithName = isReactAPIWithName;
exports.isReactHook = isReactHook;
exports.isReactHookCall = isReactHookCall;
exports.isReactHookCallWithName = isReactHookCallWithName;
exports.isReactHookCallWithNameLoose = isReactHookCallWithNameLoose;
exports.isReactHookName = isReactHookName;
exports.isUseCallbackCall = isUseCallbackCall;
exports.isUseContextCall = isUseContextCall;
exports.isUseDebugValueCall = isUseDebugValueCall;
exports.isUseDeferredValueCall = isUseDeferredValueCall;
exports.isUseEffectCall = isUseEffectCall;
exports.isUseIdCall = isUseIdCall;
exports.isUseImperativeHandleCall = isUseImperativeHandleCall;
exports.isUseInsertionEffectCall = isUseInsertionEffectCall;
exports.isUseLayoutEffectCall = isUseLayoutEffectCall;
exports.isUseMemoCall = isUseMemoCall;
exports.isUseReducerCall = isUseReducerCall;
exports.isUseRefCall = isUseRefCall;
exports.isUseStateCall = isUseStateCall;
exports.isUseSyncExternalStoreCall = isUseSyncExternalStoreCall;
exports.isUseTransitionCall = isUseTransitionCall;
exports.unsafeIsDeclaredInRenderProp = unsafeIsDeclaredInRenderProp;
exports.unsafeIsDirectValueOfRenderProperty = unsafeIsDirectValueOfRenderProperty;
exports.unsafeIsRenderFunction = unsafeIsRenderFunction;
exports.unsafeIsRenderProp = unsafeIsRenderProp;
exports.useComponentCollector = useComponentCollector;
exports.useComponentCollectorLegacy = useComponentCollectorLegacy;
exports.useHookCollector = useHookCollector;
